# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/connectionmanager/v1/common.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x80\x01\n\tTLSParams\x12*\n\x08\x64isabled\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12;\n\x03tls\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSConfigH\x00\x42\n\n\x08tls_mode\"#\n\tTLSConfig\x12\x16\n\x0e\x63\x61_certificate\x18\x01 \x01(\t\"\xa6\x01\n\x08Password\x12\x0b\n\x03raw\x18\x01 \x01(\t\x12\x61\n\x1bpassword_generation_options\x18\x03 \x01(\x0b\x32<.yandex.cloud.connectionmanager.v1.PasswordGenerationOptions\x12\x1c\n\x12lockbox_secret_key\x18\x02 \x01(\tH\x00\x42\x0c\n\nsecret_key\"\xbe\x01\n\x19PasswordGenerationOptions\x12\x0e\n\x06\x63ookie\x18\x01 \x01(\t\x12r\n#lockbox_password_generation_options\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.connectionmanager.v1.LockboxPasswordGenerationOptionsH\x00\x42\x1d\n\x1bpassword_generation_options\"\xcf\x02\n LockboxPasswordGenerationOptions\x12\x0e\n\x06length\x18\x02 \x01(\x03\x12\x35\n\x11include_uppercase\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11include_lowercase\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0einclude_digits\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13include_punctuation\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1c\n\x14included_punctuation\x18\x07 \x01(\t\x12\x1c\n\x14\x65xcluded_punctuation\x18\x08 \x01(\tJ\x04\x08\x01\x10\x02\"_\n\x10UserPasswordAuth\x12\x0c\n\x04user\x18\x01 \x01(\t\x12=\n\x08password\x18\x02 \x01(\x0b\x32+.yandex.cloud.connectionmanager.v1.PasswordB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_TLSPARAMS']._serialized_start=147
  _globals['_TLSPARAMS']._serialized_end=275
  _globals['_TLSCONFIG']._serialized_start=277
  _globals['_TLSCONFIG']._serialized_end=312
  _globals['_PASSWORD']._serialized_start=315
  _globals['_PASSWORD']._serialized_end=481
  _globals['_PASSWORDGENERATIONOPTIONS']._serialized_start=484
  _globals['_PASSWORDGENERATIONOPTIONS']._serialized_end=674
  _globals['_LOCKBOXPASSWORDGENERATIONOPTIONS']._serialized_start=677
  _globals['_LOCKBOXPASSWORDGENERATIONOPTIONS']._serialized_end=1012
  _globals['_USERPASSWORDAUTH']._serialized_start=1014
  _globals['_USERPASSWORDAUTH']._serialized_end=1109
# @@protoc_insertion_point(module_scope)
