# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/operationlog/v1/operation_log.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/operationlog/v1/operation_log.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/operationlog/v1/operation_log.proto\x12 yandex.cloud.mdb.operationlog.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"Z\n\nHostEntity\x12\x0c\n\x04\x66qdn\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12.\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa0\x01\n\rClusterEntity\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12.\n\nstarted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x05hosts\x18\x04 \x03(\x0b\x32,.yandex.cloud.mdb.operationlog.v1.HostEntity\"Q\n\x0cOperationLog\x12\x41\n\x08\x65ntities\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.operationlog.v1.ClusterEntityBy\n$yandex.cloud.api.mdb.operationlog.v1ZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/operationlog/v1;operationlogb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.operationlog.v1.operation_log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$yandex.cloud.api.mdb.operationlog.v1ZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/operationlog/v1;operationlog'
  _globals['_HOSTENTITY']._serialized_start=123
  _globals['_HOSTENTITY']._serialized_end=213
  _globals['_CLUSTERENTITY']._serialized_start=216
  _globals['_CLUSTERENTITY']._serialized_end=376
  _globals['_OPERATIONLOG']._serialized_start=378
  _globals['_OPERATIONLOG']._serialized_end=459
# @@protoc_insertion_point(module_scope)
