# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/public_subnet.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/public_subnet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.baremetal.v1alpha import dhcp_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_dhcp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/baremetal/v1alpha/public_subnet.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)yandex/cloud/baremetal/v1alpha/dhcp.proto\"\x87\x04\n\x0cPublicSubnet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07zone_id\x18\x07 \x01(\t\x12\x19\n\x11hardware_pool_ids\x18\x08 \x03(\t\x12>\n\x04type\x18\t \x01(\x0e\x32\x30.yandex.cloud.baremetal.v1alpha.PublicSubnetType\x12\x15\n\rprefix_length\x18\n \x01(\x03\x12\x0c\n\x04\x63idr\x18\x0b \x01(\t\x12\x41\n\x0c\x64hcp_options\x18\x0c \x01(\x0b\x32+.yandex.cloud.baremetal.v1alpha.DhcpOptions\x12\x12\n\ngateway_ip\x18\r \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12I\n\x06labels\x18\xc8\x01 \x03(\x0b\x32\x38.yandex.cloud.baremetal.v1alpha.PublicSubnet.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x07J\x04\x08\x0e\x10\x64J\x05\x08\x65\x10\xc8\x01*T\n\x10PublicSubnetType\x12\"\n\x1ePUBLIC_SUBNET_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tDEDICATED\x10\x01\x12\r\n\tEPHEMERAL\x10\x02\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.public_subnet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_PUBLICSUBNET_LABELSENTRY']._loaded_options = None
  _globals['_PUBLICSUBNET_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_PUBLICSUBNETTYPE']._serialized_start=684
  _globals['_PUBLICSUBNETTYPE']._serialized_end=768
  _globals['_PUBLICSUBNET']._serialized_start=163
  _globals['_PUBLICSUBNET']._serialized_end=682
  _globals['_PUBLICSUBNET_LABELSENTRY']._serialized_start=618
  _globals['_PUBLICSUBNET_LABELSENTRY']._serialized_end=663
# @@protoc_insertion_point(module_scope)
