# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/access_control.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/access_control.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/trino/v1/access_control.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\xb2\x04\n\x13\x41\x63\x63\x65ssControlConfig\x12:\n\x08\x63\x61talogs\x18\x01 \x03(\x0b\x32(.yandex.cloud.trino.v1.CatalogAccessRule\x12\x38\n\x07schemas\x18\x02 \x03(\x0b\x32\'.yandex.cloud.trino.v1.SchemaAccessRule\x12\x36\n\x06tables\x18\x03 \x03(\x0b\x32&.yandex.cloud.trino.v1.TableAccessRule\x12<\n\tfunctions\x18\x04 \x03(\x0b\x32).yandex.cloud.trino.v1.FunctionAccessRule\x12>\n\nprocedures\x18\x05 \x03(\x0b\x32*.yandex.cloud.trino.v1.ProcedureAccessRule\x12\x37\n\x07queries\x18\x06 \x03(\x0b\x32&.yandex.cloud.trino.v1.QueryAccessRule\x12Y\n\x19system_session_properties\x18\x07 \x03(\x0b\x32\x36.yandex.cloud.trino.v1.SystemSessionPropertyAccessRule\x12[\n\x1a\x63\x61talog_session_properties\x18\x08 \x03(\x0b\x32\x37.yandex.cloud.trino.v1.CatalogSessionPropertyAccessRule\"\xda\x02\n\x18\x43\x61talogAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12I\n\x03ids\x18\x04 \x01(\x0b\x32:.yandex.cloud.trino.v1.CatalogAccessRuleMatcher.CatalogIdsH\x00\x12M\n\x05names\x18\x05 \x01(\x0b\x32<.yandex.cloud.trino.v1.CatalogAccessRuleMatcher.CatalogNamesH\x00\x1a\x30\n\nCatalogIds\x12\"\n\x03\x61ny\x18\x01 \x03(\tB\x15\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x1a\x32\n\x0c\x43\x61talogNames\x12\"\n\x03\x61ny\x18\x01 \x03(\tB\x15\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xe2\x01\n\x17SchemaAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12K\n\x05names\x18\x03 \x01(\x0b\x32:.yandex.cloud.trino.v1.SchemaAccessRuleMatcher.SchemaNamesH\x00\x1a@\n\x0bSchemaNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xde\x01\n\x16TableAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12I\n\x05names\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.trino.v1.TableAccessRuleMatcher.TableNamesH\x00\x1a?\n\nTableNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xea\x01\n\x19\x46unctionAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12O\n\x05names\x18\x03 \x01(\x0b\x32>.yandex.cloud.trino.v1.FunctionAccessRuleMatcher.FunctionNamesH\x00\x1a\x42\n\rFunctionNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xee\x01\n\x1aProcedureAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12Q\n\x05names\x18\x03 \x01(\x0b\x32@.yandex.cloud.trino.v1.ProcedureAccessRuleMatcher.ProcedureNamesH\x00\x1a\x43\n\x0eProcedureNames\x12\x31\n\x03\x61ny\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[a-z0-9_-]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\xe6\x01\n\x19PropertyAccessRuleMatcher\x12 \n\x0bname_regexp\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256H\x00\x12O\n\x05names\x18\x03 \x01(\x0b\x32>.yandex.cloud.trino.v1.PropertyAccessRuleMatcher.PropertyNamesH\x00\x1a>\n\rPropertyNames\x12-\n\x03\x61ny\x18\x01 \x03(\tB \xf2\xc7\x31\x07[a-z_]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x42\x10\n\x08match_by\x12\x04\xc0\xc1\x31\x01J\x04\x08\x01\x10\x02\"\x81\x03\n\x11\x43\x61talogAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12M\n\npermission\x18\x05 \x01(\x0e\x32\x33.yandex.cloud.trino.v1.CatalogAccessRule.PermissionB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\"J\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x41LL\x10\x02\x12\r\n\tREAD_ONLY\x10\x03J\x04\x08\x02\x10\x03\"\x9a\x03\n\x10SchemaAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12\x42\n\x05owner\x18\x06 \x01(\x0e\x32-.yandex.cloud.trino.v1.SchemaAccessRule.OwnerB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=128\"/\n\x05Owner\x12\x15\n\x11OWNER_UNSPECIFIED\x10\x00\x12\x06\n\x02NO\x10\x01\x12\x07\n\x03YES\x10\x02J\x04\x08\x02\x10\x03\"\xe5\x06\n\x0fTableAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12<\n\x05table\x18\x06 \x01(\x0b\x32-.yandex.cloud.trino.v1.TableAccessRuleMatcher\x12J\n\nprivileges\x18\x07 \x03(\x0e\x32\x30.yandex.cloud.trino.v1.TableAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12>\n\x07\x63olumns\x18\x08 \x03(\x0b\x32-.yandex.cloud.trino.v1.TableAccessRule.Column\x12\x19\n\x06\x66ilter\x18\t \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x1e\n\x0b\x64\x65scription\x18\x0b \x01(\tB\t\x8a\xc8\x31\x05<=128\x1a\xda\x01\n\x06\x43olumn\x12)\n\x04name\x18\x01 \x01(\tB\x1b\xe8\xc7\x31\x01\xf2\xc7\x31\x0b[a-z0-9_-]+\x8a\xc8\x31\x04<=63\x12N\n\x06\x61\x63\x63\x65ss\x18\x02 \x01(\x0e\x32\x38.yandex.cloud.trino.v1.TableAccessRule.Column.AccessModeB\x04\xe8\xc7\x31\x01\x12\x17\n\x04mask\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=128\"<\n\nAccessMode\x12\x1b\n\x17\x41\x43\x43\x45SS_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03\x41LL\x10\x02\"w\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\n\n\x06SELECT\x10\x01\x12\n\n\x06INSERT\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\n\n\x06UPDATE\x10\x04\x12\r\n\tOWNERSHIP\x10\x05\x12\x10\n\x0cGRANT_SELECT\x10\x06J\x04\x08\x02\x10\x03J\x04\x08\n\x10\x0b\"\x91\x04\n\x12\x46unctionAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12\x42\n\x08\x66unction\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.FunctionAccessRuleMatcher\x12M\n\nprivileges\x18\x07 \x03(\x0e\x32\x33.yandex.cloud.trino.v1.FunctionAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=128\"U\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XECUTE\x10\x01\x12\x11\n\rGRANT_EXECUTE\x10\x02\x12\r\n\tOWNERSHIP\x10\x03J\x04\x08\x02\x10\x03\"\xf9\x03\n\x13ProcedureAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12>\n\x06schema\x18\x05 \x01(\x0b\x32..yandex.cloud.trino.v1.SchemaAccessRuleMatcher\x12\x44\n\tprocedure\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.trino.v1.ProcedureAccessRuleMatcher\x12N\n\nprivileges\x18\x07 \x03(\x0e\x32\x34.yandex.cloud.trino.v1.ProcedureAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=128\"9\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x45XECUTE\x10\x01\"\x04\x08\x02\x10\x02J\x04\x08\x02\x10\x03\"\xf3\x02\n\x0fQueryAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12:\n\x0cquery_owners\x18\x04 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12J\n\nprivileges\x18\x05 \x03(\x0e\x32\x30.yandex.cloud.trino.v1.QueryAccessRule.PrivilegeB\x04\x90\xc8\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\"G\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x08\n\x04VIEW\x10\x01\x12\x0b\n\x07\x45XECUTE\x10\x02\x12\x08\n\x04KILL\x10\x03J\x04\x08\x02\x10\x03\"\xfa\x02\n\x1fSystemSessionPropertyAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x42\n\x08property\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.PropertyAccessRuleMatcher\x12Q\n\x05\x61llow\x18\x05 \x01(\x0e\x32<.yandex.cloud.trino.v1.SystemSessionPropertyAccessRule.AllowB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\"/\n\x05\x41llow\x12\x15\n\x11\x41LLOW_UNSPECIFIED\x10\x00\x12\x06\n\x02NO\x10\x01\x12\x07\n\x03YES\x10\x02J\x04\x08\x02\x10\x03\"\xbe\x03\n CatalogSessionPropertyAccessRule\x12\x33\n\x05users\x18\x01 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12\x34\n\x06groups\x18\x03 \x03(\tB$\xf2\xc7\x31\x0b[-_0-9a-z]+\x82\xc8\x31\x05<=128\x8a\xc8\x31\x04<=63\x90\xc8\x31\x01\x12@\n\x07\x63\x61talog\x18\x04 \x01(\x0b\x32/.yandex.cloud.trino.v1.CatalogAccessRuleMatcher\x12\x42\n\x08property\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.trino.v1.PropertyAccessRuleMatcher\x12R\n\x05\x61llow\x18\x06 \x01(\x0e\x32=.yandex.cloud.trino.v1.CatalogSessionPropertyAccessRule.AllowB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=128\"/\n\x05\x41llow\x12\x15\n\x11\x41LLOW_UNSPECIFIED\x10\x00\x12\x06\n\x02NO\x10\x01\x12\x07\n\x03YES\x10\x02J\x04\x08\x02\x10\x03\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.access_control_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS'].fields_by_name['any']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS'].fields_by_name['any']._serialized_options = b'\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES'].fields_by_name['any']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES'].fields_by_name['any']._serialized_options = b'\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_CATALOGACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_CATALOGACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES'].fields_by_name['any']._loaded_options = None
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SCHEMAACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_SCHEMAACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_SCHEMAACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_SCHEMAACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES'].fields_by_name['any']._loaded_options = None
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_TABLEACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_TABLEACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_TABLEACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_TABLEACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES'].fields_by_name['any']._loaded_options = None
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_FUNCTIONACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_FUNCTIONACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_FUNCTIONACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_FUNCTIONACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES'].fields_by_name['any']._loaded_options = None
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES'].fields_by_name['any']._serialized_options = b'\362\3071\013[a-z0-9_-]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROCEDUREACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_PROCEDUREACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_PROCEDUREACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_PROCEDUREACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES'].fields_by_name['any']._loaded_options = None
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES'].fields_by_name['any']._serialized_options = b'\362\3071\007[a-z_]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROPERTYACCESSRULEMATCHER'].oneofs_by_name['match_by']._loaded_options = None
  _globals['_PROPERTYACCESSRULEMATCHER'].oneofs_by_name['match_by']._serialized_options = b'\300\3011\001'
  _globals['_PROPERTYACCESSRULEMATCHER'].fields_by_name['name_regexp']._loaded_options = None
  _globals['_PROPERTYACCESSRULEMATCHER'].fields_by_name['name_regexp']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGACCESSRULE'].fields_by_name['permission']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['permission']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['owner']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['owner']._serialized_options = b'\350\3071\001'
  _globals['_SCHEMAACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_SCHEMAACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['name']._loaded_options = None
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\013[a-z0-9_-]+\212\3101\004<=63'
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['access']._loaded_options = None
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['access']._serialized_options = b'\350\3071\001'
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['mask']._loaded_options = None
  _globals['_TABLEACCESSRULE_COLUMN'].fields_by_name['mask']._serialized_options = b'\212\3101\005<=128'
  _globals['_TABLEACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_TABLEACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_TABLEACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_TABLEACCESSRULE'].fields_by_name['filter']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['filter']._serialized_options = b'\212\3101\005<=128'
  _globals['_TABLEACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_TABLEACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_FUNCTIONACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_PROCEDUREACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_QUERYACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['query_owners']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['query_owners']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['privileges']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['privileges']._serialized_options = b'\220\3101\001'
  _globals['_QUERYACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_QUERYACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._serialized_options = b'\350\3071\001'
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['users']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['groups']._serialized_options = b'\362\3071\013[-_0-9a-z]+\202\3101\005<=128\212\3101\004<=63\220\3101\001'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['allow']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE'].fields_by_name['description']._serialized_options = b'\212\3101\005<=128'
  _globals['_ACCESSCONTROLCONFIG']._serialized_start=101
  _globals['_ACCESSCONTROLCONFIG']._serialized_end=663
  _globals['_CATALOGACCESSRULEMATCHER']._serialized_start=666
  _globals['_CATALOGACCESSRULEMATCHER']._serialized_end=1012
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS']._serialized_start=882
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGIDS']._serialized_end=930
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES']._serialized_start=932
  _globals['_CATALOGACCESSRULEMATCHER_CATALOGNAMES']._serialized_end=982
  _globals['_SCHEMAACCESSRULEMATCHER']._serialized_start=1015
  _globals['_SCHEMAACCESSRULEMATCHER']._serialized_end=1241
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES']._serialized_start=1153
  _globals['_SCHEMAACCESSRULEMATCHER_SCHEMANAMES']._serialized_end=1217
  _globals['_TABLEACCESSRULEMATCHER']._serialized_start=1244
  _globals['_TABLEACCESSRULEMATCHER']._serialized_end=1466
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES']._serialized_start=1379
  _globals['_TABLEACCESSRULEMATCHER_TABLENAMES']._serialized_end=1442
  _globals['_FUNCTIONACCESSRULEMATCHER']._serialized_start=1469
  _globals['_FUNCTIONACCESSRULEMATCHER']._serialized_end=1703
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES']._serialized_start=1613
  _globals['_FUNCTIONACCESSRULEMATCHER_FUNCTIONNAMES']._serialized_end=1679
  _globals['_PROCEDUREACCESSRULEMATCHER']._serialized_start=1706
  _globals['_PROCEDUREACCESSRULEMATCHER']._serialized_end=1944
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES']._serialized_start=1853
  _globals['_PROCEDUREACCESSRULEMATCHER_PROCEDURENAMES']._serialized_end=1920
  _globals['_PROPERTYACCESSRULEMATCHER']._serialized_start=1947
  _globals['_PROPERTYACCESSRULEMATCHER']._serialized_end=2177
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES']._serialized_start=2091
  _globals['_PROPERTYACCESSRULEMATCHER_PROPERTYNAMES']._serialized_end=2153
  _globals['_CATALOGACCESSRULE']._serialized_start=2180
  _globals['_CATALOGACCESSRULE']._serialized_end=2565
  _globals['_CATALOGACCESSRULE_PERMISSION']._serialized_start=2485
  _globals['_CATALOGACCESSRULE_PERMISSION']._serialized_end=2559
  _globals['_SCHEMAACCESSRULE']._serialized_start=2568
  _globals['_SCHEMAACCESSRULE']._serialized_end=2978
  _globals['_SCHEMAACCESSRULE_OWNER']._serialized_start=2925
  _globals['_SCHEMAACCESSRULE_OWNER']._serialized_end=2972
  _globals['_TABLEACCESSRULE']._serialized_start=2981
  _globals['_TABLEACCESSRULE']._serialized_end=3850
  _globals['_TABLEACCESSRULE_COLUMN']._serialized_start=3499
  _globals['_TABLEACCESSRULE_COLUMN']._serialized_end=3717
  _globals['_TABLEACCESSRULE_COLUMN_ACCESSMODE']._serialized_start=3657
  _globals['_TABLEACCESSRULE_COLUMN_ACCESSMODE']._serialized_end=3717
  _globals['_TABLEACCESSRULE_PRIVILEGE']._serialized_start=3719
  _globals['_TABLEACCESSRULE_PRIVILEGE']._serialized_end=3838
  _globals['_FUNCTIONACCESSRULE']._serialized_start=3853
  _globals['_FUNCTIONACCESSRULE']._serialized_end=4382
  _globals['_FUNCTIONACCESSRULE_PRIVILEGE']._serialized_start=4291
  _globals['_FUNCTIONACCESSRULE_PRIVILEGE']._serialized_end=4376
  _globals['_PROCEDUREACCESSRULE']._serialized_start=4385
  _globals['_PROCEDUREACCESSRULE']._serialized_end=4890
  _globals['_PROCEDUREACCESSRULE_PRIVILEGE']._serialized_start=4827
  _globals['_PROCEDUREACCESSRULE_PRIVILEGE']._serialized_end=4884
  _globals['_QUERYACCESSRULE']._serialized_start=4893
  _globals['_QUERYACCESSRULE']._serialized_end=5264
  _globals['_QUERYACCESSRULE_PRIVILEGE']._serialized_start=5187
  _globals['_QUERYACCESSRULE_PRIVILEGE']._serialized_end=5258
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE']._serialized_start=5267
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE']._serialized_end=5645
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_start=5592
  _globals['_SYSTEMSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_end=5639
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE']._serialized_start=5648
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE']._serialized_end=6094
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_start=5592
  _globals['_CATALOGSESSIONPROPERTYACCESSRULE_ALLOW']._serialized_end=5639
# @@protoc_insertion_point(module_scope)
