# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/test/artifact_settings.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/test/artifact_settings.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/loadtesting/api/v1/test/artifact_settings.proto\x12$yandex.cloud.loadtesting.api.v1.test\"\x8a\x01\n\x10\x41rtifactSettings\x12\x1f\n\x15object_storage_bucket\x18\x01 \x01(\tH\x00\x12\x12\n\nis_archive\x18\x06 \x01(\x08\x12\x16\n\x0e\x66ilter_include\x18\x07 \x03(\t\x12\x16\n\x0e\x66ilter_exclude\x18\x08 \x03(\tB\x0b\n\tupload_toJ\x04\x08\x02\x10\x06\x42y\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.artifact_settings_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_ARTIFACTSETTINGS']._serialized_start=103
  _globals['_ARTIFACTSETTINGS']._serialized_end=241
# @@protoc_insertion_point(module_scope)
