# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/elasticsearch/v1/auth.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/elasticsearch/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/elasticsearch/v1/auth.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1dyandex/cloud/validation.proto\"S\n\rAuthProviders\x12\x42\n\tproviders\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"\x80\x03\n\x0c\x41uthProvider\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.mdb.elasticsearch.v1.AuthProvider.Type\x12*\n\x04name\x18\x02 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\x12\r\n\x05order\x18\x03 \x01(\x03\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x0e\n\x06hidden\x18\x05 \x01(\x08\x12\x1d\n\x0b\x64\x65scription\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x04hint\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x17\n\x04icon\x18\x08 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12?\n\x04saml\x18\t \x01(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.SamlSettingsH\x00\"2\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06NATIVE\x10\x01\x12\x08\n\x04SAML\x10\x02\x42\n\n\x08settings\"\xc8\x02\n\x0cSamlSettings\x12 \n\ridp_entity_id\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12&\n\x11idp_metadata_file\x18\x02 \x01(\x0c\x42\x0b\x8a\xc8\x31\x07<=10000\x12\x1f\n\x0csp_entity_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12\x1d\n\nkibana_url\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=250\x12%\n\x13\x61ttribute_principal\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\"\n\x10\x61ttribute_groups\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12 \n\x0e\x61ttribute_name\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12!\n\x0f\x61ttribute_email\x18\x08 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0c\x61ttribute_dn\x18\t \x01(\tB\x08\x8a\xc8\x31\x04<=50B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _globals['_AUTHPROVIDER'].fields_by_name['name']._loaded_options = None
  _globals['_AUTHPROVIDER'].fields_by_name['name']._serialized_options = b'\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_AUTHPROVIDER'].fields_by_name['description']._loaded_options = None
  _globals['_AUTHPROVIDER'].fields_by_name['description']._serialized_options = b'\212\3101\004<=50'
  _globals['_AUTHPROVIDER'].fields_by_name['hint']._loaded_options = None
  _globals['_AUTHPROVIDER'].fields_by_name['hint']._serialized_options = b'\212\3101\005<=250'
  _globals['_AUTHPROVIDER'].fields_by_name['icon']._loaded_options = None
  _globals['_AUTHPROVIDER'].fields_by_name['icon']._serialized_options = b'\212\3101\005<=250'
  _globals['_SAMLSETTINGS'].fields_by_name['idp_entity_id']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['idp_entity_id']._serialized_options = b'\212\3101\005<=250'
  _globals['_SAMLSETTINGS'].fields_by_name['idp_metadata_file']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['idp_metadata_file']._serialized_options = b'\212\3101\007<=10000'
  _globals['_SAMLSETTINGS'].fields_by_name['sp_entity_id']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['sp_entity_id']._serialized_options = b'\212\3101\005<=250'
  _globals['_SAMLSETTINGS'].fields_by_name['kibana_url']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['kibana_url']._serialized_options = b'\212\3101\005<=250'
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_principal']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_principal']._serialized_options = b'\212\3101\004<=50'
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_groups']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_groups']._serialized_options = b'\212\3101\004<=50'
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_name']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_name']._serialized_options = b'\212\3101\004<=50'
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_email']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_email']._serialized_options = b'\212\3101\004<=50'
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_dn']._loaded_options = None
  _globals['_SAMLSETTINGS'].fields_by_name['attribute_dn']._serialized_options = b'\212\3101\004<=50'
  _globals['_AUTHPROVIDERS']._serialized_start=114
  _globals['_AUTHPROVIDERS']._serialized_end=197
  _globals['_AUTHPROVIDER']._serialized_start=200
  _globals['_AUTHPROVIDER']._serialized_end=584
  _globals['_AUTHPROVIDER_TYPE']._serialized_start=522
  _globals['_AUTHPROVIDER_TYPE']._serialized_end=572
  _globals['_SAMLSETTINGS']._serialized_start=587
  _globals['_SAMLSETTINGS']._serialized_end=915
# @@protoc_insertion_point(module_scope)
