"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetPrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the Private cloud connection resource to return.

    To get the server ID, use a [PrivateCloudConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___GetPrivateCloudConnectionRequest = GetPrivateCloudConnectionRequest

@typing.final
class ListPrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list private cloud connections in.

    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is greater than `page_size`,
    the service returns a [ListPrivateCloudConnectionResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value is 20.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListPrivateCloudConnectionResponse.next_page_token] returned by a previous list request.
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    Supported fields: ["id", "createdAt", "updatedAt"].
    Both snake_case and camelCase are supported for fields.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=` (equal), `:` (substring).
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Example: "key1='value' AND key2='value'"
    Supported operators: ["AND"].
    Supported fields: ["id", "name", "status", "vrfId", "routingInstanceId"].
    Both snake_case and camelCase are supported for fields.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        order_by: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListPrivateCloudConnectionRequest = ListPrivateCloudConnectionRequest

@typing.final
class ListPrivateCloudConnectionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list. If the number of results is greater than
    [ListPrivateCloudConnectionRequest.page_size], use `next_page_token` as the value
    for the [ListPrivateCloudConnectionRequest.page_token] parameter in the next list request.

    Each subsequent page will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def private_cloud_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection]:
        """List of Private cloud connection resources."""

    def __init__(
        self,
        *,
        private_cloud_connections: collections.abc.Iterable[yandex.cloud.baremetal.v1alpha.private_cloud_connection_pb2.PrivateCloudConnection] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "private_cloud_connections", b"private_cloud_connections"]) -> None: ...

global___ListPrivateCloudConnectionResponse = ListPrivateCloudConnectionResponse

@typing.final
class CreatePrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    VRF_ID_FIELD_NUMBER: builtins.int
    routing_instance_id: builtins.str
    """ID of Cloud Router Routing Instance."""
    vrf_id: builtins.str
    """ID of VRF that is connected to routing Instance.

    To get the VRF ID, use a [VrfService.List] request.
    """
    def __init__(
        self,
        *,
        routing_instance_id: builtins.str = ...,
        vrf_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["routing_instance_id", b"routing_instance_id", "vrf_id", b"vrf_id"]) -> None: ...

global___CreatePrivateCloudConnectionRequest = CreatePrivateCloudConnectionRequest

@typing.final
class CreatePrivateCloudConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the private cloud connection that is being created."""
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___CreatePrivateCloudConnectionMetadata = CreatePrivateCloudConnectionMetadata

@typing.final
class UpdatePrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    ROUTING_INSTANCE_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the private cloud connection to update.

    To get the private cloud connection ID, use a [PrivateCloudConnectionService.List] request.
    """
    routing_instance_id: builtins.str
    """ID of Cloud Router Routing Instance."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the PrivateCloudConnection resource are going to be updated."""

    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        routing_instance_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id", "routing_instance_id", b"routing_instance_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdatePrivateCloudConnectionRequest = UpdatePrivateCloudConnectionRequest

@typing.final
class UpdatePrivateCloudConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the Private cloud connection resource that is being update."""
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___UpdatePrivateCloudConnectionMetadata = UpdatePrivateCloudConnectionMetadata

@typing.final
class DeletePrivateCloudConnectionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the private cloud connection to delete.

    To get the private cloud connection ID, use a [PrivateCloudConnectionService.List] request.
    """
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___DeletePrivateCloudConnectionRequest = DeletePrivateCloudConnectionRequest

@typing.final
class DeletePrivateCloudConnectionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRIVATE_CLOUD_CONNECTION_ID_FIELD_NUMBER: builtins.int
    private_cloud_connection_id: builtins.str
    """ID of the Private cloud connection resource that is being deleted."""
    def __init__(
        self,
        *,
        private_cloud_connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["private_cloud_connection_id", b"private_cloud_connection_id"]) -> None: ...

global___DeletePrivateCloudConnectionMetadata = DeletePrivateCloudConnectionMetadata
