# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/configuration.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/configuration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.baremetal.v1alpha import disk_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/baremetal/v1alpha/configuration.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a)yandex/cloud/baremetal/v1alpha/disk.proto\"2\n\x03\x43PU\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06vendor\x18\x02 \x01(\t\x12\r\n\x05\x63ores\x18\x03 \x01(\x03\"\x80\x01\n\x16\x44iskDriveConfiguration\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.yandex.cloud.baremetal.v1alpha.DiskDriveType\x12\x12\n\ndisk_count\x18\x02 \x01(\x03\x12\x15\n\rdisk_size_gib\x18\x03 \x01(\x03\"\xf2\x01\n\rConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nmemory_gib\x18\x03 \x01(\x03\x12\x30\n\x03\x63pu\x18\x04 \x01(\x0b\x32#.yandex.cloud.baremetal.v1alpha.CPU\x12K\n\x0b\x64isk_drives\x18\x05 \x03(\x0b\x32\x36.yandex.cloud.baremetal.v1alpha.DiskDriveConfiguration\x12\x1d\n\x15network_capacity_gbps\x18\x06 \x01(\x03\x12\x0f\n\x07\x63pu_num\x18\x08 \x01(\x03J\x04\x08\x07\x10\x08\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.configuration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_CPU']._serialized_start=129
  _globals['_CPU']._serialized_end=179
  _globals['_DISKDRIVECONFIGURATION']._serialized_start=182
  _globals['_DISKDRIVECONFIGURATION']._serialized_end=310
  _globals['_CONFIGURATION']._serialized_start=313
  _globals['_CONFIGURATION']._serialized_end=555
# @@protoc_insertion_point(module_scope)
