# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/cluster_extension_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/cluster_extension_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import cluster_extension_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_cluster__extension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/mdb/clickhouse/v1/cluster_extension_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x36yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto\"d\n\x1aGetClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\x0e\x65xtension_name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\"~\n\x1cListClusterExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"~\n\x1dListClusterExtensionsResponse\x12\x44\n\nextensions\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.mdb.clickhouse.v1.ClusterExtension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x01\n\x1d\x43reateClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x0e\x65xtension_spec\x18\x02 \x01(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ExtensionSpecB\x04\xe8\xc7\x31\x01\"L\n\x1e\x43reateClusterExtensionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x02 \x01(\t\"g\n\x1d\x44\x65leteClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12$\n\x0e\x65xtension_name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\"L\n\x1e\x44\x65leteClusterExtensionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x02 \x01(\t\"\x8e\x01\n\x1dUpdateClusterExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x0e\x65xtension_spec\x18\x02 \x01(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ExtensionSpecB\x04\xe8\xc7\x31\x01\"L\n\x1eUpdateClusterExtensionMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65xtension_name\x18\x02 \x01(\t\"\x8f\x01\n\x1bSetClusterExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12N\n\x0f\x65xtension_specs\x18\x02 \x03(\x0b\x32-.yandex.cloud.mdb.clickhouse.v1.ExtensionSpecB\x06\x82\xc8\x31\x02>0\"\x93\x01\n\x1cSetClusterExtensionsMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x1d\n\x15\x61\x64\x64\x65\x64_extension_names\x18\x02 \x03(\t\x12\x1f\n\x17updated_extension_names\x18\x03 \x03(\t\x12\x1f\n\x17\x64\x65leted_extension_names\x18\x04 \x03(\t\"<\n\rExtensionSpec\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x0f\n\x07version\x18\x02 \x01(\t2\xfd\n\n\x17\x43lusterExtensionService\x12\xc5\x01\n\x03Get\x12:.yandex.cloud.mdb.clickhouse.v1.GetClusterExtensionRequest\x1a\x30.yandex.cloud.mdb.clickhouse.v1.ClusterExtension\"P\x82\xd3\xe4\x93\x02J\x12H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}\x12\xc4\x01\n\x04List\x12<.yandex.cloud.mdb.clickhouse.v1.ListClusterExtensionsRequest\x1a=.yandex.cloud.mdb.clickhouse.v1.ListClusterExtensionsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/managed-clickhouse/v1/clusters/{cluster_id}/extensions\x12\xe4\x01\n\x06\x43reate\x12=.yandex.cloud.mdb.clickhouse.v1.CreateClusterExtensionRequest\x1a!.yandex.cloud.operation.Operation\"x\xb2\xd2*2\n\x1e\x43reateClusterExtensionMetadata\x12\x10\x43lusterExtension\x82\xd3\xe4\x93\x02<\"7/managed-clickhouse/v1/clusters/{cluster_id}/extensions:\x01*\x12\xf8\x01\n\x06\x44\x65lete\x12=.yandex.cloud.mdb.clickhouse.v1.DeleteClusterExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*7\n\x1e\x44\x65leteClusterExtensionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02J*H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}\x12\xfb\x01\n\x06Update\x12=.yandex.cloud.mdb.clickhouse.v1.UpdateClusterExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*2\n\x1eUpdateClusterExtensionMetadata\x12\x10\x43lusterExtension\x82\xd3\xe4\x93\x02R2M/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_spec.name}:\x01*\x12\xf2\x01\n\rSetExtensions\x12;.yandex.cloud.mdb.clickhouse.v1.SetClusterExtensionsRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*1\n\x1cSetClusterExtensionsMetadata\x12\x11\x43lusterExtensions\x82\xd3\xe4\x93\x02\x45\"@/managed-clickhouse/v1/clusters/{cluster_id}/extensions:batchSet:\x01*Bs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.cluster_extension_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._loaded_options = None
  _globals['_GETCLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCLUSTEREXTENSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._loaded_options = None
  _globals['_CREATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._serialized_options = b'\350\3071\001'
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._loaded_options = None
  _globals['_DELETECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._loaded_options = None
  _globals['_UPDATECLUSTEREXTENSIONREQUEST'].fields_by_name['extension_spec']._serialized_options = b'\350\3071\001'
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['extension_specs']._loaded_options = None
  _globals['_SETCLUSTEREXTENSIONSREQUEST'].fields_by_name['extension_specs']._serialized_options = b'\202\3101\002>0'
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002J\022H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0029\0227/managed-clickhouse/v1/clusters/{cluster_id}/extensions'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*2\n\036CreateClusterExtensionMetadata\022\020ClusterExtension\202\323\344\223\002<\"7/managed-clickhouse/v1/clusters/{cluster_id}/extensions:\001*'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*7\n\036DeleteClusterExtensionMetadata\022\025google.protobuf.Empty\202\323\344\223\002J*H/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_name}'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*2\n\036UpdateClusterExtensionMetadata\022\020ClusterExtension\202\323\344\223\002R2M/managed-clickhouse/v1/clusters/{cluster_id}/extensions/{extension_spec.name}:\001*'
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['SetExtensions']._loaded_options = None
  _globals['_CLUSTEREXTENSIONSERVICE'].methods_by_name['SetExtensions']._serialized_options = b'\262\322*1\n\034SetClusterExtensionsMetadata\022\021ClusterExtensions\202\323\344\223\002E\"@/managed-clickhouse/v1/clusters/{cluster_id}/extensions:batchSet:\001*'
  _globals['_GETCLUSTEREXTENSIONREQUEST']._serialized_start=289
  _globals['_GETCLUSTEREXTENSIONREQUEST']._serialized_end=389
  _globals['_LISTCLUSTEREXTENSIONSREQUEST']._serialized_start=391
  _globals['_LISTCLUSTEREXTENSIONSREQUEST']._serialized_end=517
  _globals['_LISTCLUSTEREXTENSIONSRESPONSE']._serialized_start=519
  _globals['_LISTCLUSTEREXTENSIONSRESPONSE']._serialized_end=645
  _globals['_CREATECLUSTEREXTENSIONREQUEST']._serialized_start=648
  _globals['_CREATECLUSTEREXTENSIONREQUEST']._serialized_end=790
  _globals['_CREATECLUSTEREXTENSIONMETADATA']._serialized_start=792
  _globals['_CREATECLUSTEREXTENSIONMETADATA']._serialized_end=868
  _globals['_DELETECLUSTEREXTENSIONREQUEST']._serialized_start=870
  _globals['_DELETECLUSTEREXTENSIONREQUEST']._serialized_end=973
  _globals['_DELETECLUSTEREXTENSIONMETADATA']._serialized_start=975
  _globals['_DELETECLUSTEREXTENSIONMETADATA']._serialized_end=1051
  _globals['_UPDATECLUSTEREXTENSIONREQUEST']._serialized_start=1054
  _globals['_UPDATECLUSTEREXTENSIONREQUEST']._serialized_end=1196
  _globals['_UPDATECLUSTEREXTENSIONMETADATA']._serialized_start=1198
  _globals['_UPDATECLUSTEREXTENSIONMETADATA']._serialized_end=1274
  _globals['_SETCLUSTEREXTENSIONSREQUEST']._serialized_start=1277
  _globals['_SETCLUSTEREXTENSIONSREQUEST']._serialized_end=1420
  _globals['_SETCLUSTEREXTENSIONSMETADATA']._serialized_start=1423
  _globals['_SETCLUSTEREXTENSIONSMETADATA']._serialized_end=1570
  _globals['_EXTENSIONSPEC']._serialized_start=1572
  _globals['_EXTENSIONSPEC']._serialized_end=1632
  _globals['_CLUSTEREXTENSIONSERVICE']._serialized_start=1635
  _globals['_CLUSTEREXTENSIONSERVICE']._serialized_end=3040
# @@protoc_insertion_point(module_scope)
