"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cloudrouter.v1.routing_instance_pb2
import yandex.cloud.cloudrouter.v1.routing_instance_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RoutingInstanceServiceStub:
    """A set of methods for managing RoutingInstance resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the specified RoutingInstance resource.

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByVpcNetworkId: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByVpcNetworkIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by vpcNetworkId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByCicPrivateConnectionId: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by cicPrivateConnectionId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse,
    ]
    """Retrieves the list of RoutingInstance resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.CreateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a RoutingInstance resource using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpsertPrefixes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpsertPrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Upserts specified prefixes to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrefixes: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified prefixes from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    MovePrefix: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.MovePrefixRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified prefix between availability zones of the RoutingInstance.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpdatePrefixMask: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdatePrefixMaskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    AddPrivateConnection: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.AddPrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds specified PrivateConnection to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrivateConnection: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.DeleteRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse,
    ]
    """Lists operations for the specified RoutingInstance."""

class RoutingInstanceServiceAsyncStub:
    """A set of methods for managing RoutingInstance resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the specified RoutingInstance resource.

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByVpcNetworkId: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByVpcNetworkIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by vpcNetworkId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    GetByCicPrivateConnectionId: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance,
    ]
    """Returns the RoutingInstance resource by cicPrivateConnectionId

    To get the list of available RoutingInstance resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse,
    ]
    """Retrieves the list of RoutingInstance resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.CreateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdateRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates a RoutingInstance resource using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpsertPrefixes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpsertPrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Upserts specified prefixes to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrefixes: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrefixesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified prefixes from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    MovePrefix: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.MovePrefixRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Moves the specified prefix between availability zones of the RoutingInstance.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    UpdatePrefixMask: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdatePrefixMaskRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    AddPrivateConnection: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.AddPrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds specified PrivateConnection to a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    RemovePrivateConnection: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrivateConnectionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes specified PrivateConnection from a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.DeleteRoutingInstanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a RoutingInstance resource.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsRequest,
        yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse,
    ]
    """Lists operations for the specified RoutingInstance."""

class RoutingInstanceServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing RoutingInstance resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]]:
        """Returns the specified RoutingInstance resource.

        To get the list of available RoutingInstance resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByVpcNetworkId(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByVpcNetworkIdRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]]:
        """Returns the RoutingInstance resource by vpcNetworkId

        To get the list of available RoutingInstance resources, make a [List] request.
        """

    @abc.abstractmethod
    def GetByCicPrivateConnectionId(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.GetRoutingInstanceByCicPrivateConnectionIdRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_pb2.RoutingInstance]]:
        """Returns the RoutingInstance resource by cicPrivateConnectionId

        To get the list of available RoutingInstance resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstancesResponse]]:
        """Retrieves the list of RoutingInstance resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.CreateRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a RoutingInstance resource in the specified folder using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdateRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates a RoutingInstance resource using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def UpsertPrefixes(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpsertPrefixesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Upserts specified prefixes to a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def RemovePrefixes(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrefixesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified prefixes from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def MovePrefix(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.MovePrefixRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Moves the specified prefix between availability zones of the RoutingInstance.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def UpdatePrefixMask(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.UpdatePrefixMaskRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified PrivateConnection from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def AddPrivateConnection(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.AddPrivateConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds specified PrivateConnection to a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def RemovePrivateConnection(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.RemovePrivateConnectionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes specified PrivateConnection from a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.DeleteRoutingInstanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a RoutingInstance resource.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse, collections.abc.Awaitable[yandex.cloud.cloudrouter.v1.routing_instance_service_pb2.ListRoutingInstanceOperationsResponse]]:
        """Lists operations for the specified RoutingInstance."""

def add_RoutingInstanceServiceServicer_to_server(servicer: RoutingInstanceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
