# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/greenplum.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/greenplum.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/connectionmanager/v1/greenplum.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"i\n\rGreenplumAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xf8\x03\n\x10GreenplumCluster\x12S\n\x11\x63oordinator_hosts\x18\x01 \x03(\x0b\x32\x38.yandex.cloud.connectionmanager.v1.GreenplumCluster.Host\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xcc\x02\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12K\n\x04role\x18\x03 \x01(\x0e\x32=.yandex.cloud.connectionmanager.v1.GreenplumCluster.Host.Role\x12O\n\x06health\x18\x04 \x01(\x0e\x32?.yandex.cloud.connectionmanager.v1.GreenplumCluster.Host.Health\"5\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"S\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0e\n\nUNBALANCED\x10\x04\"\xca\x01\n\x13GreenplumConnection\x12\x44\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.GreenplumCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12>\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.connectionmanager.v1.GreenplumAuth\x12\x11\n\tdatabases\x18\x04 \x03(\tB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.greenplum_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_GREENPLUMAUTH']._serialized_start=136
  _globals['_GREENPLUMAUTH']._serialized_end=241
  _globals['_GREENPLUMCLUSTER']._serialized_start=244
  _globals['_GREENPLUMCLUSTER']._serialized_end=748
  _globals['_GREENPLUMCLUSTER_HOST']._serialized_start=416
  _globals['_GREENPLUMCLUSTER_HOST']._serialized_end=748
  _globals['_GREENPLUMCLUSTER_HOST_ROLE']._serialized_start=610
  _globals['_GREENPLUMCLUSTER_HOST_ROLE']._serialized_end=663
  _globals['_GREENPLUMCLUSTER_HOST_HEALTH']._serialized_start=665
  _globals['_GREENPLUMCLUSTER_HOST_HEALTH']._serialized_end=748
  _globals['_GREENPLUMCONNECTION']._serialized_start=751
  _globals['_GREENPLUMCONNECTION']._serialized_end=953
# @@protoc_insertion_point(module_scope)
