"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Extension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Required. Extension name."""
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExtensionVersion]:
        """Required. All extension available versions."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        versions: collections.abc.Iterable[global___ExtensionVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "versions", b"versions"]) -> None: ...

global___Extension = Extension

@typing.final
class ExtensionVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DEFAULT_FIELD_NUMBER: builtins.int
    DEPRECATED_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. Version ID."""
    default: builtins.bool
    """Is default version."""
    deprecated: builtins.bool
    """Is version deprecated."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        default: builtins.bool = ...,
        deprecated: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["default", b"default", "deprecated", b"deprecated", "id", b"id"]) -> None: ...

global___ExtensionVersion = ExtensionVersion
