# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/saml/federation.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/saml/federation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/organizationmanager/v1/saml/federation.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xbc\x05\n\nFederation\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12\x33\n\x04name\x18\x03 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x0e\x63ookie_max_age\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x07 \x01(\x08\x12\x1e\n\x06issuer\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\t \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\n \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\x0b \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\x0c \x01(\x08\x12P\n\x06labels\x18\r \x03(\x0b\x32@.yandex.cloud.organizationmanager.v1.saml.Federation.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"O\n\x1a\x46\x65\x64\x65rationSecuritySettings\x12\x1c\n\x14\x65ncrypted_assertions\x18\x01 \x01(\x08\x12\x13\n\x0b\x66orce_authn\x18\x02 \x01(\x08\"\x95\x03\n\x06\x44omain\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12G\n\x06status\x18\x02 \x01(\x0e\x32\x37.yandex.cloud.organizationmanager.v1.saml.Domain.Status\x12\x13\n\x0bstatus_code\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cvalidated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12M\n\nchallenges\x18\x06 \x03(\x0b\x32\x39.yandex.cloud.organizationmanager.v1.saml.DomainChallenge\"l\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10NEED_TO_VALIDATE\x10\x01\x12\x0e\n\nVALIDATING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\"\xa8\x05\n\x0f\x44omainChallenge\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12L\n\x04type\x18\x03 \x01(\x0e\x32>.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.Type\x12P\n\x06status\x18\x04 \x01(\x0e\x32@.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.Status\x12\\\n\rdns_challenge\x18\x05 \x01(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.DnsRecordH\x00\x1a\xa7\x01\n\tDnsRecord\x12\x0c\n\x04name\x18\x01 \x01(\t\x12V\n\x04type\x18\x02 \x01(\x0e\x32H.yandex.cloud.organizationmanager.v1.saml.DomainChallenge.DnsRecord.Type\x12\r\n\x05value\x18\x03 \x01(\t\"%\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03TXT\x10\x01\")\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x44NS_TXT\x10\x01\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\t\n\x05VALID\x10\x03\x12\x0b\n\x07INVALID\x10\x04\x42\x0b\n\tchallenge*Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04POST\x10\x01\x12\x0c\n\x08REDIRECT\x10\x02\x12\x0c\n\x08\x41RTIFACT\x10\x03\x42\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.saml.federation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml'
  _globals['_FEDERATION_LABELSENTRY']._loaded_options = None
  _globals['_FEDERATION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_FEDERATION'].fields_by_name['id']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FEDERATION'].fields_by_name['name']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_FEDERATION'].fields_by_name['description']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_FEDERATION'].fields_by_name['cookie_max_age']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['cookie_max_age']._serialized_options = b'\372\3071\00710m-12h'
  _globals['_FEDERATION'].fields_by_name['issuer']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['issuer']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_FEDERATION'].fields_by_name['sso_url']._loaded_options = None
  _globals['_FEDERATION'].fields_by_name['sso_url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_BINDINGTYPE']._serialized_start=2074
  _globals['_BINDINGTYPE']._serialized_end=2155
  _globals['_FEDERATION']._serialized_start=200
  _globals['_FEDERATION']._serialized_end=900
  _globals['_FEDERATION_LABELSENTRY']._serialized_start=855
  _globals['_FEDERATION_LABELSENTRY']._serialized_end=900
  _globals['_FEDERATIONSECURITYSETTINGS']._serialized_start=902
  _globals['_FEDERATIONSECURITYSETTINGS']._serialized_end=981
  _globals['_DOMAIN']._serialized_start=984
  _globals['_DOMAIN']._serialized_end=1389
  _globals['_DOMAIN_STATUS']._serialized_start=1281
  _globals['_DOMAIN_STATUS']._serialized_end=1389
  _globals['_DOMAINCHALLENGE']._serialized_start=1392
  _globals['_DOMAINCHALLENGE']._serialized_end=2072
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_start=1762
  _globals['_DOMAINCHALLENGE_DNSRECORD']._serialized_end=1929
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_start=1892
  _globals['_DOMAINCHALLENGE_DNSRECORD_TYPE']._serialized_end=1929
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_start=1931
  _globals['_DOMAINCHALLENGE_TYPE']._serialized_end=1972
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_start=1974
  _globals['_DOMAINCHALLENGE_STATUS']._serialized_end=2059
# @@protoc_insertion_point(module_scope)
