# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/workflows/v1/workflow_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/workflows/v1/workflow_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.workflows.v1 import workflow_pb2 as yandex_dot_cloud_dot_serverless_dot_workflows_dot_v1_dot_workflow__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;yandex/cloud/serverless/workflows/v1/workflow_service.proto\x12$yandex.cloud.serverless.workflows.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/serverless/workflows/v1/workflow.proto\x1a\x1dyandex/cloud/validation.proto\"\x82\x05\n\x15\x43reateWorkflowRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x36\n\x04name\x18\x02 \x01(\tB(\xe8\xc7\x31\x01\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.serverless.workflows.v1.CreateWorkflowRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12X\n\rspecification\x18\x05 \x01(\x0b\x32;.yandex.cloud.serverless.workflows.v1.WorkflowSpecificationB\x04\xe8\xc7\x31\x01\x12\x45\n\x0blog_options\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.serverless.workflows.v1.LogOptions\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12\x0f\n\x07\x65xpress\x18\t \x01(\x08\x12H\n\x08schedule\x18\n \x01(\x0b\x32\x36.yandex.cloud.serverless.workflows.v1.WorkflowSchedule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x16\x43reateWorkflowMetadata\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\xab\x05\n\x15UpdateWorkflowRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.serverless.workflows.v1.UpdateWorkflowRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12R\n\rspecification\x18\x05 \x01(\x0b\x32;.yandex.cloud.serverless.workflows.v1.WorkflowSpecification\x12\x45\n\x0blog_options\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.serverless.workflows.v1.LogOptions\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x1a\n\x12service_account_id\x18\x08 \x01(\t\x12/\n\x0bupdate_mask\x18\t \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0f\n\x07\x65xpress\x18\n \x01(\x08\x12H\n\x08schedule\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.serverless.workflows.v1.WorkflowSchedule\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x16UpdateWorkflowMetadata\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x12GetWorkflowRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x13GetWorkflowResponse\x12@\n\x08workflow\x18\x01 \x01(\x0b\x32..yandex.cloud.serverless.workflows.v1.Workflow\"2\n\x15\x44\x65leteWorkflowRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"-\n\x16\x44\x65leteWorkflowMetadata\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\t\"f\n\x14ListWorkflowsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"z\n\x15ListWorkflowsResponse\x12H\n\tworkflows\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.serverless.workflows.v1.WorkflowPreview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8c\x01\n\x15ListOperationsRequest\x12\x19\n\x0bworkflow_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe7\x08\n\x0fWorkflowService\x12\xb1\x01\n\x06\x43reate\x12;.yandex.cloud.serverless.workflows.v1.CreateWorkflowRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\"\n\x16\x43reateWorkflowMetadata\x12\x08Workflow\x82\xd3\xe4\x93\x02\x1b\"\x16/workflows/v1/workflow:\x01*\x12\xbf\x01\n\x06Update\x12;.yandex.cloud.serverless.workflows.v1.UpdateWorkflowRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\"\n\x16UpdateWorkflowMetadata\x12\x08Workflow\x82\xd3\xe4\x93\x02)2$/workflows/v1/workflow/{workflow_id}:\x01*\x12\xa8\x01\n\x03Get\x12\x38.yandex.cloud.serverless.workflows.v1.GetWorkflowRequest\x1a\x39.yandex.cloud.serverless.workflows.v1.GetWorkflowResponse\",\x82\xd3\xe4\x93\x02&\x12$/workflows/v1/workflow/{workflow_id}\x12\xc9\x01\n\x06\x44\x65lete\x12;.yandex.cloud.serverless.workflows.v1.DeleteWorkflowRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*/\n\x16\x44\x65leteWorkflowMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/workflows/v1/workflow/{workflow_id}\x12\x9f\x01\n\x04List\x12:.yandex.cloud.serverless.workflows.v1.ListWorkflowsRequest\x1a;.yandex.cloud.serverless.workflows.v1.ListWorkflowsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/workflows/v1/workflow\x12\xc4\x01\n\x0eListOperations\x12;.yandex.cloud.serverless.workflows.v1.ListOperationsRequest\x1a<.yandex.cloud.serverless.workflows.v1.ListOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//workflows/v1/workflow/{workflow_id}/operationsB~\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflowsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.workflows.v1.workflow_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.serverless.workflows.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/workflows/v1;workflows'
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['specification']._loaded_options = None
  _globals['_CREATEWORKFLOWREQUEST'].fields_by_name['specification']._serialized_options = b'\350\3071\001'
  _globals['_CREATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_CREATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEWORKFLOWREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_UPDATEWORKFLOWMETADATA'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_GETWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_GETWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEWORKFLOWREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_DELETEWORKFLOWREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTWORKFLOWSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTWORKFLOWSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['workflow_id']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['workflow_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateWorkflowMetadata\022\010Workflow\202\323\344\223\002\033\"\026/workflows/v1/workflow:\001*'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateWorkflowMetadata\022\010Workflow\202\323\344\223\002)2$/workflows/v1/workflow/{workflow_id}:\001*'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/workflows/v1/workflow/{workflow_id}'
  _globals['_WORKFLOWSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteWorkflowMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/workflows/v1/workflow/{workflow_id}'
  _globals['_WORKFLOWSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/workflows/v1/workflow'
  _globals['_WORKFLOWSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_WORKFLOWSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0021\022//workflows/v1/workflow/{workflow_id}/operations'
  _globals['_CREATEWORKFLOWREQUEST']._serialized_start=324
  _globals['_CREATEWORKFLOWREQUEST']._serialized_end=966
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._serialized_start=921
  _globals['_CREATEWORKFLOWREQUEST_LABELSENTRY']._serialized_end=966
  _globals['_CREATEWORKFLOWMETADATA']._serialized_start=968
  _globals['_CREATEWORKFLOWMETADATA']._serialized_end=1019
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_start=1022
  _globals['_UPDATEWORKFLOWREQUEST']._serialized_end=1705
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._serialized_start=921
  _globals['_UPDATEWORKFLOWREQUEST_LABELSENTRY']._serialized_end=966
  _globals['_UPDATEWORKFLOWMETADATA']._serialized_start=1707
  _globals['_UPDATEWORKFLOWMETADATA']._serialized_end=1758
  _globals['_GETWORKFLOWREQUEST']._serialized_start=1760
  _globals['_GETWORKFLOWREQUEST']._serialized_end=1807
  _globals['_GETWORKFLOWRESPONSE']._serialized_start=1809
  _globals['_GETWORKFLOWRESPONSE']._serialized_end=1896
  _globals['_DELETEWORKFLOWREQUEST']._serialized_start=1898
  _globals['_DELETEWORKFLOWREQUEST']._serialized_end=1948
  _globals['_DELETEWORKFLOWMETADATA']._serialized_start=1950
  _globals['_DELETEWORKFLOWMETADATA']._serialized_end=1995
  _globals['_LISTWORKFLOWSREQUEST']._serialized_start=1997
  _globals['_LISTWORKFLOWSREQUEST']._serialized_end=2099
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_start=2101
  _globals['_LISTWORKFLOWSRESPONSE']._serialized_end=2223
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=2226
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=2366
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=2368
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=2472
  _globals['_WORKFLOWSERVICE']._serialized_start=2475
  _globals['_WORKFLOWSERVICE']._serialized_end=3602
# @@protoc_insertion_point(module_scope)
