# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/registry_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/registry_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.containerregistry.v1 import registry_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_registry__pb2
from yandex.cloud.containerregistry.v1 import ip_permission_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_ip__permission__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/containerregistry/v1/registry_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a\x30yandex/cloud/containerregistry/v1/registry.proto\x1a\x35yandex/cloud/containerregistry/v1/ip_permission.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\"7\n\x12GetRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x92\x01\n\x15ListRegistriesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"r\n\x16ListRegistriesResponse\x12?\n\nregistries\x18\x01 \x03(\x0b\x32+.yandex.cloud.containerregistry.v1.Registry\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xbc\x02\n\x15\x43reateRegistryRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x91\x01\n\x06labels\x18\x03 \x03(\x0b\x32\x44.yandex.cloud.containerregistry.v1.CreateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x0e\n\x06secure\x18\x04 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16\x43reateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\xdf\x02\n\x15UpdateRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x91\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x44.yandex.cloud.containerregistry.v1.UpdateRegistryRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteRegistryRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteRegistryMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"\x83\x01\n\x16SetIpPermissionRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\rip_permission\x18\x02 \x03(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermission\"\x92\x01\n\x19UpdateIpPermissionRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12R\n\x14ip_permission_deltas\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.containerregistry.v1.IpPermissionDelta\"<\n\x17ListIpPermissionRequest\x12!\n\x0bregistry_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"a\n\x19ListIpPermissionsResponse\x12\x44\n\x0bpermissions\x18\x01 \x03(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermission\".\n\x17SetIpPermissionMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t\"1\n\x1aUpdateIpPermissionMetadata\x12\x13\n\x0bregistry_id\x18\x01 \x01(\t2\xbb\x12\n\x0fRegistryService\x12\xa2\x01\n\x03Get\x12\x35.yandex.cloud.containerregistry.v1.GetRegistryRequest\x1a+.yandex.cloud.containerregistry.v1.Registry\"7\x82\xd3\xe4\x93\x02\x31\x12//container-registry/v1/registries/{registry_id}\x12\xa6\x01\n\x04List\x12\x38.yandex.cloud.containerregistry.v1.ListRegistriesRequest\x1a\x39.yandex.cloud.containerregistry.v1.ListRegistriesResponse\")\x82\xd3\xe4\x93\x02#\x12!/container-registry/v1/registries\x12\xb9\x01\n\x06\x43reate\x12\x38.yandex.cloud.containerregistry.v1.CreateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*\"\n\x16\x43reateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02&\"!/container-registry/v1/registries:\x01*\x12\xc7\x01\n\x06Update\x12\x38.yandex.cloud.containerregistry.v1.UpdateRegistryRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*\"\n\x16UpdateRegistryMetadata\x12\x08Registry\x82\xd3\xe4\x93\x02\x34\x32//container-registry/v1/registries/{registry_id}:\x01*\x12\xd1\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.containerregistry.v1.DeleteRegistryRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*/\n\x16\x44\x65leteRegistryMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31*//container-registry/v1/registries/{registry_id}\x12\xc1\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"J\x82\xd3\xe4\x93\x02\x44\x12\x42/container-registry/v1/registries/{resource_id}:listAccessBindings\x12\xf1\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x46\"A/container-registry/v1/registries/{resource_id}:setAccessBindings:\x01*\x12\xfd\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8f\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02I\"D/container-registry/v1/registries/{resource_id}:updateAccessBindings:\x01*\x12\xd6\x01\n\x10ListIpPermission\x12:.yandex.cloud.containerregistry.v1.ListIpPermissionRequest\x1a<.yandex.cloud.containerregistry.v1.ListIpPermissionsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/container-registry/v1/registries/{registry_id}:listIpPermission\x12\xef\x01\n\x0fSetIpPermission\x12\x39.yandex.cloud.containerregistry.v1.SetIpPermissionRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*0\n\x17SetIpPermissionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x44\"?/container-registry/v1/registries/{registry_id}:setIpPermission:\x01*\x12\xfc\x01\n\x12UpdateIpPermission\x12<.yandex.cloud.containerregistry.v1.UpdateIpPermissionRequest\x1a!.yandex.cloud.operation.Operation\"\x84\x01\xb2\xd2*3\n\x1aUpdateIpPermissionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G\"B/container-registry/v1/registries/{registry_id}:updateIpPermission:\x01*B\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.registry_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_GETREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTREGISTRIESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEREGISTRYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_DELETEREGISTRYREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETIPPERMISSIONREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_SETIPPERMISSIONREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEIPPERMISSIONREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_UPDATEIPPERMISSIONREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTIPPERMISSIONREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTIPPERMISSIONREQUEST'].fields_by_name['registry_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0021\022//container-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/container-registry/v1/registries'
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateRegistryMetadata\022\010Registry\202\323\344\223\002&\"!/container-registry/v1/registries:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateRegistryMetadata\022\010Registry\202\323\344\223\00242//container-registry/v1/registries/{registry_id}:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteRegistryMetadata\022\025google.protobuf.Empty\202\323\344\223\0021*//container-registry/v1/registries/{registry_id}'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002D\022B/container-registry/v1/registries/{resource_id}:listAccessBindings'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002F\"A/container-registry/v1/registries/{resource_id}:setAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002I\"D/container-registry/v1/registries/{resource_id}:updateAccessBindings:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermission']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['ListIpPermission']._serialized_options = b'\202\323\344\223\002B\022@/container-registry/v1/registries/{registry_id}:listIpPermission'
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermission']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['SetIpPermission']._serialized_options = b'\262\322*0\n\027SetIpPermissionMetadata\022\025google.protobuf.Empty\202\323\344\223\002D\"?/container-registry/v1/registries/{registry_id}:setIpPermission:\001*'
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermission']._loaded_options = None
  _globals['_REGISTRYSERVICE'].methods_by_name['UpdateIpPermission']._serialized_options = b'\262\322*3\n\032UpdateIpPermissionMetadata\022\025google.protobuf.Empty\202\323\344\223\002G\"B/container-registry/v1/registries/{registry_id}:updateIpPermission:\001*'
  _globals['_GETREGISTRYREQUEST']._serialized_start=403
  _globals['_GETREGISTRYREQUEST']._serialized_end=458
  _globals['_LISTREGISTRIESREQUEST']._serialized_start=461
  _globals['_LISTREGISTRIESREQUEST']._serialized_end=607
  _globals['_LISTREGISTRIESRESPONSE']._serialized_start=609
  _globals['_LISTREGISTRIESRESPONSE']._serialized_end=723
  _globals['_CREATEREGISTRYREQUEST']._serialized_start=726
  _globals['_CREATEREGISTRYREQUEST']._serialized_end=1042
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=997
  _globals['_CREATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1042
  _globals['_CREATEREGISTRYMETADATA']._serialized_start=1044
  _globals['_CREATEREGISTRYMETADATA']._serialized_end=1089
  _globals['_UPDATEREGISTRYREQUEST']._serialized_start=1092
  _globals['_UPDATEREGISTRYREQUEST']._serialized_end=1443
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_start=997
  _globals['_UPDATEREGISTRYREQUEST_LABELSENTRY']._serialized_end=1042
  _globals['_UPDATEREGISTRYMETADATA']._serialized_start=1445
  _globals['_UPDATEREGISTRYMETADATA']._serialized_end=1490
  _globals['_DELETEREGISTRYREQUEST']._serialized_start=1492
  _globals['_DELETEREGISTRYREQUEST']._serialized_end=1550
  _globals['_DELETEREGISTRYMETADATA']._serialized_start=1552
  _globals['_DELETEREGISTRYMETADATA']._serialized_end=1597
  _globals['_SETIPPERMISSIONREQUEST']._serialized_start=1600
  _globals['_SETIPPERMISSIONREQUEST']._serialized_end=1731
  _globals['_UPDATEIPPERMISSIONREQUEST']._serialized_start=1734
  _globals['_UPDATEIPPERMISSIONREQUEST']._serialized_end=1880
  _globals['_LISTIPPERMISSIONREQUEST']._serialized_start=1882
  _globals['_LISTIPPERMISSIONREQUEST']._serialized_end=1942
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_start=1944
  _globals['_LISTIPPERMISSIONSRESPONSE']._serialized_end=2041
  _globals['_SETIPPERMISSIONMETADATA']._serialized_start=2043
  _globals['_SETIPPERMISSIONMETADATA']._serialized_end=2089
  _globals['_UPDATEIPPERMISSIONMETADATA']._serialized_start=2091
  _globals['_UPDATEIPPERMISSIONMETADATA']._serialized_end=2140
  _globals['_REGISTRYSERVICE']._serialized_start=2143
  _globals['_REGISTRYSERVICE']._serialized_end=4506
# @@protoc_insertion_point(module_scope)
