"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExtensionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExtensionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExtensionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXTENSION_TYPE_UNSPECIFIED: _ExtensionType.ValueType  # 0
    EXTENSION_TYPE_SYNONYMS: _ExtensionType.ValueType  # 1
    EXTENSION_TYPE_STOPWORDS: _ExtensionType.ValueType  # 2

class ExtensionType(_ExtensionType, metaclass=_ExtensionTypeEnumTypeWrapper): ...

EXTENSION_TYPE_UNSPECIFIED: ExtensionType.ValueType  # 0
EXTENSION_TYPE_SYNONYMS: ExtensionType.ValueType  # 1
EXTENSION_TYPE_STOPWORDS: ExtensionType.ValueType  # 2
global___ExtensionType = ExtensionType
