# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/postgresql.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/postgresql.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/connectionmanager/v1/postgresql.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"j\n\x0ePostgreSQLAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xa5\x05\n\x11PostgreSQLCluster\x12H\n\x05hosts\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host\x12@\n\ntls_params\x18\x03 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xf7\x03\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12L\n\x04role\x18\x03 \x01(\x0e\x32>.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host.Role\x12[\n\x0creplica_type\x18\x04 \x01(\x0e\x32\x45.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host.ReplicaType\x12P\n\x06health\x18\x05 \x01(\x0e\x32@.yandex.cloud.connectionmanager.v1.PostgreSQLCluster.Host.Health\"5\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"L\n\x0bReplicaType\x12\x1c\n\x18REPLICA_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x41SYNC\x10\x01\x12\x08\n\x04SYNC\x10\x02\x12\n\n\x06QUORUM\x10\x03\"Q\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0c\n\x08READONLY\x10\x04J\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xd3\x01\n\x14PostgreSQLConnection\x12\x45\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.PostgreSQLCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12?\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.connectionmanager.v1.PostgreSQLAuth\x12\x11\n\tdatabases\x18\x05 \x03(\tJ\x04\x08\x03\x10\x04\x42\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.postgresql_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_POSTGRESQLAUTH']._serialized_start=137
  _globals['_POSTGRESQLAUTH']._serialized_end=243
  _globals['_POSTGRESQLCLUSTER']._serialized_start=246
  _globals['_POSTGRESQLCLUSTER']._serialized_end=923
  _globals['_POSTGRESQLCLUSTER_HOST']._serialized_start=408
  _globals['_POSTGRESQLCLUSTER_HOST']._serialized_end=911
  _globals['_POSTGRESQLCLUSTER_HOST_ROLE']._serialized_start=697
  _globals['_POSTGRESQLCLUSTER_HOST_ROLE']._serialized_end=750
  _globals['_POSTGRESQLCLUSTER_HOST_REPLICATYPE']._serialized_start=752
  _globals['_POSTGRESQLCLUSTER_HOST_REPLICATYPE']._serialized_end=828
  _globals['_POSTGRESQLCLUSTER_HOST_HEALTH']._serialized_start=830
  _globals['_POSTGRESQLCLUSTER_HOST_HEALTH']._serialized_end=911
  _globals['_POSTGRESQLCONNECTION']._serialized_start=926
  _globals['_POSTGRESQLCONNECTION']._serialized_end=1137
# @@protoc_insertion_point(module_scope)
