"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HostEntity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FQDN_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    fqdn: builtins.str
    action: builtins.str
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        fqdn: builtins.str = ...,
        action: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "fqdn", b"fqdn", "started_at", b"started_at"]) -> None: ...

global___HostEntity = HostEntity

@typing.final
class ClusterEntity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    action: builtins.str
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HostEntity]: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        action: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hosts: collections.abc.Iterable[global___HostEntity] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "cluster_id", b"cluster_id", "hosts", b"hosts", "started_at", b"started_at"]) -> None: ...

global___ClusterEntity = ClusterEntity

@typing.final
class OperationLog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterEntity]: ...
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[global___ClusterEntity] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entities", b"entities"]) -> None: ...

global___OperationLog = OperationLog
