"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.cloudapps.workload.v1.cloud_application_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResolveByWorkloadRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WorkloadType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WorkloadTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ResolveByWorkloadRequest._WorkloadType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WORKLOAD_TYPE_UNSPECIFIED: ResolveByWorkloadRequest._WorkloadType.ValueType  # 0
        COMPUTE_INSTANCE: ResolveByWorkloadRequest._WorkloadType.ValueType  # 1
        """Compute Instance"""

    class WorkloadType(_WorkloadType, metaclass=_WorkloadTypeEnumTypeWrapper): ...
    WORKLOAD_TYPE_UNSPECIFIED: ResolveByWorkloadRequest.WorkloadType.ValueType  # 0
    COMPUTE_INSTANCE: ResolveByWorkloadRequest.WorkloadType.ValueType  # 1
    """Compute Instance"""

    WORKLOAD_TYPE_FIELD_NUMBER: builtins.int
    WORKLOAD_ID_FIELD_NUMBER: builtins.int
    workload_type: global___ResolveByWorkloadRequest.WorkloadType.ValueType
    """Type of workload. See WorkloadType."""
    workload_id: builtins.str
    """Identifier of workload"""
    def __init__(
        self,
        *,
        workload_type: global___ResolveByWorkloadRequest.WorkloadType.ValueType = ...,
        workload_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["workload_id", b"workload_id", "workload_type", b"workload_type"]) -> None: ...

global___ResolveByWorkloadRequest = ResolveByWorkloadRequest

@typing.final
class ResolveByWorkloadResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_APPLICATION_FIELD_NUMBER: builtins.int
    @property
    def cloud_application(self) -> yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication:
        """Details of cloud application"""

    def __init__(
        self,
        *,
        cloud_application: yandex.cloud.cloudapps.workload.v1.cloud_application_pb2.CloudApplication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cloud_application", b"cloud_application"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cloud_application", b"cloud_application"]) -> None: ...

global___ResolveByWorkloadResponse = ResolveByWorkloadResponse
