# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/oauth_client_secret_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/oauth_client_secret_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.iam.v1 import oauth_client_secret_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_oauth__client__secret__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/iam/v1/oauth_client_secret_service.proto\x12\x13yandex.cloud.iam.v1\x1a-yandex/cloud/iam/v1/oauth_client_secret.proto\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"K\n\x1bGetOAuthClientSecretRequest\x12,\n\x16oauth_client_secret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x85\x01\n\x1dListOAuthClientSecretsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12%\n\x0foauth_client_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x7f\n\x1eListOAuthClientSecretsResponse\x12\x44\n\x14oauth_client_secrets\x18\x01 \x03(\x0b\x32&.yandex.cloud.iam.v1.OAuthClientSecret\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"g\n\x1e\x43reateOAuthClientSecretRequest\x12%\n\x0foauth_client_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"A\n\x1f\x43reateOAuthClientSecretMetadata\x12\x1e\n\x16oauth_client_secret_id\x18\x01 \x01(\t\"|\n\x1f\x43reateOAuthClientSecretResponse\x12\x43\n\x13oauth_client_secret\x18\x01 \x01(\x0b\x32&.yandex.cloud.iam.v1.OAuthClientSecret\x12\x14\n\x0csecret_value\x18\x02 \x01(\t\"N\n\x1e\x44\x65leteOAuthClientSecretRequest\x12,\n\x16oauth_client_secret_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"A\n\x1f\x44\x65leteOAuthClientSecretMetadata\x12\x1e\n\x16oauth_client_secret_id\x18\x01 \x01(\t2\xfb\x05\n\x18OAuthClientSecretService\x12\x9c\x01\n\x03Get\x12\x30.yandex.cloud.iam.v1.GetOAuthClientSecretRequest\x1a&.yandex.cloud.iam.v1.OAuthClientSecret\";\x82\xd3\xe4\x93\x02\x35\x12\x33/iam/v1/oauthClientSecrets/{oauth_client_secret_id}\x12\x93\x01\n\x04List\x12\x32.yandex.cloud.iam.v1.ListOAuthClientSecretsRequest\x1a\x33.yandex.cloud.iam.v1.ListOAuthClientSecretsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/iam/v1/oauthClientSecrets\x12\xcd\x01\n\x06\x43reate\x12\x33.yandex.cloud.iam.v1.CreateOAuthClientSecretRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*B\n\x1f\x43reateOAuthClientSecretMetadata\x12\x1f\x43reateOAuthClientSecretResponse\x82\xd3\xe4\x93\x02\x1f\"\x1a/iam/v1/oauthClientSecrets:\x01*\x12\xd9\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.iam.v1.DeleteOAuthClientSecretRequest\x1a!.yandex.cloud.operation.Operation\"w\xb2\xd2*8\n\x1f\x44\x65leteOAuthClientSecretMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x35*3/iam/v1/oauthClientSecrets/{oauth_client_secret_id}BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.oauth_client_secret_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._loaded_options = None
  _globals['_GETOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._loaded_options = None
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST'].fields_by_name['oauth_client_secret_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0025\0223/iam/v1/oauthClientSecrets/{oauth_client_secret_id}'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\034\022\032/iam/v1/oauthClientSecrets'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*B\n\037CreateOAuthClientSecretMetadata\022\037CreateOAuthClientSecretResponse\202\323\344\223\002\037\"\032/iam/v1/oauthClientSecrets:\001*'
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_OAUTHCLIENTSECRETSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*8\n\037DeleteOAuthClientSecretMetadata\022\025google.protobuf.Empty\202\323\344\223\0025*3/iam/v1/oauthClientSecrets/{oauth_client_secret_id}'
  _globals['_GETOAUTHCLIENTSECRETREQUEST']._serialized_start=260
  _globals['_GETOAUTHCLIENTSECRETREQUEST']._serialized_end=335
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST']._serialized_start=338
  _globals['_LISTOAUTHCLIENTSECRETSREQUEST']._serialized_end=471
  _globals['_LISTOAUTHCLIENTSECRETSRESPONSE']._serialized_start=473
  _globals['_LISTOAUTHCLIENTSECRETSRESPONSE']._serialized_end=600
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST']._serialized_start=602
  _globals['_CREATEOAUTHCLIENTSECRETREQUEST']._serialized_end=705
  _globals['_CREATEOAUTHCLIENTSECRETMETADATA']._serialized_start=707
  _globals['_CREATEOAUTHCLIENTSECRETMETADATA']._serialized_end=772
  _globals['_CREATEOAUTHCLIENTSECRETRESPONSE']._serialized_start=774
  _globals['_CREATEOAUTHCLIENTSECRETRESPONSE']._serialized_end=898
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST']._serialized_start=900
  _globals['_DELETEOAUTHCLIENTSECRETREQUEST']._serialized_end=978
  _globals['_DELETEOAUTHCLIENTSECRETMETADATA']._serialized_start=980
  _globals['_DELETEOAUTHCLIENTSECRETMETADATA']._serialized_end=1045
  _globals['_OAUTHCLIENTSECRETSERVICE']._serialized_start=1048
  _globals['_OAUTHCLIENTSECRETSERVICE']._serialized_end=1811
# @@protoc_insertion_point(module_scope)
