"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HardwarePool(google.protobuf.message.Message):
    """A HardwarePool resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the hardware pool."""
    zone_id: builtins.str
    """ID of the zone where the hardware pool is located.

    To get the zone ID use a [ZoneService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        zone_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "zone_id", b"zone_id"]) -> None: ...

global___HardwarePool = HardwarePool
