# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/playlist.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/playlist.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/video/v1/playlist.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x81\x02\n\x08Playlist\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x32\n\x05items\x18\x05 \x03(\x0b\x32#.yandex.cloud.video.v1.PlaylistItem\x12\x17\n\x0fstyle_preset_id\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.TimestampJ\x04\x08\x07\x10\x64\"u\n\x0cPlaylistItem\x12\x1c\n\x08video_id\x18\x64 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1e\n\nepisode_id\x18\x65 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1b\n\x08position\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100B\x04\n\x02idJ\x04\x08\x02\x10\x64\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.playlist_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_PLAYLISTITEM'].fields_by_name['video_id']._loaded_options = None
  _globals['_PLAYLISTITEM'].fields_by_name['video_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_PLAYLISTITEM'].fields_by_name['episode_id']._loaded_options = None
  _globals['_PLAYLISTITEM'].fields_by_name['episode_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_PLAYLISTITEM'].fields_by_name['position']._loaded_options = None
  _globals['_PLAYLISTITEM'].fields_by_name['position']._serialized_options = b'\372\3071\0050-100'
  _globals['_PLAYLIST']._serialized_start=128
  _globals['_PLAYLIST']._serialized_end=385
  _globals['_PLAYLISTITEM']._serialized_start=387
  _globals['_PLAYLISTITEM']._serialized_end=504
# @@protoc_insertion_point(module_scope)
