# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/smartwebsecurity/v1/waf/waf_profile_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/smartwebsecurity/v1/waf/waf_profile_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartwebsecurity.v1.waf import waf_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_waf_dot_waf__profile__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/smartwebsecurity/v1/waf/waf_profile_service.proto\x12$yandex.cloud.smartwebsecurity.v1.waf\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x36yandex/cloud/smartwebsecurity/v1/waf/waf_profile.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x14GetWafProfileRequest\x12\x1c\n\x0ewaf_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x16ListWafProfilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"a\n\x17ListWafProfilesResponse\x12\x46\n\x0cwaf_profiles\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.smartwebsecurity.v1.waf.WafProfile\"\xb0\x05\n\x17\x43reateWafProfileRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12Y\n\x06labels\x18\x04 \x03(\x0b\x32I.yandex.cloud.smartwebsecurity.v1.waf.CreateWafProfileRequest.LabelsEntry\x12\x43\n\x05rules\x18\x05 \x03(\x0b\x32\x34.yandex.cloud.smartwebsecurity.v1.waf.WafProfileRule\x12V\n\x0f\x65xclusion_rules\x18\x06 \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.waf.WafProfileExclusionRule\x12U\n\rcore_rule_set\x18\x07 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.CoreRuleSetH\x00\x12\x61\n\x14\x61nalyze_request_body\x18\x08 \x01(\x0b\x32\x43.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.AnalyzeRequestBody\x12U\n\trule_sets\x18\t \x03(\x0b\x32\x42.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet\x12\x1b\n\x13match_all_rule_sets\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08rule_set\"2\n\x18\x43reateWafProfileMetadata\x12\x16\n\x0ewaf_profile_id\x18\x01 \x01(\t\"\xec\x05\n\x17UpdateWafProfileRequest\x12\x1c\n\x0ewaf_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12Y\n\x06labels\x18\x05 \x03(\x0b\x32I.yandex.cloud.smartwebsecurity.v1.waf.UpdateWafProfileRequest.LabelsEntry\x12\x43\n\x05rules\x18\x06 \x03(\x0b\x32\x34.yandex.cloud.smartwebsecurity.v1.waf.WafProfileRule\x12V\n\x0f\x65xclusion_rules\x18\x07 \x03(\x0b\x32=.yandex.cloud.smartwebsecurity.v1.waf.WafProfileExclusionRule\x12U\n\rcore_rule_set\x18\x08 \x01(\x0b\x32<.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.CoreRuleSetH\x00\x12\x61\n\x14\x61nalyze_request_body\x18\t \x01(\x0b\x32\x43.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.AnalyzeRequestBody\x12U\n\trule_sets\x18\n \x03(\x0b\x32\x42.yandex.cloud.smartwebsecurity.v1.waf.WafProfile.WafProfileRuleSet\x12\x1b\n\x13match_all_rule_sets\x18\x0b \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08rule_set\"2\n\x18UpdateWafProfileMetadata\x12\x16\n\x0ewaf_profile_id\x18\x01 \x01(\t\"7\n\x17\x44\x65leteWafProfileRequest\x12\x1c\n\x0ewaf_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x18\x44\x65leteWafProfileMetadata\x12\x16\n\x0ewaf_profile_id\x18\x01 \x01(\t2\xea\x07\n\x11WafProfileService\x12\xae\x01\n\x03Get\x12:.yandex.cloud.smartwebsecurity.v1.waf.GetWafProfileRequest\x1a\x30.yandex.cloud.smartwebsecurity.v1.waf.WafProfile\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/smartwebsecurity/v1/wafProfiles/{waf_profile_id}\x12\xad\x01\n\x04List\x12<.yandex.cloud.smartwebsecurity.v1.waf.ListWafProfilesRequest\x1a=.yandex.cloud.smartwebsecurity.v1.waf.ListWafProfilesResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /smartwebsecurity/v1/wafProfiles\x12\xc1\x01\n\x06\x43reate\x12=.yandex.cloud.smartwebsecurity.v1.waf.CreateWafProfileRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*&\n\x18\x43reateWafProfileMetadata\x12\nWafProfile\x82\xd3\xe4\x93\x02%\" /smartwebsecurity/v1/wafProfiles:\x01*\x12\xd2\x01\n\x06Update\x12=.yandex.cloud.smartwebsecurity.v1.waf.UpdateWafProfileRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*&\n\x18UpdateWafProfileMetadata\x12\nWafProfile\x82\xd3\xe4\x93\x02\x36\x32\x31/smartwebsecurity/v1/wafProfiles/{waf_profile_id}:\x01*\x12\xda\x01\n\x06\x44\x65lete\x12=.yandex.cloud.smartwebsecurity.v1.waf.DeleteWafProfileRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*1\n\x18\x44\x65leteWafProfileMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33*1/smartwebsecurity/v1/wafProfiles/{waf_profile_id}B\x85\x01\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.smartwebsecurity.v1.wafZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1/waf;smartwebsecurity'
  _globals['_GETWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_GETWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTWAFPROFILESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTWAFPROFILESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_UPDATEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._loaded_options = None
  _globals['_DELETEWAFPROFILEREQUEST'].fields_by_name['waf_profile_id']._serialized_options = b'\350\3071\001'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/smartwebsecurity/v1/wafProfiles/{waf_profile_id}'
  _globals['_WAFPROFILESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\"\022 /smartwebsecurity/v1/wafProfiles'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateWafProfileMetadata\022\nWafProfile\202\323\344\223\002%\" /smartwebsecurity/v1/wafProfiles:\001*'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateWafProfileMetadata\022\nWafProfile\202\323\344\223\002621/smartwebsecurity/v1/wafProfiles/{waf_profile_id}:\001*'
  _globals['_WAFPROFILESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_WAFPROFILESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteWafProfileMetadata\022\025google.protobuf.Empty\202\323\344\223\0023*1/smartwebsecurity/v1/wafProfiles/{waf_profile_id}'
  _globals['_GETWAFPROFILEREQUEST']._serialized_start=329
  _globals['_GETWAFPROFILEREQUEST']._serialized_end=381
  _globals['_LISTWAFPROFILESREQUEST']._serialized_start=383
  _globals['_LISTWAFPROFILESREQUEST']._serialized_end=432
  _globals['_LISTWAFPROFILESRESPONSE']._serialized_start=434
  _globals['_LISTWAFPROFILESRESPONSE']._serialized_end=531
  _globals['_CREATEWAFPROFILEREQUEST']._serialized_start=534
  _globals['_CREATEWAFPROFILEREQUEST']._serialized_end=1222
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_CREATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_CREATEWAFPROFILEMETADATA']._serialized_start=1224
  _globals['_CREATEWAFPROFILEMETADATA']._serialized_end=1274
  _globals['_UPDATEWAFPROFILEREQUEST']._serialized_start=1277
  _globals['_UPDATEWAFPROFILEREQUEST']._serialized_end=2025
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_start=1165
  _globals['_UPDATEWAFPROFILEREQUEST_LABELSENTRY']._serialized_end=1210
  _globals['_UPDATEWAFPROFILEMETADATA']._serialized_start=2027
  _globals['_UPDATEWAFPROFILEMETADATA']._serialized_end=2077
  _globals['_DELETEWAFPROFILEREQUEST']._serialized_start=2079
  _globals['_DELETEWAFPROFILEREQUEST']._serialized_end=2134
  _globals['_DELETEWAFPROFILEMETADATA']._serialized_start=2136
  _globals['_DELETEWAFPROFILEMETADATA']._serialized_end=2186
  _globals['_WAFPROFILESERVICE']._serialized_start=2189
  _globals['_WAFPROFILESERVICE']._serialized_end=3191
# @@protoc_insertion_point(module_scope)
