"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SchedulerLinear(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_LR_FIELD_NUMBER: builtins.int
    min_lr: builtins.float
    def __init__(
        self,
        *,
        min_lr: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["min_lr", b"min_lr"]) -> None: ...

global___SchedulerLinear = SchedulerLinear

@typing.final
class SchedulerConstant(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SchedulerConstant = SchedulerConstant

@typing.final
class SchedulerCosine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_LR_FIELD_NUMBER: builtins.int
    min_lr: builtins.float
    def __init__(
        self,
        *,
        min_lr: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["min_lr", b"min_lr"]) -> None: ...

global___SchedulerCosine = SchedulerCosine
