# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ytsaurus/v1/cluster_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ytsaurus/v1/cluster_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ytsaurus.v1 import cluster_pb2 as yandex_dot_cloud_dot_ytsaurus_dot_v1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/ytsaurus/v1/cluster_service.proto\x12\x18yandex.cloud.ytsaurus.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/ytsaurus/v1/cluster.proto\"5\n\x11GetClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x13ListClustersRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x03(\t\"d\n\x14ListClustersResponse\x12\x33\n\x08\x63lusters\x18\x01 \x03(\x0b\x32!.yandex.cloud.ytsaurus.v1.Cluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8c\x03\n\x14\x43reateClusterRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x15\n\x07zone_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12J\n\x04name\x18\x03 \x01(\tB<\xf2\xc7\x31\x30[a-zA-Z0-9\xd0\x81\xd1\x91\xd0\x90-\xd1\x8f]\\S{1,61}[a-zA-Z0-9\xd0\x81\xd1\x91\xd0\x90-\xd1\x8f]\x8a\xc8\x31\x04<=63\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12J\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.ytsaurus.v1.CreateClusterRequest.LabelsEntry\x12\x17\n\tsubnet_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x33\n\x04spec\x18\x08 \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.ClusterSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15\x43reateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"\xeb\x02\n\x14UpdateClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12J\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.ytsaurus.v1.UpdateClusterRequest.LabelsEntry\x12\x11\n\tsubnet_id\x18\x06 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\x12\x33\n\x04spec\x18\x08 \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.ClusterSpec\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"+\n\x15UpdateClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"8\n\x14\x44\x65leteClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x15\x44\x65leteClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"7\n\x13StartClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14StartClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\"6\n\x12StopClusterRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x13StopClusterMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t2\x83\t\n\x0e\x43lusterService\x12\x81\x01\n\x03Get\x12+.yandex.cloud.ytsaurus.v1.GetClusterRequest\x1a!.yandex.cloud.ytsaurus.v1.Cluster\"*\x82\xd3\xe4\x93\x02$\x12\"/ytsaurus/v1/clusters/{cluster_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.ytsaurus.v1.ListClustersRequest\x1a..yandex.cloud.ytsaurus.v1.ListClustersResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/ytsaurus/v1/clusters\x12\xa1\x01\n\x06\x43reate\x12..yandex.cloud.ytsaurus.v1.CreateClusterRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2* \n\x15\x43reateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1a\"\x15/ytsaurus/v1/clusters:\x01*\x12\xa1\x01\n\x06Update\x12..yandex.cloud.ytsaurus.v1.UpdateClusterRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2* \n\x15UpdateClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02\x1a\x32\x15/ytsaurus/v1/clusters:\x01*\x12\xb9\x01\n\x06\x44\x65lete\x12..yandex.cloud.ytsaurus.v1.DeleteClusterRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*.\n\x15\x44\x65leteClusterMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/ytsaurus/v1/clusters/{cluster_id}\x12\xb1\x01\n\x05Start\x12-.yandex.cloud.ytsaurus.v1.StartClusterRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*\x1f\n\x14StartClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02-\"(/ytsaurus/v1/clusters/{cluster_id}:start:\x01*\x12\xad\x01\n\x04Stop\x12,.yandex.cloud.ytsaurus.v1.StopClusterRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*\x1e\n\x13StopClusterMetadata\x12\x07\x43luster\x82\xd3\xe4\x93\x02,\"\'/ytsaurus/v1/clusters/{cluster_id}:stop:\x01*Be\n\x1cyandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ytsaurus.v1.cluster_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurus'
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTCLUSTERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['zone_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['zone_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['name']._serialized_options = b'\362\30710[a-zA-Z0-9\320\201\321\221\320\220-\321\217]\\S{1,61}[a-zA-Z0-9\320\201\321\221\320\220-\321\217]\212\3101\004<=63'
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_CREATECLUSTERREQUEST'].fields_by_name['subnet_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STARTCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_STOPCLUSTERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/ytsaurus/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/ytsaurus/v1/clusters'
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateClusterMetadata\022\007Cluster\202\323\344\223\002\032\"\025/ytsaurus/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateClusterMetadata\022\007Cluster\202\323\344\223\002\0322\025/ytsaurus/v1/clusters:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteClusterMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/ytsaurus/v1/clusters/{cluster_id}'
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Start']._serialized_options = b'\262\322*\037\n\024StartClusterMetadata\022\007Cluster\202\323\344\223\002-\"(/ytsaurus/v1/clusters/{cluster_id}:start:\001*'
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._loaded_options = None
  _globals['_CLUSTERSERVICE'].methods_by_name['Stop']._serialized_options = b'\262\322*\036\n\023StopClusterMetadata\022\007Cluster\202\323\344\223\002,\"\'/ytsaurus/v1/clusters/{cluster_id}:stop:\001*'
  _globals['_GETCLUSTERREQUEST']._serialized_start=285
  _globals['_GETCLUSTERREQUEST']._serialized_end=338
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=340
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=441
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=443
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=543
  _globals['_CREATECLUSTERREQUEST']._serialized_start=546
  _globals['_CREATECLUSTERREQUEST']._serialized_end=942
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_start=897
  _globals['_CREATECLUSTERREQUEST_LABELSENTRY']._serialized_end=942
  _globals['_CREATECLUSTERMETADATA']._serialized_start=944
  _globals['_CREATECLUSTERMETADATA']._serialized_end=987
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=990
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1353
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_start=897
  _globals['_UPDATECLUSTERREQUEST_LABELSENTRY']._serialized_end=942
  _globals['_UPDATECLUSTERMETADATA']._serialized_start=1355
  _globals['_UPDATECLUSTERMETADATA']._serialized_end=1398
  _globals['_DELETECLUSTERREQUEST']._serialized_start=1400
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1456
  _globals['_DELETECLUSTERMETADATA']._serialized_start=1458
  _globals['_DELETECLUSTERMETADATA']._serialized_end=1501
  _globals['_STARTCLUSTERREQUEST']._serialized_start=1503
  _globals['_STARTCLUSTERREQUEST']._serialized_end=1558
  _globals['_STARTCLUSTERMETADATA']._serialized_start=1560
  _globals['_STARTCLUSTERMETADATA']._serialized_end=1602
  _globals['_STOPCLUSTERREQUEST']._serialized_start=1604
  _globals['_STOPCLUSTERREQUEST']._serialized_end=1658
  _globals['_STOPCLUSTERMETADATA']._serialized_start=1660
  _globals['_STOPCLUSTERMETADATA']._serialized_end=1701
  _globals['_CLUSTERSERVICE']._serialized_start=1704
  _globals['_CLUSTERSERVICE']._serialized_end=2859
# @@protoc_insertion_point(module_scope)
