# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.containerregistry.v1 import lifecycle_policy_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_lifecycle__policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@yandex/cloud/containerregistry/v1/lifecycle_policy_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a-yandex/cloud/containerregistry/v1/image.proto\x1a\x38yandex/cloud/containerregistry/v1/lifecycle_policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"F\n\x19GetLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xe5\x01\n\x1cListLifecyclePoliciesRequest\x12\x1f\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12!\n\rrepository_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100B\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"\x88\x01\n\x1dListLifecyclePoliciesResponse\x12N\n\x12lifecycle_policies\x18\x01 \x03(\x0b\x32\x32.yandex.cloud.containerregistry.v1.LifecyclePolicy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa6\x02\n\x1c\x43reateLifecyclePolicyRequest\x12#\n\rrepository_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12O\n\x06status\x18\x04 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x05rules\x18\x05 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\"\xdd\x02\n\x1cUpdateLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12O\n\x06status\x18\x05 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.LifecyclePolicy.StatusB\x04\xe8\xc7\x31\x01\x12?\n\x05rules\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.containerregistry.v1.LifecycleRule\"I\n\x1c\x44\x65leteLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x43reateLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"<\n\x1dUpdateLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"<\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x1b\n\x13lifecycle_policy_id\x18\x01 \x01(\t\"I\n\x1c\x44ryRunLifecyclePolicyRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"h\n\x1d\x44ryRunLifecyclePolicyMetadata\x12*\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\t\x12\x1b\n\x13lifecycle_policy_id\x18\x02 \x01(\t\"\xb1\x01\n\x1b\x44ryRunLifecyclePolicyResult\x12*\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\t\x12\x1b\n\x13lifecycle_policy_id\x18\x02 \x01(\t\x12*\n\x06run_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15\x61\x66\x66\x65\x63ted_images_count\x18\x04 \x01(\x03\"a\n%GetDryRunLifecyclePolicyResultRequest\x12\x38\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xcb\x01\n\'ListDryRunLifecyclePolicyResultsRequest\x12)\n\x13lifecycle_policy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xad\x01\n(ListDryRunLifecyclePolicyResultsResponse\x12h\n dry_run_lifecycle_policy_results\x18\x01 \x03(\x0b\x32>.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe7\x01\n4ListDryRunLifecyclePolicyResultAffectedImagesRequest\x12\x38\n\"dry_run_lifecycle_policy_result_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x93\x01\n5ListDryRunLifecyclePolicyResultAffectedImagesResponse\x12\x41\n\x0f\x61\x66\x66\x65\x63ted_images\x18\x01 \x03(\x0b\x32(.yandex.cloud.containerregistry.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x82\x11\n\x16LifecyclePolicyService\x12\xbf\x01\n\x03Get\x12<.yandex.cloud.containerregistry.v1.GetLifecyclePolicyRequest\x1a\x32.yandex.cloud.containerregistry.v1.LifecyclePolicy\"F\x82\xd3\xe4\x93\x02@\x12>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}\x12\xbb\x01\n\x04List\x12?.yandex.cloud.containerregistry.v1.ListLifecyclePoliciesRequest\x1a@.yandex.cloud.containerregistry.v1.ListLifecyclePoliciesResponse\"0\x82\xd3\xe4\x93\x02*\x12(/container-registry/v1/lifecyclePolicies\x12\xd5\x01\n\x06\x43reate\x12?.yandex.cloud.containerregistry.v1.CreateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"g\xb2\xd2*0\n\x1d\x43reateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x82\xd3\xe4\x93\x02-\"(/container-registry/v1/lifecyclePolicies:\x01*\x12\xeb\x01\n\x06Update\x12?.yandex.cloud.containerregistry.v1.UpdateLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*0\n\x1dUpdateLifecyclePolicyMetadata\x12\x0fLifecyclePolicy\x82\xd3\xe4\x93\x02\x43\x32>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}:\x01*\x12\xef\x01\n\x06\x44\x65lete\x12?.yandex.cloud.containerregistry.v1.DeleteLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*6\n\x1d\x44\x65leteLifecyclePolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}\x12\xfc\x01\n\x06\x44ryRun\x12?.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyRequest\x1a!.yandex.cloud.operation.Operation\"\x8d\x01\xb2\xd2*<\n\x1d\x44ryRunLifecyclePolicyMetadata\x12\x1b\x44ryRunLifecyclePolicyResult\x82\xd3\xe4\x93\x02G\"B/container-registry/v1/dryRunLifecyclePolicy/{lifecycle_policy_id}:\x01*\x12\xfd\x01\n\x0fGetDryRunResult\x12H.yandex.cloud.containerregistry.v1.GetDryRunLifecyclePolicyResultRequest\x1a>.yandex.cloud.containerregistry.v1.DryRunLifecyclePolicyResult\"`\x82\xd3\xe4\x93\x02Z\x12X/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}\x12\xe9\x01\n\x11ListDryRunResults\x12J.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsRequest\x1aK.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/container-registry/v1/dryRunLifecyclePolicyResults\x12\xc4\x02\n\x1eListDryRunResultAffectedImages\x12W.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesRequest\x1aX.yandex.cloud.containerregistry.v1.ListDryRunLifecyclePolicyResultAffectedImagesResponse\"o\x82\xd3\xe4\x93\x02i\x12g/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}:affectedImagesB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.lifecycle_policy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_GETLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_GETLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].oneofs_by_name['id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['registry_id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['registry_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['repository_id']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['repository_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTLIFECYCLEPOLICIESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['repository_id']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['repository_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_CREATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_UPDATELIFECYCLEPOLICYREQUEST'].fields_by_name['status']._serialized_options = b'\350\3071\001'
  _globals['_DELETELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_DELETELIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._loaded_options = None
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['lifecycle_policy_id']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['lifecycle_policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['dry_run_lifecycle_policy_result_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002@\022>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002*\022(/container-registry/v1/lifecyclePolicies'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateLifecyclePolicyMetadata\022\017LifecyclePolicy\202\323\344\223\002-\"(/container-registry/v1/lifecyclePolicies:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateLifecyclePolicyMetadata\022\017LifecyclePolicy\202\323\344\223\002C2>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteLifecyclePolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/container-registry/v1/lifecyclePolicies/{lifecycle_policy_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['DryRun']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['DryRun']._serialized_options = b'\262\322*<\n\035DryRunLifecyclePolicyMetadata\022\033DryRunLifecyclePolicyResult\202\323\344\223\002G\"B/container-registry/v1/dryRunLifecyclePolicy/{lifecycle_policy_id}:\001*'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['GetDryRunResult']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['GetDryRunResult']._serialized_options = b'\202\323\344\223\002Z\022X/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResults']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResults']._serialized_options = b'\202\323\344\223\0025\0223/container-registry/v1/dryRunLifecyclePolicyResults'
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResultAffectedImages']._loaded_options = None
  _globals['_LIFECYCLEPOLICYSERVICE'].methods_by_name['ListDryRunResultAffectedImages']._serialized_options = b'\202\323\344\223\002i\022g/container-registry/v1/dryRunLifecyclePolicyResults/{dry_run_lifecycle_policy_result_id}:affectedImages'
  _globals['_GETLIFECYCLEPOLICYREQUEST']._serialized_start=410
  _globals['_GETLIFECYCLEPOLICYREQUEST']._serialized_end=480
  _globals['_LISTLIFECYCLEPOLICIESREQUEST']._serialized_start=483
  _globals['_LISTLIFECYCLEPOLICIESREQUEST']._serialized_end=712
  _globals['_LISTLIFECYCLEPOLICIESRESPONSE']._serialized_start=715
  _globals['_LISTLIFECYCLEPOLICIESRESPONSE']._serialized_end=851
  _globals['_CREATELIFECYCLEPOLICYREQUEST']._serialized_start=854
  _globals['_CREATELIFECYCLEPOLICYREQUEST']._serialized_end=1148
  _globals['_UPDATELIFECYCLEPOLICYREQUEST']._serialized_start=1151
  _globals['_UPDATELIFECYCLEPOLICYREQUEST']._serialized_end=1500
  _globals['_DELETELIFECYCLEPOLICYREQUEST']._serialized_start=1502
  _globals['_DELETELIFECYCLEPOLICYREQUEST']._serialized_end=1575
  _globals['_CREATELIFECYCLEPOLICYMETADATA']._serialized_start=1577
  _globals['_CREATELIFECYCLEPOLICYMETADATA']._serialized_end=1637
  _globals['_UPDATELIFECYCLEPOLICYMETADATA']._serialized_start=1639
  _globals['_UPDATELIFECYCLEPOLICYMETADATA']._serialized_end=1699
  _globals['_DELETELIFECYCLEPOLICYMETADATA']._serialized_start=1701
  _globals['_DELETELIFECYCLEPOLICYMETADATA']._serialized_end=1761
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST']._serialized_start=1763
  _globals['_DRYRUNLIFECYCLEPOLICYREQUEST']._serialized_end=1836
  _globals['_DRYRUNLIFECYCLEPOLICYMETADATA']._serialized_start=1838
  _globals['_DRYRUNLIFECYCLEPOLICYMETADATA']._serialized_end=1942
  _globals['_DRYRUNLIFECYCLEPOLICYRESULT']._serialized_start=1945
  _globals['_DRYRUNLIFECYCLEPOLICYRESULT']._serialized_end=2122
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST']._serialized_start=2124
  _globals['_GETDRYRUNLIFECYCLEPOLICYRESULTREQUEST']._serialized_end=2221
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST']._serialized_start=2224
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSREQUEST']._serialized_end=2427
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE']._serialized_start=2430
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTSRESPONSE']._serialized_end=2603
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST']._serialized_start=2606
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESREQUEST']._serialized_end=2837
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE']._serialized_start=2840
  _globals['_LISTDRYRUNLIFECYCLEPOLICYRESULTAFFECTEDIMAGESRESPONSE']._serialized_end=2987
  _globals['_LIFECYCLEPOLICYSERVICE']._serialized_start=2990
  _globals['_LIFECYCLEPOLICYSERVICE']._serialized_end=5168
# @@protoc_insertion_point(module_scope)
