# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/kafka.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/kafka.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/connectionmanager/v1/kafka.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a.yandex/cloud/connectionmanager/v1/common.proto\"\x95\x02\n\x11KafkaSaslSecurity\x12\x0c\n\x04user\x18\x01 \x01(\t\x12=\n\x08password\x18\x02 \x01(\x0b\x32+.yandex.cloud.connectionmanager.v1.Password\x12\\\n\x14supported_mechanisms\x18\x03 \x03(\x0e\x32>.yandex.cloud.connectionmanager.v1.KafkaSaslSecurity.Mechanism\"U\n\tMechanism\x12\x19\n\x15MECHANISM_UNSPECIFIED\x10\x00\x12\t\n\x05PLAIN\x10\x01\x12\x10\n\x0cSCRAM_SHA256\x10\x02\x12\x10\n\x0cSCRAM_SHA512\x10\x03\"\x89\x01\n\tKafkaAuth\x12\x44\n\x04sasl\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.KafkaSaslSecurityH\x00\x12*\n\x08\x64isabled\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\n\n\x08security\"\xcc\x02\n\x0cKafkaCluster\x12\x43\n\x05hosts\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.KafkaCluster.Host\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xb4\x01\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12K\n\x06health\x18\x03 \x01(\x0e\x32;.yandex.cloud.connectionmanager.v1.KafkaCluster.Host.Health\"C\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xab\x01\n\x0fKafkaConnection\x12@\n\x07\x63luster\x18\x01 \x01(\x0b\x32/.yandex.cloud.connectionmanager.v1.KafkaCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12:\n\x04\x61uth\x18\x03 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.KafkaAuthB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.kafka_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_KAFKASASLSECURITY']._serialized_start=162
  _globals['_KAFKASASLSECURITY']._serialized_end=439
  _globals['_KAFKASASLSECURITY_MECHANISM']._serialized_start=354
  _globals['_KAFKASASLSECURITY_MECHANISM']._serialized_end=439
  _globals['_KAFKAAUTH']._serialized_start=442
  _globals['_KAFKAAUTH']._serialized_end=579
  _globals['_KAFKACLUSTER']._serialized_start=582
  _globals['_KAFKACLUSTER']._serialized_end=914
  _globals['_KAFKACLUSTER_HOST']._serialized_start=734
  _globals['_KAFKACLUSTER_HOST']._serialized_end=914
  _globals['_KAFKACLUSTER_HOST_HEALTH']._serialized_start=847
  _globals['_KAFKACLUSTER_HOST_HEALTH']._serialized_end=914
  _globals['_KAFKACONNECTION']._serialized_start=917
  _globals['_KAFKACONNECTION']._serialized_end=1088
# @@protoc_insertion_point(module_scope)
