"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UserInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    INN_FIELD_NUMBER: builtins.int
    KPP_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID, reserved field"""
    name: builtins.str
    """Name of legal person"""
    inn: builtins.str
    """INN of legal person"""
    kpp: builtins.str
    """KPP of legal person"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        inn: builtins.str = ...,
        kpp: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "inn", b"inn", "kpp", b"kpp", "name", b"name"]) -> None: ...

global___UserInfo = UserInfo
