# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/test/summary.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/test/summary.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import file_pointer_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_file__pointer__pb2
from yandex.cloud.loadtesting.api.v1.test import imbalance_point_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_imbalance__point__pb2
from yandex.cloud.loadtesting.api.v1.test import status_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_status__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/loadtesting/api/v1/test/summary.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x37yandex/cloud/loadtesting/api/v1/test/file_pointer.proto\x1a:yandex/cloud/loadtesting/api/v1/test/imbalance_point.proto\x1a\x31yandex/cloud/loadtesting/api/v1/test/status.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc0\x03\n\x07Summary\x12<\n\x06status\x18\x01 \x01(\x0e\x32,.yandex.cloud.loadtesting.api.v1.test.Status\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x03 \x01(\t\x12.\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bis_finished\x18\x06 \x01(\x08\x12\r\n\x05\x65rror\x18\x07 \x01(\t\x12M\n\x0fimbalance_point\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.test.ImbalancePoint\x12\x19\n\x11\x61ssigned_agent_id\x18\t \x01(\t\x12\x44\n\tartifacts\x18\n \x01(\x0b\x32\x31.yandex.cloud.loadtesting.api.v1.test.FilePointerBy\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.summary_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_SUMMARY']._serialized_start=294
  _globals['_SUMMARY']._serialized_end=742
# @@protoc_insertion_point(module_scope)
