"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Payload(google.protobuf.message.Message):
    """A payload."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Entry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        TEXT_VALUE_FIELD_NUMBER: builtins.int
        BINARY_VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        """Non-confidential key of the entry."""
        text_value: builtins.str
        """Text value."""
        binary_value: builtins.bytes
        """Binary value."""
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            text_value: builtins.str = ...,
            binary_value: builtins.bytes = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["binary_value", b"binary_value", "text_value", b"text_value", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["binary_value", b"binary_value", "key", b"key", "text_value", b"text_value", "value", b"value"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["text_value", "binary_value"] | None: ...

    VERSION_ID_FIELD_NUMBER: builtins.int
    ENTRIES_FIELD_NUMBER: builtins.int
    version_id: builtins.str
    """ID of the version that the payload belongs to."""
    @property
    def entries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Payload.Entry]:
        """Payload entries."""

    def __init__(
        self,
        *,
        version_id: builtins.str = ...,
        entries: collections.abc.Iterable[global___Payload.Entry] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["entries", b"entries", "version_id", b"version_id"]) -> None: ...

global___Payload = Payload
