# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/elasticsearch/v1/auth_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/elasticsearch/v1/auth_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import auth_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/mdb/elasticsearch/v1/auth_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a,yandex/cloud/mdb/elasticsearch/v1/auth.proto\"<\n\x18ListAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"_\n\x19ListAuthProvidersResponse\x12\x42\n\tproviders\x18\x01 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"j\n\x16GetAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\"\x89\x01\n\x17\x41\x64\x64\x41uthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\tproviders\x18\x02 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x08\x82\xc8\x31\x04<=10\"\x8c\x01\n\x1aUpdateAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\tproviders\x18\x02 \x03(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x08\x82\xc8\x31\x04<=10\"|\n\x1a\x44\x65leteAuthProvidersRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12<\n\x0eprovider_names\x18\x02 \x03(\tB$\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x82\xc8\x31\x04<=10\x8a\xc8\x31\x04<=50\"\xb6\x01\n\x19UpdateAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\x12G\n\x08provider\x18\x03 \x01(\x0b\x32/.yandex.cloud.mdb.elasticsearch.v1.AuthProviderB\x04\xe8\xc7\x31\x01\"m\n\x19\x44\x65leteAuthProviderRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x04name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x10[a-z][a-z0-9_-]*\x8a\xc8\x31\x04<=50\"=\n\x18\x41\x64\x64\x41uthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"@\n\x1bUpdateAuthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"@\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t2\xef\x0c\n\x0b\x41uthService\x12\xd2\x01\n\rListProviders\x12;.yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersRequest\x1a<.yandex.cloud.mdb.elasticsearch.v1.ListAuthProvidersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\x12\xc8\x01\n\x0bGetProvider\x12\x39.yandex.cloud.mdb.elasticsearch.v1.GetAuthProviderRequest\x1a/.yandex.cloud.mdb.elasticsearch.v1.AuthProvider\"M\x82\xd3\xe4\x93\x02G\x12\x45/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}\x12\xe5\x01\n\x0c\x41\x64\x64Providers\x12:.yandex.cloud.mdb.elasticsearch.v1.AddAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*)\n\x18\x41\x64\x64\x41uthProvidersMetadata\x12\rAuthProviders\x82\xd3\xe4\x93\x02\x43\">/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\x01*\x12\xee\x01\n\x0fUpdateProviders\x12=.yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"y\xb2\xd2*,\n\x1bUpdateAuthProvidersMetadata\x12\rAuthProviders\x82\xd3\xe4\x93\x02\x43\x1a>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\x01*\x12\xf3\x01\n\x0f\x44\x65leteProviders\x12=.yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProvidersRequest\x1a!.yandex.cloud.operation.Operation\"~\xb2\xd2*4\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@*>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers\x12\xf4\x01\n\x0eUpdateProvider\x12<.yandex.cloud.mdb.elasticsearch.v1.UpdateAuthProviderRequest\x1a!.yandex.cloud.operation.Operation\"\x80\x01\xb2\xd2*,\n\x1bUpdateAuthProvidersMetadata\x12\rAuthProviders\x82\xd3\xe4\x93\x02J\x1a\x45/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}:\x01*\x12\xf9\x01\n\x0e\x44\x65leteProvider\x12<.yandex.cloud.mdb.elasticsearch.v1.DeleteAuthProviderRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*4\n\x1b\x44\x65leteAuthProvidersMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02G*E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.auth_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _globals['_LISTAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETAUTHPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['providers']._loaded_options = None
  _globals['_ADDAUTHPROVIDERSREQUEST'].fields_by_name['providers']._serialized_options = b'\202\3101\004<=10'
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['providers']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERSREQUEST'].fields_by_name['providers']._serialized_options = b'\202\3101\004<=10'
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['provider_names']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERSREQUEST'].fields_by_name['provider_names']._serialized_options = b'\362\3071\020[a-z][a-z0-9_-]*\202\3101\004<=10\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['provider']._loaded_options = None
  _globals['_UPDATEAUTHPROVIDERREQUEST'].fields_by_name['provider']._serialized_options = b'\350\3071\001'
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEAUTHPROVIDERREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\020[a-z][a-z0-9_-]*\212\3101\004<=50'
  _globals['_AUTHSERVICE'].methods_by_name['ListProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['ListProviders']._serialized_options = b'\202\323\344\223\002@\022>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers'
  _globals['_AUTHSERVICE'].methods_by_name['GetProvider']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['GetProvider']._serialized_options = b'\202\323\344\223\002G\022E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}'
  _globals['_AUTHSERVICE'].methods_by_name['AddProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['AddProviders']._serialized_options = b'\262\322*)\n\030AddAuthProvidersMetadata\022\rAuthProviders\202\323\344\223\002C\">/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProviders']._serialized_options = b'\262\322*,\n\033UpdateAuthProvidersMetadata\022\rAuthProviders\202\323\344\223\002C\032>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProviders']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProviders']._serialized_options = b'\262\322*4\n\033DeleteAuthProvidersMetadata\022\025google.protobuf.Empty\202\323\344\223\002@*>/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers'
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProvider']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['UpdateProvider']._serialized_options = b'\262\322*,\n\033UpdateAuthProvidersMetadata\022\rAuthProviders\202\323\344\223\002J\032E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}:\001*'
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProvider']._loaded_options = None
  _globals['_AUTHSERVICE'].methods_by_name['DeleteProvider']._serialized_options = b'\262\322*4\n\033DeleteAuthProvidersMetadata\022\025google.protobuf.Empty\202\323\344\223\002G*E/managed-elasticsearch/v1/clusters/{cluster_id}/auth/providers/{name}'
  _globals['_LISTAUTHPROVIDERSREQUEST']._serialized_start=272
  _globals['_LISTAUTHPROVIDERSREQUEST']._serialized_end=332
  _globals['_LISTAUTHPROVIDERSRESPONSE']._serialized_start=334
  _globals['_LISTAUTHPROVIDERSRESPONSE']._serialized_end=429
  _globals['_GETAUTHPROVIDERREQUEST']._serialized_start=431
  _globals['_GETAUTHPROVIDERREQUEST']._serialized_end=537
  _globals['_ADDAUTHPROVIDERSREQUEST']._serialized_start=540
  _globals['_ADDAUTHPROVIDERSREQUEST']._serialized_end=677
  _globals['_UPDATEAUTHPROVIDERSREQUEST']._serialized_start=680
  _globals['_UPDATEAUTHPROVIDERSREQUEST']._serialized_end=820
  _globals['_DELETEAUTHPROVIDERSREQUEST']._serialized_start=822
  _globals['_DELETEAUTHPROVIDERSREQUEST']._serialized_end=946
  _globals['_UPDATEAUTHPROVIDERREQUEST']._serialized_start=949
  _globals['_UPDATEAUTHPROVIDERREQUEST']._serialized_end=1131
  _globals['_DELETEAUTHPROVIDERREQUEST']._serialized_start=1133
  _globals['_DELETEAUTHPROVIDERREQUEST']._serialized_end=1242
  _globals['_ADDAUTHPROVIDERSMETADATA']._serialized_start=1244
  _globals['_ADDAUTHPROVIDERSMETADATA']._serialized_end=1305
  _globals['_UPDATEAUTHPROVIDERSMETADATA']._serialized_start=1307
  _globals['_UPDATEAUTHPROVIDERSMETADATA']._serialized_end=1371
  _globals['_DELETEAUTHPROVIDERSMETADATA']._serialized_start=1373
  _globals['_DELETEAUTHPROVIDERSMETADATA']._serialized_end=1437
  _globals['_AUTHSERVICE']._serialized_start=1440
  _globals['_AUTHSERVICE']._serialized_end=3087
# @@protoc_insertion_point(module_scope)
