# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iot/broker/v1/broker_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iot/broker/v1/broker_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iot.broker.v1 import broker_pb2 as yandex_dot_cloud_dot_iot_dot_broker_dot_v1_dot_broker__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/iot/broker/v1/broker_service.proto\x12\x1ayandex.cloud.iot.broker.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\'yandex/cloud/iot/broker/v1/broker.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"3\n\x10GetBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"s\n\x12ListBrokersRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x13ListBrokersResponse\x12\x33\n\x07\x62rokers\x18\x01 \x03(\x0b\x32\".yandex.cloud.iot.broker.v1.Broker\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x85\x04\n\x13\x43reateBrokerRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12(\n\x04name\x18\x02 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x04 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.CreateBrokerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12Q\n\x0c\x63\x65rtificates\x18\x05 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.CreateBrokerRequest.Certificate\x12\x10\n\x08password\x18\x06 \x01(\t\x12;\n\x0blog_options\x18\x07 \x01(\x0b\x32&.yandex.cloud.iot.broker.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\'\n\x0b\x43\x65rtificate\x12\x18\n\x10\x63\x65rtificate_data\x18\x01 \x01(\t\")\n\x14\x43reateBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"\xa8\x03\n\x13UpdateBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12(\n\x04name\x18\x03 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x88\x01\n\x06labels\x18\x05 \x03(\x0b\x32;.yandex.cloud.iot.broker.v1.UpdateBrokerRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12;\n\x0blog_options\x18\x06 \x01(\x0b\x32&.yandex.cloud.iot.broker.v1.LogOptions\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x14UpdateBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"6\n\x13\x44\x65leteBrokerRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\")\n\x14\x44\x65leteBrokerMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\"@\n\x1dListBrokerCertificatesRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1eListBrokerCertificatesResponse\x12\x43\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32-.yandex.cloud.iot.broker.v1.BrokerCertificate\"^\n\x1b\x41\x64\x64\x42rokerCertificateRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10\x63\x65rtificate_data\x18\x03 \x01(\tJ\x04\x08\x02\x10\x03\"F\n\x1c\x41\x64\x64\x42rokerCertificateMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\"d\n\x1e\x44\x65leteBrokerCertificateRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"e\n\x1f\x44\x65leteBrokerCertificateMetadata\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x66ingerprint\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"=\n\x1aListBrokerPasswordsRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\\\n\x1bListBrokerPasswordsResponse\x12=\n\tpasswords\x18\x01 \x03(\x0b\x32*.yandex.cloud.iot.broker.v1.BrokerPassword\"W\n\x18\x41\x64\x64\x42rokerPasswordRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x08password\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04>=14\"C\n\x19\x41\x64\x64\x42rokerPasswordMetadata\x12\x11\n\tbroker_id\x18\x01 \x01(\t\x12\x13\n\x0bpassword_id\x18\x02 \x01(\t\"a\n\x1b\x44\x65leteBrokerPasswordRequest\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"b\n\x1c\x44\x65leteBrokerPasswordMetadata\x12\x1f\n\tbroker_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0bpassword_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x90\x01\n\x1bListBrokerOperationsRequest\x12\x17\n\tbroker_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"n\n\x1cListBrokerOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x80\x12\n\rBrokerService\x12\x83\x01\n\x03Get\x12,.yandex.cloud.iot.broker.v1.GetBrokerRequest\x1a\".yandex.cloud.iot.broker.v1.Broker\"*\x82\xd3\xe4\x93\x02$\x12\"/iot-broker/v1/brokers/{broker_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.iot.broker.v1.ListBrokersRequest\x1a/.yandex.cloud.iot.broker.v1.ListBrokersResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/iot-broker/v1/brokers\x12\xa1\x01\n\x06\x43reate\x12/.yandex.cloud.iot.broker.v1.CreateBrokerRequest\x1a!.yandex.cloud.operation.Operation\"C\xb2\xd2*\x1e\n\x14\x43reateBrokerMetadata\x12\x06\x42roker\x82\xd3\xe4\x93\x02\x1b\"\x16/iot-broker/v1/brokers:\x01*\x12\xad\x01\n\x06Update\x12/.yandex.cloud.iot.broker.v1.UpdateBrokerRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*\x1e\n\x14UpdateBrokerMetadata\x12\x06\x42roker\x82\xd3\xe4\x93\x02\'2\"/iot-broker/v1/brokers/{broker_id}:\x01*\x12\xb9\x01\n\x06\x44\x65lete\x12/.yandex.cloud.iot.broker.v1.DeleteBrokerRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*-\n\x14\x44\x65leteBrokerMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02$*\"/iot-broker/v1/brokers/{broker_id}\x12\xc2\x01\n\x10ListCertificates\x12\x39.yandex.cloud.iot.broker.v1.ListBrokerCertificatesRequest\x1a:.yandex.cloud.iot.broker.v1.ListBrokerCertificatesResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//iot-broker/v1/brokers/{broker_id}/certificates\x12\xdd\x01\n\x0e\x41\x64\x64\x43\x65rtificate\x12\x37.yandex.cloud.iot.broker.v1.AddBrokerCertificateRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*1\n\x1c\x41\x64\x64\x42rokerCertificateMetadata\x12\x11\x42rokerCertificate\x82\xd3\xe4\x93\x02\x34\"//iot-broker/v1/brokers/{broker_id}/certificates:\x01*\x12\xf6\x01\n\x11\x44\x65leteCertificate\x12:.yandex.cloud.iot.broker.v1.DeleteBrokerCertificateRequest\x1a!.yandex.cloud.operation.Operation\"\x81\x01\xb2\xd2*8\n\x1f\x44\x65leteBrokerCertificateMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02?*=/iot-broker/v1/brokers/{broker_id}/certificates/{fingerprint}\x12\xb6\x01\n\rListPasswords\x12\x36.yandex.cloud.iot.broker.v1.ListBrokerPasswordsRequest\x1a\x37.yandex.cloud.iot.broker.v1.ListBrokerPasswordsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/iot-broker/v1/brokers/{broker_id}/passwords\x12\xce\x01\n\x0b\x41\x64\x64Password\x12\x34.yandex.cloud.iot.broker.v1.AddBrokerPasswordRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*+\n\x19\x41\x64\x64\x42rokerPasswordMetadata\x12\x0e\x42rokerPassword\x82\xd3\xe4\x93\x02\x31\",/iot-broker/v1/brokers/{broker_id}/passwords:\x01*\x12\xe9\x01\n\x0e\x44\x65letePassword\x12\x37.yandex.cloud.iot.broker.v1.DeleteBrokerPasswordRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*5\n\x1c\x44\x65leteBrokerPasswordMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02<*:/iot-broker/v1/brokers/{broker_id}/passwords/{password_id}\x12\xba\x01\n\x0eListOperations\x12\x37.yandex.cloud.iot.broker.v1.ListBrokerOperationsRequest\x1a\x38.yandex.cloud.iot.broker.v1.ListBrokerOperationsResponse\"5\x82\xd3\xe4\x93\x02/\x12-/iot-broker/v1/brokers/{broker_id}/operationsBg\n\x1eyandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;brokerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iot.broker.v1.broker_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.iot.broker.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/iot/broker/v1;broker'
  _globals['_GETBROKERREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_GETBROKERREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTBROKERSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBROKERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEBROKERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEBROKERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=50'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEBROKERREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEBROKERREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERCERTIFICATESREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_LISTBROKERCERTIFICATESREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_ADDBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEREQUEST'].fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['fingerprint']._loaded_options = None
  _globals['_DELETEBROKERCERTIFICATEMETADATA'].fields_by_name['fingerprint']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKERPASSWORDSREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_LISTBROKERPASSWORDSREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['password']._loaded_options = None
  _globals['_ADDBROKERPASSWORDREQUEST'].fields_by_name['password']._serialized_options = b'\212\3101\004>=14'
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['password_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDREQUEST'].fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['broker_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['password_id']._loaded_options = None
  _globals['_DELETEBROKERPASSWORDMETADATA'].fields_by_name['password_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['broker_id']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['broker_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTBROKEROPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_BROKERSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002$\022\"/iot-broker/v1/brokers/{broker_id}'
  _globals['_BROKERSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/iot-broker/v1/brokers'
  _globals['_BROKERSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateBrokerMetadata\022\006Broker\202\323\344\223\002\033\"\026/iot-broker/v1/brokers:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateBrokerMetadata\022\006Broker\202\323\344\223\002\'2\"/iot-broker/v1/brokers/{broker_id}:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBrokerMetadata\022\025google.protobuf.Empty\202\323\344\223\002$*\"/iot-broker/v1/brokers/{broker_id}'
  _globals['_BROKERSERVICE'].methods_by_name['ListCertificates']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['ListCertificates']._serialized_options = b'\202\323\344\223\0021\022//iot-broker/v1/brokers/{broker_id}/certificates'
  _globals['_BROKERSERVICE'].methods_by_name['AddCertificate']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['AddCertificate']._serialized_options = b'\262\322*1\n\034AddBrokerCertificateMetadata\022\021BrokerCertificate\202\323\344\223\0024\"//iot-broker/v1/brokers/{broker_id}/certificates:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['DeleteCertificate']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['DeleteCertificate']._serialized_options = b'\262\322*8\n\037DeleteBrokerCertificateMetadata\022\025google.protobuf.Empty\202\323\344\223\002?*=/iot-broker/v1/brokers/{broker_id}/certificates/{fingerprint}'
  _globals['_BROKERSERVICE'].methods_by_name['ListPasswords']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['ListPasswords']._serialized_options = b'\202\323\344\223\002.\022,/iot-broker/v1/brokers/{broker_id}/passwords'
  _globals['_BROKERSERVICE'].methods_by_name['AddPassword']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['AddPassword']._serialized_options = b'\262\322*+\n\031AddBrokerPasswordMetadata\022\016BrokerPassword\202\323\344\223\0021\",/iot-broker/v1/brokers/{broker_id}/passwords:\001*'
  _globals['_BROKERSERVICE'].methods_by_name['DeletePassword']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['DeletePassword']._serialized_options = b'\262\322*5\n\034DeleteBrokerPasswordMetadata\022\025google.protobuf.Empty\202\323\344\223\002<*:/iot-broker/v1/brokers/{broker_id}/passwords/{password_id}'
  _globals['_BROKERSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_BROKERSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002/\022-/iot-broker/v1/brokers/{broker_id}/operations'
  _globals['_GETBROKERREQUEST']._serialized_start=289
  _globals['_GETBROKERREQUEST']._serialized_end=340
  _globals['_LISTBROKERSREQUEST']._serialized_start=342
  _globals['_LISTBROKERSREQUEST']._serialized_end=457
  _globals['_LISTBROKERSRESPONSE']._serialized_start=459
  _globals['_LISTBROKERSRESPONSE']._serialized_end=558
  _globals['_CREATEBROKERREQUEST']._serialized_start=561
  _globals['_CREATEBROKERREQUEST']._serialized_end=1078
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._serialized_start=992
  _globals['_CREATEBROKERREQUEST_LABELSENTRY']._serialized_end=1037
  _globals['_CREATEBROKERREQUEST_CERTIFICATE']._serialized_start=1039
  _globals['_CREATEBROKERREQUEST_CERTIFICATE']._serialized_end=1078
  _globals['_CREATEBROKERMETADATA']._serialized_start=1080
  _globals['_CREATEBROKERMETADATA']._serialized_end=1121
  _globals['_UPDATEBROKERREQUEST']._serialized_start=1124
  _globals['_UPDATEBROKERREQUEST']._serialized_end=1548
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._serialized_start=992
  _globals['_UPDATEBROKERREQUEST_LABELSENTRY']._serialized_end=1037
  _globals['_UPDATEBROKERMETADATA']._serialized_start=1550
  _globals['_UPDATEBROKERMETADATA']._serialized_end=1591
  _globals['_DELETEBROKERREQUEST']._serialized_start=1593
  _globals['_DELETEBROKERREQUEST']._serialized_end=1647
  _globals['_DELETEBROKERMETADATA']._serialized_start=1649
  _globals['_DELETEBROKERMETADATA']._serialized_end=1690
  _globals['_LISTBROKERCERTIFICATESREQUEST']._serialized_start=1692
  _globals['_LISTBROKERCERTIFICATESREQUEST']._serialized_end=1756
  _globals['_LISTBROKERCERTIFICATESRESPONSE']._serialized_start=1758
  _globals['_LISTBROKERCERTIFICATESRESPONSE']._serialized_end=1859
  _globals['_ADDBROKERCERTIFICATEREQUEST']._serialized_start=1861
  _globals['_ADDBROKERCERTIFICATEREQUEST']._serialized_end=1955
  _globals['_ADDBROKERCERTIFICATEMETADATA']._serialized_start=1957
  _globals['_ADDBROKERCERTIFICATEMETADATA']._serialized_end=2027
  _globals['_DELETEBROKERCERTIFICATEREQUEST']._serialized_start=2029
  _globals['_DELETEBROKERCERTIFICATEREQUEST']._serialized_end=2129
  _globals['_DELETEBROKERCERTIFICATEMETADATA']._serialized_start=2131
  _globals['_DELETEBROKERCERTIFICATEMETADATA']._serialized_end=2232
  _globals['_LISTBROKERPASSWORDSREQUEST']._serialized_start=2234
  _globals['_LISTBROKERPASSWORDSREQUEST']._serialized_end=2295
  _globals['_LISTBROKERPASSWORDSRESPONSE']._serialized_start=2297
  _globals['_LISTBROKERPASSWORDSRESPONSE']._serialized_end=2389
  _globals['_ADDBROKERPASSWORDREQUEST']._serialized_start=2391
  _globals['_ADDBROKERPASSWORDREQUEST']._serialized_end=2478
  _globals['_ADDBROKERPASSWORDMETADATA']._serialized_start=2480
  _globals['_ADDBROKERPASSWORDMETADATA']._serialized_end=2547
  _globals['_DELETEBROKERPASSWORDREQUEST']._serialized_start=2549
  _globals['_DELETEBROKERPASSWORDREQUEST']._serialized_end=2646
  _globals['_DELETEBROKERPASSWORDMETADATA']._serialized_start=2648
  _globals['_DELETEBROKERPASSWORDMETADATA']._serialized_end=2746
  _globals['_LISTBROKEROPERATIONSREQUEST']._serialized_start=2749
  _globals['_LISTBROKEROPERATIONSREQUEST']._serialized_end=2893
  _globals['_LISTBROKEROPERATIONSRESPONSE']._serialized_start=2895
  _globals['_LISTBROKEROPERATIONSRESPONSE']._serialized_end=3005
  _globals['_BROKERSERVICE']._serialized_start=3008
  _globals['_BROKERSERVICE']._serialized_end=5312
# @@protoc_insertion_point(module_scope)
