# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/trunk_connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/trunk_connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.cic.v1.common import transceiver_type_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_transceiver__type__pb2
from yandex.cloud.cic.v1.common import lag_allocation_settings_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_lag__allocation__settings__pb2
from yandex.cloud.cic.v1 import trunk_connection_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_trunk__connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/cic/v1/trunk_connection_service.proto\x12\x13yandex.cloud.cic.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x31yandex/cloud/cic/v1/common/transceiver_type.proto\x1a\x38yandex/cloud/cic/v1/common/lag_allocation_settings.proto\x1a*yandex/cloud/cic/v1/trunk_connection.proto\"F\n\x19GetTrunkConnectionRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x98\x01\n\x1bListTrunkConnectionsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"x\n\x1cListTrunkConnectionsResponse\x12?\n\x11trunk_connections\x18\x01 \x03(\x0b\x32$.yandex.cloud.cic.v1.TrunkConnection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf0\x08\n\x1c\x43reateTrunkConnectionRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x05 \x01(\t\x12k\n\x18single_port_direct_joint\x18\n \x01(\x0b\x32G.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.SinglePortDirectJointH\x00\x12\\\n\x10lag_direct_joint\x18\x0b \x01(\x0b\x32@.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.LagDirectJointH\x00\x12\\\n\x12partner_joint_info\x18\x0c \x01(\x0b\x32>.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.PartnerJointH\x00\x12:\n\x14point_of_presence_id\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08\x63\x61pacity\x18\x11 \x01(\x0e\x32-.yandex.cloud.cic.v1.TrunkConnection.Capacity\x12\x8a\x01\n\x06labels\x18\x12 \x03(\x0b\x32=.yandex.cloud.cic.v1.CreateTrunkConnectionRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x64\n\x15SinglePortDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverTypeJ\x04\x08\x02\x10\x05\x1a\xb8\x01\n\x0eLagDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverType\x12Y\n\x17lag_allocation_settings\x18\x03 \x01(\x0b\x32\x38.yandex.cloud.cic.v1.common.LagAllocationSettingsRequestJ\x04\x08\x02\x10\x03\x1a\x46\n\x0cPartnerJoint\x12\x30\n\npartner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueJ\x04\x08\x01\x10\x04\x42\x07\n\x05jointJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\nJ\x04\x08\x0e\x10\x11J\x04\x08\x13\x10\x14\"<\n\x1d\x43reateTrunkConnectionMetadata\x12\x1b\n\x13trunk_connection_id\x18\x01 \x01(\t\"\x9e\x04\n\x1cUpdateTrunkConnectionRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tregion_id\x18\x07 \x01(\t\x12:\n\x14point_of_presence_id\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08\x63\x61pacity\x18\x11 \x01(\x0e\x32-.yandex.cloud.cic.v1.TrunkConnection.Capacity\x12\x8a\x01\n\x06labels\x18\x12 \x03(\x0b\x32=.yandex.cloud.cic.v1.UpdateTrunkConnectionRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x05\x10\x07J\x04\x08\x08\x10\rJ\x04\x08\x0e\x10\x11J\x04\x08\x13\x10\x14\"<\n\x1dUpdateTrunkConnectionMetadata\x12\x1b\n\x13trunk_connection_id\x18\x01 \x01(\t\"I\n\x1c\x44\x65leteTrunkConnectionRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"<\n\x1d\x44\x65leteTrunkConnectionMetadata\x12\x1b\n\x13trunk_connection_id\x18\x01 \x01(\t\"x\n$ListTrunkConnectionOperationsRequest\x12)\n\x13trunk_connection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n%ListTrunkConnectionOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe8\x08\n\x16TrunkConnectionService\x12\x93\x01\n\x03Get\x12..yandex.cloud.cic.v1.GetTrunkConnectionRequest\x1a$.yandex.cloud.cic.v1.TrunkConnection\"6\x82\xd3\xe4\x93\x02\x30\x12./cic/v1/trunkConnections/{trunk_connection_id}\x12\x8d\x01\n\x04List\x12\x30.yandex.cloud.cic.v1.ListTrunkConnectionsRequest\x1a\x31.yandex.cloud.cic.v1.ListTrunkConnectionsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cic/v1/trunkConnections\x12\xb7\x01\n\x06\x43reate\x12\x31.yandex.cloud.cic.v1.CreateTrunkConnectionRequest\x1a!.yandex.cloud.operation.Operation\"W\xb2\xd2*0\n\x1d\x43reateTrunkConnectionMetadata\x12\x0fTrunkConnection\x82\xd3\xe4\x93\x02\x1d\"\x18/cic/v1/trunkConnections:\x01*\x12\xcd\x01\n\x06Update\x12\x31.yandex.cloud.cic.v1.UpdateTrunkConnectionRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*0\n\x1dUpdateTrunkConnectionMetadata\x12\x0fTrunkConnection\x82\xd3\xe4\x93\x02\x33\x32./cic/v1/trunkConnections/{trunk_connection_id}:\x01*\x12\xd0\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.cic.v1.DeleteTrunkConnectionRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*6\n\x1d\x44\x65leteTrunkConnectionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x30*./cic/v1/trunkConnections/{trunk_connection_id}\x12\xca\x01\n\x0eListOperations\x12\x39.yandex.cloud.cic.v1.ListTrunkConnectionOperationsRequest\x1a:.yandex.cloud.cic.v1.ListTrunkConnectionOperationsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/cic/v1/trunkConnections/{trunk_connection_id}/operationsBV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.trunk_connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_GETTRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_GETTRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATETRUNKCONNECTIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_DELETETRUNKCONNECTIONREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST'].fields_by_name['trunk_connection_id']._loaded_options = None
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST'].fields_by_name['trunk_connection_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0020\022./cic/v1/trunkConnections/{trunk_connection_id}'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/cic/v1/trunkConnections'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateTrunkConnectionMetadata\022\017TrunkConnection\202\323\344\223\002\035\"\030/cic/v1/trunkConnections:\001*'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateTrunkConnectionMetadata\022\017TrunkConnection\202\323\344\223\00232./cic/v1/trunkConnections/{trunk_connection_id}:\001*'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteTrunkConnectionMetadata\022\025google.protobuf.Empty\202\323\344\223\0020*./cic/v1/trunkConnections/{trunk_connection_id}'
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_TRUNKCONNECTIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002;\0229/cic/v1/trunkConnections/{trunk_connection_id}/operations'
  _globals['_GETTRUNKCONNECTIONREQUEST']._serialized_start=429
  _globals['_GETTRUNKCONNECTIONREQUEST']._serialized_end=499
  _globals['_LISTTRUNKCONNECTIONSREQUEST']._serialized_start=502
  _globals['_LISTTRUNKCONNECTIONSREQUEST']._serialized_end=654
  _globals['_LISTTRUNKCONNECTIONSRESPONSE']._serialized_start=656
  _globals['_LISTTRUNKCONNECTIONSRESPONSE']._serialized_end=776
  _globals['_CREATETRUNKCONNECTIONREQUEST']._serialized_start=779
  _globals['_CREATETRUNKCONNECTIONREQUEST']._serialized_end=1915
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_start=1476
  _globals['_CREATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_end=1521
  _globals['_CREATETRUNKCONNECTIONREQUEST_SINGLEPORTDIRECTJOINT']._serialized_start=1523
  _globals['_CREATETRUNKCONNECTIONREQUEST_SINGLEPORTDIRECTJOINT']._serialized_end=1623
  _globals['_CREATETRUNKCONNECTIONREQUEST_LAGDIRECTJOINT']._serialized_start=1626
  _globals['_CREATETRUNKCONNECTIONREQUEST_LAGDIRECTJOINT']._serialized_end=1810
  _globals['_CREATETRUNKCONNECTIONREQUEST_PARTNERJOINT']._serialized_start=1812
  _globals['_CREATETRUNKCONNECTIONREQUEST_PARTNERJOINT']._serialized_end=1882
  _globals['_CREATETRUNKCONNECTIONMETADATA']._serialized_start=1917
  _globals['_CREATETRUNKCONNECTIONMETADATA']._serialized_end=1977
  _globals['_UPDATETRUNKCONNECTIONREQUEST']._serialized_start=1980
  _globals['_UPDATETRUNKCONNECTIONREQUEST']._serialized_end=2522
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_start=1476
  _globals['_UPDATETRUNKCONNECTIONREQUEST_LABELSENTRY']._serialized_end=1521
  _globals['_UPDATETRUNKCONNECTIONMETADATA']._serialized_start=2524
  _globals['_UPDATETRUNKCONNECTIONMETADATA']._serialized_end=2584
  _globals['_DELETETRUNKCONNECTIONREQUEST']._serialized_start=2586
  _globals['_DELETETRUNKCONNECTIONREQUEST']._serialized_end=2659
  _globals['_DELETETRUNKCONNECTIONMETADATA']._serialized_start=2661
  _globals['_DELETETRUNKCONNECTIONMETADATA']._serialized_end=2721
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST']._serialized_start=2723
  _globals['_LISTTRUNKCONNECTIONOPERATIONSREQUEST']._serialized_end=2843
  _globals['_LISTTRUNKCONNECTIONOPERATIONSRESPONSE']._serialized_start=2845
  _globals['_LISTTRUNKCONNECTIONOPERATIONSRESPONSE']._serialized_end=2964
  _globals['_TRUNKCONNECTIONSERVICE']._serialized_start=2967
  _globals['_TRUNKCONNECTIONSERVICE']._serialized_end=4095
# @@protoc_insertion_point(module_scope)
