"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.points_pb2
import yandex.cloud.speechsense.v1.analysis.silence_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.speech_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.summarization_pb2
import yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2
import yandex.cloud.speechsense.v1.analysis.transcription_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FieldType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FieldTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FieldType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FIELD_TYPE_UNSPECIFIED: _FieldType.ValueType  # 0
    FIELD_TYPE_STRING: _FieldType.ValueType  # 1
    FIELD_TYPE_NUMBER: _FieldType.ValueType  # 2
    FIELD_TYPE_DECIMAL: _FieldType.ValueType  # 3
    FIELD_TYPE_BOOLEAN: _FieldType.ValueType  # 4
    FIELD_TYPE_DATE: _FieldType.ValueType  # 5
    FIELD_TYPE_JSON: _FieldType.ValueType  # 6

class FieldType(_FieldType, metaclass=_FieldTypeEnumTypeWrapper):
    """connection field type"""

FIELD_TYPE_UNSPECIFIED: FieldType.ValueType  # 0
FIELD_TYPE_STRING: FieldType.ValueType  # 1
FIELD_TYPE_NUMBER: FieldType.ValueType  # 2
FIELD_TYPE_DECIMAL: FieldType.ValueType  # 3
FIELD_TYPE_BOOLEAN: FieldType.ValueType  # 4
FIELD_TYPE_DATE: FieldType.ValueType  # 5
FIELD_TYPE_JSON: FieldType.ValueType  # 6
global___FieldType = FieldType

class _ProcessingState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProcessingStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ProcessingState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROCESSING_STATE_UNSPECIFIED: _ProcessingState.ValueType  # 0
    PROCESSING_STATE_NOT_STARTED: _ProcessingState.ValueType  # 1
    PROCESSING_STATE_PROCESSING: _ProcessingState.ValueType  # 2
    PROCESSING_STATE_SUCCESS: _ProcessingState.ValueType  # 3
    PROCESSING_STATE_FAILED: _ProcessingState.ValueType  # 4

class ProcessingState(_ProcessingState, metaclass=_ProcessingStateEnumTypeWrapper): ...

PROCESSING_STATE_UNSPECIFIED: ProcessingState.ValueType  # 0
PROCESSING_STATE_NOT_STARTED: ProcessingState.ValueType  # 1
PROCESSING_STATE_PROCESSING: ProcessingState.ValueType  # 2
PROCESSING_STATE_SUCCESS: ProcessingState.ValueType  # 3
PROCESSING_STATE_FAILED: ProcessingState.ValueType  # 4
global___ProcessingState = ProcessingState

class _Algorithm:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Algorithm.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ALGORITHM_UNSPECIFIED: _Algorithm.ValueType  # 0
    ALGORITHM_SPEECHKIT: _Algorithm.ValueType  # 1
    ALGORITHM_YGPT: _Algorithm.ValueType  # 2
    ALGORITHM_CLASSIFIER: _Algorithm.ValueType  # 3
    ALGORITHM_SUMMARIZATION: _Algorithm.ValueType  # 4
    ALGORITHM_EMBEDDING: _Algorithm.ValueType  # 5
    ALGORITHM_STATISTICS: _Algorithm.ValueType  # 6

class Algorithm(_Algorithm, metaclass=_AlgorithmEnumTypeWrapper): ...

ALGORITHM_UNSPECIFIED: Algorithm.ValueType  # 0
ALGORITHM_SPEECHKIT: Algorithm.ValueType  # 1
ALGORITHM_YGPT: Algorithm.ValueType  # 2
ALGORITHM_CLASSIFIER: Algorithm.ValueType  # 3
ALGORITHM_SUMMARIZATION: Algorithm.ValueType  # 4
ALGORITHM_EMBEDDING: Algorithm.ValueType  # 5
ALGORITHM_STATISTICS: Algorithm.ValueType  # 6
global___Algorithm = Algorithm

@typing.final
class Talk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    SPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PROJECT_IDS_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    TALK_FIELDS_FIELD_NUMBER: builtins.int
    TRANSCRIPTION_FIELD_NUMBER: builtins.int
    SPEECH_STATISTICS_FIELD_NUMBER: builtins.int
    SILENCE_STATISTICS_FIELD_NUMBER: builtins.int
    INTERRUPTS_STATISTICS_FIELD_NUMBER: builtins.int
    CONVERSATION_STATISTICS_FIELD_NUMBER: builtins.int
    POINTS_FIELD_NUMBER: builtins.int
    TEXT_CLASSIFIERS_FIELD_NUMBER: builtins.int
    SUMMARIZATION_FIELD_NUMBER: builtins.int
    TALK_STATE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """talk id"""
    organization_id: builtins.str
    space_id: builtins.str
    connection_id: builtins.str
    created_by: builtins.str
    """audition info"""
    modified_by: builtins.str
    @property
    def project_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def talk_fields(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Field]:
        """key-value representation of talk fields with values"""

    @property
    def transcription(self) -> yandex.cloud.speechsense.v1.analysis.transcription_pb2.Transcription:
        """various ml analysis results"""

    @property
    def speech_statistics(self) -> yandex.cloud.speechsense.v1.analysis.speech_statistics_pb2.SpeechStatistics: ...
    @property
    def silence_statistics(self) -> yandex.cloud.speechsense.v1.analysis.silence_statistics_pb2.SilenceStatistics: ...
    @property
    def interrupts_statistics(self) -> yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2.InterruptsStatistics: ...
    @property
    def conversation_statistics(self) -> yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2.ConversationStatistics: ...
    @property
    def points(self) -> yandex.cloud.speechsense.v1.analysis.points_pb2.Points: ...
    @property
    def text_classifiers(self) -> yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2.TextClassifiers: ...
    @property
    def summarization(self) -> yandex.cloud.speechsense.v1.analysis.summarization_pb2.Summarization: ...
    @property
    def talk_state(self) -> global___TalkState: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        organization_id: builtins.str = ...,
        space_id: builtins.str = ...,
        connection_id: builtins.str = ...,
        project_ids: collections.abc.Iterable[builtins.str] | None = ...,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_by: builtins.str = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        talk_fields: collections.abc.Iterable[global___Field] | None = ...,
        transcription: yandex.cloud.speechsense.v1.analysis.transcription_pb2.Transcription | None = ...,
        speech_statistics: yandex.cloud.speechsense.v1.analysis.speech_statistics_pb2.SpeechStatistics | None = ...,
        silence_statistics: yandex.cloud.speechsense.v1.analysis.silence_statistics_pb2.SilenceStatistics | None = ...,
        interrupts_statistics: yandex.cloud.speechsense.v1.analysis.interrupts_statistics_pb2.InterruptsStatistics | None = ...,
        conversation_statistics: yandex.cloud.speechsense.v1.analysis.conversation_statistics_pb2.ConversationStatistics | None = ...,
        points: yandex.cloud.speechsense.v1.analysis.points_pb2.Points | None = ...,
        text_classifiers: yandex.cloud.speechsense.v1.analysis.text_classifiers_pb2.TextClassifiers | None = ...,
        summarization: yandex.cloud.speechsense.v1.analysis.summarization_pb2.Summarization | None = ...,
        talk_state: global___TalkState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conversation_statistics", b"conversation_statistics", "created_at", b"created_at", "interrupts_statistics", b"interrupts_statistics", "modified_at", b"modified_at", "points", b"points", "silence_statistics", b"silence_statistics", "speech_statistics", b"speech_statistics", "summarization", b"summarization", "talk_state", b"talk_state", "text_classifiers", b"text_classifiers", "transcription", b"transcription"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "conversation_statistics", b"conversation_statistics", "created_at", b"created_at", "created_by", b"created_by", "id", b"id", "interrupts_statistics", b"interrupts_statistics", "modified_at", b"modified_at", "modified_by", b"modified_by", "organization_id", b"organization_id", "points", b"points", "project_ids", b"project_ids", "silence_statistics", b"silence_statistics", "space_id", b"space_id", "speech_statistics", b"speech_statistics", "summarization", b"summarization", "talk_fields", b"talk_fields", "talk_state", b"talk_state", "text_classifiers", b"text_classifiers", "transcription", b"transcription"]) -> None: ...

global___Talk = Talk

@typing.final
class TalkState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROCESSING_STATE_FIELD_NUMBER: builtins.int
    ALGORITHM_PROCESSING_INFOS_FIELD_NUMBER: builtins.int
    processing_state: global___ProcessingState.ValueType
    @property
    def algorithm_processing_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AlgorithmProcessingInfo]: ...
    def __init__(
        self,
        *,
        processing_state: global___ProcessingState.ValueType = ...,
        algorithm_processing_infos: collections.abc.Iterable[global___AlgorithmProcessingInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["algorithm_processing_infos", b"algorithm_processing_infos", "processing_state", b"processing_state"]) -> None: ...

global___TalkState = TalkState

@typing.final
class Field(google.protobuf.message.Message):
    """connection field value"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name of the field"""
    value: builtins.str
    """field value"""
    type: global___FieldType.ValueType
    """field type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        value: builtins.str = ...,
        type: global___FieldType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "type", b"type", "value", b"value"]) -> None: ...

global___Field = Field

@typing.final
class AlgorithmProcessingInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALGORITHM_FIELD_NUMBER: builtins.int
    PROCESSING_STATE_FIELD_NUMBER: builtins.int
    algorithm: global___Algorithm.ValueType
    processing_state: global___ProcessingState.ValueType
    def __init__(
        self,
        *,
        algorithm: global___Algorithm.ValueType = ...,
        processing_state: global___ProcessingState.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["algorithm", b"algorithm", "processing_state", b"processing_state"]) -> None: ...

global___AlgorithmProcessingInfo = AlgorithmProcessingInfo
