"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TuningError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[TuningError._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: TuningError._Type.ValueType  # 0
        PUBLIC: TuningError._Type.ValueType  # 1
        INTERNAL: TuningError._Type.ValueType  # 2

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: TuningError.Type.ValueType  # 0
    PUBLIC: TuningError.Type.ValueType  # 1
    INTERNAL: TuningError.Type.ValueType  # 2

    TUNING_TASK_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    tuning_task_id: builtins.str
    message: builtins.str
    type: global___TuningError.Type.ValueType
    def __init__(
        self,
        *,
        tuning_task_id: builtins.str = ...,
        message: builtins.str = ...,
        type: global___TuningError.Type.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["message", b"message", "tuning_task_id", b"tuning_task_id", "type", b"type"]) -> None: ...

global___TuningError = TuningError
