# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/connection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.connectionmanager.v1 import mysql_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_mysql__pb2
from yandex.cloud.connectionmanager.v1 import postgresql_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_postgresql__pb2
from yandex.cloud.connectionmanager.v1 import mongodb_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_mongodb__pb2
from yandex.cloud.connectionmanager.v1 import clickhouse_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_clickhouse__pb2
from yandex.cloud.connectionmanager.v1 import redis_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_redis__pb2
from yandex.cloud.connectionmanager.v1 import trino_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_trino__pb2
from yandex.cloud.connectionmanager.v1 import valkey_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_valkey__pb2
from yandex.cloud.connectionmanager.v1 import opensearch_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_opensearch__pb2
from yandex.cloud.connectionmanager.v1 import greenplum_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_greenplum__pb2
from yandex.cloud.connectionmanager.v1 import kafka_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_kafka__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/connectionmanager/v1/connection.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/connectionmanager/v1/mysql.proto\x1a\x32yandex/cloud/connectionmanager/v1/postgresql.proto\x1a/yandex/cloud/connectionmanager/v1/mongodb.proto\x1a\x32yandex/cloud/connectionmanager/v1/clickhouse.proto\x1a-yandex/cloud/connectionmanager/v1/redis.proto\x1a-yandex/cloud/connectionmanager/v1/trino.proto\x1a.yandex/cloud/connectionmanager/v1/valkey.proto\x1a\x32yandex/cloud/connectionmanager/v1/opensearch.proto\x1a\x31yandex/cloud/connectionmanager/v1/greenplum.proto\x1a-yandex/cloud/connectionmanager/v1/kafka.proto\"\xf8\x05\n\x10\x43onnectionParams\x12M\n\npostgresql\x18\x01 \x01(\x0b\x32\x37.yandex.cloud.connectionmanager.v1.PostgreSQLConnectionH\x00\x12\x43\n\x05mysql\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.MySQLConnectionH\x00\x12G\n\x07mongodb\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.connectionmanager.v1.MongoDBConnectionH\x00\x12M\n\nclickhouse\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.connectionmanager.v1.ClickHouseConnectionH\x00\x12\x43\n\x05kafka\x18\x05 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.KafkaConnectionH\x00\x12\x43\n\x05redis\x18\x06 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.RedisConnectionH\x00\x12M\n\nopensearch\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.connectionmanager.v1.OpenSearchConnectionH\x00\x12\x43\n\x05trino\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.connectionmanager.v1.TrinoConnectionH\x00\x12\x45\n\x06valkey\x18\t \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ValkeyConnectionH\x00\x12K\n\tgreenplum\x18\n \x01(\x0b\x32\x36.yandex.cloud.connectionmanager.v1.GreenplumConnectionH\x00\x42\x06\n\x04type\"D\n\rLockboxSecret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0enewest_version\x18\x03 \x01(\t\"\x9e\x04\n\nConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12I\n\x06labels\x18\x07 \x03(\x0b\x32\x39.yandex.cloud.connectionmanager.v1.Connection.LabelsEntry\x12\x12\n\ncreated_by\x18\x08 \x01(\t\x12\x43\n\x06params\x18\t \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ConnectionParams\x12J\n\x0elockbox_secret\x18\n \x01(\x0b\x32\x30.yandex.cloud.connectionmanager.v1.LockboxSecretH\x00\x12\x12\n\nis_managed\x18\x0c \x01(\x08\x12+\n\x07\x63\x61n_use\x18\r \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06secretJ\x04\x08\x0b\x10\x0c*\xa5\x01\n\x06\x44\x42Type\x12\x17\n\x13\x44\x42_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\t\n\x05MYSQL\x10\x02\x12\x0e\n\nCLICKHOUSE\x10\x03\x12\x0b\n\x07MONGODB\x10\x04\x12\t\n\x05KAFKA\x10\x05\x12\t\n\x05REDIS\x10\x06\x12\x0e\n\nOPENSEARCH\x10\x07\x12\t\n\x05TRINO\x10\x08\x12\n\n\x06VALKEY\x10\t\x12\r\n\tGREENPLUM\x10\nB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_CONNECTION_LABELSENTRY']._loaded_options = None
  _globals['_CONNECTION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DBTYPE']._serialized_start=2025
  _globals['_DBTYPE']._serialized_end=2190
  _globals['_CONNECTIONPARAMS']._serialized_start=647
  _globals['_CONNECTIONPARAMS']._serialized_end=1407
  _globals['_LOCKBOXSECRET']._serialized_start=1409
  _globals['_LOCKBOXSECRET']._serialized_end=1477
  _globals['_CONNECTION']._serialized_start=1480
  _globals['_CONNECTION']._serialized_end=2022
  _globals['_CONNECTION_LABELSENTRY']._serialized_start=1961
  _globals['_CONNECTION_LABELSENTRY']._serialized_end=2006
# @@protoc_insertion_point(module_scope)
