# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop_group.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop_group.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.clouddesktop.v1 import disk_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/clouddesktop/v1/desktop_group.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/access/access.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/clouddesktop/v1/disk.proto\"\xd3\x07\n\x0c\x44\x65sktopGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x06status\x18\x04 \x01(\x0e\x32\x35.yandex.cloud.clouddesktop.v1.api.DesktopGroup.Status\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0c \x01(\t\x12G\n\x0eresources_spec\x18\x15 \x01(\x0b\x32/.yandex.cloud.clouddesktop.v1.api.ResourcesSpec\x12V\n\x16network_interface_spec\x18\x16 \x01(\x0b\x32\x36.yandex.cloud.clouddesktop.v1.api.NetworkInterfaceSpec\x12J\n\x06labels\x18\x17 \x03(\x0b\x32:.yandex.cloud.clouddesktop.v1.api.DesktopGroup.LabelsEntry\x12\x42\n\x0e\x62oot_disk_spec\x18\x18 \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12\x42\n\x0e\x64\x61ta_disk_spec\x18\x19 \x01(\x0b\x32*.yandex.cloud.clouddesktop.v1.api.DiskSpec\x12Q\n\x0cgroup_config\x18\x1a \x01(\x0b\x32;.yandex.cloud.clouddesktop.v1.api.DesktopGroupConfiguration\x12P\n\x12\x61uto_update_policy\x18\x1b \x01(\x0b\x32\x32.yandex.cloud.clouddesktop.v1.api.AutoUpdatePolicyH\x00\x12T\n\x14manual_update_policy\x18\x1c \x01(\x0b\x32\x34.yandex.cloud.clouddesktop.v1.api.ManualUpdatePolicyH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\x15\n\rupdate_policy\x12\x04\xc0\xc1\x31\x01J\x04\x08\r\x10\x15J\x04\x08\x05\x10\x0b\"\xd3\x02\n\x19\x44\x65sktopGroupConfiguration\x12%\n\x12min_ready_desktops\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-512\x12&\n\x13max_desktops_amount\x18\x02 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-512\x12]\n\x0c\x64\x65sktop_type\x18\x03 \x01(\x0e\x32G.yandex.cloud.clouddesktop.v1.api.DesktopGroupConfiguration.DesktopType\x12\x37\n\x07members\x18\x04 \x03(\x0b\x32\x1c.yandex.cloud.access.SubjectB\x08\x82\xc8\x31\x04\x30-10\"O\n\x0b\x44\x65sktopType\x12\x1c\n\x18\x44\x45SKTOP_TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPERSISTENT\x10\x01\x12\x12\n\x0eNON_PERSISTENT\x10\x02\"b\n\rResourcesSpec\x12\x17\n\x06memory\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"`\n\x14NetworkInterfaceSpec\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12&\n\nsubnet_ids\x18\x02 \x03(\tB\x12\x82\xc8\x31\x02>0\x8a\xc8\x31\x04<=50\x90\xc8\x31\x01\"\x14\n\x12ManualUpdatePolicy\"\x12\n\x10\x41utoUpdatePolicyBq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_DESKTOPGROUP_LABELSENTRY']._loaded_options = None
  _globals['_DESKTOPGROUP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_DESKTOPGROUP'].oneofs_by_name['update_policy']._loaded_options = None
  _globals['_DESKTOPGROUP'].oneofs_by_name['update_policy']._serialized_options = b'\300\3011\001'
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['min_ready_desktops']._loaded_options = None
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['min_ready_desktops']._serialized_options = b'\372\3071\0051-512'
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['max_desktops_amount']._loaded_options = None
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['max_desktops_amount']._serialized_options = b'\372\3071\0050-512'
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['members']._loaded_options = None
  _globals['_DESKTOPGROUPCONFIGURATION'].fields_by_name['members']._serialized_options = b'\202\3101\0040-10'
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['memory']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['cores']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._loaded_options = None
  _globals['_RESOURCESSPEC'].fields_by_name['core_fraction']._serialized_options = b'\372\3071\0050-100'
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['network_id']._loaded_options = None
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['subnet_ids']._loaded_options = None
  _globals['_NETWORKINTERFACESPEC'].fields_by_name['subnet_ids']._serialized_options = b'\202\3101\002>0\212\3101\004<=50\220\3101\001'
  _globals['_DESKTOPGROUP']._serialized_start=226
  _globals['_DESKTOPGROUP']._serialized_end=1205
  _globals['_DESKTOPGROUP_LABELSENTRY']._serialized_start=1051
  _globals['_DESKTOPGROUP_LABELSENTRY']._serialized_end=1096
  _globals['_DESKTOPGROUP_STATUS']._serialized_start=1098
  _globals['_DESKTOPGROUP_STATUS']._serialized_end=1170
  _globals['_DESKTOPGROUPCONFIGURATION']._serialized_start=1208
  _globals['_DESKTOPGROUPCONFIGURATION']._serialized_end=1547
  _globals['_DESKTOPGROUPCONFIGURATION_DESKTOPTYPE']._serialized_start=1468
  _globals['_DESKTOPGROUPCONFIGURATION_DESKTOPTYPE']._serialized_end=1547
  _globals['_RESOURCESSPEC']._serialized_start=1549
  _globals['_RESOURCESSPEC']._serialized_end=1647
  _globals['_NETWORKINTERFACESPEC']._serialized_start=1649
  _globals['_NETWORKINTERFACESPEC']._serialized_end=1745
  _globals['_MANUALUPDATEPOLICY']._serialized_start=1747
  _globals['_MANUALUPDATEPOLICY']._serialized_end=1767
  _globals['_AUTOUPDATEPOLICY']._serialized_start=1769
  _globals['_AUTOUPDATEPOLICY']._serialized_end=1787
# @@protoc_insertion_point(module_scope)
