"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iam.v1.oauth_client_secret_pb2
import yandex.cloud.iam.v1.oauth_client_secret_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class OAuthClientSecretServiceStub:
    """A set of methods for managing OAuthClientSecret resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.GetOAuthClientSecretRequest,
        yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret,
    ]
    """Returns the sepcified OAuthClientSecret resource.

    To get the list of available OAuthClientSecret resources, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsRequest,
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse,
    ]
    """Retrieves the list of OAuthClientSecret resources of the specified OAuthClient."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.CreateOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuthClientSecret resource for the specified OAuthClient."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.DeleteOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuthClientSecret resource."""

class OAuthClientSecretServiceAsyncStub:
    """A set of methods for managing OAuthClientSecret resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.GetOAuthClientSecretRequest,
        yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret,
    ]
    """Returns the sepcified OAuthClientSecret resource.

    To get the list of available OAuthClientSecret resources, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsRequest,
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse,
    ]
    """Retrieves the list of OAuthClientSecret resources of the specified OAuthClient."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.CreateOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an OAuthClientSecret resource for the specified OAuthClient."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iam.v1.oauth_client_secret_service_pb2.DeleteOAuthClientSecretRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified OAuthClientSecret resource."""

class OAuthClientSecretServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing OAuthClientSecret resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.GetOAuthClientSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret, collections.abc.Awaitable[yandex.cloud.iam.v1.oauth_client_secret_pb2.OAuthClientSecret]]:
        """Returns the sepcified OAuthClientSecret resource.

        To get the list of available OAuthClientSecret resources, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse, collections.abc.Awaitable[yandex.cloud.iam.v1.oauth_client_secret_service_pb2.ListOAuthClientSecretsResponse]]:
        """Retrieves the list of OAuthClientSecret resources of the specified OAuthClient."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.CreateOAuthClientSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an OAuthClientSecret resource for the specified OAuthClient."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iam.v1.oauth_client_secret_service_pb2.DeleteOAuthClientSecretRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified OAuthClientSecret resource."""

def add_OAuthClientSecretServiceServicer_to_server(servicer: OAuthClientSecretServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
