# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/multi_source_chart_widget.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/multi_source_chart_widget.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.monitoring.v3 import downsampling_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_downsampling__pb2
from yandex.cloud.monitoring.v3 import unit_format_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_unit__format__pb2
from yandex.cloud.monitoring.v3 import thresholds_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_thresholds__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/monitoring/v3/multi_source_chart_widget.proto\x12\x1ayandex.cloud.monitoring.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a-yandex/cloud/monitoring/v3/downsampling.proto\x1a,yandex/cloud/monitoring/v3/unit_format.proto\x1a+yandex/cloud/monitoring/v3/thresholds.proto\"\x8f\x38\n\x16MultiSourceChartWidget\x12\n\n\x02id\x18\x01 \x01(\t\x12J\n\x07targets\x18\x02 \x03(\x0b\x32\x39.yandex.cloud.monitoring.v3.MultiSourceChartWidget.Target\x12S\n\x0c\x64\x61ta_sources\x18\x03 \x03(\x0b\x32=.yandex.cloud.monitoring.v3.MultiSourceChartWidget.DataSource\x12h\n\x16visualization_settings\x18\x04 \x01(\x0b\x32H.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings\x12\\\n\x10series_overrides\x18\x05 \x03(\x0b\x32\x42.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides\x12\x63\n\x14name_hiding_settings\x18\x06 \x01(\x0b\x32\x45.yandex.cloud.monitoring.v3.MultiSourceChartWidget.NameHidingSettings\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\r\n\x05title\x18\x08 \x01(\t\x12\x16\n\x0e\x64isplay_legend\x18\t \x01(\x08\x12Q\n\x06\x66reeze\x18\n \x01(\x0e\x32\x41.yandex.cloud.monitoring.v3.MultiSourceChartWidget.FreezeDuration\x12Q\n\x06repeat\x18\x0b \x01(\x0b\x32\x41.yandex.cloud.monitoring.v3.MultiSourceChartWidget.RepeatSettings\x12:\n\nthresholds\x18\x0c \x01(\x0b\x32&.yandex.cloud.monitoring.v3.Thresholds\x1a\xe1\x03\n\x06Target\x12g\n\x11monitoring_target\x18\x01 \x01(\x0b\x32J.yandex.cloud.monitoring.v3.MultiSourceChartWidget.Target.MonitoringTargetH\x00\x12g\n\x11prometheus_target\x18\x02 \x01(\x0b\x32J.yandex.cloud.monitoring.v3.MultiSourceChartWidget.Target.PrometheusTargetH\x00\x1aj\n\x10MonitoringTarget\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x11\n\ttext_mode\x18\x03 \x01(\x08\x12\x0e\n\x06hidden\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\t\x1a\x8e\x01\n\x10PrometheusTarget\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x11\n\ttext_mode\x18\x04 \x01(\x08\x12\x0e\n\x06hidden\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0c\n\x04step\x18\x07 \x01(\tB\x08\n\x06target\x1a\x9d\x03\n\nDataSource\x12t\n\x16monitoring_data_source\x18\x01 \x01(\x0b\x32R.yandex.cloud.monitoring.v3.MultiSourceChartWidget.DataSource.MonitoringDataSourceH\x00\x12t\n\x16prometheus_data_source\x18\x02 \x01(\x0b\x32R.yandex.cloud.monitoring.v3.MultiSourceChartWidget.DataSource.PrometheusDataSourceH\x00\x1a\x62\n\x14MonitoringDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12>\n\x0c\x64ownsampling\x18\x02 \x01(\x0b\x32(.yandex.cloud.monitoring.v3.Downsampling\x1a\x30\n\x14PrometheusDataSource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04step\x18\x02 \x01(\x03\x42\r\n\x0b\x64\x61ta_source\x1a\xd5\x1a\n\x15VisualizationSettings\x12h\n\x04type\x18\x01 \x01(\x0e\x32Z.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.VisualizationType\x12\x11\n\tnormalize\x18\x02 \x01(\x08\x12i\n\x0binterpolate\x18\x03 \x01(\x0e\x32T.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.Interpolate\x12o\n\x0b\x61ggregation\x18\x04 \x01(\x0e\x32Z.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.SeriesAggregation\x12{\n\x15\x63olor_scheme_settings\x18\x05 \x01(\x0b\x32\\.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings\x12r\n\x10heatmap_settings\x18\x06 \x01(\x0b\x32X.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.HeatmapSettings\x12n\n\x0eyaxis_settings\x18\x07 \x01(\x0b\x32V.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.YaxisSettings\x12\r\n\x05title\x18\x08 \x01(\t\x12\x13\n\x0bshow_labels\x18\t \x01(\x08\x1a\xe0\n\n\x13\x43olorSchemeSettings\x12\x86\x01\n\tautomatic\x18\x01 \x01(\x0b\x32q.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorSchemeH\x00\x12\x84\x01\n\x08standard\x18\x02 \x01(\x0b\x32p.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorSchemeH\x00\x12\x84\x01\n\x08gradient\x18\x03 \x01(\x0b\x32p.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorSchemeH\x00\x12|\n\x04hash\x18\x04 \x01(\x0b\x32l.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorSchemeH\x00\x12\x88\x01\n\nthresholds\x18\x05 \x01(\x0b\x32r.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorSchemeH\x00\x12\x84\x01\n\x08\x63onstant\x18\x06 \x01(\x0b\x32p.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.ConstantColorSchemeH\x00\x1a\x16\n\x14\x41utomaticColorScheme\x1a\x15\n\x13StandardColorScheme\x1ai\n\x13GradientColorScheme\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\x11\n\x0fHashColorScheme\x1a$\n\x13\x43onstantColorScheme\x12\r\n\x05\x63olor\x18\x01 \x01(\t\x1a\xc4\x02\n\x15ThresholdsColorScheme\x12\x93\x01\n\x0b\x61ggregation\x18\x01 \x01(\x0e\x32~.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation\"\x94\x01\n\x0b\x41ggregation\x12\x1b\n\x17\x41GGREGATION_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41GGREGATION_LAST\x10\x01\x12\x13\n\x0f\x41GGREGATION_MIN\x10\x02\x12\x13\n\x0f\x41GGREGATION_MAX\x10\x03\x12\x13\n\x0f\x41GGREGATION_AVG\x10\x04\x12\x13\n\x0f\x41GGREGATION_SUM\x10\x05\x42\x08\n\x06scheme\x1a\x65\n\x0fHeatmapSettings\x12\x13\n\x0bgreen_value\x18\x02 \x01(\t\x12\x14\n\x0cyellow_value\x18\x03 \x01(\t\x12\x11\n\tred_value\x18\x04 \x01(\t\x12\x14\n\x0cviolet_value\x18\x05 \x01(\t\x1a\xff\x01\n\x05Yaxis\x12`\n\x04type\x18\x01 \x01(\x0e\x32R.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.YaxisType\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0b\n\x03min\x18\x03 \x01(\t\x12\x0b\n\x03max\x18\x04 \x01(\t\x12;\n\x0bunit_format\x18\x05 \x01(\x0e\x32&.yandex.cloud.monitoring.v3.UnitFormat\x12.\n\tprecision\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1a\xcc\x01\n\rYaxisSettings\x12\\\n\x04left\x18\x01 \x01(\x0b\x32N.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.Yaxis\x12]\n\x05right\x18\x02 \x01(\x0b\x32N.yandex.cloud.monitoring.v3.MultiSourceChartWidget.VisualizationSettings.Yaxis\"\xae\x02\n\x11VisualizationType\x12\"\n\x1eVISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17VISUALIZATION_TYPE_LINE\x10\x01\x12\x1c\n\x18VISUALIZATION_TYPE_STACK\x10\x02\x12\x1d\n\x19VISUALIZATION_TYPE_COLUMN\x10\x03\x12\x1d\n\x19VISUALIZATION_TYPE_POINTS\x10\x04\x12\x1a\n\x16VISUALIZATION_TYPE_PIE\x10\x05\x12\x1b\n\x17VISUALIZATION_TYPE_BARS\x10\x06\x12#\n\x1fVISUALIZATION_TYPE_DISTRIBUTION\x10\x07\x12\x1e\n\x1aVISUALIZATION_TYPE_HEATMAP\x10\x08\"o\n\x0bInterpolate\x12\x1b\n\x17INTERPOLATE_UNSPECIFIED\x10\x00\x12\x16\n\x12INTERPOLATE_LINEAR\x10\x01\x12\x14\n\x10INTERPOLATE_LEFT\x10\x02\x12\x15\n\x11INTERPOLATE_RIGHT\x10\x03\"Z\n\tYaxisType\x12\x1a\n\x16YAXIS_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11YAXIS_TYPE_LINEAR\x10\x01\x12\x1a\n\x16YAXIS_TYPE_LOGARITHMIC\x10\x02\"\xc4\x01\n\x11SeriesAggregation\x12\"\n\x1eSERIES_AGGREGATION_UNSPECIFIED\x10\x00\x12\x1a\n\x16SERIES_AGGREGATION_AVG\x10\x01\x12\x1a\n\x16SERIES_AGGREGATION_MIN\x10\x02\x12\x1a\n\x16SERIES_AGGREGATION_MAX\x10\x03\x12\x1b\n\x17SERIES_AGGREGATION_LAST\x10\x04\x12\x1a\n\x16SERIES_AGGREGATION_SUM\x10\x05\x1a\x83\t\n\x0fSeriesOverrides\x12\x0e\n\x04name\x18\x01 \x01(\tH\x00\x12\x16\n\x0ctarget_index\x18\x02 \x01(\tH\x00\x12k\n\x08settings\x18\x03 \x01(\x0b\x32Y.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.SeriesOverrideSettings\x12\x15\n\roverride_name\x18\x04 \x01(\t\x12S\n\x07matcher\x18\x05 \x01(\x0b\x32\x42.yandex.cloud.monitoring.v3.MultiSourceChartWidget.OverrideMatcher\x1a\xa6\x04\n\x16SeriesOverrideSettings\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63olor\x18\x02 \x01(\t\x12h\n\x04type\x18\x03 \x01(\x0e\x32Z.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.SeriesVisualizationType\x12\x12\n\nstack_name\x18\x04 \x01(\t\x12\x11\n\tgrow_down\x18\x05 \x01(\x08\x12h\n\x0eyaxis_position\x18\x06 \x01(\x0e\x32P.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.YaxisPosition\x12\x12\n\nline_width\x18\x07 \x01(\x03\x12w\n\nline_style\x18\x08 \x01(\x0e\x32\x63.yandex.cloud.monitoring.v3.MultiSourceChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle\"g\n\tLineStyle\x12\x1a\n\x16LINE_STYLE_UNSPECIFIED\x10\x00\x12\x14\n\x10LINE_STYLE_SOLID\x10\x01\x12\x13\n\x0fLINE_STYLE_DASH\x10\x02\x12\x13\n\x0fLINE_STYLE_DOTS\x10\x03\"b\n\rYaxisPosition\x12\x1e\n\x1aYAXIS_POSITION_UNSPECIFIED\x10\x00\x12\x17\n\x13YAXIS_POSITION_LEFT\x10\x01\x12\x18\n\x14YAXIS_POSITION_RIGHT\x10\x02\"\xd9\x01\n\x17SeriesVisualizationType\x12)\n%SERIES_VISUALIZATION_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eSERIES_VISUALIZATION_TYPE_LINE\x10\x01\x12#\n\x1fSERIES_VISUALIZATION_TYPE_STACK\x10\x02\x12$\n SERIES_VISUALIZATION_TYPE_COLUMN\x10\x03\x12$\n SERIES_VISUALIZATION_TYPE_POINTS\x10\x04\x42\x06\n\x04type\x1a\xe2\x02\n\x0fOverrideMatcher\x12P\n\x05query\x18\x01 \x01(\x0b\x32?.yandex.cloud.monitoring.v3.MultiSourceChartWidget.QueryMatcherH\x00\x12N\n\x04line\x18\x02 \x01(\x0b\x32>.yandex.cloud.monitoring.v3.MultiSourceChartWidget.LineMatcherH\x00\x12R\n\x06regexp\x18\x03 \x01(\x0b\x32@.yandex.cloud.monitoring.v3.MultiSourceChartWidget.RegExpMatcherH\x00\x12Q\n\x06values\x18\x04 \x01(\x0b\x32?.yandex.cloud.monitoring.v3.MultiSourceChartWidget.ValueMatcherH\x00\x42\x06\n\x04type\x1a\x1d\n\x0cQueryMatcher\x12\r\n\x05names\x18\x01 \x03(\t\x1a\x1f\n\x0bLineMatcher\x12\x10\n\x08line_ids\x18\x01 \x03(\t\x1a \n\rRegExpMatcher\x12\x0f\n\x07reg_exp\x18\x01 \x01(\t\x1a\x61\n\x0cValueMatcher\x12Q\n\nvalue_type\x18\x01 \x01(\x0e\x32=.yandex.cloud.monitoring.v3.MultiSourceChartWidget.ValuesType\x1a\x35\n\x12NameHidingSettings\x12\x10\n\x08positive\x18\x01 \x01(\x08\x12\r\n\x05names\x18\x02 \x03(\t\x1a>\n\x0eRepeatSettings\x12\x11\n\trepeat_by\x18\x01 \x03(\t\x12\x19\n\x11max_charts_in_row\x18\x02 \x01(\x03\"^\n\nValuesType\x12\x1b\n\x17VALUES_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15VALUES_TYPE_ALL_ZEROS\x10\x01\x12\x18\n\x14VALUES_TYPE_ALL_NULL\x10\x02\"\x99\x01\n\x0e\x46reezeDuration\x12\x1f\n\x1b\x46REEZE_DURATION_UNSPECIFIED\x10\x00\x12\x18\n\x14\x46REEZE_DURATION_HOUR\x10\x01\x12\x17\n\x13\x46REEZE_DURATION_DAY\x10\x02\x12\x18\n\x14\x46REEZE_DURATION_WEEK\x10\x03\x12\x19\n\x15\x46REEZE_DURATION_MONTH\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.multi_source_chart_widget_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_MULTISOURCECHARTWIDGET']._serialized_start=261
  _globals['_MULTISOURCECHARTWIDGET']._serialized_end=7444
  _globals['_MULTISOURCECHARTWIDGET_TARGET']._serialized_start=1048
  _globals['_MULTISOURCECHARTWIDGET_TARGET']._serialized_end=1529
  _globals['_MULTISOURCECHARTWIDGET_TARGET_MONITORINGTARGET']._serialized_start=1268
  _globals['_MULTISOURCECHARTWIDGET_TARGET_MONITORINGTARGET']._serialized_end=1374
  _globals['_MULTISOURCECHARTWIDGET_TARGET_PROMETHEUSTARGET']._serialized_start=1377
  _globals['_MULTISOURCECHARTWIDGET_TARGET_PROMETHEUSTARGET']._serialized_end=1519
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE']._serialized_start=1532
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE']._serialized_end=1945
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_MONITORINGDATASOURCE']._serialized_start=1782
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_MONITORINGDATASOURCE']._serialized_end=1880
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_PROMETHEUSDATASOURCE']._serialized_start=1882
  _globals['_MULTISOURCECHARTWIDGET_DATASOURCE_PROMETHEUSDATASOURCE']._serialized_end=1930
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS']._serialized_start=1948
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS']._serialized_end=5361
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS']._serialized_start=2708
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS']._serialized_end=4084
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME']._serialized_start=3538
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_AUTOMATICCOLORSCHEME']._serialized_end=3560
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME']._serialized_start=3562
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_STANDARDCOLORSCHEME']._serialized_end=3583
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME']._serialized_start=3585
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_GRADIENTCOLORSCHEME']._serialized_end=3690
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_HASHCOLORSCHEME']._serialized_start=3692
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_HASHCOLORSCHEME']._serialized_end=3709
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_CONSTANTCOLORSCHEME']._serialized_start=3711
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_CONSTANTCOLORSCHEME']._serialized_end=3747
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME']._serialized_start=3750
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME']._serialized_end=4074
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME_AGGREGATION']._serialized_start=3926
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_COLORSCHEMESETTINGS_THRESHOLDSCOLORSCHEME_AGGREGATION']._serialized_end=4074
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS']._serialized_start=4086
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_HEATMAPSETTINGS']._serialized_end=4187
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS']._serialized_start=4190
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXIS']._serialized_end=4445
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS']._serialized_start=4448
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISSETTINGS']._serialized_end=4652
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE']._serialized_start=4655
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_VISUALIZATIONTYPE']._serialized_end=4957
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE']._serialized_start=4959
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_INTERPOLATE']._serialized_end=5070
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE']._serialized_start=5072
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_YAXISTYPE']._serialized_end=5162
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION']._serialized_start=5165
  _globals['_MULTISOURCECHARTWIDGET_VISUALIZATIONSETTINGS_SERIESAGGREGATION']._serialized_end=5361
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES']._serialized_start=5364
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES']._serialized_end=6519
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS']._serialized_start=5641
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS']._serialized_end=6191
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS_LINESTYLE']._serialized_start=6088
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESOVERRIDESETTINGS_LINESTYLE']._serialized_end=6191
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION']._serialized_start=6193
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_YAXISPOSITION']._serialized_end=6291
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE']._serialized_start=6294
  _globals['_MULTISOURCECHARTWIDGET_SERIESOVERRIDES_SERIESVISUALIZATIONTYPE']._serialized_end=6511
  _globals['_MULTISOURCECHARTWIDGET_OVERRIDEMATCHER']._serialized_start=6522
  _globals['_MULTISOURCECHARTWIDGET_OVERRIDEMATCHER']._serialized_end=6876
  _globals['_MULTISOURCECHARTWIDGET_QUERYMATCHER']._serialized_start=6878
  _globals['_MULTISOURCECHARTWIDGET_QUERYMATCHER']._serialized_end=6907
  _globals['_MULTISOURCECHARTWIDGET_LINEMATCHER']._serialized_start=6909
  _globals['_MULTISOURCECHARTWIDGET_LINEMATCHER']._serialized_end=6940
  _globals['_MULTISOURCECHARTWIDGET_REGEXPMATCHER']._serialized_start=6942
  _globals['_MULTISOURCECHARTWIDGET_REGEXPMATCHER']._serialized_end=6974
  _globals['_MULTISOURCECHARTWIDGET_VALUEMATCHER']._serialized_start=6976
  _globals['_MULTISOURCECHARTWIDGET_VALUEMATCHER']._serialized_end=7073
  _globals['_MULTISOURCECHARTWIDGET_NAMEHIDINGSETTINGS']._serialized_start=7075
  _globals['_MULTISOURCECHARTWIDGET_NAMEHIDINGSETTINGS']._serialized_end=7128
  _globals['_MULTISOURCECHARTWIDGET_REPEATSETTINGS']._serialized_start=7130
  _globals['_MULTISOURCECHARTWIDGET_REPEATSETTINGS']._serialized_end=7192
  _globals['_MULTISOURCECHARTWIDGET_VALUESTYPE']._serialized_start=7194
  _globals['_MULTISOURCECHARTWIDGET_VALUESTYPE']._serialized_end=7288
  _globals['_MULTISOURCECHARTWIDGET_FREEZEDURATION']._serialized_start=7291
  _globals['_MULTISOURCECHARTWIDGET_FREEZEDURATION']._serialized_end=7444
# @@protoc_insertion_point(module_scope)
