# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ytsaurus/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ytsaurus/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/ytsaurus/v1/cluster.proto\x12\x18yandex.cloud.ytsaurus.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1dyandex/cloud/validation.proto\"\xc6\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12=\n\x06labels\x18\x06 \x03(\x0b\x32-.yandex.cloud.ytsaurus.v1.Cluster.LabelsEntry\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x08 \x03(\t\x12\x33\n\x04spec\x18\t \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.ClusterSpec\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12.\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nupdated_by\x18\r \x01(\t\x12\x38\n\x06status\x18\x0e \x01(\x0e\x32(.yandex.cloud.ytsaurus.v1.Cluster.Status\x12\x38\n\x06health\x18\x0f \x01(\x0e\x32(.yandex.cloud.ytsaurus.v1.Cluster.Health\x12>\n\tendpoints\x18\x10 \x01(\x0b\x32+.yandex.cloud.ytsaurus.v1.Cluster.Endpoints\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8e\x01\n\tEndpoints\x12\n\n\x02ui\x18\x01 \x01(\t\x12$\n\x1c\x65xternal_http_proxy_balancer\x18\x02 \x01(\t\x12!\n\x19internal_http_proxy_alias\x18\x03 \x01(\t\x12 \n\x18internal_rpc_proxy_alias\x18\x04 \x01(\tJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"\x87\x01\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08STOPPING\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08UPDATING\x10\x07\x12\x0c\n\x08\x44\x45LETING\x10\x08\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xf5\x01\n\x0bStorageSpec\x12:\n\x03hdd\x18\x01 \x01(\x0b\x32-.yandex.cloud.ytsaurus.v1.StorageSpec.HddSpec\x12:\n\x03ssd\x18\x02 \x01(\x0b\x32-.yandex.cloud.ytsaurus.v1.StorageSpec.SsdSpec\x1a/\n\x07HddSpec\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\x12\r\n\x05\x63ount\x18\x03 \x01(\x03J\x04\x08\x01\x10\x02\x1a=\n\x07SsdSpec\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05\x63ount\x18\x04 \x01(\x03J\x04\x08\x01\x10\x02\"\xfa\x03\n\x0b\x43omputeSpec\x12\x0e\n\x06preset\x18\x01 \x01(\t\x12=\n\x05\x64isks\x18\x02 \x03(\x0b\x32..yandex.cloud.ytsaurus.v1.ComputeSpec.DiskSpec\x12G\n\x0cscale_policy\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.ytsaurus.v1.ComputeSpec.ScalePolicy\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a<\n\x08\x44iskSpec\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07size_gb\x18\x02 \x01(\x03\x12\x11\n\tlocations\x18\x03 \x03(\t\x1a\x86\x02\n\x0bScalePolicy\x12M\n\x05\x66ixed\x18\x01 \x01(\x0b\x32<.yandex.cloud.ytsaurus.v1.ComputeSpec.ScalePolicy.FixedScaleH\x00\x12K\n\x04\x61uto\x18\x02 \x01(\x0b\x32;.yandex.cloud.ytsaurus.v1.ComputeSpec.ScalePolicy.AutoScaleH\x00\x1a\x1a\n\nFixedScale\x12\x0c\n\x04size\x18\x01 \x01(\x03\x1a/\n\tAutoScale\x12\x10\n\x08min_size\x18\x01 \x01(\x03\x12\x10\n\x08max_size\x18\x02 \x01(\x03\x42\x0e\n\x06policy\x12\x04\xc0\xc1\x31\x01\"$\n\rHttpProxySpec\x12\r\n\x05\x63ount\x18\x02 \x01(\x03J\x04\x08\x01\x10\x02\"#\n\x0cRpcProxySpec\x12\r\n\x05\x63ount\x18\x02 \x01(\x03J\x04\x08\x01\x10\x02\"+\n\nTabletSpec\x12\x0e\n\x06preset\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"w\n\tProxySpec\x12\x35\n\x04http\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ytsaurus.v1.HttpProxySpec\x12\x33\n\x03rpc\x18\x02 \x01(\x0b\x32&.yandex.cloud.ytsaurus.v1.RpcProxySpec\"9\n\x08OdinSpec\x12-\n\nchecks_ttl\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x99\x02\n\x0b\x43lusterSpec\x12\x36\n\x07storage\x18\x01 \x01(\x0b\x32%.yandex.cloud.ytsaurus.v1.StorageSpec\x12\x36\n\x07\x63ompute\x18\x02 \x03(\x0b\x32%.yandex.cloud.ytsaurus.v1.ComputeSpec\x12\x34\n\x06tablet\x18\x03 \x01(\x0b\x32$.yandex.cloud.ytsaurus.v1.TabletSpec\x12\x32\n\x05proxy\x18\x04 \x01(\x0b\x32#.yandex.cloud.ytsaurus.v1.ProxySpec\x12\x30\n\x04odin\x18\x05 \x01(\x0b\x32\".yandex.cloud.ytsaurus.v1.OdinSpecBe\n\x1cyandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ytsaurus.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034yandex.cloud.api.ytsaurus.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/ytsaurus/v1;ytsaurus'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_COMPUTESPEC_SCALEPOLICY'].oneofs_by_name['policy']._loaded_options = None
  _globals['_COMPUTESPEC_SCALEPOLICY'].oneofs_by_name['policy']._serialized_options = b'\300\3011\001'
  _globals['_CLUSTER']._serialized_start=165
  _globals['_CLUSTER']._serialized_end=1131
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=738
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=783
  _globals['_CLUSTER_ENDPOINTS']._serialized_start=786
  _globals['_CLUSTER_ENDPOINTS']._serialized_end=928
  _globals['_CLUSTER_STATUS']._serialized_start=931
  _globals['_CLUSTER_STATUS']._serialized_end=1066
  _globals['_CLUSTER_HEALTH']._serialized_start=1068
  _globals['_CLUSTER_HEALTH']._serialized_end=1131
  _globals['_STORAGESPEC']._serialized_start=1134
  _globals['_STORAGESPEC']._serialized_end=1379
  _globals['_STORAGESPEC_HDDSPEC']._serialized_start=1269
  _globals['_STORAGESPEC_HDDSPEC']._serialized_end=1316
  _globals['_STORAGESPEC_SSDSPEC']._serialized_start=1318
  _globals['_STORAGESPEC_SSDSPEC']._serialized_end=1379
  _globals['_COMPUTESPEC']._serialized_start=1382
  _globals['_COMPUTESPEC']._serialized_end=1888
  _globals['_COMPUTESPEC_DISKSPEC']._serialized_start=1563
  _globals['_COMPUTESPEC_DISKSPEC']._serialized_end=1623
  _globals['_COMPUTESPEC_SCALEPOLICY']._serialized_start=1626
  _globals['_COMPUTESPEC_SCALEPOLICY']._serialized_end=1888
  _globals['_COMPUTESPEC_SCALEPOLICY_FIXEDSCALE']._serialized_start=1797
  _globals['_COMPUTESPEC_SCALEPOLICY_FIXEDSCALE']._serialized_end=1823
  _globals['_COMPUTESPEC_SCALEPOLICY_AUTOSCALE']._serialized_start=1825
  _globals['_COMPUTESPEC_SCALEPOLICY_AUTOSCALE']._serialized_end=1872
  _globals['_HTTPPROXYSPEC']._serialized_start=1890
  _globals['_HTTPPROXYSPEC']._serialized_end=1926
  _globals['_RPCPROXYSPEC']._serialized_start=1928
  _globals['_RPCPROXYSPEC']._serialized_end=1963
  _globals['_TABLETSPEC']._serialized_start=1965
  _globals['_TABLETSPEC']._serialized_end=2008
  _globals['_PROXYSPEC']._serialized_start=2010
  _globals['_PROXYSPEC']._serialized_end=2129
  _globals['_ODINSPEC']._serialized_start=2131
  _globals['_ODINSPEC']._serialized_end=2188
  _globals['_CLUSTERSPEC']._serialized_start=2191
  _globals['_CLUSTERSPEC']._serialized_end=2472
# @@protoc_insertion_point(module_scope)
