"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2
import yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class WafProfileServiceStub:
    """A set of methods for managing WafProfile resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.GetWafProfileRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile,
    ]
    """Returns the specified WafProfile resource."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse,
    ]
    """Retrieves the list of WafProfile resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.CreateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a WAF profile in the specified folder using the data specified in the request."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.UpdateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified WAF profile."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.DeleteWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified WAF profile."""

class WafProfileServiceAsyncStub:
    """A set of methods for managing WafProfile resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.GetWafProfileRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile,
    ]
    """Returns the specified WafProfile resource."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesRequest,
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse,
    ]
    """Retrieves the list of WafProfile resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.CreateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a WAF profile in the specified folder using the data specified in the request."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.UpdateWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified WAF profile."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.DeleteWafProfileRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified WAF profile."""

class WafProfileServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing WafProfile resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.GetWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile, collections.abc.Awaitable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_pb2.WafProfile]]:
        """Returns the specified WafProfile resource."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse, collections.abc.Awaitable[yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.ListWafProfilesResponse]]:
        """Retrieves the list of WafProfile resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.CreateWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a WAF profile in the specified folder using the data specified in the request."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.UpdateWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified WAF profile."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.smartwebsecurity.v1.waf.waf_profile_service_pb2.DeleteWafProfileRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified WAF profile."""

def add_WafProfileServiceServicer_to_server(servicer: WafProfileServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
