# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/monitoring/v3/link_item.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/monitoring/v3/link_item.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.monitoring.v3 import link_pb2 as yandex_dot_cloud_dot_monitoring_dot_v3_dot_link__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/monitoring/v3/link_item.proto\x12\x1ayandex.cloud.monitoring.v3\x1a%yandex/cloud/monitoring/v3/link.proto\"\xd6\x01\n\x08LinkItem\x12\x30\n\x04link\x18\x01 \x01(\x0b\x32 .yandex.cloud.monitoring.v3.LinkH\x00\x12?\n\x05group\x18\x02 \x01(\x0b\x32..yandex.cloud.monitoring.v3.LinkItem.LinkGroupH\x00\x1aO\n\tLinkGroup\x12\r\n\x05title\x18\x01 \x01(\t\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.yandex.cloud.monitoring.v3.LinkItemB\x06\n\x04typeBk\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.monitoring.v3.link_item_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring'
  _globals['_LINKITEM']._serialized_start=114
  _globals['_LINKITEM']._serialized_end=328
  _globals['_LINKITEM_LINKGROUP']._serialized_start=241
  _globals['_LINKITEM_LINKGROUP']._serialized_end=320
# @@protoc_insertion_point(module_scope)
