# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/batch_inference/v1/inference_options.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/batch_inference/v1/inference_options.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/ai/batch_inference/v1/inference_options.proto\x12\"yandex.cloud.ai.batch_inference.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1dyandex/cloud/validation.proto\"\xb5\x02\n\x16\x42\x61tchCompletionRequest\x12\x17\n\tmodel_uri\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\x11source_dataset_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12Q\n\x12\x63ompletion_options\x18\x03 \x01(\x0b\x32\x35.yandex.cloud.ai.batch_inference.v1.CompletionOptions\x12\x1c\n\x14\x64\x61ta_logging_enabled\x18\x04 \x01(\x08\x12\x15\n\x0bjson_object\x18\x05 \x01(\x08H\x00\x12\x45\n\x0bjson_schema\x18\x06 \x01(\x0b\x32..yandex.cloud.ai.batch_inference.v1.JsonSchemaH\x00\x42\x12\n\x10StructuredOutput\"\xc8\x01\n\x11\x43ompletionOptions\x12\x31\n\x0btemperature\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12/\n\nmax_tokens\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12O\n\x11reasoning_options\x18\x03 \x01(\x0b\x32\x34.yandex.cloud.ai.batch_inference.v1.ReasoningOptions\"\xb7\x01\n\x10ReasoningOptions\x12P\n\x04mode\x18\x01 \x01(\x0e\x32\x42.yandex.cloud.ai.batch_inference.v1.ReasoningOptions.ReasoningMode\"Q\n\rReasoningMode\x12\x1e\n\x1aREASONING_MODE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\x12\n\x0e\x45NABLED_HIDDEN\x10\x02\"5\n\nJsonSchema\x12\'\n\x06schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructBu\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.batch_inference.v1.inference_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&yandex.cloud.api.ai.batch_inference.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/batch_inference/v1;fomo'
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['model_uri']._loaded_options = None
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['model_uri']._serialized_options = b'\350\3071\001'
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['source_dataset_id']._loaded_options = None
  _globals['_BATCHCOMPLETIONREQUEST'].fields_by_name['source_dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_BATCHCOMPLETIONREQUEST']._serialized_start=192
  _globals['_BATCHCOMPLETIONREQUEST']._serialized_end=501
  _globals['_COMPLETIONOPTIONS']._serialized_start=504
  _globals['_COMPLETIONOPTIONS']._serialized_end=704
  _globals['_REASONINGOPTIONS']._serialized_start=707
  _globals['_REASONINGOPTIONS']._serialized_end=890
  _globals['_REASONINGOPTIONS_REASONINGMODE']._serialized_start=809
  _globals['_REASONINGOPTIONS_REASONINGMODE']._serialized_end=890
  _globals['_JSONSCHEMA']._serialized_start=892
  _globals['_JSONSCHEMA']._serialized_end=945
# @@protoc_insertion_point(module_scope)
