"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.compute.v1.host_group_pb2
import yandex.cloud.compute.v1.host_group_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HostGroupServiceStub:
    """A set of methods for managing groups of dedicated hosts."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.GetHostGroupRequest,
        yandex.cloud.compute.v1.host_group_pb2.HostGroup,
    ]
    """Returns the specified host group."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse,
    ]
    """Retrieves the list of host groups in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.CreateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a host group in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified host group."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.DeleteHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified host group."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse,
    ]
    """Lists operations for the specified host group."""

    ListInstances: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse,
    ]
    """Lists instances that belongs to the specified host group."""

    ListHosts: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse,
    ]
    """Lists hosts that belongs to the specified host group."""

    UpdateHost: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update host"""

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the host group.
    """

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the host group."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the host group."""

class HostGroupServiceAsyncStub:
    """A set of methods for managing groups of dedicated hosts."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.GetHostGroupRequest,
        yandex.cloud.compute.v1.host_group_pb2.HostGroup,
    ]
    """Returns the specified host group."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse,
    ]
    """Retrieves the list of host groups in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.CreateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a host group in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified host group."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.DeleteHostGroupRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified host group."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse,
    ]
    """Lists operations for the specified host group."""

    ListInstances: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse,
    ]
    """Lists instances that belongs to the specified host group."""

    ListHosts: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsRequest,
        yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse,
    ]
    """Lists hosts that belongs to the specified host group."""

    UpdateHost: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupHostRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update host"""

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """access

    Lists access bindings for the host group.
    """

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the host group."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the host group."""

class HostGroupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing groups of dedicated hosts."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.GetHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_pb2.HostGroup, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_pb2.HostGroup]]:
        """Returns the specified host group."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupsResponse]]:
        """Retrieves the list of host groups in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.CreateHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a host group in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified host group."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.DeleteHostGroupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified host group."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupOperationsResponse]]:
        """Lists operations for the specified host group."""

    @abc.abstractmethod
    def ListInstances(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupInstancesResponse]]:
        """Lists instances that belongs to the specified host group."""

    @abc.abstractmethod
    def ListHosts(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse, collections.abc.Awaitable[yandex.cloud.compute.v1.host_group_service_pb2.ListHostGroupHostsResponse]]:
        """Lists hosts that belongs to the specified host group."""

    @abc.abstractmethod
    def UpdateHost(
        self,
        request: yandex.cloud.compute.v1.host_group_service_pb2.UpdateHostGroupHostRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update host"""

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """access

        Lists access bindings for the host group.
        """

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the host group."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the host group."""

def add_HostGroupServiceServicer_to_server(servicer: HostGroupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
