# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/sqlserver/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/sqlserver/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2016sp2_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2016sp2__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2017_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2017__pb2
from yandex.cloud.mdb.sqlserver.v1.config import sqlserver2019_pb2 as yandex_dot_cloud_dot_mdb_dot_sqlserver_dot_v1_dot_config_dot_sqlserver2019__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/mdb/sqlserver/v1/cluster.proto\x12\x1dyandex.cloud.mdb.sqlserver.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/type/timeofday.proto\x1a;yandex/cloud/mdb/sqlserver/v1/config/sqlserver2016sp2.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2017.proto\x1a\x38yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto\"\xd0\x07\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.LabelsEntry\x12G\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x32.yandex.cloud.mdb.sqlserver.v1.Cluster.Environment\x12=\n\nmonitoring\x18\x08 \x03(\x0b\x32).yandex.cloud.mdb.sqlserver.v1.Monitoring\x12<\n\x06\x63onfig\x18\t \x01(\x0b\x32,.yandex.cloud.mdb.sqlserver.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12=\n\x06health\x18\x0b \x01(\x0e\x32-.yandex.cloud.mdb.sqlserver.v1.Cluster.Health\x12=\n\x06status\x18\x0c \x01(\x0e\x32-.yandex.cloud.mdb.sqlserver.v1.Cluster.Status\x12\x1a\n\x12security_group_ids\x18\r \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x0e \x01(\x08\x12\x14\n\x0csqlcollation\x18\x0f \x01(\t\x12\x16\n\x0ehost_group_ids\x18\x10 \x03(\t\x12\x1a\n\x12service_account_id\x18\x11 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xcb\t\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x85\x01\n\x1bsqlserver_config_2016sp2std\x18\x02 \x01(\x0b\x32\x42.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2016sp2stdH\x00R\x1asqlserverConfig_2016sp2std\x12\x85\x01\n\x1bsqlserver_config_2016sp2ent\x18\x05 \x01(\x0b\x32\x42.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2016sp2entH\x00R\x1asqlserverConfig_2016sp2ent\x12|\n\x18sqlserver_config_2017std\x18\x08 \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2017stdH\x00R\x17sqlserverConfig_2017std\x12|\n\x18sqlserver_config_2017ent\x18\t \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2017entH\x00R\x17sqlserverConfig_2017ent\x12|\n\x18sqlserver_config_2019std\x18\n \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019stdH\x00R\x17sqlserverConfig_2019std\x12|\n\x18sqlserver_config_2019ent\x18\x0b \x01(\x0b\x32?.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019entH\x00R\x17sqlserverConfig_2019ent\x12;\n\tresources\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.Resources\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x04 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12\x35\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32%.yandex.cloud.mdb.sqlserver.v1.Access\x12`\n\x15secondary_connections\x18\x07 \x01(\x0e\x32\x41.yandex.cloud.mdb.sqlserver.v1.ClusterConfig.SecondaryConnections\"\x81\x01\n\x14SecondaryConnections\x12%\n!SECONDARY_CONNECTIONS_UNSPECIFIED\x10\x00\x12\x1d\n\x19SECONDARY_CONNECTIONS_OFF\x10\x01\x12#\n\x1fSECONDARY_CONNECTIONS_READ_ONLY\x10\x02\x42\x12\n\x10sqlserver_config\"\xc5\x03\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12;\n\tresources\x18\x04 \x01(\x0b\x32(.yandex.cloud.mdb.sqlserver.v1.Resources\x12\x36\n\x04role\x18\x05 \x01(\x0e\x32(.yandex.cloud.mdb.sqlserver.v1.Host.Role\x12:\n\x06health\x18\x06 \x01(\x0e\x32*.yandex.cloud.mdb.sqlserver.v1.Host.Health\x12\x38\n\x08services\x18\x07 \x03(\x0b\x32&.yandex.cloud.mdb.sqlserver.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\"1\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xe3\x01\n\x07Service\x12\x39\n\x04type\x18\x01 \x01(\x0e\x32+.yandex.cloud.mdb.sqlserver.v1.Service.Type\x12=\n\x06health\x18\x02 \x01(\x0e\x32-.yandex.cloud.mdb.sqlserver.v1.Service.Health\"+\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tSQLSERVER\x10\x01\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\",\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x42u\n!yandex.cloud.api.mdb.sqlserver.v1B\x03PSCZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.sqlserver.v1B\003PSCZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1;sqlserver'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=318
  _globals['_CLUSTER']._serialized_end=1294
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=986
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1031
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1033
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1106
  _globals['_CLUSTER_HEALTH']._serialized_start=1108
  _globals['_CLUSTER_HEALTH']._serialized_end=1171
  _globals['_CLUSTER_STATUS']._serialized_start=1173
  _globals['_CLUSTER_STATUS']._serialized_end=1294
  _globals['_MONITORING']._serialized_start=1296
  _globals['_MONITORING']._serialized_end=1357
  _globals['_CLUSTERCONFIG']._serialized_start=1360
  _globals['_CLUSTERCONFIG']._serialized_end=2587
  _globals['_CLUSTERCONFIG_SECONDARYCONNECTIONS']._serialized_start=2438
  _globals['_CLUSTERCONFIG_SECONDARYCONNECTIONS']._serialized_end=2567
  _globals['_HOST']._serialized_start=2590
  _globals['_HOST']._serialized_end=3043
  _globals['_HOST_ROLE']._serialized_start=2929
  _globals['_HOST_ROLE']._serialized_end=2978
  _globals['_HOST_HEALTH']._serialized_start=1108
  _globals['_HOST_HEALTH']._serialized_end=1171
  _globals['_SERVICE']._serialized_start=3046
  _globals['_SERVICE']._serialized_end=3273
  _globals['_SERVICE_TYPE']._serialized_start=3179
  _globals['_SERVICE_TYPE']._serialized_end=3222
  _globals['_SERVICE_HEALTH']._serialized_start=1108
  _globals['_SERVICE_HEALTH']._serialized_end=1157
  _globals['_RESOURCES']._serialized_start=3275
  _globals['_RESOURCES']._serialized_end=3355
  _globals['_ACCESS']._serialized_start=3357
  _globals['_ACCESS']._serialized_end=3401
# @@protoc_insertion_point(module_scope)
