"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ClusterExtension(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Required. Extension name."""
    cluster_id: builtins.str
    """Required. ID of the ClickHouse cluster."""
    version: builtins.str
    """Required. Extension version."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        cluster_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "name", b"name", "version", b"version"]) -> None: ...

global___ClusterExtension = ClusterExtension

@typing.final
class ClusterExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTENSIONS_FIELD_NUMBER: builtins.int
    @property
    def extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterExtension]: ...
    def __init__(
        self,
        *,
        extensions: collections.abc.Iterable[global___ClusterExtension] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["extensions", b"extensions"]) -> None: ...

global___ClusterExtensions = ClusterExtensions
