# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/trino/v1/catalog.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/trino/v1/catalog.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#yandex/cloud/trino/v1/catalog.proto\x12\x15yandex.cloud.trino.v1\x1a\x1dyandex/cloud/validation.proto\"\xb8\x04\n\tConnector\x12\x34\n\x04hive\x18\x01 \x01(\x0b\x32$.yandex.cloud.trino.v1.HiveConnectorH\x00\x12:\n\x07iceberg\x18\x02 \x01(\x0b\x32\'.yandex.cloud.trino.v1.IcebergConnectorH\x00\x12?\n\ndelta_lake\x18\x03 \x01(\x0b\x32).yandex.cloud.trino.v1.DeltaLakeConnectorH\x00\x12@\n\npostgresql\x18\x04 \x01(\x0b\x32*.yandex.cloud.trino.v1.PostgresqlConnectorH\x00\x12@\n\nclickhouse\x18\x05 \x01(\x0b\x32*.yandex.cloud.trino.v1.ClickhouseConnectorH\x00\x12\x34\n\x04tpch\x18\x06 \x01(\x0b\x32$.yandex.cloud.trino.v1.TPCHConnectorH\x00\x12\x36\n\x05tpcds\x18\x07 \x01(\x0b\x32%.yandex.cloud.trino.v1.TPCDSConnectorH\x00\x12\x38\n\x06oracle\x18\x08 \x01(\x0b\x32&.yandex.cloud.trino.v1.OracleConnectorH\x00\x12>\n\tsqlserver\x18\t \x01(\x0b\x32).yandex.cloud.trino.v1.SQLServerConnectorH\x00\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xd8\x01\n\x07\x43\x61talog\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\tconnector\x18\x03 \x01(\x0b\x32 .yandex.cloud.trino.v1.Connector\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12:\n\x06labels\x18\x05 \x03(\x0b\x32*.yandex.cloud.trino.v1.Catalog.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc2\x02\n\x0b\x43\x61talogSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x39\n\tconnector\x18\x02 \x01(\x0b\x32 .yandex.cloud.trino.v1.ConnectorB\x04\xe8\xc7\x31\x01\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12{\n\x06labels\x18\x04 \x03(\x0b\x32..yandex.cloud.trino.v1.CatalogSpec.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc5\x02\n\x11\x43\x61talogUpdateSpec\x12(\n\x04name\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x33\n\tconnector\x18\x02 \x01(\x0b\x32 .yandex.cloud.trino.v1.Connector\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x81\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.trino.v1.CatalogUpdateSpec.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\tMetastore\x12>\n\x04hive\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.Metastore.HiveMetastoreH\x00\x1a\x32\n\rHiveMetastore\x12\r\n\x03uri\x18\x01 \x01(\tH\x00\x42\x12\n\nconnection\x12\x04\xc0\xc1\x31\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc2\x02\n\nFileSystem\x12<\n\x02s3\x18\x01 \x01(\x0b\x32..yandex.cloud.trino.v1.FileSystem.S3FileSystemH\x00\x12M\n\x0b\x65xternal_s3\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.trino.v1.FileSystem.ExternalS3FileSystemH\x00\x1a\x0e\n\x0cS3FileSystem\x1a\x88\x01\n\x14\x45xternalS3FileSystem\x12\x1c\n\x0e\x61ws_access_key\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1c\n\x0e\x61ws_secret_key\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x0c\x61ws_endpoint\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x18\n\naws_region\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xef\x02\n\rHiveConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32>.yandex.cloud.trino.v1.HiveConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x02\n\x10IcebergConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xab\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x41.yandex.cloud.trino.v1.IcebergConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x02\n\x12\x44\x65ltaLakeConnector\x12\x39\n\tmetastore\x18\x01 \x01(\x0b\x32 .yandex.cloud.trino.v1.MetastoreB\x04\xe8\xc7\x31\x01\x12;\n\nfilesystem\x18\x02 \x01(\x0b\x32!.yandex.cloud.trino.v1.FileSystemB\x04\xe8\xc7\x31\x01\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x03 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.DeltaLakeConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdb\x05\n\x14PostgresqlConnection\x12K\n\non_premise\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.PostgresqlConnection.OnPremiseH\x00\x12[\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32=.yandex.cloud.trino.v1.PostgresqlConnection.ConnectionManagerH\x00\x1a\xa5\x01\n\tOnPremise\x12\x44\n\x0e\x63onnection_url\x18\x01 \x01(\tB,\xe8\xc7\x31\x01\xf2\xc7\x31$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe2\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb8\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32W.yandex.cloud.trino.v1.PostgresqlConnection.ConnectionManager.ConnectionPropertiesEntryB@\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x12\x12\t[a-zA-Z]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc4\x02\n\x13PostgresqlConnector\x12?\n\nconnection\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.PostgresqlConnection\x12\xae\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.trino.v1.PostgresqlConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x05\n\x14\x43lickhouseConnection\x12K\n\non_premise\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.trino.v1.ClickhouseConnection.OnPremiseH\x00\x12[\n\x12\x63onnection_manager\x18\x02 \x01(\x0b\x32=.yandex.cloud.trino.v1.ClickhouseConnection.ConnectionManagerH\x00\x1a\xa5\x01\n\tOnPremise\x12\x44\n\x0e\x63onnection_url\x18\x01 \x01(\tB,\xe8\xc7\x31\x01\xf2\xc7\x31$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128\x1a\xe3\x02\n\x11\x43onnectionManager\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04\x31-50\x12\x30\n\x08\x64\x61tabase\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\xb9\x01\n\x15\x63onnection_properties\x18\x03 \x03(\x0b\x32W.yandex.cloud.trino.v1.ClickhouseConnection.ConnectionManager.ConnectionPropertiesEntryBA\xf2\xc7\x31\x14[-_0-9a-zA-Z.,:\\/_]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x13\x12\n[a-zA-Z_]*\x1a\x05\x31-128\x1a;\n\x19\x43onnectionPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc4\x02\n\x13\x43lickhouseConnector\x12?\n\nconnection\x18\x01 \x01(\x0b\x32+.yandex.cloud.trino.v1.ClickhouseConnection\x12\xae\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x44.yandex.cloud.trino.v1.ClickhouseConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf7\x01\n\rTPCHConnector\x12\xa8\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32>.yandex.cloud.trino.v1.TPCHConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf9\x01\n\x0eTPCDSConnector\x12\xa9\x01\n\x15\x61\x64\x64itional_properties\x18\x01 \x03(\x0b\x32?.yandex.cloud.trino.v1.TPCDSConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x02\n\x10OracleConnection\x12G\n\non_premise\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.trino.v1.OracleConnection.OnPremiseH\x00\x1a\x99\x01\n\tOnPremise\x12\x38\n\x0e\x63onnection_url\x18\x01 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x18^jdbc:[a-z0-9]+:(?s:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xb8\x02\n\x0fOracleConnector\x12;\n\nconnection\x18\x01 \x01(\x0b\x32\'.yandex.cloud.trino.v1.OracleConnection\x12\xaa\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32@.yandex.cloud.trino.v1.OracleConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x02\n\x13SQLServerConnection\x12J\n\non_premise\x18\x01 \x01(\x0b\x32\x34.yandex.cloud.trino.v1.SQLServerConnection.OnPremiseH\x00\x1a\x99\x01\n\tOnPremise\x12\x38\n\x0e\x63onnection_url\x18\x01 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x18^jdbc:[a-z0-9]+:(?s:.*)$\x12\x31\n\tuser_name\x18\x02 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63\x12\x1f\n\x08password\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x30-128B\x0c\n\x04type\x12\x04\xc0\xc1\x31\x01\"\xc1\x02\n\x12SQLServerConnector\x12>\n\nconnection\x18\x01 \x01(\x0b\x32*.yandex.cloud.trino.v1.SQLServerConnection\x12\xad\x01\n\x15\x61\x64\x64itional_properties\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.trino.v1.SQLServerConnector.AdditionalPropertiesEntryBI\xf2\xc7\x31\x15[-_0-9a-zA-Z.,:\\/_ ]*\x82\xc8\x31\x05<=256\x8a\xc8\x31\x05<=128\xb2\xc8\x31\x1a\x12\x11[a-z][-_0-9a-z.]*\x1a\x05\x31-128\x1a;\n\x19\x41\x64\x64itionalPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\\\n\x19yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trinob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.trino.v1.catalog_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.trino.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/trino/v1;trino'
  _globals['_CONNECTOR'].oneofs_by_name['type']._loaded_options = None
  _globals['_CONNECTOR'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_CATALOG_LABELSENTRY']._loaded_options = None
  _globals['_CATALOG_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGSPEC_LABELSENTRY']._loaded_options = None
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CATALOGSPEC'].fields_by_name['connector']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['connector']._serialized_options = b'\350\3071\001'
  _globals['_CATALOGSPEC'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGSPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_CATALOGSPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._loaded_options = None
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['name']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['name']._serialized_options = b'\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['description']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CATALOGUPDATESPEC'].fields_by_name['labels']._loaded_options = None
  _globals['_CATALOGUPDATESPEC'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_METASTORE_HIVEMETASTORE'].oneofs_by_name['connection']._loaded_options = None
  _globals['_METASTORE_HIVEMETASTORE'].oneofs_by_name['connection']._serialized_options = b'\300\3011\001'
  _globals['_METASTORE'].oneofs_by_name['type']._loaded_options = None
  _globals['_METASTORE'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_access_key']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_access_key']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_secret_key']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_secret_key']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_endpoint']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_endpoint']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_region']._loaded_options = None
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM'].fields_by_name['aws_region']._serialized_options = b'\350\3071\001'
  _globals['_FILESYSTEM'].oneofs_by_name['type']._loaded_options = None
  _globals['_FILESYSTEM'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_HIVECONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_HIVECONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_HIVECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_HIVECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_ICEBERGCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_ICEBERGCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['metastore']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['metastore']._serialized_options = b'\350\3071\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['filesystem']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['filesystem']._serialized_options = b'\350\3071\001'
  _globals['_DELTALAKECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_DELTALAKECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\022\022\t[a-zA-Z]*\032\0051-128'
  _globals['_POSTGRESQLCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_POSTGRESQLCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_POSTGRESQLCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_POSTGRESQLCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071$^jdbc:[a-z0-9]+://(?:.+:\\d+)/(?:.*)$'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_id']._serialized_options = b'\350\3071\001\212\3101\0041-50'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['database']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER'].fields_by_name['connection_properties']._serialized_options = b'\362\3071\024[-_0-9a-zA-Z.,:\\/_]*\202\3101\005<=256\212\3101\005<=128\262\3101\023\022\n[a-zA-Z_]*\032\0051-128'
  _globals['_CLICKHOUSECONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_CLICKHOUSECONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_CLICKHOUSECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_CLICKHOUSECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TPCHCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_TPCHCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_TPCDSCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_TPCDSCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071\030^jdbc:[a-z0-9]+:(?s:.*)$'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_ORACLECONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_ORACLECONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_ORACLECONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_ORACLECONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_ORACLECONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['connection_url']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['connection_url']._serialized_options = b'\350\3071\001\362\3071\030^jdbc:[a-z0-9]+:(?s:.*)$'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['user_name']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['user_name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['password']._loaded_options = None
  _globals['_SQLSERVERCONNECTION_ONPREMISE'].fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0050-128'
  _globals['_SQLSERVERCONNECTION'].oneofs_by_name['type']._loaded_options = None
  _globals['_SQLSERVERCONNECTION'].oneofs_by_name['type']._serialized_options = b'\300\3011\001'
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._loaded_options = None
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_SQLSERVERCONNECTOR'].fields_by_name['additional_properties']._loaded_options = None
  _globals['_SQLSERVERCONNECTOR'].fields_by_name['additional_properties']._serialized_options = b'\362\3071\025[-_0-9a-zA-Z.,:\\/_ ]*\202\3101\005<=256\212\3101\005<=128\262\3101\032\022\021[a-z][-_0-9a-z.]*\032\0051-128'
  _globals['_CONNECTOR']._serialized_start=94
  _globals['_CONNECTOR']._serialized_end=662
  _globals['_CATALOG']._serialized_start=665
  _globals['_CATALOG']._serialized_end=881
  _globals['_CATALOG_LABELSENTRY']._serialized_start=836
  _globals['_CATALOG_LABELSENTRY']._serialized_end=881
  _globals['_CATALOGSPEC']._serialized_start=884
  _globals['_CATALOGSPEC']._serialized_end=1206
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_start=836
  _globals['_CATALOGSPEC_LABELSENTRY']._serialized_end=881
  _globals['_CATALOGUPDATESPEC']._serialized_start=1209
  _globals['_CATALOGUPDATESPEC']._serialized_end=1534
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_start=836
  _globals['_CATALOGUPDATESPEC_LABELSENTRY']._serialized_end=881
  _globals['_METASTORE']._serialized_start=1537
  _globals['_METASTORE']._serialized_end=1678
  _globals['_METASTORE_HIVEMETASTORE']._serialized_start=1614
  _globals['_METASTORE_HIVEMETASTORE']._serialized_end=1664
  _globals['_FILESYSTEM']._serialized_start=1681
  _globals['_FILESYSTEM']._serialized_end=2003
  _globals['_FILESYSTEM_S3FILESYSTEM']._serialized_start=1836
  _globals['_FILESYSTEM_S3FILESYSTEM']._serialized_end=1850
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM']._serialized_start=1853
  _globals['_FILESYSTEM_EXTERNALS3FILESYSTEM']._serialized_end=1989
  _globals['_HIVECONNECTOR']._serialized_start=2006
  _globals['_HIVECONNECTOR']._serialized_end=2373
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_HIVECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_ICEBERGCONNECTOR']._serialized_start=2376
  _globals['_ICEBERGCONNECTOR']._serialized_end=2749
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_ICEBERGCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_DELTALAKECONNECTOR']._serialized_start=2752
  _globals['_DELTALAKECONNECTOR']._serialized_end=3129
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_DELTALAKECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_POSTGRESQLCONNECTION']._serialized_start=3132
  _globals['_POSTGRESQLCONNECTION']._serialized_end=3863
  _globals['_POSTGRESQLCONNECTION_ONPREMISE']._serialized_start=3327
  _globals['_POSTGRESQLCONNECTION_ONPREMISE']._serialized_end=3492
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER']._serialized_start=3495
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER']._serialized_end=3849
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=3790
  _globals['_POSTGRESQLCONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=3849
  _globals['_POSTGRESQLCONNECTOR']._serialized_start=3866
  _globals['_POSTGRESQLCONNECTOR']._serialized_end=4190
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_POSTGRESQLCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_CLICKHOUSECONNECTION']._serialized_start=4193
  _globals['_CLICKHOUSECONNECTION']._serialized_end=4925
  _globals['_CLICKHOUSECONNECTION_ONPREMISE']._serialized_start=3327
  _globals['_CLICKHOUSECONNECTION_ONPREMISE']._serialized_end=3492
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER']._serialized_start=4556
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER']._serialized_end=4911
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_start=3790
  _globals['_CLICKHOUSECONNECTION_CONNECTIONMANAGER_CONNECTIONPROPERTIESENTRY']._serialized_end=3849
  _globals['_CLICKHOUSECONNECTOR']._serialized_start=4928
  _globals['_CLICKHOUSECONNECTOR']._serialized_end=5252
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_CLICKHOUSECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_TPCHCONNECTOR']._serialized_start=5255
  _globals['_TPCHCONNECTOR']._serialized_end=5502
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_TPCHCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_TPCDSCONNECTOR']._serialized_start=5505
  _globals['_TPCDSCONNECTOR']._serialized_end=5754
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_TPCDSCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_ORACLECONNECTION']._serialized_start=5757
  _globals['_ORACLECONNECTION']._serialized_end=6018
  _globals['_ORACLECONNECTION_ONPREMISE']._serialized_start=5851
  _globals['_ORACLECONNECTION_ONPREMISE']._serialized_end=6004
  _globals['_ORACLECONNECTOR']._serialized_start=6021
  _globals['_ORACLECONNECTOR']._serialized_end=6333
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_ORACLECONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
  _globals['_SQLSERVERCONNECTION']._serialized_start=6336
  _globals['_SQLSERVERCONNECTION']._serialized_end=6603
  _globals['_SQLSERVERCONNECTION_ONPREMISE']._serialized_start=5851
  _globals['_SQLSERVERCONNECTION_ONPREMISE']._serialized_end=6004
  _globals['_SQLSERVERCONNECTOR']._serialized_start=6606
  _globals['_SQLSERVERCONNECTOR']._serialized_end=6927
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_start=2314
  _globals['_SQLSERVERCONNECTOR_ADDITIONALPROPERTIESENTRY']._serialized_end=2373
# @@protoc_insertion_point(module_scope)
