# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.ai.tuning.v1 import tuning_service_pb2 as yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/ai/tuning/v1/tuning_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TuningServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tune = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Tune',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/List',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.FromString,
                _registered_method=True)
        self.Describe = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Describe',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.FromString,
                _registered_method=True)
        self.Cancel = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Cancel',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.FromString,
                _registered_method=True)
        self.GetMetricsUrl = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/GetMetricsUrl',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.FromString,
                _registered_method=True)
        self.GetOptions = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/GetOptions',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.FromString,
                _registered_method=True)
        self.ListErrors = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/ListErrors',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsResponse.FromString,
                _registered_method=True)
        self.CreateDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/CreateDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftResponse.FromString,
                _registered_method=True)
        self.UpdateDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/UpdateDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftResponse.FromString,
                _registered_method=True)
        self.DeleteDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/DeleteDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftResponse.FromString,
                _registered_method=True)
        self.TuneDraft = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/TuneDraft',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuneDraftRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Archive = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/Archive',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ArchiveTuningRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.EnableBilling = channel.unary_unary(
                '/yandex.cloud.ai.tuning.v1.TuningService/EnableBilling',
                request_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.EnableBillingRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class TuningServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Tune(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Describe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Cancel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMetricsUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOptions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListErrors(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TuneDraft(self, request, context):
        """Unimplemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Archive(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EnableBilling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TuningServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Tune': grpc.unary_unary_rpc_method_handler(
                    servicer.Tune,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.SerializeToString,
            ),
            'Describe': grpc.unary_unary_rpc_method_handler(
                    servicer.Describe,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.SerializeToString,
            ),
            'Cancel': grpc.unary_unary_rpc_method_handler(
                    servicer.Cancel,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.SerializeToString,
            ),
            'GetMetricsUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMetricsUrl,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.SerializeToString,
            ),
            'GetOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOptions,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.SerializeToString,
            ),
            'ListErrors': grpc.unary_unary_rpc_method_handler(
                    servicer.ListErrors,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsResponse.SerializeToString,
            ),
            'CreateDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftResponse.SerializeToString,
            ),
            'UpdateDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftResponse.SerializeToString,
            ),
            'DeleteDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftResponse.SerializeToString,
            ),
            'TuneDraft': grpc.unary_unary_rpc_method_handler(
                    servicer.TuneDraft,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuneDraftRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Archive': grpc.unary_unary_rpc_method_handler(
                    servicer.Archive,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ArchiveTuningRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'EnableBilling': grpc.unary_unary_rpc_method_handler(
                    servicer.EnableBilling,
                    request_deserializer=yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.EnableBillingRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.ai.tuning.v1.TuningService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.ai.tuning.v1.TuningService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TuningService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Tune(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Tune',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuningRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/List',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListTuningsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Describe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Describe',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DescribeTuningResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Cancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Cancel',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CancelTuningResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetMetricsUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/GetMetricsUrl',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetMetricsUrlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/GetOptions',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.GetOptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListErrors(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/ListErrors',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ListErrorsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/CreateDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.CreateTuningDraftResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/UpdateDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.UpdateTuningDraftResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/DeleteDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.DeleteTuningDraftResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TuneDraft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/TuneDraft',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.TuneDraftRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Archive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/Archive',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.ArchiveTuningRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EnableBilling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.ai.tuning.v1.TuningService/EnableBilling',
            yandex_dot_cloud_dot_ai_dot_tuning_dot_v1_dot_tuning__service__pb2.EnableBillingRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
