# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop_image_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop_image_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.clouddesktop.v1 import desktop_image_pb2 as yandex_dot_cloud_dot_clouddesktop_dot_v1_dot_desktop__image__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/clouddesktop/v1/desktop_image_service.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x30yandex/cloud/clouddesktop/v1/desktop_image.proto\x1a google/protobuf/field_mask.proto\"\xb8\x01\n\x18ListDesktopImagesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x15 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x16 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x17 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x18 \x01(\tB\t\x8a\xc8\x31\x05<=100J\x04\x08\x02\x10\x15\"\x82\x01\n\x19ListDesktopImagesResponse\x12\x46\n\x0e\x64\x65sktop_images\x18\x01 \x03(\x0b\x32..yandex.cloud.clouddesktop.v1.api.DesktopImage\x12\x17\n\x0fnext_page_token\x18\x16 \x01(\tJ\x04\x08\x02\x10\x16\"|\n\x17\x43opyDesktopImageRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x08image_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x03\x10\x08\"\xc2\x02\n\x19UpdateDesktopImageRequest\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x16\n\x04name\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x94\x01\n\x06labels\x18\x04 \x03(\x0b\x32G.yandex.cloud.clouddesktop.v1.api.UpdateDesktopImageRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x16\x43opyFromDesktopRequest\x12\x1b\n\tfolder_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12 \n\ndesktop_id\x18\x08 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50J\x04\x08\x05\x10\x08\",\n\x18\x43opyDesktopImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"+\n\x17\x43opyFromDesktopMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"3\n\x19\x44\x65leteDesktopImageRequest\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\".\n\x1a\x44\x65leteDesktopImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"0\n\x16GetDesktopImageRequest\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x1aUpdateDesktopImageMetadata\x12\x16\n\x08image_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xfe\x08\n\x13\x44\x65sktopImageService\x12\xa1\x01\n\x04List\x12:.yandex.cloud.clouddesktop.v1.api.ListDesktopImagesRequest\x1a;.yandex.cloud.clouddesktop.v1.api.ListDesktopImagesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/cloud-desktop/v1/images\x12\x9c\x01\n\x03Get\x12\x38.yandex.cloud.clouddesktop.v1.api.GetDesktopImageRequest\x1a..yandex.cloud.clouddesktop.v1.api.DesktopImage\"+\x82\xd3\xe4\x93\x02%\x12#/cloud-desktop/v1/images/{image_id}\x12\xba\x01\n\x04\x43opy\x12\x39.yandex.cloud.clouddesktop.v1.api.CopyDesktopImageRequest\x1a!.yandex.cloud.operation.Operation\"T\xb2\xd2*(\n\x18\x43opyDesktopImageMetadata\x12\x0c\x44\x65sktopImage\x82\xd3\xe4\x93\x02\"\"\x1d/cloud-desktop/v1/images:copy:\x01*\x12\xc6\x01\n\x06Update\x12;.yandex.cloud.clouddesktop.v1.api.UpdateDesktopImageRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2**\n\x1aUpdateDesktopImageMetadata\x12\x0c\x44\x65sktopImage\x82\xd3\xe4\x93\x02(2#/cloud-desktop/v1/images/{image_id}:\x01*\x12\xce\x01\n\x0f\x43opyFromDesktop\x12\x38.yandex.cloud.clouddesktop.v1.api.CopyFromDesktopRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*\'\n\x17\x43opyFromDesktopMetadata\x12\x0c\x44\x65sktopImage\x82\xd3\xe4\x93\x02-\"(/cloud-desktop/v1/images:copyFromDesktop:\x01*\x12\xcc\x01\n\x06\x44\x65lete\x12;.yandex.cloud.clouddesktop.v1.api.DeleteDesktopImageRequest\x1a!.yandex.cloud.operation.Operation\"b\xb2\xd2*3\n\x1a\x44\x65leteDesktopImageMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02%*#/cloud-desktop/v1/images/{image_id}Bq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_image_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTDESKTOPIMAGESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_COPYDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\004<=50'
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['desktop_id']._loaded_options = None
  _globals['_COPYFROMDESKTOPREQUEST'].fields_by_name['desktop_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_DELETEDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_GETDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_GETDESKTOPIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEDESKTOPIMAGEMETADATA'].fields_by_name['image_id']._loaded_options = None
  _globals['_UPDATEDESKTOPIMAGEMETADATA'].fields_by_name['image_id']._serialized_options = b'\350\3071\001'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/cloud-desktop/v1/images'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002%\022#/cloud-desktop/v1/images/{image_id}'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Copy']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Copy']._serialized_options = b'\262\322*(\n\030CopyDesktopImageMetadata\022\014DesktopImage\202\323\344\223\002\"\"\035/cloud-desktop/v1/images:copy:\001*'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateDesktopImageMetadata\022\014DesktopImage\202\323\344\223\002(2#/cloud-desktop/v1/images/{image_id}:\001*'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['CopyFromDesktop']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['CopyFromDesktop']._serialized_options = b'\262\322*\'\n\027CopyFromDesktopMetadata\022\014DesktopImage\202\323\344\223\002-\"(/cloud-desktop/v1/images:copyFromDesktop:\001*'
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_DESKTOPIMAGESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteDesktopImageMetadata\022\025google.protobuf.Empty\202\323\344\223\002%*#/cloud-desktop/v1/images/{image_id}'
  _globals['_LISTDESKTOPIMAGESREQUEST']._serialized_start=314
  _globals['_LISTDESKTOPIMAGESREQUEST']._serialized_end=498
  _globals['_LISTDESKTOPIMAGESRESPONSE']._serialized_start=501
  _globals['_LISTDESKTOPIMAGESRESPONSE']._serialized_end=631
  _globals['_COPYDESKTOPIMAGEREQUEST']._serialized_start=633
  _globals['_COPYDESKTOPIMAGEREQUEST']._serialized_end=757
  _globals['_UPDATEDESKTOPIMAGEREQUEST']._serialized_start=760
  _globals['_UPDATEDESKTOPIMAGEREQUEST']._serialized_end=1082
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._serialized_start=1037
  _globals['_UPDATEDESKTOPIMAGEREQUEST_LABELSENTRY']._serialized_end=1082
  _globals['_COPYFROMDESKTOPREQUEST']._serialized_start=1084
  _globals['_COPYFROMDESKTOPREQUEST']._serialized_end=1201
  _globals['_COPYDESKTOPIMAGEMETADATA']._serialized_start=1203
  _globals['_COPYDESKTOPIMAGEMETADATA']._serialized_end=1247
  _globals['_COPYFROMDESKTOPMETADATA']._serialized_start=1249
  _globals['_COPYFROMDESKTOPMETADATA']._serialized_end=1292
  _globals['_DELETEDESKTOPIMAGEREQUEST']._serialized_start=1294
  _globals['_DELETEDESKTOPIMAGEREQUEST']._serialized_end=1345
  _globals['_DELETEDESKTOPIMAGEMETADATA']._serialized_start=1347
  _globals['_DELETEDESKTOPIMAGEMETADATA']._serialized_end=1393
  _globals['_GETDESKTOPIMAGEREQUEST']._serialized_start=1395
  _globals['_GETDESKTOPIMAGEREQUEST']._serialized_end=1443
  _globals['_UPDATEDESKTOPIMAGEMETADATA']._serialized_start=1445
  _globals['_UPDATEDESKTOPIMAGEMETADATA']._serialized_end=1497
  _globals['_DESKTOPIMAGESERVICE']._serialized_start=1500
  _globals['_DESKTOPIMAGESERVICE']._serialized_end=2650
# @@protoc_insertion_point(module_scope)
