# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/extension_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/extension_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.clickhouse.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_clickhouse_dot_v1_dot_extension__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/clickhouse/v1/extension_service.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a.yandex/cloud/mdb/clickhouse/v1/extension.proto\"X\n\x13GetExtensionRequest\x12$\n\x0e\x65xtension_name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x1b\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"r\n\x15ListExtensionsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1b\n\tfolder_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"p\n\x16ListExtensionsResponse\x12=\n\nextensions\x18\x01 \x03(\x0b\x32).yandex.cloud.mdb.clickhouse.v1.Extension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd9\x02\n\x10\x45xtensionService\x12\xa1\x01\n\x03Get\x12\x33.yandex.cloud.mdb.clickhouse.v1.GetExtensionRequest\x1a).yandex.cloud.mdb.clickhouse.v1.Extension\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-clickhouse/v1/extensions/{extension_name}\x12\xa0\x01\n\x04List\x12\x35.yandex.cloud.mdb.clickhouse.v1.ListExtensionsRequest\x1a\x36.yandex.cloud.mdb.clickhouse.v1.ListExtensionsResponse\")\x82\xd3\xe4\x93\x02#\x12!/managed-clickhouse/v1/extensionsBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.extension_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['extension_name']._loaded_options = None
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['extension_name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETEXTENSIONREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTEXTENSIONSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_EXTENSIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0024\0222/managed-clickhouse/v1/extensions/{extension_name}'
  _globals['_EXTENSIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_EXTENSIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/managed-clickhouse/v1/extensions'
  _globals['_GETEXTENSIONREQUEST']._serialized_start=199
  _globals['_GETEXTENSIONREQUEST']._serialized_end=287
  _globals['_LISTEXTENSIONSREQUEST']._serialized_start=289
  _globals['_LISTEXTENSIONSREQUEST']._serialized_end=403
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_start=405
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_end=517
  _globals['_EXTENSIONSERVICE']._serialized_start=520
  _globals['_EXTENSIONSERVICE']._serialized_end=865
# @@protoc_insertion_point(module_scope)
