# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/storage/v1/presign_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/storage/v1/presign_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/storage/v1/presign_service.proto\x12\x17yandex.cloud.storage.v1\"\xed\x01\n\x14PresignObjectRequest\x12\x0f\n\x07\x65xpires\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12K\n\x07headers\x18\x04 \x03(\x0b\x32:.yandex.cloud.storage.v1.PresignObjectRequest.HeadersEntry\x12\x12\n\nversion_id\x18\x05 \x01(\t\x12\x15\n\ras_attachment\x18\x06 \x01(\x08\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x7f\n\x12PresignURLsRequest\x12\x13\n\x0b\x62ucket_name\x18\x01 \x01(\t\x12\x14\n\x0cpresign_host\x18\x02 \x01(\t\x12>\n\x07objects\x18\x03 \x03(\x0b\x32-.yandex.cloud.storage.v1.PresignObjectRequest\"#\n\x13PresignURLsResponse\x12\x0c\n\x04urls\x18\x01 \x03(\t2u\n\x0ePresignService\x12\x63\n\x06\x43reate\x12+.yandex.cloud.storage.v1.PresignURLsRequest\x1a,.yandex.cloud.storage.v1.PresignURLsResponseBb\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.presign_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_PRESIGNOBJECTREQUEST']._serialized_start=75
  _globals['_PRESIGNOBJECTREQUEST']._serialized_end=312
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._serialized_start=266
  _globals['_PRESIGNOBJECTREQUEST_HEADERSENTRY']._serialized_end=312
  _globals['_PRESIGNURLSREQUEST']._serialized_start=314
  _globals['_PRESIGNURLSREQUEST']._serialized_end=441
  _globals['_PRESIGNURLSRESPONSE']._serialized_start=443
  _globals['_PRESIGNURLSRESPONSE']._serialized_end=478
  _globals['_PRESIGNSERVICE']._serialized_start=480
  _globals['_PRESIGNSERVICE']._serialized_end=597
# @@protoc_insertion_point(module_scope)
