"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    EMAIL_FIELD_NUMBER: builtins.int
    PICTURE_FIELD_NUMBER: builtins.int
    PICTURE_DATA_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the user."""
    name: builtins.str
    """Name of the user."""
    email: builtins.str
    """Email of the user."""
    picture: builtins.str
    """URL to the user's profile picture."""
    picture_data: builtins.str
    """An image content of the user's profile picture."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        email: builtins.str = ...,
        picture: builtins.str = ...,
        picture_data: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["email", b"email", "id", b"id", "name", b"name", "picture", b"picture", "picture_data", b"picture_data"]) -> None: ...

global___User = User
