"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.clouddesktop.v1.desktop_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class UpdatePropertiesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """To get the desktop ID use a [DesktopService.List] request."""
    name: builtins.str
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "labels", b"labels", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdatePropertiesRequest = UpdatePropertiesRequest

@typing.final
class StartRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StartRequest = StartRequest

@typing.final
class StopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StopRequest = StopRequest

@typing.final
class UpdateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___UpdateRequest = UpdateRequest

@typing.final
class GetDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop resource to return.

    To get the desktop ID use a [DesktopService.List] request.
    """
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___GetDesktopRequest = GetDesktopRequest

@typing.final
class GetRdpFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop resource to return.

    To get the desktop ID use a [DesktopService.List] request.
    """
    @property
    def user(self) -> yandex.cloud.clouddesktop.v1.desktop_pb2.User:
        """User of the desktop."""

    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        user: yandex.cloud.clouddesktop.v1.desktop_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "user", b"user"]) -> None: ...

global___GetRdpFileRequest = GetRdpFileRequest

@typing.final
class RdpFileResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class HeadersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    HEADERS_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.str
    """RDP file content."""
    @property
    def headers(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """HTTP headers mapping."""

    def __init__(
        self,
        *,
        headers: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        content: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content", "headers", b"headers"]) -> None: ...

global___RdpFileResponse = RdpFileResponse

@typing.final
class ListDesktopsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a DesktopGroup in.

    To get a folder ID make a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDesktopsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDesktopsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Desktop.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. Value or a list of values to compare against the values of the field.
    """
    order_by: builtins.str
    """Sorting the list by [Desktop.name], [Desktop.created_at] and [Desktop.status] fields.
    The default sorting order is ascending.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDesktopsRequest = ListDesktopsRequest

@typing.final
class ListDesktopsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDesktopsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDesktopsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def desktops(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop]:
        """List of desktops."""

    def __init__(
        self,
        *,
        desktops: collections.abc.Iterable[yandex.cloud.clouddesktop.v1.desktop_pb2.Desktop] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktops", b"desktops", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDesktopsResponse = ListDesktopsResponse

@typing.final
class ListDesktopOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListDesktopOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListDesktopOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [Desktop.name] field.
    2. An operator. Can be either `=` or `!=` for single values, `IN` or `NOT IN` for lists of values.
    3. Value or a list of values to compare against the values of the field.
    """
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDesktopOperationsRequest = ListDesktopOperationsRequest

@typing.final
class ListDesktopOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListDesktopOperationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListDesktopOperationsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified desktop."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListDesktopOperationsResponse = ListDesktopOperationsResponse

@typing.final
class CreateDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_GROUP_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    USERS_FIELD_NUMBER: builtins.int
    desktop_group_id: builtins.str
    """ID of the desktop group."""
    subnet_id: builtins.str
    """ID of the subnet for desktop."""
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.clouddesktop.v1.desktop_pb2.User]:
        """List of users."""

    def __init__(
        self,
        *,
        desktop_group_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        users: collections.abc.Iterable[yandex.cloud.clouddesktop.v1.desktop_pb2.User] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_group_id", b"desktop_group_id", "subnet_id", b"subnet_id", "users", b"users"]) -> None: ...

global___CreateDesktopRequest = CreateDesktopRequest

@typing.final
class CreateDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop that is being created."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___CreateDesktopMetadata = CreateDesktopMetadata

@typing.final
class DeleteDesktopRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop to delete."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___DeleteDesktopRequest = DeleteDesktopRequest

@typing.final
class DeleteDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop that is being deleted."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___DeleteDesktopMetadata = DeleteDesktopMetadata

@typing.final
class ResetPasswordRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    @property
    def user(self) -> yandex.cloud.clouddesktop.v1.desktop_pb2.User:
        """User of the desktop."""

    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
        user: yandex.cloud.clouddesktop.v1.desktop_pb2.User | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id", "user", b"user"]) -> None: ...

global___ResetPasswordRequest = ResetPasswordRequest

@typing.final
class ResetPasswordResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PASSWORD_FIELD_NUMBER: builtins.int
    password: builtins.str
    """Generated password"""
    def __init__(
        self,
        *,
        password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["password", b"password"]) -> None: ...

global___ResetPasswordResponse = ResetPasswordResponse

@typing.final
class RestartRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___RestartRequest = RestartRequest

@typing.final
class RestartDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    """ID of the desktop."""
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___RestartDesktopMetadata = RestartDesktopMetadata

@typing.final
class UpdateDesktopPropertiesMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___UpdateDesktopPropertiesMetadata = UpdateDesktopPropertiesMetadata

@typing.final
class StartDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StartDesktopMetadata = StartDesktopMetadata

@typing.final
class StopDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___StopDesktopMetadata = StopDesktopMetadata

@typing.final
class UpdateDesktopMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESKTOP_ID_FIELD_NUMBER: builtins.int
    desktop_id: builtins.str
    def __init__(
        self,
        *,
        desktop_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["desktop_id", b"desktop_id"]) -> None: ...

global___UpdateDesktopMetadata = UpdateDesktopMetadata
