# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/v1/external_instance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/v1/external_instance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nByandex/cloud/marketplace/licensemanager/v1/external_instance.proto\x12*yandex.cloud.marketplace.licensemanager.v1\"\xef\x02\n\x10\x45xternalInstance\x12\x0c\n\x04name\x18\x01 \x01(\t\x12`\n\nproperties\x18\x15 \x03(\x0b\x32L.yandex.cloud.marketplace.licensemanager.v1.ExternalInstance.PropertiesEntry\x12X\n\x0csubscription\x18\x16 \x01(\x0b\x32@.yandex.cloud.marketplace.licensemanager.v1.ExternalSubscriptionH\x00\x12N\n\x07license\x18\x17 \x01(\x0b\x32;.yandex.cloud.marketplace.licensemanager.v1.ExternalLicenseH\x00\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06vendorJ\x04\x08\x02\x10\x15\"[\n\x14\x45xternalSubscription\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\x12\x12\n\nlicense_id\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x63tivation_key\x18\x03 \x01(\t\"6\n\x0f\x45xternalLicense\x12\x12\n\nlicense_id\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\x42\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.v1.external_instance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager'
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._loaded_options = None
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._serialized_options = b'8\001'
  _globals['_EXTERNALINSTANCE']._serialized_start=115
  _globals['_EXTERNALINSTANCE']._serialized_end=482
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._serialized_start=417
  _globals['_EXTERNALINSTANCE_PROPERTIESENTRY']._serialized_end=466
  _globals['_EXTERNALSUBSCRIPTION']._serialized_start=484
  _globals['_EXTERNALSUBSCRIPTION']._serialized_end=575
  _globals['_EXTERNALLICENSE']._serialized_start=577
  _globals['_EXTERNALLICENSE']._serialized_end=631
# @@protoc_insertion_point(module_scope)
