"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.datasphere.v1.project_pb2
import yandex.cloud.datasphere.v1.project_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProjectServiceStub:
    """A set of methods for managing Project resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.CreateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a project in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.UpdateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified project."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.DeleteProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified project."""

    Open: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.OpenProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens the specified project."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetProjectRequest,
        yandex.cloud.datasphere.v1.project_pb2.Project,
    ]
    """Returns the specified project."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse,
    ]
    """Lists projects for the specified folder."""

    GetUnitBalance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse,
    ]
    """Returns the unit balance of the specified project."""

    SetUnitBalance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.SetUnitBalanceRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Sets the unit balance of the specified project."""

    Execute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ProjectExecutionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes code in the specified cell or notebook."""

class ProjectServiceAsyncStub:
    """A set of methods for managing Project resources."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.CreateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a project in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.UpdateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified project."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.DeleteProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified project."""

    Open: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.OpenProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens the specified project."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetProjectRequest,
        yandex.cloud.datasphere.v1.project_pb2.Project,
    ]
    """Returns the specified project."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse,
    ]
    """Lists projects for the specified folder."""

    GetUnitBalance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceRequest,
        yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse,
    ]
    """Returns the unit balance of the specified project."""

    SetUnitBalance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.SetUnitBalanceRequest,
        google.protobuf.empty_pb2.Empty,
    ]
    """Sets the unit balance of the specified project."""

    Execute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_service_pb2.ProjectExecutionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes code in the specified cell or notebook."""

class ProjectServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Project resources."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.CreateProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a project in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.UpdateProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified project."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.DeleteProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified project."""

    @abc.abstractmethod
    def Open(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.OpenProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Opens the specified project."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.GetProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_pb2.Project, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_pb2.Project]]:
        """Returns the specified project."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_service_pb2.ListProjectsResponse]]:
        """Lists projects for the specified folder."""

    @abc.abstractmethod
    def GetUnitBalance(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_service_pb2.GetUnitBalanceResponse]]:
        """Returns the unit balance of the specified project."""

    @abc.abstractmethod
    def SetUnitBalance(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.SetUnitBalanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Sets the unit balance of the specified project."""

    @abc.abstractmethod
    def Execute(
        self,
        request: yandex.cloud.datasphere.v1.project_service_pb2.ProjectExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Executes code in the specified cell or notebook."""

def add_ProjectServiceServicer_to_server(servicer: ProjectServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
