# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/speechsense/v1/analysis/points.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/speechsense/v1/analysis/points.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/speechsense/v1/analysis/points.proto\x12$yandex.cloud.speechsense.v1.analysis\x1a\x1egoogle/protobuf/wrappers.proto\"B\n\x06Points\x12\x38\n\x04quiz\x18\x01 \x03(\x0b\x32*.yandex.cloud.speechsense.v1.analysis.Quiz\"S\n\x04Quiz\x12\x0f\n\x07request\x18\x01 \x01(\t\x12.\n\x08response\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\n\n\x02id\x18\x03 \x01(\tB\x8d\x01\n(yandex.cloud.api.speechsense.v1.analysisB\x0bPointsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.analysis.points_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.speechsense.v1.analysisB\013PointsProtoZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1/analysis;speechsense'
  _globals['_POINTS']._serialized_start=123
  _globals['_POINTS']._serialized_end=189
  _globals['_QUIZ']._serialized_start=191
  _globals['_QUIZ']._serialized_end=274
# @@protoc_insertion_point(module_scope)
