# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/marketplace/licensemanager/v1/lock_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/marketplace/licensemanager/v1/lock_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.marketplace.licensemanager.v1 import lock_pb2 as yandex_dot_cloud_dot_marketplace_dot_licensemanager_dot_v1_dot_lock__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=yandex/cloud/marketplace/licensemanager/v1/lock_service.proto\x12*yandex.cloud.marketplace.licensemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/marketplace/licensemanager/v1/lock.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\'\n\x0eGetLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x11\x43reateLockRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"I\n\x11\x45nsureLockRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x43reateLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"%\n\x12\x45nsureLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"*\n\x11\x44\x65leteLockRequest\x12\x15\n\x07lock_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"%\n\x12\x44\x65leteLockMetadata\x12\x0f\n\x07lock_id\x18\x01 \x01(\t\"[\n#GetLockByInstanceAndResourceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x19\n\x0bresource_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\xbd\x01\n\x10ListLocksRequest\x12\x19\n\x0bresource_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tfolder_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\"m\n\x11ListLocksResponse\x12?\n\x05locks\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xbd\t\n\x0bLockService\x12\xac\x01\n\x03Get\x12:.yandex.cloud.marketplace.licensemanager.v1.GetLockRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"7\x82\xd3\xe4\x93\x02\x31\x12//marketplace/license-manager/v1/locks/{lock_id}\x12\xe5\x01\n\x18GetByInstanceAndResource\x12O.yandex.cloud.marketplace.licensemanager.v1.GetLockByInstanceAndResourceRequest\x1a\x30.yandex.cloud.marketplace.licensemanager.v1.Lock\"F\x82\xd3\xe4\x93\x02@\x12>/marketplace/license-manager/v1/locks:getByInstanceAndResource\x12\xb2\x01\n\x04List\x12<.yandex.cloud.marketplace.licensemanager.v1.ListLocksRequest\x1a=.yandex.cloud.marketplace.licensemanager.v1.ListLocksResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/marketplace/license-manager/v1/locks\x12\xba\x01\n\x06\x43reate\x12=.yandex.cloud.marketplace.licensemanager.v1.CreateLockRequest\x1a!.yandex.cloud.operation.Operation\"N\xb2\xd2*\x1a\n\x12\x43reateLockMetadata\x12\x04Lock\x82\xd3\xe4\x93\x02*\"%/marketplace/license-manager/v1/locks:\x01*\x12\xcf\x01\n\x06\x45nsure\x12=.yandex.cloud.marketplace.licensemanager.v1.EnsureLockRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*\x1a\n\x12\x45nsureLockMetadata\x12\x04Lock\x82\xd3\xe4\x93\x02?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\x01*\x12\xd2\x01\n\x06\x44\x65lete\x12=.yandex.cloud.marketplace.licensemanager.v1.DeleteLockRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*+\n\x12\x44\x65leteLockMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x31*//marketplace/license-manager/v1/locks/{lock_id}B\x8f\x01\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.marketplace.licensemanager.v1.lock_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n.yandex.cloud.api.marketplace.licensemanager.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/marketplace/licensemanager/v1;licensemanager'
  _globals['_GETLOCKREQUEST'].fields_by_name['lock_id']._loaded_options = None
  _globals['_GETLOCKREQUEST'].fields_by_name['lock_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATELOCKREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_CREATELOCKREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATELOCKREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATELOCKREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_ENSURELOCKREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_ENSURELOCKREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_ENSURELOCKREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ENSURELOCKREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETELOCKREQUEST'].fields_by_name['lock_id']._loaded_options = None
  _globals['_DELETELOCKREQUEST'].fields_by_name['lock_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['instance_id']._loaded_options = None
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['instance_id']._serialized_options = b'\350\3071\001'
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTLOCKSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTLOCKSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LOCKSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\0021\022//marketplace/license-manager/v1/locks/{lock_id}'
  _globals['_LOCKSERVICE'].methods_by_name['GetByInstanceAndResource']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['GetByInstanceAndResource']._serialized_options = b'\202\323\344\223\002@\022>/marketplace/license-manager/v1/locks:getByInstanceAndResource'
  _globals['_LOCKSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\'\022%/marketplace/license-manager/v1/locks'
  _globals['_LOCKSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\032\n\022CreateLockMetadata\022\004Lock\202\323\344\223\002*\"%/marketplace/license-manager/v1/locks:\001*'
  _globals['_LOCKSERVICE'].methods_by_name['Ensure']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Ensure']._serialized_options = b'\262\322*\032\n\022EnsureLockMetadata\022\004Lock\202\323\344\223\002?\":/marketplace/license-manager/v1/locks/{instance_id}:ensure:\001*'
  _globals['_LOCKSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_LOCKSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*+\n\022DeleteLockMetadata\022\025google.protobuf.Empty\202\323\344\223\0021*//marketplace/license-manager/v1/locks/{lock_id}'
  _globals['_GETLOCKREQUEST']._serialized_start=299
  _globals['_GETLOCKREQUEST']._serialized_end=338
  _globals['_CREATELOCKREQUEST']._serialized_start=340
  _globals['_CREATELOCKREQUEST']._serialized_end=413
  _globals['_ENSURELOCKREQUEST']._serialized_start=415
  _globals['_ENSURELOCKREQUEST']._serialized_end=488
  _globals['_CREATELOCKMETADATA']._serialized_start=490
  _globals['_CREATELOCKMETADATA']._serialized_end=527
  _globals['_ENSURELOCKMETADATA']._serialized_start=529
  _globals['_ENSURELOCKMETADATA']._serialized_end=566
  _globals['_DELETELOCKREQUEST']._serialized_start=568
  _globals['_DELETELOCKREQUEST']._serialized_end=610
  _globals['_DELETELOCKMETADATA']._serialized_start=612
  _globals['_DELETELOCKMETADATA']._serialized_end=649
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST']._serialized_start=651
  _globals['_GETLOCKBYINSTANCEANDRESOURCEREQUEST']._serialized_end=742
  _globals['_LISTLOCKSREQUEST']._serialized_start=745
  _globals['_LISTLOCKSREQUEST']._serialized_end=934
  _globals['_LISTLOCKSRESPONSE']._serialized_start=936
  _globals['_LISTLOCKSRESPONSE']._serialized_end=1045
  _globals['_LOCKSERVICE']._serialized_start=1048
  _globals['_LOCKSERVICE']._serialized_end=2261
# @@protoc_insertion_point(module_scope)
