"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.hardware_pool_pb2
import yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HardwarePoolServiceStub:
    """A set of methods to retrieve information about HardwarePool resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.GetHardwarePoolRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool,
    ]
    """Returns the specific HardwarePool resource.

    To get the list of available HardwarePool resource, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse,
    ]
    """Retrieves the list of HardwarePool resources."""

class HardwarePoolServiceAsyncStub:
    """A set of methods to retrieve information about HardwarePool resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.GetHardwarePoolRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool,
    ]
    """Returns the specific HardwarePool resource.

    To get the list of available HardwarePool resource, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsRequest,
        yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse,
    ]
    """Retrieves the list of HardwarePool resources."""

class HardwarePoolServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods to retrieve information about HardwarePool resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.GetHardwarePoolRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.hardware_pool_pb2.HardwarePool]]:
        """Returns the specific HardwarePool resource.

        To get the list of available HardwarePool resource, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.hardware_pool_service_pb2.ListHardwarePoolsResponse]]:
        """Retrieves the list of HardwarePool resources."""

def add_HardwarePoolServiceServicer_to_server(servicer: HardwarePoolServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
