# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/mdb/clickhouse/v1/cluster_extension.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\x1a\x1dyandex/cloud/validation.proto\"g\n\x10\x43lusterExtension\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12 \n\ncluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\x07version\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\"Y\n\x11\x43lusterExtensions\x12\x44\n\nextensions\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.mdb.clickhouse.v1.ClusterExtensionBs\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.cluster_extension_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_CLUSTEREXTENSION'].fields_by_name['name']._loaded_options = None
  _globals['_CLUSTEREXTENSION'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_CLUSTEREXTENSION'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CLUSTEREXTENSION'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CLUSTEREXTENSION'].fields_by_name['version']._loaded_options = None
  _globals['_CLUSTEREXTENSION'].fields_by_name['version']._serialized_options = b'\350\3071\001'
  _globals['_CLUSTEREXTENSION']._serialized_start=121
  _globals['_CLUSTEREXTENSION']._serialized_end=224
  _globals['_CLUSTEREXTENSIONS']._serialized_start=226
  _globals['_CLUSTEREXTENSIONS']._serialized_end=315
# @@protoc_insertion_point(module_scope)
