"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.monitoring.v3.downsampling_pb2
import yandex.cloud.monitoring.v3.thresholds_pb2
import yandex.cloud.monitoring.v3.unit_format_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ChartWidget(google.protobuf.message.Message):
    """Chart widget."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ValuesType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ValuesTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget._ValuesType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VALUES_TYPE_UNSPECIFIED: ChartWidget._ValuesType.ValueType  # 0
        VALUES_TYPE_ALL_ZEROS: ChartWidget._ValuesType.ValueType  # 1
        VALUES_TYPE_ALL_NULL: ChartWidget._ValuesType.ValueType  # 2

    class ValuesType(_ValuesType, metaclass=_ValuesTypeEnumTypeWrapper): ...
    VALUES_TYPE_UNSPECIFIED: ChartWidget.ValuesType.ValueType  # 0
    VALUES_TYPE_ALL_ZEROS: ChartWidget.ValuesType.ValueType  # 1
    VALUES_TYPE_ALL_NULL: ChartWidget.ValuesType.ValueType  # 2

    class _FreezeDuration:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _FreezeDurationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget._FreezeDuration.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        FREEZE_DURATION_UNSPECIFIED: ChartWidget._FreezeDuration.ValueType  # 0
        FREEZE_DURATION_HOUR: ChartWidget._FreezeDuration.ValueType  # 1
        """Last hour."""
        FREEZE_DURATION_DAY: ChartWidget._FreezeDuration.ValueType  # 2
        """Last day = last 24 hours."""
        FREEZE_DURATION_WEEK: ChartWidget._FreezeDuration.ValueType  # 3
        """Last 7 days."""
        FREEZE_DURATION_MONTH: ChartWidget._FreezeDuration.ValueType  # 4
        """Last 31 days."""

    class FreezeDuration(_FreezeDuration, metaclass=_FreezeDurationEnumTypeWrapper): ...
    FREEZE_DURATION_UNSPECIFIED: ChartWidget.FreezeDuration.ValueType  # 0
    FREEZE_DURATION_HOUR: ChartWidget.FreezeDuration.ValueType  # 1
    """Last hour."""
    FREEZE_DURATION_DAY: ChartWidget.FreezeDuration.ValueType  # 2
    """Last day = last 24 hours."""
    FREEZE_DURATION_WEEK: ChartWidget.FreezeDuration.ValueType  # 3
    """Last 7 days."""
    FREEZE_DURATION_MONTH: ChartWidget.FreezeDuration.ValueType  # 4
    """Last 31 days."""

    @typing.final
    class Queries(google.protobuf.message.Message):
        """Query settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing.final
        class Target(google.protobuf.message.Message):
            """Query target."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            QUERY_FIELD_NUMBER: builtins.int
            TEXT_MODE_FIELD_NUMBER: builtins.int
            HIDDEN_FIELD_NUMBER: builtins.int
            NAME_FIELD_NUMBER: builtins.int
            query: builtins.str
            """Required. Query."""
            text_mode: builtins.bool
            """Text mode."""
            hidden: builtins.bool
            """Checks that target is visible or invisible."""
            name: builtins.str
            """Name of the query."""
            def __init__(
                self,
                *,
                query: builtins.str = ...,
                text_mode: builtins.bool = ...,
                hidden: builtins.bool = ...,
                name: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["hidden", b"hidden", "name", b"name", "query", b"query", "text_mode", b"text_mode"]) -> None: ...

        TARGETS_FIELD_NUMBER: builtins.int
        DOWNSAMPLING_FIELD_NUMBER: builtins.int
        @property
        def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChartWidget.Queries.Target]:
            """Required. List of targets."""

        @property
        def downsampling(self) -> yandex.cloud.monitoring.v3.downsampling_pb2.Downsampling:
            """Required. Downsampling settings."""

        def __init__(
            self,
            *,
            targets: collections.abc.Iterable[global___ChartWidget.Queries.Target] | None = ...,
            downsampling: yandex.cloud.monitoring.v3.downsampling_pb2.Downsampling | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["downsampling", b"downsampling"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["downsampling", b"downsampling", "targets", b"targets"]) -> None: ...

    @typing.final
    class VisualizationSettings(google.protobuf.message.Message):
        """Visualization settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _VisualizationType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _VisualizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._VisualizationType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 0
            """Not specified (line by default)."""
            VISUALIZATION_TYPE_LINE: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 1
            """Line chart."""
            VISUALIZATION_TYPE_STACK: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 2
            """Stack chart."""
            VISUALIZATION_TYPE_COLUMN: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 3
            """Points as columns chart."""
            VISUALIZATION_TYPE_POINTS: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 4
            """Points."""
            VISUALIZATION_TYPE_PIE: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 5
            """Pie aggregation chart."""
            VISUALIZATION_TYPE_BARS: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 6
            """Bars aggregation chart."""
            VISUALIZATION_TYPE_DISTRIBUTION: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 7
            """Distribution aggregation chart."""
            VISUALIZATION_TYPE_HEATMAP: ChartWidget.VisualizationSettings._VisualizationType.ValueType  # 8
            """Heatmap aggregation chart."""

        class VisualizationType(_VisualizationType, metaclass=_VisualizationTypeEnumTypeWrapper):
            """Chart visualization type."""

        VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 0
        """Not specified (line by default)."""
        VISUALIZATION_TYPE_LINE: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 1
        """Line chart."""
        VISUALIZATION_TYPE_STACK: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 2
        """Stack chart."""
        VISUALIZATION_TYPE_COLUMN: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 3
        """Points as columns chart."""
        VISUALIZATION_TYPE_POINTS: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 4
        """Points."""
        VISUALIZATION_TYPE_PIE: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 5
        """Pie aggregation chart."""
        VISUALIZATION_TYPE_BARS: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 6
        """Bars aggregation chart."""
        VISUALIZATION_TYPE_DISTRIBUTION: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 7
        """Distribution aggregation chart."""
        VISUALIZATION_TYPE_HEATMAP: ChartWidget.VisualizationSettings.VisualizationType.ValueType  # 8
        """Heatmap aggregation chart."""

        class _Interpolate:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _InterpolateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._Interpolate.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            INTERPOLATE_UNSPECIFIED: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 0
            """Not specified (linear by default)."""
            INTERPOLATE_LINEAR: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 1
            """Linear."""
            INTERPOLATE_LEFT: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 2
            """Left."""
            INTERPOLATE_RIGHT: ChartWidget.VisualizationSettings._Interpolate.ValueType  # 3
            """Right."""

        class Interpolate(_Interpolate, metaclass=_InterpolateEnumTypeWrapper): ...
        INTERPOLATE_UNSPECIFIED: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 0
        """Not specified (linear by default)."""
        INTERPOLATE_LINEAR: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 1
        """Linear."""
        INTERPOLATE_LEFT: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 2
        """Left."""
        INTERPOLATE_RIGHT: ChartWidget.VisualizationSettings.Interpolate.ValueType  # 3
        """Right."""

        class _YaxisType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _YaxisTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._YaxisType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            YAXIS_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings._YaxisType.ValueType  # 0
            """Not specified (linear by default)."""
            YAXIS_TYPE_LINEAR: ChartWidget.VisualizationSettings._YaxisType.ValueType  # 1
            """Linear."""
            YAXIS_TYPE_LOGARITHMIC: ChartWidget.VisualizationSettings._YaxisType.ValueType  # 2
            """Logarithmic."""

        class YaxisType(_YaxisType, metaclass=_YaxisTypeEnumTypeWrapper):
            """Y axis type.
            N.B. _TYPE prefix is necessary to expect name clash with Interpolate LINEAR value.
            """

        YAXIS_TYPE_UNSPECIFIED: ChartWidget.VisualizationSettings.YaxisType.ValueType  # 0
        """Not specified (linear by default)."""
        YAXIS_TYPE_LINEAR: ChartWidget.VisualizationSettings.YaxisType.ValueType  # 1
        """Linear."""
        YAXIS_TYPE_LOGARITHMIC: ChartWidget.VisualizationSettings.YaxisType.ValueType  # 2
        """Logarithmic."""

        class _SeriesAggregation:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SeriesAggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings._SeriesAggregation.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SERIES_AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 0
            """Not specified (avg by default)."""
            SERIES_AGGREGATION_AVG: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 1
            """Average."""
            SERIES_AGGREGATION_MIN: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 2
            """Minimum."""
            SERIES_AGGREGATION_MAX: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 3
            """Maximum."""
            SERIES_AGGREGATION_LAST: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 4
            """Last non-NaN value."""
            SERIES_AGGREGATION_SUM: ChartWidget.VisualizationSettings._SeriesAggregation.ValueType  # 5
            """Sum."""

        class SeriesAggregation(_SeriesAggregation, metaclass=_SeriesAggregationEnumTypeWrapper): ...
        SERIES_AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 0
        """Not specified (avg by default)."""
        SERIES_AGGREGATION_AVG: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 1
        """Average."""
        SERIES_AGGREGATION_MIN: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 2
        """Minimum."""
        SERIES_AGGREGATION_MAX: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 3
        """Maximum."""
        SERIES_AGGREGATION_LAST: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 4
        """Last non-NaN value."""
        SERIES_AGGREGATION_SUM: ChartWidget.VisualizationSettings.SeriesAggregation.ValueType  # 5
        """Sum."""

        @typing.final
        class ColorSchemeSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            @typing.final
            class AutomaticColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class StandardColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class GradientColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                GREEN_VALUE_FIELD_NUMBER: builtins.int
                YELLOW_VALUE_FIELD_NUMBER: builtins.int
                RED_VALUE_FIELD_NUMBER: builtins.int
                VIOLET_VALUE_FIELD_NUMBER: builtins.int
                green_value: builtins.str
                """Gradient green value."""
                yellow_value: builtins.str
                """Gradient yellow value."""
                red_value: builtins.str
                """Gradient red value."""
                violet_value: builtins.str
                """Gradient violet_value."""
                def __init__(
                    self,
                    *,
                    green_value: builtins.str = ...,
                    yellow_value: builtins.str = ...,
                    red_value: builtins.str = ...,
                    violet_value: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["green_value", b"green_value", "red_value", b"red_value", "violet_value", b"violet_value", "yellow_value", b"yellow_value"]) -> None: ...

            @typing.final
            class HashColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                def __init__(
                    self,
                ) -> None: ...

            @typing.final
            class ConstantColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                COLOR_FIELD_NUMBER: builtins.int
                color: builtins.str
                def __init__(
                    self,
                    *,
                    color: builtins.str = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["color", b"color"]) -> None: ...

            @typing.final
            class ThresholdsColorScheme(google.protobuf.message.Message):
                DESCRIPTOR: google.protobuf.descriptor.Descriptor

                class _Aggregation:
                    ValueType = typing.NewType("ValueType", builtins.int)
                    V: typing_extensions.TypeAlias = ValueType

                class _AggregationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType], builtins.type):
                    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                    AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 0
                    AGGREGATION_LAST: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 1
                    AGGREGATION_MIN: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 2
                    AGGREGATION_MAX: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 3
                    AGGREGATION_AVG: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 4
                    AGGREGATION_SUM: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme._Aggregation.ValueType  # 5

                class Aggregation(_Aggregation, metaclass=_AggregationEnumTypeWrapper): ...
                AGGREGATION_UNSPECIFIED: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 0
                AGGREGATION_LAST: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 1
                AGGREGATION_MIN: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 2
                AGGREGATION_MAX: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 3
                AGGREGATION_AVG: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 4
                AGGREGATION_SUM: ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType  # 5

                AGGREGATION_FIELD_NUMBER: builtins.int
                aggregation: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType
                def __init__(
                    self,
                    *,
                    aggregation: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme.Aggregation.ValueType = ...,
                ) -> None: ...
                def ClearField(self, field_name: typing.Literal["aggregation", b"aggregation"]) -> None: ...

            AUTOMATIC_FIELD_NUMBER: builtins.int
            STANDARD_FIELD_NUMBER: builtins.int
            GRADIENT_FIELD_NUMBER: builtins.int
            HASH_FIELD_NUMBER: builtins.int
            THRESHOLDS_FIELD_NUMBER: builtins.int
            CONSTANT_FIELD_NUMBER: builtins.int
            @property
            def automatic(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme:
                """Automatic color scheme."""

            @property
            def standard(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme:
                """Standard color scheme."""

            @property
            def gradient(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme:
                """Gradient color scheme."""

            @property
            def hash(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorScheme:
                """Hash color scheme. Based on line name or value."""

            @property
            def thresholds(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme:
                """Threshold settings color scheme."""

            @property
            def constant(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ConstantColorScheme: ...
            def __init__(
                self,
                *,
                automatic: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.AutomaticColorScheme | None = ...,
                standard: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.StandardColorScheme | None = ...,
                gradient: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.GradientColorScheme | None = ...,
                hash: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.HashColorScheme | None = ...,
                thresholds: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ThresholdsColorScheme | None = ...,
                constant: global___ChartWidget.VisualizationSettings.ColorSchemeSettings.ConstantColorScheme | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["automatic", b"automatic", "constant", b"constant", "gradient", b"gradient", "hash", b"hash", "scheme", b"scheme", "standard", b"standard", "thresholds", b"thresholds"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["automatic", b"automatic", "constant", b"constant", "gradient", b"gradient", "hash", b"hash", "scheme", b"scheme", "standard", b"standard", "thresholds", b"thresholds"]) -> None: ...
            def WhichOneof(self, oneof_group: typing.Literal["scheme", b"scheme"]) -> typing.Literal["automatic", "standard", "gradient", "hash", "thresholds", "constant"] | None: ...

        @typing.final
        class HeatmapSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            GREEN_VALUE_FIELD_NUMBER: builtins.int
            YELLOW_VALUE_FIELD_NUMBER: builtins.int
            RED_VALUE_FIELD_NUMBER: builtins.int
            VIOLET_VALUE_FIELD_NUMBER: builtins.int
            green_value: builtins.str
            """Heatmap green value."""
            yellow_value: builtins.str
            """Heatmap yellow value."""
            red_value: builtins.str
            """Heatmap red value."""
            violet_value: builtins.str
            """Heatmap violet_value."""
            def __init__(
                self,
                *,
                green_value: builtins.str = ...,
                yellow_value: builtins.str = ...,
                red_value: builtins.str = ...,
                violet_value: builtins.str = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["green_value", b"green_value", "red_value", b"red_value", "violet_value", b"violet_value", "yellow_value", b"yellow_value"]) -> None: ...

        @typing.final
        class Yaxis(google.protobuf.message.Message):
            """Y axis settings."""

            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            TYPE_FIELD_NUMBER: builtins.int
            TITLE_FIELD_NUMBER: builtins.int
            MIN_FIELD_NUMBER: builtins.int
            MAX_FIELD_NUMBER: builtins.int
            UNIT_FORMAT_FIELD_NUMBER: builtins.int
            PRECISION_FIELD_NUMBER: builtins.int
            type: global___ChartWidget.VisualizationSettings.YaxisType.ValueType
            """Type."""
            title: builtins.str
            """Title or empty."""
            min: builtins.str
            """Min value in extended number format or empty."""
            max: builtins.str
            """Max value in extended number format or empty."""
            unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType
            """Unit format."""
            @property
            def precision(self) -> google.protobuf.wrappers_pb2.Int64Value:
                """Tick value precision (null as default, 0-7 in other cases)."""

            def __init__(
                self,
                *,
                type: global___ChartWidget.VisualizationSettings.YaxisType.ValueType = ...,
                title: builtins.str = ...,
                min: builtins.str = ...,
                max: builtins.str = ...,
                unit_format: yandex.cloud.monitoring.v3.unit_format_pb2.UnitFormat.ValueType = ...,
                precision: google.protobuf.wrappers_pb2.Int64Value | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["precision", b"precision"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["max", b"max", "min", b"min", "precision", b"precision", "title", b"title", "type", b"type", "unit_format", b"unit_format"]) -> None: ...

        @typing.final
        class YaxisSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            LEFT_FIELD_NUMBER: builtins.int
            RIGHT_FIELD_NUMBER: builtins.int
            @property
            def left(self) -> global___ChartWidget.VisualizationSettings.Yaxis:
                """Left Y axis settings."""

            @property
            def right(self) -> global___ChartWidget.VisualizationSettings.Yaxis:
                """Right Y axis settings."""

            def __init__(
                self,
                *,
                left: global___ChartWidget.VisualizationSettings.Yaxis | None = ...,
                right: global___ChartWidget.VisualizationSettings.Yaxis | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing.Literal["left", b"left", "right", b"right"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing.Literal["left", b"left", "right", b"right"]) -> None: ...

        TYPE_FIELD_NUMBER: builtins.int
        NORMALIZE_FIELD_NUMBER: builtins.int
        INTERPOLATE_FIELD_NUMBER: builtins.int
        AGGREGATION_FIELD_NUMBER: builtins.int
        COLOR_SCHEME_SETTINGS_FIELD_NUMBER: builtins.int
        HEATMAP_SETTINGS_FIELD_NUMBER: builtins.int
        YAXIS_SETTINGS_FIELD_NUMBER: builtins.int
        TITLE_FIELD_NUMBER: builtins.int
        SHOW_LABELS_FIELD_NUMBER: builtins.int
        type: global___ChartWidget.VisualizationSettings.VisualizationType.ValueType
        """Visualization type."""
        normalize: builtins.bool
        """Normalize."""
        interpolate: global___ChartWidget.VisualizationSettings.Interpolate.ValueType
        """Interpolate."""
        aggregation: global___ChartWidget.VisualizationSettings.SeriesAggregation.ValueType
        """Aggregation."""
        title: builtins.str
        """Inside chart title."""
        show_labels: builtins.bool
        """Show chart labels."""
        @property
        def color_scheme_settings(self) -> global___ChartWidget.VisualizationSettings.ColorSchemeSettings:
            """Color scheme settings."""

        @property
        def heatmap_settings(self) -> global___ChartWidget.VisualizationSettings.HeatmapSettings:
            """Heatmap settings."""

        @property
        def yaxis_settings(self) -> global___ChartWidget.VisualizationSettings.YaxisSettings:
            """Y axis settings."""

        def __init__(
            self,
            *,
            type: global___ChartWidget.VisualizationSettings.VisualizationType.ValueType = ...,
            normalize: builtins.bool = ...,
            interpolate: global___ChartWidget.VisualizationSettings.Interpolate.ValueType = ...,
            aggregation: global___ChartWidget.VisualizationSettings.SeriesAggregation.ValueType = ...,
            color_scheme_settings: global___ChartWidget.VisualizationSettings.ColorSchemeSettings | None = ...,
            heatmap_settings: global___ChartWidget.VisualizationSettings.HeatmapSettings | None = ...,
            yaxis_settings: global___ChartWidget.VisualizationSettings.YaxisSettings | None = ...,
            title: builtins.str = ...,
            show_labels: builtins.bool = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["color_scheme_settings", b"color_scheme_settings", "heatmap_settings", b"heatmap_settings", "yaxis_settings", b"yaxis_settings"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["aggregation", b"aggregation", "color_scheme_settings", b"color_scheme_settings", "heatmap_settings", b"heatmap_settings", "interpolate", b"interpolate", "normalize", b"normalize", "show_labels", b"show_labels", "title", b"title", "type", b"type", "yaxis_settings", b"yaxis_settings"]) -> None: ...

    @typing.final
    class SeriesOverrides(google.protobuf.message.Message):
        """Series override settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _YaxisPosition:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _YaxisPositionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.SeriesOverrides._YaxisPosition.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            YAXIS_POSITION_UNSPECIFIED: ChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 0
            """Not specified (left by default)."""
            YAXIS_POSITION_LEFT: ChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 1
            """Left."""
            YAXIS_POSITION_RIGHT: ChartWidget.SeriesOverrides._YaxisPosition.ValueType  # 2
            """Right."""

        class YaxisPosition(_YaxisPosition, metaclass=_YaxisPositionEnumTypeWrapper): ...
        YAXIS_POSITION_UNSPECIFIED: ChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 0
        """Not specified (left by default)."""
        YAXIS_POSITION_LEFT: ChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 1
        """Left."""
        YAXIS_POSITION_RIGHT: ChartWidget.SeriesOverrides.YaxisPosition.ValueType  # 2
        """Right."""

        class _SeriesVisualizationType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _SeriesVisualizationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            SERIES_VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 0
            """Not specified (line by default)."""
            SERIES_VISUALIZATION_TYPE_LINE: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 1
            """Line chart."""
            SERIES_VISUALIZATION_TYPE_STACK: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 2
            """Stack chart."""
            SERIES_VISUALIZATION_TYPE_COLUMN: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 3
            """Points as columns chart."""
            SERIES_VISUALIZATION_TYPE_POINTS: ChartWidget.SeriesOverrides._SeriesVisualizationType.ValueType  # 4
            """Points."""

        class SeriesVisualizationType(_SeriesVisualizationType, metaclass=_SeriesVisualizationTypeEnumTypeWrapper): ...
        SERIES_VISUALIZATION_TYPE_UNSPECIFIED: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 0
        """Not specified (line by default)."""
        SERIES_VISUALIZATION_TYPE_LINE: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 1
        """Line chart."""
        SERIES_VISUALIZATION_TYPE_STACK: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 2
        """Stack chart."""
        SERIES_VISUALIZATION_TYPE_COLUMN: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 3
        """Points as columns chart."""
        SERIES_VISUALIZATION_TYPE_POINTS: ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType  # 4
        """Points."""

        @typing.final
        class SeriesOverrideSettings(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            class _LineStyle:
                ValueType = typing.NewType("ValueType", builtins.int)
                V: typing_extensions.TypeAlias = ValueType

            class _LineStyleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType], builtins.type):
                DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
                LINE_STYLE_UNSPECIFIED: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 0
                LINE_STYLE_SOLID: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 1
                LINE_STYLE_DASH: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 2
                LINE_STYLE_DOTS: ChartWidget.SeriesOverrides.SeriesOverrideSettings._LineStyle.ValueType  # 3

            class LineStyle(_LineStyle, metaclass=_LineStyleEnumTypeWrapper): ...
            LINE_STYLE_UNSPECIFIED: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 0
            LINE_STYLE_SOLID: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 1
            LINE_STYLE_DASH: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 2
            LINE_STYLE_DOTS: ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType  # 3

            NAME_FIELD_NUMBER: builtins.int
            COLOR_FIELD_NUMBER: builtins.int
            TYPE_FIELD_NUMBER: builtins.int
            STACK_NAME_FIELD_NUMBER: builtins.int
            GROW_DOWN_FIELD_NUMBER: builtins.int
            YAXIS_POSITION_FIELD_NUMBER: builtins.int
            LINE_WIDTH_FIELD_NUMBER: builtins.int
            LINE_STYLE_FIELD_NUMBER: builtins.int
            name: builtins.str
            """Series name or empty."""
            color: builtins.str
            """Series color or empty."""
            type: global___ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType
            """Type."""
            stack_name: builtins.str
            """Stack name or empty."""
            grow_down: builtins.bool
            """Stack grow down."""
            yaxis_position: global___ChartWidget.SeriesOverrides.YaxisPosition.ValueType
            """Yaxis position."""
            line_width: builtins.int
            """Line Border Width"""
            line_style: global___ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType
            def __init__(
                self,
                *,
                name: builtins.str = ...,
                color: builtins.str = ...,
                type: global___ChartWidget.SeriesOverrides.SeriesVisualizationType.ValueType = ...,
                stack_name: builtins.str = ...,
                grow_down: builtins.bool = ...,
                yaxis_position: global___ChartWidget.SeriesOverrides.YaxisPosition.ValueType = ...,
                line_width: builtins.int = ...,
                line_style: global___ChartWidget.SeriesOverrides.SeriesOverrideSettings.LineStyle.ValueType = ...,
            ) -> None: ...
            def ClearField(self, field_name: typing.Literal["color", b"color", "grow_down", b"grow_down", "line_style", b"line_style", "line_width", b"line_width", "name", b"name", "stack_name", b"stack_name", "type", b"type", "yaxis_position", b"yaxis_position"]) -> None: ...

        NAME_FIELD_NUMBER: builtins.int
        TARGET_INDEX_FIELD_NUMBER: builtins.int
        SETTINGS_FIELD_NUMBER: builtins.int
        OVERRIDE_NAME_FIELD_NUMBER: builtins.int
        MATCHER_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Series name."""
        target_index: builtins.str
        """Target index."""
        override_name: builtins.str
        @property
        def settings(self) -> global___ChartWidget.SeriesOverrides.SeriesOverrideSettings:
            """Required. Override settings."""

        @property
        def matcher(self) -> global___ChartWidget.OverrideMatcher: ...
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            target_index: builtins.str = ...,
            settings: global___ChartWidget.SeriesOverrides.SeriesOverrideSettings | None = ...,
            override_name: builtins.str = ...,
            matcher: global___ChartWidget.OverrideMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["matcher", b"matcher", "name", b"name", "settings", b"settings", "target_index", b"target_index", "type", b"type"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["matcher", b"matcher", "name", b"name", "override_name", b"override_name", "settings", b"settings", "target_index", b"target_index", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["name", "target_index"] | None: ...

    @typing.final
    class OverrideMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        QUERY_FIELD_NUMBER: builtins.int
        LINE_FIELD_NUMBER: builtins.int
        REGEXP_FIELD_NUMBER: builtins.int
        VALUES_FIELD_NUMBER: builtins.int
        @property
        def query(self) -> global___ChartWidget.QueryMatcher: ...
        @property
        def line(self) -> global___ChartWidget.LineMatcher: ...
        @property
        def regexp(self) -> global___ChartWidget.RegExpMatcher: ...
        @property
        def values(self) -> global___ChartWidget.ValueMatcher: ...
        def __init__(
            self,
            *,
            query: global___ChartWidget.QueryMatcher | None = ...,
            line: global___ChartWidget.LineMatcher | None = ...,
            regexp: global___ChartWidget.RegExpMatcher | None = ...,
            values: global___ChartWidget.ValueMatcher | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["line", b"line", "query", b"query", "regexp", b"regexp", "type", b"type", "values", b"values"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["line", b"line", "query", b"query", "regexp", b"regexp", "type", b"type", "values", b"values"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["query", "line", "regexp", "values"] | None: ...

    @typing.final
    class QueryMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAMES_FIELD_NUMBER: builtins.int
        @property
        def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            names: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["names", b"names"]) -> None: ...

    @typing.final
    class LineMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LINE_IDS_FIELD_NUMBER: builtins.int
        @property
        def line_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        def __init__(
            self,
            *,
            line_ids: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["line_ids", b"line_ids"]) -> None: ...

    @typing.final
    class RegExpMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REG_EXP_FIELD_NUMBER: builtins.int
        reg_exp: builtins.str
        def __init__(
            self,
            *,
            reg_exp: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["reg_exp", b"reg_exp"]) -> None: ...

    @typing.final
    class ValueMatcher(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VALUE_TYPE_FIELD_NUMBER: builtins.int
        value_type: global___ChartWidget.ValuesType.ValueType
        def __init__(
            self,
            *,
            value_type: global___ChartWidget.ValuesType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["value_type", b"value_type"]) -> None: ...

    @typing.final
    class NameHidingSettings(google.protobuf.message.Message):
        """Name hiding settings."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        POSITIVE_FIELD_NUMBER: builtins.int
        NAMES_FIELD_NUMBER: builtins.int
        positive: builtins.bool
        """True if we want to show concrete series names only, false if we want to hide concrete series names."""
        @property
        def names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Series names to show or hide."""

        def __init__(
            self,
            *,
            positive: builtins.bool = ...,
            names: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["names", b"names", "positive", b"positive"]) -> None: ...

    @typing.final
    class RepeatSettings(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REPEAT_BY_FIELD_NUMBER: builtins.int
        MAX_CHARTS_IN_ROW_FIELD_NUMBER: builtins.int
        max_charts_in_row: builtins.int
        """Max number of chart in one row."""
        @property
        def repeat_by(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Parameters to repeat by."""

        def __init__(
            self,
            *,
            repeat_by: collections.abc.Iterable[builtins.str] | None = ...,
            max_charts_in_row: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["max_charts_in_row", b"max_charts_in_row", "repeat_by", b"repeat_by"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    QUERIES_FIELD_NUMBER: builtins.int
    VISUALIZATION_SETTINGS_FIELD_NUMBER: builtins.int
    SERIES_OVERRIDES_FIELD_NUMBER: builtins.int
    NAME_HIDING_SETTINGS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DISPLAY_LEGEND_FIELD_NUMBER: builtins.int
    FREEZE_FIELD_NUMBER: builtins.int
    REPEAT_FIELD_NUMBER: builtins.int
    THRESHOLDS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Required. Chart ID."""
    description: builtins.str
    """Chart description in dashboard (not enabled in UI)."""
    title: builtins.str
    """Chart widget title."""
    display_legend: builtins.bool
    """Enable legend under chart."""
    freeze: global___ChartWidget.FreezeDuration.ValueType
    """Fixed time interval for chart."""
    @property
    def queries(self) -> global___ChartWidget.Queries:
        """Queries."""

    @property
    def visualization_settings(self) -> global___ChartWidget.VisualizationSettings:
        """Visualization settings."""

    @property
    def series_overrides(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChartWidget.SeriesOverrides]:
        """Override settings."""

    @property
    def name_hiding_settings(self) -> global___ChartWidget.NameHidingSettings:
        """Name hiding settings."""

    @property
    def repeat(self) -> global___ChartWidget.RepeatSettings:
        """Setting for repeat panel / repeat row"""

    @property
    def thresholds(self) -> yandex.cloud.monitoring.v3.thresholds_pb2.Thresholds:
        """Threshold settings"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        queries: global___ChartWidget.Queries | None = ...,
        visualization_settings: global___ChartWidget.VisualizationSettings | None = ...,
        series_overrides: collections.abc.Iterable[global___ChartWidget.SeriesOverrides] | None = ...,
        name_hiding_settings: global___ChartWidget.NameHidingSettings | None = ...,
        description: builtins.str = ...,
        title: builtins.str = ...,
        display_legend: builtins.bool = ...,
        freeze: global___ChartWidget.FreezeDuration.ValueType = ...,
        repeat: global___ChartWidget.RepeatSettings | None = ...,
        thresholds: yandex.cloud.monitoring.v3.thresholds_pb2.Thresholds | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["name_hiding_settings", b"name_hiding_settings", "queries", b"queries", "repeat", b"repeat", "thresholds", b"thresholds", "visualization_settings", b"visualization_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "display_legend", b"display_legend", "freeze", b"freeze", "id", b"id", "name_hiding_settings", b"name_hiding_settings", "queries", b"queries", "repeat", b"repeat", "series_overrides", b"series_overrides", "thresholds", b"thresholds", "title", b"title", "visualization_settings", b"visualization_settings"]) -> None: ...

global___ChartWidget = ChartWidget
