# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/pxf.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/pxf.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xbd\x04\n\tPXFConfig\x12\x42\n\x12\x63onnection_timeout\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12>\n\x0eupload_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12<\n\x0bmax_threads\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x42\n\x1epool_allow_core_thread_timeout\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0epool_core_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x41\n\x13pool_queue_capacity\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\rpool_max_size\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x32\n\x03xmx\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=64\x12\x32\n\x03xms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04>=64\"\xd9\x01\n\x0cPXFConfigSet\x12H\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigB\x04\xe8\xc7\x31\x01\x12=\n\x0buser_config\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\x12@\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\"\xe1\x01\n\x0fPXFDatasourceS3\x12\x1d\n\naccess_key\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1d\n\nsecret_key\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12/\n\x0b\x66\x61st_upload\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12_\n\x08\x65ndpoint\x18\x04 \x01(\tBM\xf2\xc7\x31@(((s3|https?)://)?([a-z0-9]([a-z0-9-]*[a-z0-9])?[.])+[a-z]{2,})?\x8a\xc8\x31\x05<=200\"\xa8\x05\n\x11PXFDatasourceJDBC\x12\x18\n\x06\x64river\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x17\n\x03url\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x17\n\x04user\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x46\n\x14statement_batch_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12G\n\x14statement_fetch_size\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12I\n\x17statement_query_timeout\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35-43200\x12\x30\n\x0cpool_enabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x41\n\x11pool_maximum_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-200\x12M\n\x17pool_connection_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b\x35\x30\x30\x30-600000\x12G\n\x11pool_idle_timeout\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b\x35\x30\x30\x30-600000\x12\x41\n\x11pool_minimum_idle\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-200\"^\n\x11PXFDatasourceCore\x12\x1d\n\ndefault_fs\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12*\n\x16security_auth_to_local\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xcf\x02\n\x15PXFDatasourceKerberos\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x07primary\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x19\n\x05realm\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x0bkdc_servers\x18\x04 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\x1f\n\x0c\x61\x64min_server\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12!\n\x0e\x64\x65\x66\x61ult_domain\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x66\n\rkeytab_base64\x18\x07 \x01(\tBO\xf2\xc7\x31@^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$\x8a\xc8\x31\x07<=65536\"\xad\x01\n\x1cPXFDatasourceHDFSDfsNamenode\x12\x1f\n\x0brpc_address\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x13service_rpc_address\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12 \n\x0chttp_address\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12!\n\rhttps_address\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xbd\x03\n\x14PXFDatasourceHDFSDfs\x12\x41\n\x1dha_automatic_failover_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x1a\x62lock_access_token_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15use_datanode_hostname\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x62\n\tnamenodes\x18\x04 \x03(\x0b\x32\x42.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfs.NamenodesEntryB\x0b\x82\xc8\x31\x07<=10000\x12\x14\n\x0cnameservices\x18\x05 \x01(\t\x1am\n\x0eNamenodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12J\n\x05value\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfsNamenode:\x02\x38\x01\"\x96\x02\n\x19PXFDatasourceHDFSYarnHaRm\x12\x1f\n\x17resourcemanager_address\x18\x01 \x01(\t\x12)\n!resourcemanager_scheduler_address\x18\x02 \x01(\t\x12\x30\n(resourcemanager_resource_tracker_address\x18\x03 \x01(\t\x12%\n\x1dresourcemanager_admin_address\x18\x04 \x01(\t\x12&\n\x1eresourcemanager_webapp_address\x18\x05 \x01(\t\x12,\n$resourcemanager_webapp_https_address\x18\x06 \x01(\t\"\xe7\x03\n\x15PXFDatasourceHDFSYarn\x12>\n\x1aresourcemanager_ha_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n(resourcemanager_ha_auto_failover_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n)resourcemanager_ha_auto_failover_embedded\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\x1aresourcemanager_cluster_id\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12Z\n\x05ha_rm\x18\x05 \x03(\x0b\x32>.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarn.HaRmEntryB\x0b\x82\xc8\x31\x07<=10000\x1a\x65\n\tHaRmEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarnHaRm:\x02\x38\x01\"\xe4\x03\n\x11PXFDatasourceHDFS\x12>\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceCore\x12\x46\n\x08kerberos\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceKerberos\x12\x36\n\x12user_impersonation\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08username\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x46\n\x17sasl_connection_retries\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-50\x12$\n\x08zk_hosts\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12@\n\x03\x64\x66s\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfs\x12\x42\n\x04yarn\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarn\"\x92\x04\n\x11PXFDatasourceHive\x12>\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceCore\x12\x46\n\x08kerberos\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceKerberos\x12\x36\n\x12user_impersonation\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08username\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x46\n\x17sasl_connection_retries\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-50\x12$\n\x08zk_hosts\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\'\n\x03ppd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x0emetastore_uris\x18\x08 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\x30\n\x1cmetastore_kerberos_principal\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12+\n\x17\x61uth_kerberos_principal\x18\n \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xd2\x02\n\rPXFDatasource\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\x12<\n\x02s3\x18\x02 \x01(\x0b\x32..yandex.cloud.mdb.greenplum.v1.PXFDatasourceS3H\x00\x12@\n\x04jdbc\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceJDBCH\x00\x12@\n\x04hdfs\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSH\x00\x12@\n\x04hive\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHiveH\x00\x42\n\n\x08settingsBp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.pxf_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_PXFCONFIG'].fields_by_name['connection_timeout']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['connection_timeout']._serialized_options = b'\372\3071\0055-600'
  _globals['_PXFCONFIG'].fields_by_name['upload_timeout']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['upload_timeout']._serialized_options = b'\372\3071\0055-600'
  _globals['_PXFCONFIG'].fields_by_name['max_threads']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['max_threads']._serialized_options = b'\372\3071\0061-1024'
  _globals['_PXFCONFIG'].fields_by_name['pool_core_size']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['pool_core_size']._serialized_options = b'\372\3071\0061-1024'
  _globals['_PXFCONFIG'].fields_by_name['pool_queue_capacity']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['pool_queue_capacity']._serialized_options = b'\372\3071\003>=0'
  _globals['_PXFCONFIG'].fields_by_name['pool_max_size']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['pool_max_size']._serialized_options = b'\372\3071\0061-1024'
  _globals['_PXFCONFIG'].fields_by_name['xmx']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['xmx']._serialized_options = b'\372\3071\004>=64'
  _globals['_PXFCONFIG'].fields_by_name['xms']._loaded_options = None
  _globals['_PXFCONFIG'].fields_by_name['xms']._serialized_options = b'\372\3071\004>=64'
  _globals['_PXFCONFIGSET'].fields_by_name['effective_config']._loaded_options = None
  _globals['_PXFCONFIGSET'].fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _globals['_PXFDATASOURCES3'].fields_by_name['access_key']._loaded_options = None
  _globals['_PXFDATASOURCES3'].fields_by_name['access_key']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCES3'].fields_by_name['secret_key']._loaded_options = None
  _globals['_PXFDATASOURCES3'].fields_by_name['secret_key']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCES3'].fields_by_name['endpoint']._loaded_options = None
  _globals['_PXFDATASOURCES3'].fields_by_name['endpoint']._serialized_options = b'\362\3071@(((s3|https?)://)?([a-z0-9]([a-z0-9-]*[a-z0-9])?[.])+[a-z]{2,})?\212\3101\005<=200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['driver']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['driver']._serialized_options = b'\212\3101\004<=50'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['url']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['url']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['user']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['user']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['password']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['password']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_batch_size']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_batch_size']._serialized_options = b'\372\3071\00750-1000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_fetch_size']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_fetch_size']._serialized_options = b'\372\3071\01050-10000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_query_timeout']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['statement_query_timeout']._serialized_options = b'\372\3071\0075-43200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_maximum_size']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_maximum_size']._serialized_options = b'\372\3071\0051-200'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_connection_timeout']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_connection_timeout']._serialized_options = b'\372\3071\0135000-600000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_idle_timeout']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_idle_timeout']._serialized_options = b'\372\3071\0135000-600000'
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_minimum_idle']._loaded_options = None
  _globals['_PXFDATASOURCEJDBC'].fields_by_name['pool_minimum_idle']._serialized_options = b'\372\3071\0050-200'
  _globals['_PXFDATASOURCECORE'].fields_by_name['default_fs']._loaded_options = None
  _globals['_PXFDATASOURCECORE'].fields_by_name['default_fs']._serialized_options = b'\212\3101\005<=200'
  _globals['_PXFDATASOURCECORE'].fields_by_name['security_auth_to_local']._loaded_options = None
  _globals['_PXFDATASOURCECORE'].fields_by_name['security_auth_to_local']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['primary']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['primary']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['realm']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['realm']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['kdc_servers']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['kdc_servers']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['admin_server']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['admin_server']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['default_domain']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['default_domain']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['keytab_base64']._loaded_options = None
  _globals['_PXFDATASOURCEKERBEROS'].fields_by_name['keytab_base64']._serialized_options = b'\362\3071@^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$\212\3101\007<=65536'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['rpc_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['rpc_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['service_rpc_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['service_rpc_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['http_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['http_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['https_address']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE'].fields_by_name['https_address']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_options = b'8\001'
  _globals['_PXFDATASOURCEHDFSDFS'].fields_by_name['namenodes']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSDFS'].fields_by_name['namenodes']._serialized_options = b'\202\3101\007<=10000'
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_options = b'8\001'
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['resourcemanager_cluster_id']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['resourcemanager_cluster_id']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['ha_rm']._loaded_options = None
  _globals['_PXFDATASOURCEHDFSYARN'].fields_by_name['ha_rm']._serialized_options = b'\202\3101\007<=10000'
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['username']._loaded_options = None
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['username']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['sasl_connection_retries']._loaded_options = None
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['sasl_connection_retries']._serialized_options = b'\372\3071\0041-50'
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['zk_hosts']._loaded_options = None
  _globals['_PXFDATASOURCEHDFS'].fields_by_name['zk_hosts']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['username']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['username']._serialized_options = b'\212\3101\005<=128'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['sasl_connection_retries']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['sasl_connection_retries']._serialized_options = b'\372\3071\0041-50'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['zk_hosts']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['zk_hosts']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_uris']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_uris']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_kerberos_principal']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['metastore_kerberos_principal']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['auth_kerberos_principal']._loaded_options = None
  _globals['_PXFDATASOURCEHIVE'].fields_by_name['auth_kerberos_principal']._serialized_options = b'\212\3101\006<=1000'
  _globals['_PXFDATASOURCE'].fields_by_name['name']._loaded_options = None
  _globals['_PXFDATASOURCE'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_PXFCONFIG']._serialized_start=138
  _globals['_PXFCONFIG']._serialized_end=711
  _globals['_PXFCONFIGSET']._serialized_start=714
  _globals['_PXFCONFIGSET']._serialized_end=931
  _globals['_PXFDATASOURCES3']._serialized_start=934
  _globals['_PXFDATASOURCES3']._serialized_end=1159
  _globals['_PXFDATASOURCEJDBC']._serialized_start=1162
  _globals['_PXFDATASOURCEJDBC']._serialized_end=1842
  _globals['_PXFDATASOURCECORE']._serialized_start=1844
  _globals['_PXFDATASOURCECORE']._serialized_end=1938
  _globals['_PXFDATASOURCEKERBEROS']._serialized_start=1941
  _globals['_PXFDATASOURCEKERBEROS']._serialized_end=2276
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE']._serialized_start=2279
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE']._serialized_end=2452
  _globals['_PXFDATASOURCEHDFSDFS']._serialized_start=2455
  _globals['_PXFDATASOURCEHDFSDFS']._serialized_end=2900
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_start=2791
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_end=2900
  _globals['_PXFDATASOURCEHDFSYARNHARM']._serialized_start=2903
  _globals['_PXFDATASOURCEHDFSYARNHARM']._serialized_end=3181
  _globals['_PXFDATASOURCEHDFSYARN']._serialized_start=3184
  _globals['_PXFDATASOURCEHDFSYARN']._serialized_end=3671
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_start=3570
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_end=3671
  _globals['_PXFDATASOURCEHDFS']._serialized_start=3674
  _globals['_PXFDATASOURCEHDFS']._serialized_end=4158
  _globals['_PXFDATASOURCEHIVE']._serialized_start=4161
  _globals['_PXFDATASOURCEHIVE']._serialized_end=4691
  _globals['_PXFDATASOURCE']._serialized_start=4694
  _globals['_PXFDATASOURCE']._serialized_end=5032
# @@protoc_insertion_point(module_scope)
