# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/project_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/project_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.datasphere.v1 import project_pb2 as yandex_dot_cloud_dot_datasphere_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/datasphere/v1/project_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a(yandex/cloud/datasphere/v1/project.proto\"\x8e\x02\n\x14\x43reateProjectRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x39\n\x04name\x18\x02 \x01(\tB+\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x08settings\x18\x04 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x05 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\"+\n\x15\x43reateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"\xc1\x02\n\x14UpdateProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x39\n\x04name\x18\x03 \x01(\tB+\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x8a\xc8\x31\x04<=63\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x08settings\x18\x05 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x06 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\"+\n\x15UpdateProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"9\n\x14\x44\x65leteProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"+\n\x15\x44\x65leteProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"7\n\x12OpenProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\")\n\x13OpenProjectMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"A\n\x13OpenProjectResponse\x12\x13\n\x0bproject_url\x18\x01 \x01(\t\x12\x15\n\rsession_token\x18\x02 \x01(\t\"6\n\x11GetProjectRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"t\n\x13ListProjectsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"f\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.yandex.cloud.datasphere.v1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x15GetUnitBalanceRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\"K\n\x16GetUnitBalanceResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"m\n\x15SetUnitBalanceRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x31\n\x0cunit_balance\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\xdd\x01\n\x17ProjectExecutionRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x30\n\x0finput_variables\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1d\n\x15output_variable_names\x18\x05 \x03(\tB\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"~\n\x18ProjectExecutionMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12 \n\x0bnotebook_id\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x12\x1c\n\x07\x63\x65ll_id\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200H\x00\x42\x0e\n\x06target\x12\x04\xc0\xc1\x31\x01\"&\n\x18ProjectExecutionResponseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\x32\xa5\x0c\n\x0eProjectService\x12\xa5\x01\n\x06\x43reate\x12\x30.yandex.cloud.datasphere.v1.CreateProjectRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2* \n\x15\x43reateProjectMetadata\x12\x07Project\x82\xd3\xe4\x93\x02\x1c\"\x17/datasphere/v1/projects:\x01*\x12\xb2\x01\n\x06Update\x12\x30.yandex.cloud.datasphere.v1.UpdateProjectRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x15UpdateProjectMetadata\x12\x07Project\x82\xd3\xe4\x93\x02)2$/datasphere/v1/projects/{project_id}:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12\x30.yandex.cloud.datasphere.v1.DeleteProjectRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*.\n\x15\x44\x65leteProjectMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/datasphere/v1/projects/{project_id}\x12\xba\x01\n\x04Open\x12..yandex.cloud.datasphere.v1.OpenProjectRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2**\n\x13OpenProjectMetadata\x12\x13OpenProjectResponse\x82\xd3\xe4\x93\x02+\")/datasphere/v1/projects/{project_id}:open\x12\x87\x01\n\x03Get\x12-.yandex.cloud.datasphere.v1.GetProjectRequest\x1a#.yandex.cloud.datasphere.v1.Project\",\x82\xd3\xe4\x93\x02&\x12$/datasphere/v1/projects/{project_id}\x12\x8a\x01\n\x04List\x12/.yandex.cloud.datasphere.v1.ListProjectsRequest\x1a\x30.yandex.cloud.datasphere.v1.ListProjectsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/datasphere/v1/projects\x12\xb1\x01\n\x0eGetUnitBalance\x12\x31.yandex.cloud.datasphere.v1.GetUnitBalanceRequest\x1a\x32.yandex.cloud.datasphere.v1.GetUnitBalanceResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/datasphere/v1/projects/{project_id}:unitBalance\x12\x98\x01\n\x0eSetUnitBalance\x12\x31.yandex.cloud.datasphere.v1.SetUnitBalanceRequest\x1a\x16.google.protobuf.Empty\";\x82\xd3\xe4\x93\x02\x35\"0/datasphere/v1/projects/{project_id}:unitBalance:\x01*\x12\xd2\x01\n\x07\x45xecute\x12\x33.yandex.cloud.datasphere.v1.ProjectExecutionRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2*4\n\x18ProjectExecutionMetadata\x12\x18ProjectExecutionResponse\x82\xd3\xe4\x93\x02\x31\",/datasphere/v1/projects/{project_id}:execute:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.project_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\004<=63'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?\212\3101\004<=63'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_DELETEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_OPENPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_OPENPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETUNITBALANCEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETUNITBALANCEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_SETUNITBALANCEREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_SETUNITBALANCEREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].oneofs_by_name['target']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['notebook_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['notebook_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['cell_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONREQUEST'].fields_by_name['cell_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONMETADATA'].oneofs_by_name['target']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].oneofs_by_name['target']._serialized_options = b'\300\3011\001'
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['notebook_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['notebook_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['cell_id']._loaded_options = None
  _globals['_PROJECTEXECUTIONMETADATA'].fields_by_name['cell_id']._serialized_options = b'\212\3101\005<=200'
  _globals['_PROJECTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322* \n\025CreateProjectMetadata\022\007Project\202\323\344\223\002\034\"\027/datasphere/v1/projects:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322* \n\025UpdateProjectMetadata\022\007Project\202\323\344\223\002)2$/datasphere/v1/projects/{project_id}:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*.\n\025DeleteProjectMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/datasphere/v1/projects/{project_id}'
  _globals['_PROJECTSERVICE'].methods_by_name['Open']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Open']._serialized_options = b'\262\322**\n\023OpenProjectMetadata\022\023OpenProjectResponse\202\323\344\223\002+\")/datasphere/v1/projects/{project_id}:open'
  _globals['_PROJECTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/datasphere/v1/projects/{project_id}'
  _globals['_PROJECTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\031\022\027/datasphere/v1/projects'
  _globals['_PROJECTSERVICE'].methods_by_name['GetUnitBalance']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['GetUnitBalance']._serialized_options = b'\202\323\344\223\0022\0220/datasphere/v1/projects/{project_id}:unitBalance'
  _globals['_PROJECTSERVICE'].methods_by_name['SetUnitBalance']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['SetUnitBalance']._serialized_options = b'\202\323\344\223\0025\"0/datasphere/v1/projects/{project_id}:unitBalance:\001*'
  _globals['_PROJECTSERVICE'].methods_by_name['Execute']._loaded_options = None
  _globals['_PROJECTSERVICE'].methods_by_name['Execute']._serialized_options = b'\262\322*4\n\030ProjectExecutionMetadata\022\030ProjectExecutionResponse\202\323\344\223\0021\",/datasphere/v1/projects/{project_id}:execute:\001*'
  _globals['_CREATEPROJECTREQUEST']._serialized_start=383
  _globals['_CREATEPROJECTREQUEST']._serialized_end=653
  _globals['_CREATEPROJECTMETADATA']._serialized_start=655
  _globals['_CREATEPROJECTMETADATA']._serialized_end=698
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=701
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1022
  _globals['_UPDATEPROJECTMETADATA']._serialized_start=1024
  _globals['_UPDATEPROJECTMETADATA']._serialized_end=1067
  _globals['_DELETEPROJECTREQUEST']._serialized_start=1069
  _globals['_DELETEPROJECTREQUEST']._serialized_end=1126
  _globals['_DELETEPROJECTMETADATA']._serialized_start=1128
  _globals['_DELETEPROJECTMETADATA']._serialized_end=1171
  _globals['_OPENPROJECTREQUEST']._serialized_start=1173
  _globals['_OPENPROJECTREQUEST']._serialized_end=1228
  _globals['_OPENPROJECTMETADATA']._serialized_start=1230
  _globals['_OPENPROJECTMETADATA']._serialized_end=1271
  _globals['_OPENPROJECTRESPONSE']._serialized_start=1273
  _globals['_OPENPROJECTRESPONSE']._serialized_end=1338
  _globals['_GETPROJECTREQUEST']._serialized_start=1340
  _globals['_GETPROJECTREQUEST']._serialized_end=1394
  _globals['_LISTPROJECTSREQUEST']._serialized_start=1396
  _globals['_LISTPROJECTSREQUEST']._serialized_end=1512
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=1514
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=1616
  _globals['_GETUNITBALANCEREQUEST']._serialized_start=1618
  _globals['_GETUNITBALANCEREQUEST']._serialized_end=1676
  _globals['_GETUNITBALANCERESPONSE']._serialized_start=1678
  _globals['_GETUNITBALANCERESPONSE']._serialized_end=1753
  _globals['_SETUNITBALANCEREQUEST']._serialized_start=1755
  _globals['_SETUNITBALANCEREQUEST']._serialized_end=1864
  _globals['_PROJECTEXECUTIONREQUEST']._serialized_start=1867
  _globals['_PROJECTEXECUTIONREQUEST']._serialized_end=2088
  _globals['_PROJECTEXECUTIONMETADATA']._serialized_start=2090
  _globals['_PROJECTEXECUTIONMETADATA']._serialized_end=2216
  _globals['_PROJECTEXECUTIONRESPONSE']._serialized_start=2218
  _globals['_PROJECTEXECUTIONRESPONSE']._serialized_end=2256
  _globals['_PROJECTSERVICE']._serialized_start=2259
  _globals['_PROJECTSERVICE']._serialized_end=3832
# @@protoc_insertion_point(module_scope)
