# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/rule_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/rule_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud.cdn.v1 import rule_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_rule__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/cdn/v1/rule_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a\x1eyandex/cloud/cdn/v1/rule.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x18ListResourceRulesRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"E\n\x19ListResourceRulesResponse\x12(\n\x05rules\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.cdn.v1.Rule\"\xb6\x01\n\x19\x43reateResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\x0crule_pattern\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\"X\n\x1a\x43reateResourceRuleMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"T\n\x16GetResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"\xc7\x01\n\x19UpdateResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x16\n\x04name\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1f\n\x0crule_pattern\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x35\n\x07options\x18\x05 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\"X\n\x1aUpdateResourceRuleMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"W\n\x19\x44\x65leteResourceRuleRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"X\n\x1a\x44\x65leteResourceRuleMetadata\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x07rule_id\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>02\x80\x06\n\x14ResourceRulesService\x12|\n\x04List\x12-.yandex.cloud.cdn.v1.ListResourceRulesRequest\x1a..yandex.cloud.cdn.v1.ListResourceRulesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/cdn/v1/rules\x12\x9b\x01\n\x06\x43reate\x12..yandex.cloud.cdn.v1.CreateResourceRuleRequest\x1a!.yandex.cloud.operation.Operation\">\xb2\xd2*\"\n\x1a\x43reateResourceRuleMetadata\x12\x04Rule\x82\xd3\xe4\x93\x02\x12\"\r/cdn/v1/rules:\x01*\x12n\n\x03Get\x12+.yandex.cloud.cdn.v1.GetResourceRuleRequest\x1a\x19.yandex.cloud.cdn.v1.Rule\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/cdn/v1/rules/{rule_id}\x12\xa5\x01\n\x06Update\x12..yandex.cloud.cdn.v1.UpdateResourceRuleRequest\x1a!.yandex.cloud.operation.Operation\"H\xb2\xd2*\"\n\x1aUpdateResourceRuleMetadata\x12\x04Rule\x82\xd3\xe4\x93\x02\x1c\x32\x17/cdn/v1/rules/{rule_id}:\x01*\x12\xb3\x01\n\x06\x44\x65lete\x12..yandex.cloud.cdn.v1.DeleteResourceRuleRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*3\n\x1a\x44\x65leteResourceRuleMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x19*\x17/cdn/v1/rules/{rule_id}BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.rule_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_LISTRESOURCERULESREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_LISTRESOURCERULESREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._loaded_options = None
  _globals['_CREATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_CREATERESOURCERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_GETRESOURCERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['name']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._loaded_options = None
  _globals['_UPDATERESOURCERULEREQUEST'].fields_by_name['rule_pattern']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_UPDATERESOURCERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DELETERESOURCERULEREQUEST'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['rule_id']._loaded_options = None
  _globals['_DELETERESOURCERULEMETADATA'].fields_by_name['rule_id']._serialized_options = b'\372\3071\002>0'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\017\022\r/cdn/v1/rules'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\032CreateResourceRuleMetadata\022\004Rule\202\323\344\223\002\022\"\r/cdn/v1/rules:\001*'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\031\022\027/cdn/v1/rules/{rule_id}'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\032UpdateResourceRuleMetadata\022\004Rule\202\323\344\223\002\0342\027/cdn/v1/rules/{rule_id}:\001*'
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RESOURCERULESSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteResourceRuleMetadata\022\025google.protobuf.Empty\202\323\344\223\002\031*\027/cdn/v1/rules/{rule_id}'
  _globals['_LISTRESOURCERULESREQUEST']._serialized_start=266
  _globals['_LISTRESOURCERULESREQUEST']._serialized_end=327
  _globals['_LISTRESOURCERULESRESPONSE']._serialized_start=329
  _globals['_LISTRESOURCERULESRESPONSE']._serialized_end=398
  _globals['_CREATERESOURCERULEREQUEST']._serialized_start=401
  _globals['_CREATERESOURCERULEREQUEST']._serialized_end=583
  _globals['_CREATERESOURCERULEMETADATA']._serialized_start=585
  _globals['_CREATERESOURCERULEMETADATA']._serialized_end=673
  _globals['_GETRESOURCERULEREQUEST']._serialized_start=675
  _globals['_GETRESOURCERULEREQUEST']._serialized_end=759
  _globals['_UPDATERESOURCERULEREQUEST']._serialized_start=762
  _globals['_UPDATERESOURCERULEREQUEST']._serialized_end=961
  _globals['_UPDATERESOURCERULEMETADATA']._serialized_start=963
  _globals['_UPDATERESOURCERULEMETADATA']._serialized_end=1051
  _globals['_DELETERESOURCERULEREQUEST']._serialized_start=1053
  _globals['_DELETERESOURCERULEREQUEST']._serialized_end=1140
  _globals['_DELETERESOURCERULEMETADATA']._serialized_start=1142
  _globals['_DELETERESOURCERULEMETADATA']._serialized_end=1230
  _globals['_RESOURCERULESSERVICE']._serialized_start=1233
  _globals['_RESOURCERULESSERVICE']._serialized_end=2001
# @@protoc_insertion_point(module_scope)
