"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DhcpOptions(google.protobuf.message.Message):
    """DHCP options for a subnet."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_IP_FIELD_NUMBER: builtins.int
    END_IP_FIELD_NUMBER: builtins.int
    start_ip: builtins.str
    """Start IP address of the DHCP range (inclusive)."""
    end_ip: builtins.str
    """End IP address of the DHCP range (inclusive)."""
    def __init__(
        self,
        *,
        start_ip: builtins.str = ...,
        end_ip: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["end_ip", b"end_ip", "start_ip", b"start_ip"]) -> None: ...

global___DhcpOptions = DhcpOptions
