# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/style_preset.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/style_preset.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/video/v1/style_preset.proto\x12\x15yandex.cloud.video.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\x9d\x06\n\x0bStylePreset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nchannel_id\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x18\n\x10\x62\x61\x63kground_color\x18\x04 \x01(\t\x12!\n\x19widget_text_color_primary\x18\x05 \x01(\t\x12#\n\x1bwidget_text_color_secondary\x18\x06 \x01(\t\x12\x1b\n\x13widget_accent_color\x18\x07 \x01(\t\x12\x18\n\x10widget_block_gap\x18\x08 \x01(\x03\x12$\n\x1cwidget_block_separator_color\x18\t \x01(\t\x12\x1c\n\x14player_border_radius\x18\x0c \x01(\x03\x12\x14\n\x0cplayer_color\x18\r \x01(\t\x12/\n\'playlist_selected_item_background_color\x18\x0e \x01(\t\x12#\n\x1bplaylist_item_border_radius\x18\x0f \x01(\x03\x12\x19\n\x11playlist_item_gap\x18\x10 \x01(\x03\x12L\n\x11playlist_location\x18\x11 \x01(\x0e\x32\x31.yandex.cloud.video.v1.StylePreset.WidgetLocation\x12\x34\n\rright_widgets\x18\x14 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12\x35\n\x0e\x62ottom_widgets\x18\x15 \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12.\n\ncreated_at\x18\x64 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x65 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"H\n\x0eWidgetLocation\x12\x1f\n\x1bWIDGET_LOCATION_UNSPECIFIED\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\n\n\x06\x42OTTOM\x10\x02J\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x12\x10\x14J\x04\x08\x16\x10\x64\"\xc0\x01\n\x06Widget\x12\x44\n\rsummarization\x18\x01 \x01(\x0b\x32+.yandex.cloud.video.v1.Widget.SummarizationH\x00\x12@\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32).yandex.cloud.video.v1.Widget.DescriptionH\x00\x1a\x0f\n\rSummarization\x1a\r\n\x0b\x44\x65scriptionB\x0e\n\x06widget\x12\x04\xc0\xc1\x31\x01\x42\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.style_preset_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_WIDGET'].oneofs_by_name['widget']._loaded_options = None
  _globals['_WIDGET'].oneofs_by_name['widget']._serialized_options = b'\300\3011\001'
  _globals['_STYLEPRESET']._serialized_start=132
  _globals['_STYLEPRESET']._serialized_end=929
  _globals['_STYLEPRESET_WIDGETLOCATION']._serialized_start=833
  _globals['_STYLEPRESET_WIDGETLOCATION']._serialized_end=905
  _globals['_WIDGET']._serialized_start=932
  _globals['_WIDGET']._serialized_end=1124
  _globals['_WIDGET_SUMMARIZATION']._serialized_start=1078
  _globals['_WIDGET_SUMMARIZATION']._serialized_end=1093
  _globals['_WIDGET_DESCRIPTION']._serialized_start=1095
  _globals['_WIDGET_DESCRIPTION']._serialized_end=1108
# @@protoc_insertion_point(module_scope)
