# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/folder_budget_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/folder_budget_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/datasphere/v1/folder_budget_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"9\n\x16GetFolderBudgetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xc3\x01\n\x17GetFolderBudgetResponse\x12\x31\n\x0cunit_balance\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_units_per_hour\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x91\x02\n\x16SetFolderBudgetRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12,\n\x08set_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x0cunit_balance\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x37\n\x12max_units_per_hour\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64Value2\xc3\x02\n\x13\x46olderBudgetService\x12\xa1\x01\n\x03Get\x12\x32.yandex.cloud.datasphere.v1.GetFolderBudgetRequest\x1a\x33.yandex.cloud.datasphere.v1.GetFolderBudgetResponse\"1\x82\xd3\xe4\x93\x02+\x12)/datasphere/v1/folders/{folder_id}:budget\x12\x87\x01\n\x03Set\x12\x32.yandex.cloud.datasphere.v1.SetFolderBudgetRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\")/datasphere/v1/folders/{folder_id}:budget:\x01*Bk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.folder_budget_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_GETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_SETFOLDERBUDGETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/datasphere/v1/folders/{folder_id}:budget'
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Set']._loaded_options = None
  _globals['_FOLDERBUDGETSERVICE'].methods_by_name['Set']._serialized_options = b'\202\323\344\223\002.\")/datasphere/v1/folders/{folder_id}:budget:\001*'
  _globals['_GETFOLDERBUDGETREQUEST']._serialized_start=242
  _globals['_GETFOLDERBUDGETREQUEST']._serialized_end=299
  _globals['_GETFOLDERBUDGETRESPONSE']._serialized_start=302
  _globals['_GETFOLDERBUDGETRESPONSE']._serialized_end=497
  _globals['_SETFOLDERBUDGETREQUEST']._serialized_start=500
  _globals['_SETFOLDERBUDGETREQUEST']._serialized_end=773
  _globals['_FOLDERBUDGETSERVICE']._serialized_start=776
  _globals['_FOLDERBUDGETSERVICE']._serialized_end=1099
# @@protoc_insertion_point(module_scope)
