# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/quotamanager/v1/quota_request.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/quotamanager/v1/quota_request.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.quotamanager.v1 import resource_pb2 as yandex_dot_cloud_dot_quotamanager_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/quotamanager/v1/quota_request.proto\x12\x1cyandex.cloud.quotamanager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+yandex/cloud/quotamanager/v1/resource.proto\"\xe9\x05\n\x0cQuotaRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x38\n\x08resource\x18\x02 \x01(\x0b\x32&.yandex.cloud.quotamanager.v1.Resource\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06status\x18\x04 \x01(\x0e\x32\x31.yandex.cloud.quotamanager.v1.QuotaRequest.Status\x12K\n\x0cquota_limits\x18\x05 \x03(\x0b\x32\x35.yandex.cloud.quotamanager.v1.QuotaRequest.QuotaLimit\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x1a\xce\x02\n\nQuotaLimit\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12\x15\n\rdesired_limit\x18\x02 \x01(\x01\x12\x16\n\x0e\x61pproved_limit\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\x12L\n\x06status\x18\x05 \x01(\x0e\x32<.yandex.cloud.quotamanager.v1.QuotaRequest.QuotaLimit.Status\x12\x0f\n\x07message\x18\x06 \x01(\t\x12\x13\n\x0bmodified_by\x18\x07 \x01(\t\"}\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\x14\n\x10PARTIAL_APPROVED\x10\x03\x12\x0c\n\x08\x41PPROVED\x10\x04\x12\x0c\n\x08REJECTED\x10\x05\x12\x0c\n\x08\x43\x41NCELED\x10\x06\"h\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0e\n\nPROCESSING\x10\x02\x12\r\n\tPROCESSED\x10\x03\x12\x0c\n\x08\x43\x41NCELED\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05J\x04\x08\x06\x10\x07\x42q\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.quotamanager.v1.quota_request_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.quotamanager.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/quotamanager/v1;quotamanager'
  _globals['_QUOTAREQUEST']._serialized_start=161
  _globals['_QUOTAREQUEST']._serialized_end=906
  _globals['_QUOTAREQUEST_QUOTALIMIT']._serialized_start=460
  _globals['_QUOTAREQUEST_QUOTALIMIT']._serialized_end=794
  _globals['_QUOTAREQUEST_QUOTALIMIT_STATUS']._serialized_start=669
  _globals['_QUOTAREQUEST_QUOTALIMIT_STATUS']._serialized_end=794
  _globals['_QUOTAREQUEST_STATUS']._serialized_start=796
  _globals['_QUOTAREQUEST_STATUS']._serialized_end=900
# @@protoc_insertion_point(module_scope)
