# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/common/transceiver_type.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/common/transceiver_type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/cic/v1/common/transceiver_type.proto\x12\x1ayandex.cloud.cic.v1.common*\xdd\x01\n\x0fTransceiverType\x12 \n\x1cTRANSCEIVER_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cTRANSCEIVER_TYPE_1000BASE_LX\x10\x01\x12\x1f\n\x1bTRANSCEIVER_TYPE_10GBASE_LR\x10\x02\x12\x1f\n\x1bTRANSCEIVER_TYPE_10GBASE_ER\x10\x03\x12!\n\x1dTRANSCEIVER_TYPE_100GBASE_LR4\x10\x04\x12!\n\x1dTRANSCEIVER_TYPE_100GBASE_ER4\x10\x05\x42\x64\n\x1eyandex.cloud.api.cic.v1.commonZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1/common;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.common.transceiver_type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.cic.v1.commonZBgithub.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1/common;cic'
  _globals['_TRANSCEIVERTYPE']._serialized_start=82
  _globals['_TRANSCEIVERTYPE']._serialized_end=303
# @@protoc_insertion_point(module_scope)
