"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.quotamanager.v1.quota_request_pb2
import yandex.cloud.quotamanager.v1.resource_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetQuotaRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_REQUEST_ID_FIELD_NUMBER: builtins.int
    quota_request_id: builtins.str
    """ID of the quota request to return."""
    def __init__(
        self,
        *,
        quota_request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["quota_request_id", b"quota_request_id"]) -> None: ...

global___GetQuotaRequestRequest = GetQuotaRequestRequest

@typing.final
class CreateQuotaRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class DesiredQuotaLimit(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        QUOTA_ID_FIELD_NUMBER: builtins.int
        DESIRED_LIMIT_FIELD_NUMBER: builtins.int
        quota_id: builtins.str
        """ID of the quota"""
        desired_limit: builtins.float
        """Desired limit of the quota"""
        def __init__(
            self,
            *,
            quota_id: builtins.str = ...,
            desired_limit: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["desired_limit", b"desired_limit", "quota_id", b"quota_id"]) -> None: ...

    RESOURCE_FIELD_NUMBER: builtins.int
    DESIRED_QUOTA_LIMITS_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> yandex.cloud.quotamanager.v1.resource_pb2.Resource:
        """Resource to create a quota request in."""

    @property
    def desired_quota_limits(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CreateQuotaRequestRequest.DesiredQuotaLimit]:
        """Desired quota limits"""

    def __init__(
        self,
        *,
        resource: yandex.cloud.quotamanager.v1.resource_pb2.Resource | None = ...,
        desired_quota_limits: collections.abc.Iterable[global___CreateQuotaRequestRequest.DesiredQuotaLimit] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["desired_quota_limits", b"desired_quota_limits", "resource", b"resource"]) -> None: ...

global___CreateQuotaRequestRequest = CreateQuotaRequestRequest

@typing.final
class CreateQuotaRequestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_REQUEST_ID_FIELD_NUMBER: builtins.int
    quota_request_id: builtins.str
    """ID of the quota request that is being created."""
    def __init__(
        self,
        *,
        quota_request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["quota_request_id", b"quota_request_id"]) -> None: ...

global___CreateQuotaRequestMetadata = CreateQuotaRequestMetadata

@typing.final
class CancelQuotaRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_REQUEST_ID_FIELD_NUMBER: builtins.int
    QUOTA_IDS_FIELD_NUMBER: builtins.int
    quota_request_id: builtins.str
    """ID of the quota request to update."""
    @property
    def quota_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Quota IDs that is being canceled."""

    def __init__(
        self,
        *,
        quota_request_id: builtins.str = ...,
        quota_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["quota_ids", b"quota_ids", "quota_request_id", b"quota_request_id"]) -> None: ...

global___CancelQuotaRequestRequest = CancelQuotaRequestRequest

@typing.final
class CancelQuotaRequestMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_REQUEST_ID_FIELD_NUMBER: builtins.int
    quota_request_id: builtins.str
    """ID of the quota request that is being updated."""
    def __init__(
        self,
        *,
        quota_request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["quota_request_id", b"quota_request_id"]) -> None: ...

global___CancelQuotaRequestMetadata = CancelQuotaRequestMetadata

@typing.final
class ListQuotaRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [quotaRequest.status] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListQuotaRequestsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListQuotaRequestsResponse.next_page_token]
    returned by a previous list request.
    """
    @property
    def resource(self) -> yandex.cloud.quotamanager.v1.resource_pb2.Resource:
        """Resource to list quota requests in."""

    def __init__(
        self,
        *,
        resource: yandex.cloud.quotamanager.v1.resource_pb2.Resource | None = ...,
        filter: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resource", b"resource"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "resource", b"resource"]) -> None: ...

global___ListQuotaRequestRequest = ListQuotaRequestRequest

@typing.final
class ListQuotaRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_REQUESTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListQuotaRequestsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListQuotaRequestsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def quota_requests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.quotamanager.v1.quota_request_pb2.QuotaRequest]:
        """List of quota requests."""

    def __init__(
        self,
        *,
        quota_requests: collections.abc.Iterable[yandex.cloud.quotamanager.v1.quota_request_pb2.QuotaRequest] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "quota_requests", b"quota_requests"]) -> None: ...

global___ListQuotaRequestResponse = ListQuotaRequestResponse

@typing.final
class ListQuotaRequestOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUOTA_REQUEST_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    quota_request_id: builtins.str
    """ID of the quota request to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListQuotaRequestOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token]
    to the [ListQuotaRequestOperationsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        quota_request_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "quota_request_id", b"quota_request_id"]) -> None: ...

global___ListQuotaRequestOperationsRequest = ListQuotaRequestOperationsRequest

@typing.final
class ListQuotaRequestOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListQuotaRequestOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListQuotaRequestOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified quota request."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListQuotaRequestOperationsResponse = ListQuotaRequestOperationsResponse
