"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.quotamanager.v1.quota_request_pb2
import yandex.cloud.quotamanager.v1.quota_request_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class QuotaRequestServiceStub:
    """A set of methods for managing quota requests."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.GetQuotaRequestRequest,
        yandex.cloud.quotamanager.v1.quota_request_pb2.QuotaRequest,
    ]
    """Returns the specified quota request."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.CreateQuotaRequestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a quota request in the specified resource."""

    Cancel: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.CancelQuotaRequestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels quotas in the specified quota request."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestRequest,
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestResponse,
    ]
    """Retrieves the list of quota requests in the specified resource."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsRequest,
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsResponse,
    ]
    """Lists operations for the specified quota request."""

class QuotaRequestServiceAsyncStub:
    """A set of methods for managing quota requests."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.GetQuotaRequestRequest,
        yandex.cloud.quotamanager.v1.quota_request_pb2.QuotaRequest,
    ]
    """Returns the specified quota request."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.CreateQuotaRequestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a quota request in the specified resource."""

    Cancel: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.CancelQuotaRequestRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Cancels quotas in the specified quota request."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestRequest,
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestResponse,
    ]
    """Retrieves the list of quota requests in the specified resource."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsRequest,
        yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsResponse,
    ]
    """Lists operations for the specified quota request."""

class QuotaRequestServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing quota requests."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.quotamanager.v1.quota_request_service_pb2.GetQuotaRequestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.quotamanager.v1.quota_request_pb2.QuotaRequest, collections.abc.Awaitable[yandex.cloud.quotamanager.v1.quota_request_pb2.QuotaRequest]]:
        """Returns the specified quota request."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.quotamanager.v1.quota_request_service_pb2.CreateQuotaRequestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a quota request in the specified resource."""

    @abc.abstractmethod
    def Cancel(
        self,
        request: yandex.cloud.quotamanager.v1.quota_request_service_pb2.CancelQuotaRequestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Cancels quotas in the specified quota request."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestResponse, collections.abc.Awaitable[yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestResponse]]:
        """Retrieves the list of quota requests in the specified resource."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsResponse, collections.abc.Awaitable[yandex.cloud.quotamanager.v1.quota_request_service_pb2.ListQuotaRequestOperationsResponse]]:
        """Lists operations for the specified quota request."""

def add_QuotaRequestServiceServicer_to_server(servicer: QuotaRequestServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
