"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.monitoring.v3.link_item_pb2
import yandex.cloud.monitoring.v3.parametrization_pb2
import yandex.cloud.monitoring.v3.timeline_pb2
import yandex.cloud.monitoring.v3.widget_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Dashboard(google.protobuf.message.Message):
    """Dashboard resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    MODIFIED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    WIDGETS_FIELD_NUMBER: builtins.int
    PARAMETRIZATION_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    MANAGED_BY_FIELD_NUMBER: builtins.int
    MANAGED_LINK_FIELD_NUMBER: builtins.int
    TIMELINE_FIELD_NUMBER: builtins.int
    LINKS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Dashboard ID."""
    folder_id: builtins.str
    """Folder ID."""
    created_by: builtins.str
    """ID of the user who created the dashboard."""
    modified_by: builtins.str
    """ID of the user who modified the dashboard."""
    name: builtins.str
    """Dashboard name."""
    description: builtins.str
    """Dashboard description."""
    title: builtins.str
    """Dashboard title."""
    etag: builtins.str
    """Dashboard etag."""
    managed_by: builtins.str
    """Entity that controls dashboard
    Must match the regular expression "[\\w \\-]{1,100}"
    """
    managed_link: builtins.str
    """Information about entity that controls dashboard
    Must be valid URI
    """
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Modification timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.widget_pb2.Widget]:
        """List of dashboard widgets."""

    @property
    def parametrization(self) -> yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization:
        """Dashboard parametrization."""

    @property
    def timeline(self) -> yandex.cloud.monitoring.v3.timeline_pb2.Timeline:
        """Refresh and time window settings"""

    @property
    def links(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.monitoring.v3.link_item_pb2.LinkItem]:
        """Dashboard links"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        modified_by: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        title: builtins.str = ...,
        widgets: collections.abc.Iterable[yandex.cloud.monitoring.v3.widget_pb2.Widget] | None = ...,
        parametrization: yandex.cloud.monitoring.v3.parametrization_pb2.Parametrization | None = ...,
        etag: builtins.str = ...,
        managed_by: builtins.str = ...,
        managed_link: builtins.str = ...,
        timeline: yandex.cloud.monitoring.v3.timeline_pb2.Timeline | None = ...,
        links: collections.abc.Iterable[yandex.cloud.monitoring.v3.link_item_pb2.LinkItem] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["container", b"container", "created_at", b"created_at", "folder_id", b"folder_id", "modified_at", b"modified_at", "parametrization", b"parametrization", "timeline", b"timeline"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container", b"container", "created_at", b"created_at", "created_by", b"created_by", "description", b"description", "etag", b"etag", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "links", b"links", "managed_by", b"managed_by", "managed_link", b"managed_link", "modified_at", b"modified_at", "modified_by", b"modified_by", "name", b"name", "parametrization", b"parametrization", "timeline", b"timeline", "title", b"title", "widgets", b"widgets"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container", b"container"]) -> typing.Literal["folder_id"] | None: ...

global___Dashboard = Dashboard
