"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.monitoring.v3.link_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LinkItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LinkGroup(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TITLE_FIELD_NUMBER: builtins.int
        ITEMS_FIELD_NUMBER: builtins.int
        title: builtins.str
        @property
        def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LinkItem]: ...
        def __init__(
            self,
            *,
            title: builtins.str = ...,
            items: collections.abc.Iterable[global___LinkItem] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["items", b"items", "title", b"title"]) -> None: ...

    LINK_FIELD_NUMBER: builtins.int
    GROUP_FIELD_NUMBER: builtins.int
    @property
    def link(self) -> yandex.cloud.monitoring.v3.link_pb2.Link: ...
    @property
    def group(self) -> global___LinkItem.LinkGroup: ...
    def __init__(
        self,
        *,
        link: yandex.cloud.monitoring.v3.link_pb2.Link | None = ...,
        group: global___LinkItem.LinkGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["group", b"group", "link", b"link", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group", b"group", "link", b"link", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["type", b"type"]) -> typing.Literal["link", "group"] | None: ...

global___LinkItem = LinkItem
