"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OAuthClient(google.protobuf.message.Message):
    """An OauthClient resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OAuthClient._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: OAuthClient._Status.ValueType  # 0
        CREATING: OAuthClient._Status.ValueType  # 1
        """OAuth client is being created."""
        ACTIVE: OAuthClient._Status.ValueType  # 2
        """OAuth client is active."""
        DELETING: OAuthClient._Status.ValueType  # 3
        """OAuth client is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: OAuthClient.Status.ValueType  # 0
    CREATING: OAuthClient.Status.ValueType  # 1
    """OAuth client is being created."""
    ACTIVE: OAuthClient.Status.ValueType  # 2
    """OAuth client is active."""
    DELETING: OAuthClient.Status.ValueType  # 3
    """OAuth client is being deleted."""

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    REDIRECT_URIS_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the oauth client."""
    name: builtins.str
    """Name for the oauth client."""
    folder_id: builtins.str
    """ID of the folder oauth client belongs to."""
    status: global___OAuthClient.Status.ValueType
    """Current status of the oauth client."""
    @property
    def redirect_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of redirect uries allowed for the oauth client."""

    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of oauth scopes requested by the oauth client."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        redirect_uris: collections.abc.Iterable[builtins.str] | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        folder_id: builtins.str = ...,
        status: global___OAuthClient.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "id", b"id", "name", b"name", "redirect_uris", b"redirect_uris", "scopes", b"scopes", "status", b"status"]) -> None: ...

global___OAuthClient = OAuthClient
