# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/video/v1/style_preset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/video/v1/style_preset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.video.v1 import style_preset_pb2 as yandex_dot_cloud_dot_video_dot_v1_dot_style__preset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/video/v1/style_preset_service.proto\x12\x15yandex.cloud.video.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/video/v1/style_preset.proto\">\n\x15GetStylePresetRequest\x12%\n\x0fstyle_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xb8\x01\n\x17ListStylePresetsRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x1f\n\npage_token\x18\x65 \x01(\tB\x0b\x8a\xc8\x31\x07<=15000\x12\x1a\n\x08order_by\x18\x66 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1a\n\x06\x66ilter\x18g \x01(\tB\n\x8a\xc8\x31\x06<=1000J\x04\x08\x02\x10\x64\"t\n\x18ListStylePresetsResponse\x12\x39\n\rstyle_presets\x18\x01 \x03(\x0b\x32\".yandex.cloud.video.v1.StylePreset\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\x9b\x07\n\x18\x43reateStylePresetRequest\x12 \n\nchannel_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\x05title\x18\x02 \x01(\tB\x1f\xe8\xc7\x31\x01\xf2\xc7\x31\x0f[a-zA-Z0-9-_ ]+\x8a\xc8\x31\x04<=50\x12\x37\n\x10\x62\x61\x63kground_color\x18\x03 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12@\n\x19widget_text_color_primary\x18\x04 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12\x42\n\x1bwidget_text_color_secondary\x18\x05 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12:\n\x13widget_accent_color\x18\x06 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12\"\n\x10widget_block_gap\x18\x07 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12\x43\n\x1cwidget_block_separator_color\x18\x08 \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12%\n\x14player_border_radius\x18\r \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\x33\n\x0cplayer_color\x18\x0e \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12N\n\'playlist_selected_item_background_color\x18\x0f \x01(\tB\x1d\xe8\xc7\x31\x01\xf2\xc7\x31\r[#a-zA-Z0-9]+\x8a\xc8\x31\x04<=50\x12,\n\x1bplaylist_item_border_radius\x18\x10 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\"\n\x11playlist_item_gap\x18\x11 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12R\n\x11playlist_location\x18\x12 \x01(\x0e\x32\x31.yandex.cloud.video.v1.StylePreset.WidgetLocationB\x04\xe8\xc7\x31\x01\x12\x34\n\rright_widgets\x18\x0b \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12\x35\n\x0e\x62ottom_widgets\x18\x0c \x03(\x0b\x32\x1d.yandex.cloud.video.v1.WidgetJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"4\n\x19\x43reateStylePresetMetadata\x12\x17\n\x0fstyle_preset_id\x18\x01 \x01(\t\"\xb5\x07\n\x18UpdateStylePresetRequest\x12%\n\x0fstyle_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x34\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12*\n\x05title\x18\x03 \x01(\tB\x1b\xf2\xc7\x31\x0f[a-zA-Z0-9-_ ]*\x8a\xc8\x31\x04<=50\x12\x34\n\x10\x62\x61\x63kground_color\x18\x04 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12=\n\x19widget_text_color_primary\x18\x05 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12?\n\x1bwidget_text_color_secondary\x18\x06 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12\x37\n\x13widget_accent_color\x18\x07 \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12\"\n\x10widget_block_gap\x18\x08 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12@\n\x1cwidget_block_separator_color\x18\t \x01(\tB\x1a\xf2\xc7\x31\x0e[#a-zA-Z0-9-]*\x8a\xc8\x31\x04<=50\x12%\n\x14player_border_radius\x18\x0e \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12/\n\x0cplayer_color\x18\x0f \x01(\tB\x19\xf2\xc7\x31\r[#a-zA-Z0-9]*\x8a\xc8\x31\x04<=50\x12J\n\'playlist_selected_item_background_color\x18\x10 \x01(\tB\x19\xf2\xc7\x31\r[#a-zA-Z0-9]*\x8a\xc8\x31\x04<=50\x12,\n\x1bplaylist_item_border_radius\x18\x11 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12\"\n\x11playlist_item_gap\x18\x12 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=0\x12L\n\x11playlist_location\x18\x13 \x01(\x0e\x32\x31.yandex.cloud.video.v1.StylePreset.WidgetLocation\x12\x34\n\rright_widgets\x18\x0c \x03(\x0b\x32\x1d.yandex.cloud.video.v1.Widget\x12\x35\n\x0e\x62ottom_widgets\x18\r \x03(\x0b\x32\x1d.yandex.cloud.video.v1.WidgetJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"4\n\x19UpdateStylePresetMetadata\x12\x17\n\x0fstyle_preset_id\x18\x01 \x01(\t\"A\n\x18\x44\x65leteStylePresetRequest\x12%\n\x0fstyle_preset_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x19\x44\x65leteStylePresetMetadata\x12\x17\n\x0fstyle_preset_id\x18\x01 \x01(\t2\xdf\x06\n\x12StylePresetService\x12\x89\x01\n\x03Get\x12,.yandex.cloud.video.v1.GetStylePresetRequest\x1a\".yandex.cloud.video.v1.StylePreset\"0\x82\xd3\xe4\x93\x02*\x12(/video/v1/stylePresets/{style_preset_id}\x12\x87\x01\n\x04List\x12..yandex.cloud.video.v1.ListStylePresetsRequest\x1a/.yandex.cloud.video.v1.ListStylePresetsResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/video/v1/stylePresets\x12\xab\x01\n\x06\x43reate\x12/.yandex.cloud.video.v1.CreateStylePresetRequest\x1a!.yandex.cloud.operation.Operation\"M\xb2\xd2*(\n\x19\x43reateStylePresetMetadata\x12\x0bStylePreset\x82\xd3\xe4\x93\x02\x1b\"\x16/video/v1/stylePresets:\x01*\x12\xbd\x01\n\x06Update\x12/.yandex.cloud.video.v1.UpdateStylePresetRequest\x1a!.yandex.cloud.operation.Operation\"_\xb2\xd2*(\n\x19UpdateStylePresetMetadata\x12\x0bStylePreset\x82\xd3\xe4\x93\x02-2(/video/v1/stylePresets/{style_preset_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12/.yandex.cloud.video.v1.DeleteStylePresetRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*2\n\x19\x44\x65leteStylePresetMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02**(/video/v1/stylePresets/{style_preset_id}B\\\n\x19yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;videob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.video.v1.style_preset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031yandex.cloud.api.video.v1Z?github.com/yandex-cloud/go-genproto/yandex/cloud/video/v1;video'
  _globals['_GETSTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_GETSTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\007<=15000'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTSTYLEPRESETSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['channel_id']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['channel_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['title']._serialized_options = b'\350\3071\001\362\3071\017[a-zA-Z0-9-_ ]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['background_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['background_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._serialized_options = b'\372\3071\0040-10'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['player_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._serialized_options = b'\350\3071\001\362\3071\r[#a-zA-Z0-9]+\212\3101\004<=50'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._serialized_options = b'\372\3071\003>=0'
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_location']._loaded_options = None
  _globals['_CREATESTYLEPRESETREQUEST'].fields_by_name['playlist_location']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['field_mask']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['field_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['title']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['title']._serialized_options = b'\362\3071\017[a-zA-Z0-9-_ ]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['background_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['background_color']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_primary']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_text_color_secondary']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_accent_color']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_gap']._serialized_options = b'\372\3071\0040-10'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['widget_block_separator_color']._serialized_options = b'\362\3071\016[#a-zA-Z0-9-]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['player_color']._serialized_options = b'\362\3071\r[#a-zA-Z0-9]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_selected_item_background_color']._serialized_options = b'\362\3071\r[#a-zA-Z0-9]*\212\3101\004<=50'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_border_radius']._serialized_options = b'\372\3071\003>=0'
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._loaded_options = None
  _globals['_UPDATESTYLEPRESETREQUEST'].fields_by_name['playlist_item_gap']._serialized_options = b'\372\3071\003>=0'
  _globals['_DELETESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._loaded_options = None
  _globals['_DELETESTYLEPRESETREQUEST'].fields_by_name['style_preset_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002*\022(/video/v1/stylePresets/{style_preset_id}'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\030\022\026/video/v1/stylePresets'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateStylePresetMetadata\022\013StylePreset\202\323\344\223\002\033\"\026/video/v1/stylePresets:\001*'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateStylePresetMetadata\022\013StylePreset\202\323\344\223\002-2(/video/v1/stylePresets/{style_preset_id}:\001*'
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_STYLEPRESETSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteStylePresetMetadata\022\025google.protobuf.Empty\202\323\344\223\002**(/video/v1/stylePresets/{style_preset_id}'
  _globals['_GETSTYLEPRESETREQUEST']._serialized_start=286
  _globals['_GETSTYLEPRESETREQUEST']._serialized_end=348
  _globals['_LISTSTYLEPRESETSREQUEST']._serialized_start=351
  _globals['_LISTSTYLEPRESETSREQUEST']._serialized_end=535
  _globals['_LISTSTYLEPRESETSRESPONSE']._serialized_start=537
  _globals['_LISTSTYLEPRESETSRESPONSE']._serialized_end=653
  _globals['_CREATESTYLEPRESETREQUEST']._serialized_start=656
  _globals['_CREATESTYLEPRESETREQUEST']._serialized_end=1579
  _globals['_CREATESTYLEPRESETMETADATA']._serialized_start=1581
  _globals['_CREATESTYLEPRESETMETADATA']._serialized_end=1633
  _globals['_UPDATESTYLEPRESETREQUEST']._serialized_start=1636
  _globals['_UPDATESTYLEPRESETREQUEST']._serialized_end=2585
  _globals['_UPDATESTYLEPRESETMETADATA']._serialized_start=2587
  _globals['_UPDATESTYLEPRESETMETADATA']._serialized_end=2639
  _globals['_DELETESTYLEPRESETREQUEST']._serialized_start=2641
  _globals['_DELETESTYLEPRESETREQUEST']._serialized_end=2706
  _globals['_DELETESTYLEPRESETMETADATA']._serialized_start=2708
  _globals['_DELETESTYLEPRESETMETADATA']._serialized_end=2760
  _globals['_STYLEPRESETSERVICE']._serialized_start=2763
  _globals['_STYLEPRESETSERVICE']._serialized_end=3626
# @@protoc_insertion_point(module_scope)
