"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MaintenanceOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DELAYED_UNTIL_FIELD_NUMBER: builtins.int
    LATEST_MAINTENANCE_TIME_FIELD_NUMBER: builtins.int
    NEXT_MAINTENANCE_WINDOW_TIME_FIELD_NUMBER: builtins.int
    info: builtins.str
    """The description of the operation."""
    @property
    def delayed_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Delay time for the maintenance operation."""

    @property
    def latest_maintenance_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the last maintenance window."""

    @property
    def next_maintenance_window_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the next maintenance window."""

    def __init__(
        self,
        *,
        info: builtins.str = ...,
        delayed_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        latest_maintenance_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        next_maintenance_window_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["delayed_until", b"delayed_until", "latest_maintenance_time", b"latest_maintenance_time", "next_maintenance_window_time", b"next_maintenance_window_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["delayed_until", b"delayed_until", "info", b"info", "latest_maintenance_time", b"latest_maintenance_time", "next_maintenance_window_time", b"next_maintenance_window_time"]) -> None: ...

global___MaintenanceOperation = MaintenanceOperation
