"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BatchInferenceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    TASK_STATUS_FIELD_NUMBER: builtins.int
    COMPLETED_BATCHES_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    task_status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType
    completed_batches: builtins.int
    total_batches: builtins.int
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        task_status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType = ...,
        completed_batches: builtins.int = ...,
        total_batches: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["completed_batches", b"completed_batches", "task_id", b"task_id", "task_status", b"task_status", "total_batches", b"total_batches"]) -> None: ...

global___BatchInferenceMetadata = BatchInferenceMetadata

@typing.final
class BatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask: ...
    def __init__(
        self,
        *,
        task: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___BatchInferenceResponse = BatchInferenceResponse

@typing.final
class DescribeBatchInferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """Required task id"""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___DescribeBatchInferenceRequest = DescribeBatchInferenceRequest

@typing.final
class DescribeBatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_FIELD_NUMBER: builtins.int
    @property
    def task(self) -> yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask: ...
    def __init__(
        self,
        *,
        task: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["task", b"task"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["task", b"task"]) -> None: ...

global___DescribeBatchInferenceResponse = DescribeBatchInferenceResponse

@typing.final
class ListBatchInferencesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """Folder ID for which the list of tasks will be provided."""
    page_size: builtins.int
    page_token: builtins.str
    status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType
    """Batch inference status for filtering"""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        status: yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token", "status", b"status"]) -> None: ...

global___ListBatchInferencesRequest = ListBatchInferencesRequest

@typing.final
class ListBatchInferencesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASKS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask]: ...
    def __init__(
        self,
        *,
        tasks: collections.abc.Iterable[yandex.cloud.ai.batch_inference.v1.batch_inference_task_pb2.BatchInferenceTask] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "tasks", b"tasks"]) -> None: ...

global___ListBatchInferencesResponse = ListBatchInferencesResponse

@typing.final
class CancelBatchInferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """Task ID that should be canceled."""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___CancelBatchInferenceRequest = CancelBatchInferenceRequest

@typing.final
class CancelBatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___CancelBatchInferenceResponse = CancelBatchInferenceResponse

@typing.final
class DeleteBatchInferenceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """Task ID that should be deleted."""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___DeleteBatchInferenceRequest = DeleteBatchInferenceRequest

@typing.final
class DeleteBatchInferenceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["task_id", b"task_id"]) -> None: ...

global___DeleteBatchInferenceResponse = DeleteBatchInferenceResponse
