# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/maintenance/v2/common.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/maintenance/v2/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/maintenance/v2/common.proto\x12\x1byandex.cloud.maintenance.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb3\x06\n\x0bMaintenance\x12\n\n\x02id\x18\x01 \x01(\t\x12H\n\rresource_path\x18\x02 \x03(\x0b\x32\x31.yandex.cloud.maintenance.v2.Maintenance.Resource\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12@\n\x07\x64\x65tails\x18\x04 \x03(\x0b\x32/.yandex.cloud.maintenance.v2.Maintenance.Detail\x12?\n\x06status\x18\x05 \x01(\x0e\x32/.yandex.cloud.maintenance.v2.Maintenance.Status\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12start_scheduled_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17\x63ompletion_scheduled_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16max_start_scheduled_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csucceeded_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11user_controllable\x18\r \x01(\x08\x1a$\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x1a$\n\x06\x44\x65tail\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\r\n\tSUCCEEDED\x10\x03\x12\r\n\tCANCELLED\x10\x04\"\xfa\x01\n\x17ListMaintenancesRequest\x12\x1c\n\x08\x63loud_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tfolder_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bresource_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1d\n\tpage_size\x18\x04 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=500\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x19\n\x06\x66ilter\x18\x07 \x01(\tB\t\x8a\xc8\x31\x05<=100B\x0b\n\tcontainer\"s\n\x18ListMaintenancesResponse\x12>\n\x0cmaintenances\x18\x01 \x03(\x0b\x32(.yandex.cloud.maintenance.v2.Maintenance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x15GetMaintenanceRequest\x12$\n\x0emaintenance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xaa\x02\n\x1cRescheduleMaintenanceRequest\x12$\n\x0emaintenance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x0freschedule_type\x18\x02 \x01(\x0e\x32>.yandex.cloud.maintenance.v2.RescheduleMaintenanceRequest.Type\x12\x30\n\x0cscheduled_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Y\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x19\n\x15NEXT_AVAILABLE_WINDOW\x10\x02\x12\x11\n\rSPECIFIC_TIME\x10\x03\x42n\n\x1fyandex.cloud.api.maintenance.v2ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/maintenance/v2;maintenanceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.maintenance.v2.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037yandex.cloud.api.maintenance.v2ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/maintenance/v2;maintenance'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['cloud_id']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['cloud_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['resource_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=500'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTMAINTENANCESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\005<=100'
  _globals['_GETMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._loaded_options = None
  _globals['_GETMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._loaded_options = None
  _globals['_RESCHEDULEMAINTENANCEREQUEST'].fields_by_name['maintenance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_MAINTENANCE']._serialized_start=138
  _globals['_MAINTENANCE']._serialized_end=957
  _globals['_MAINTENANCE_RESOURCE']._serialized_start=791
  _globals['_MAINTENANCE_RESOURCE']._serialized_end=827
  _globals['_MAINTENANCE_DETAIL']._serialized_start=829
  _globals['_MAINTENANCE_DETAIL']._serialized_end=865
  _globals['_MAINTENANCE_STATUS']._serialized_start=867
  _globals['_MAINTENANCE_STATUS']._serialized_end=957
  _globals['_LISTMAINTENANCESREQUEST']._serialized_start=960
  _globals['_LISTMAINTENANCESREQUEST']._serialized_end=1210
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_start=1212
  _globals['_LISTMAINTENANCESRESPONSE']._serialized_end=1327
  _globals['_GETMAINTENANCEREQUEST']._serialized_start=1329
  _globals['_GETMAINTENANCEREQUEST']._serialized_end=1390
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=1393
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=1691
  _globals['_RESCHEDULEMAINTENANCEREQUEST_TYPE']._serialized_start=1602
  _globals['_RESCHEDULEMAINTENANCEREQUEST_TYPE']._serialized_end=1691
# @@protoc_insertion_point(module_scope)
