# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/disk.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/disk.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/clouddesktop/v1/disk.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1dyandex/cloud/validation.proto\"\x95\x01\n\x08\x44iskSpec\x12\x43\n\x04type\x18\x03 \x01(\x0e\x32/.yandex.cloud.clouddesktop.v1.api.DiskSpec.TypeB\x04\xe8\xc7\x31\x01\x12\x14\n\x04size\x18\x04 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\".\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03HDD\x10\x01\x12\x07\n\x03SSD\x10\x02\x42w\n yandex.cloud.api.clouddesktop.v1B\x04PADDZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.disk_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1B\004PADDZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_DISKSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_DISKSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_DISKSPEC'].fields_by_name['size']._loaded_options = None
  _globals['_DISKSPEC'].fields_by_name['size']._serialized_options = b'\372\3071\002>0'
  _globals['_DISKSPEC']._serialized_start=109
  _globals['_DISKSPEC']._serialized_end=258
  _globals['_DISKSPEC_TYPE']._serialized_start=212
  _globals['_DISKSPEC_TYPE']._serialized_end=258
# @@protoc_insertion_point(module_scope)
