# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/test/test.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/test/test.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import single_agent_configuration_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_single__agent__configuration__pb2
from yandex.cloud.loadtesting.api.v1.test import details_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_details__pb2
from yandex.cloud.loadtesting.api.v1.test import summary_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_summary__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/loadtesting/api/v1/test/test.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x45yandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto\x1a\x32yandex/cloud/loadtesting/api/v1/test/details.proto\x1a\x32yandex/cloud/loadtesting/api/v1/test/summary.proto\"\xfd\x01\n\x04Test\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x0e\x63onfigurations\x18\x02 \x03(\x0b\x32>.yandex.cloud.loadtesting.api.v1.test.SingleAgentConfiguration\x12>\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32-.yandex.cloud.loadtesting.api.v1.test.Details\x12>\n\x07summary\x18\x04 \x01(\x0b\x32-.yandex.cloud.loadtesting.api.v1.test.Summary\x12\x11\n\tfolder_id\x18\x05 \x01(\tBy\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.test_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _globals['_TEST']._serialized_start=265
  _globals['_TEST']._serialized_end=518
# @@protoc_insertion_point(module_scope)
