"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _YdbCleanupPolicy:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _YdbCleanupPolicyEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_YdbCleanupPolicy.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    YDB_CLEANUP_POLICY_UNSPECIFIED: _YdbCleanupPolicy.ValueType  # 0
    YDB_CLEANUP_POLICY_DISABLED: _YdbCleanupPolicy.ValueType  # 1
    YDB_CLEANUP_POLICY_DROP: _YdbCleanupPolicy.ValueType  # 2

class YdbCleanupPolicy(_YdbCleanupPolicy, metaclass=_YdbCleanupPolicyEnumTypeWrapper): ...

YDB_CLEANUP_POLICY_UNSPECIFIED: YdbCleanupPolicy.ValueType  # 0
YDB_CLEANUP_POLICY_DISABLED: YdbCleanupPolicy.ValueType  # 1
YDB_CLEANUP_POLICY_DROP: YdbCleanupPolicy.ValueType  # 2
global___YdbCleanupPolicy = YdbCleanupPolicy

class _YdbDefaultCompression:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _YdbDefaultCompressionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_YdbDefaultCompression.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    YDB_DEFAULT_COMPRESSION_UNSPECIFIED: _YdbDefaultCompression.ValueType  # 0
    YDB_DEFAULT_COMPRESSION_DISABLED: _YdbDefaultCompression.ValueType  # 1
    YDB_DEFAULT_COMPRESSION_LZ4: _YdbDefaultCompression.ValueType  # 2

class YdbDefaultCompression(_YdbDefaultCompression, metaclass=_YdbDefaultCompressionEnumTypeWrapper): ...

YDB_DEFAULT_COMPRESSION_UNSPECIFIED: YdbDefaultCompression.ValueType  # 0
YDB_DEFAULT_COMPRESSION_DISABLED: YdbDefaultCompression.ValueType  # 1
YDB_DEFAULT_COMPRESSION_LZ4: YdbDefaultCompression.ValueType  # 2
global___YdbDefaultCompression = YdbDefaultCompression

@typing.final
class YdbSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SA_KEY_CONTENT_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    CHANGEFEED_CUSTOM_NAME_FIELD_NUMBER: builtins.int
    CHANGEFEED_CUSTOM_CONSUMER_NAME_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Path in YDB where to store tables"""
    instance: builtins.str
    """Instance of YDB. example: ydb-ru-prestable.yandex.net:2135"""
    service_account_id: builtins.str
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    sa_key_content: builtins.str
    """Authorization Key"""
    changefeed_custom_name: builtins.str
    """Pre-created change feed"""
    changefeed_custom_consumer_name: builtins.str
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        database: builtins.str = ...,
        instance: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        service_account_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
        sa_key_content: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        changefeed_custom_name: builtins.str = ...,
        changefeed_custom_consumer_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["changefeed_custom_consumer_name", b"changefeed_custom_consumer_name", "changefeed_custom_name", b"changefeed_custom_name", "database", b"database", "instance", b"instance", "paths", b"paths", "sa_key_content", b"sa_key_content", "security_groups", b"security_groups", "service_account_id", b"service_account_id", "subnet_id", b"subnet_id"]) -> None: ...

global___YdbSource = YdbSource

@typing.final
class YdbTarget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASE_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    CLEANUP_POLICY_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    SA_KEY_CONTENT_FIELD_NUMBER: builtins.int
    SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    IS_TABLE_COLUMN_ORIENTED_FIELD_NUMBER: builtins.int
    DEFAULT_COMPRESSION_FIELD_NUMBER: builtins.int
    IS_SCHEMA_MIGRATION_DISABLED_FIELD_NUMBER: builtins.int
    database: builtins.str
    """Path in YDB where to store tables"""
    instance: builtins.str
    """Instance of YDB. example: ydb-ru-prestable.yandex.net:2135"""
    path: builtins.str
    """Path extension for database, each table will be layouted into this path"""
    service_account_id: builtins.str
    cleanup_policy: global___YdbCleanupPolicy.ValueType
    """Cleanup policy"""
    subnet_id: builtins.str
    """Network interface for endpoint. If none will assume public ipv4"""
    sa_key_content: builtins.str
    """SA content"""
    is_table_column_oriented: builtins.bool
    """Should create column-oriented table (OLAP). By default it creates row-oriented
    (OLTP)
    """
    default_compression: global___YdbDefaultCompression.ValueType
    """Compression that will be used for default columns family on YDB table creation"""
    is_schema_migration_disabled: builtins.bool
    @property
    def security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Security groups"""

    def __init__(
        self,
        *,
        database: builtins.str = ...,
        instance: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
        cleanup_policy: global___YdbCleanupPolicy.ValueType = ...,
        subnet_id: builtins.str = ...,
        sa_key_content: builtins.str = ...,
        security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        is_table_column_oriented: builtins.bool = ...,
        default_compression: global___YdbDefaultCompression.ValueType = ...,
        is_schema_migration_disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cleanup_policy", b"cleanup_policy", "database", b"database", "default_compression", b"default_compression", "instance", b"instance", "is_schema_migration_disabled", b"is_schema_migration_disabled", "is_table_column_oriented", b"is_table_column_oriented", "path", b"path", "sa_key_content", b"sa_key_content", "security_groups", b"security_groups", "service_account_id", b"service_account_id", "subnet_id", b"subnet_id"]) -> None: ...

global___YdbTarget = YdbTarget
