"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DiskDriveType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DiskDriveTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DiskDriveType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DISK_DRIVE_TYPE_UNSPECIFIED: _DiskDriveType.ValueType  # 0
    """Unspecified disk drive type."""
    HDD: _DiskDriveType.ValueType  # 1
    """Hard disk drive (magnetic storage)."""
    SSD: _DiskDriveType.ValueType  # 2
    """Solid state drive with SATA/SAS interface."""
    NVME: _DiskDriveType.ValueType  # 3
    """Solid state drive with NVMe interface."""

class DiskDriveType(_DiskDriveType, metaclass=_DiskDriveTypeEnumTypeWrapper):
    """Disk drive type."""

DISK_DRIVE_TYPE_UNSPECIFIED: DiskDriveType.ValueType  # 0
"""Unspecified disk drive type."""
HDD: DiskDriveType.ValueType  # 1
"""Hard disk drive (magnetic storage)."""
SSD: DiskDriveType.ValueType  # 2
"""Solid state drive with SATA/SAS interface."""
NVME: DiskDriveType.ValueType  # 3
"""Solid state drive with NVMe interface."""
global___DiskDriveType = DiskDriveType

@typing.final
class Disk(google.protobuf.message.Message):
    """Disk."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SIZE_GIB_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the disk."""
    type: global___DiskDriveType.ValueType
    """Type of the disk drive."""
    size_gib: builtins.int
    """Size of the disk in gibibytes (2^30 bytes)."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: global___DiskDriveType.ValueType = ...,
        size_gib: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "size_gib", b"size_gib", "type", b"type"]) -> None: ...

global___Disk = Disk
