"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.searchapi.v2.img_search_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ImageSearchServiceStub:
    """A set of methods for searching of images using the Yandex Images."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Search: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse,
    ]

    SearchByImage: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse,
    ]

class ImageSearchServiceAsyncStub:
    """A set of methods for searching of images using the Yandex Images."""

    Search: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse,
    ]

    SearchByImage: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageRequest,
        yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse,
    ]

class ImageSearchServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for searching of images using the Yandex Images."""

    @abc.abstractmethod
    def Search(
        self,
        request: yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchResponse]]: ...

    @abc.abstractmethod
    def SearchByImage(
        self,
        request: yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse, collections.abc.Awaitable[yandex.cloud.searchapi.v2.img_search_service_pb2.ImageSearchByImageResponse]]: ...

def add_ImageSearchServiceServicer_to_server(servicer: ImageSearchServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
