# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.loadtesting.api.v1.config import config_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2
from yandex.cloud.loadtesting.api.v1 import config_service_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/loadtesting/api/v1/config_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ConfigServiceStub(object):
    """A set of methods for managing test configurations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/Create',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.CreateConfigRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Get = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/Get',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.GetConfigRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2.Config.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/List',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsResponse.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.loadtesting.api.v1.ConfigService/Delete',
                request_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.DeleteConfigRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class ConfigServiceServicer(object):
    """A set of methods for managing test configurations.
    """

    def Create(self, request, context):
        """Creates a test config in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified config.

        To get the list of all available configs, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of configs in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConfigServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.CreateConfigRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.GetConfigRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2.Config.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.DeleteConfigRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.loadtesting.api.v1.ConfigService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.loadtesting.api.v1.ConfigService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ConfigService(object):
    """A set of methods for managing test configurations.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/Create',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.CreateConfigRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/Get',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.GetConfigRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config_dot_config__pb2.Config.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/List',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsRequest.SerializeToString,
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.ListConfigsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.loadtesting.api.v1.ConfigService/Delete',
            yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_config__service__pb2.DeleteConfigRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
