# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/connection_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/connection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.connectionmanager.v1 import connection_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/connectionmanager/v1/connection_service.proto\x12!yandex.cloud.connectionmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x32yandex/cloud/connectionmanager/v1/connection.proto\"\xa1\x02\n\x17\x43reateConnectionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12V\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.connectionmanager.v1.CreateConnectionRequest.LabelsEntry\x12\x43\n\x06params\x18\x05 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ConnectionParams\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x06\x10\x0b\"1\n\x18\x43reateConnectionMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\xd6\x02\n\x17UpdateConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12V\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.connectionmanager.v1.UpdateConnectionRequest.LabelsEntry\x12\x43\n\x06params\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.ConnectionParams\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x07\x10\n\"1\n\x18UpdateConnectionMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"0\n\x17\x44\x65leteConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteConnectionMetadata\"\xd1\x02\n\x15ListConnectionRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x16\n\x0emdb_cluster_id\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x03\x12\x12\n\npage_token\x18\x05 \x01(\t\x12\x1a\n\x12name_pattern_or_id\x18\x06 \x01(\t\x12\x11\n\tauthor_id\x18\x07 \x01(\t\x12\x14\n\x0cwith_can_use\x18\x08 \x01(\x08\x12\x30\n\x0cis_onpremise\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12-\n\tis_manual\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12:\n\x07\x64\x62_type\x18\x0b \x01(\x0e\x32).yandex.cloud.connectionmanager.v1.DBTypeJ\x04\x08\x03\x10\x04\"t\n\x16ListConnectionResponse\x12\x41\n\nconnection\x18\x01 \x03(\x0b\x32-.yandex.cloud.connectionmanager.v1.Connection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x14GetConnectionRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"4\n\x15ResolveClusterRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\tJ\x04\x08\x02\x10\x03\"B\n\x15\x44\x65leteVersionMetadata\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\"U\n\x15ListOperationsRequest\x12\x15\n\rconnection_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xca\t\n\x11\x43onnectionService\x12\x95\x01\n\x03Get\x12\x37.yandex.cloud.connectionmanager.v1.GetConnectionRequest\x1a-.yandex.cloud.connectionmanager.v1.Connection\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/connection/{connection_id}\x12\xb0\x01\n\x0eResolveCluster\x12\x38.yandex.cloud.connectionmanager.v1.ResolveClusterRequest\x1a-.yandex.cloud.connectionmanager.v1.Connection\"5\x82\xd3\xe4\x93\x02/\x12-/v1/connection/resolveCluster/{connection_id}\x12\x94\x01\n\x04List\x12\x38.yandex.cloud.connectionmanager.v1.ListConnectionRequest\x1a\x39.yandex.cloud.connectionmanager.v1.ListConnectionResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/connections\x12\xac\x01\n\x06\x43reate\x12:.yandex.cloud.connectionmanager.v1.CreateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"C\xb2\xd2*&\n\x18\x43reateConnectionMetadata\x12\nConnection\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/connection:\x01*\x12\xbc\x01\n\x06Update\x12:.yandex.cloud.connectionmanager.v1.UpdateConnectionRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*&\n\x18UpdateConnectionMetadata\x12\nConnection\x82\xd3\xe4\x93\x02#2\x1e/v1/connection/{connection_id}:\x01*\x12\xc4\x01\n\x06\x44\x65lete\x12:.yandex.cloud.connectionmanager.v1.DeleteConnectionRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*1\n\x18\x44\x65leteConnectionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02 *\x1e/v1/connection/{connection_id}\x12\x9d\x01\n\x0eListOperations\x12\x38.yandex.cloud.connectionmanager.v1.ListOperationsRequest\x1a\x39.yandex.cloud.connectionmanager.v1.ListOperationsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/operationsB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.connection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002 \022\036/v1/connection/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ResolveCluster']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ResolveCluster']._serialized_options = b'\202\323\344\223\002/\022-/v1/connection/resolveCluster/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/connections'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateConnectionMetadata\022\nConnection\202\323\344\223\002\023\"\016/v1/connection:\001*'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateConnectionMetadata\022\nConnection\202\323\344\223\002#2\036/v1/connection/{connection_id}:\001*'
  _globals['_CONNECTIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteConnectionMetadata\022\025google.protobuf.Empty\202\323\344\223\002 *\036/v1/connection/{connection_id}'
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_CONNECTIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/operations'
  _globals['_CREATECONNECTIONREQUEST']._serialized_start=320
  _globals['_CREATECONNECTIONREQUEST']._serialized_end=609
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._serialized_start=558
  _globals['_CREATECONNECTIONREQUEST_LABELSENTRY']._serialized_end=603
  _globals['_CREATECONNECTIONMETADATA']._serialized_start=611
  _globals['_CREATECONNECTIONMETADATA']._serialized_end=660
  _globals['_UPDATECONNECTIONREQUEST']._serialized_start=663
  _globals['_UPDATECONNECTIONREQUEST']._serialized_end=1005
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._serialized_start=558
  _globals['_UPDATECONNECTIONREQUEST_LABELSENTRY']._serialized_end=603
  _globals['_UPDATECONNECTIONMETADATA']._serialized_start=1007
  _globals['_UPDATECONNECTIONMETADATA']._serialized_end=1056
  _globals['_DELETECONNECTIONREQUEST']._serialized_start=1058
  _globals['_DELETECONNECTIONREQUEST']._serialized_end=1106
  _globals['_DELETECONNECTIONMETADATA']._serialized_start=1108
  _globals['_DELETECONNECTIONMETADATA']._serialized_end=1134
  _globals['_LISTCONNECTIONREQUEST']._serialized_start=1137
  _globals['_LISTCONNECTIONREQUEST']._serialized_end=1474
  _globals['_LISTCONNECTIONRESPONSE']._serialized_start=1476
  _globals['_LISTCONNECTIONRESPONSE']._serialized_end=1592
  _globals['_GETCONNECTIONREQUEST']._serialized_start=1594
  _globals['_GETCONNECTIONREQUEST']._serialized_end=1651
  _globals['_RESOLVECLUSTERREQUEST']._serialized_start=1653
  _globals['_RESOLVECLUSTERREQUEST']._serialized_end=1705
  _globals['_DELETEVERSIONMETADATA']._serialized_start=1707
  _globals['_DELETEVERSIONMETADATA']._serialized_end=1773
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=1775
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=1860
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=1862
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=1966
  _globals['_CONNECTIONSERVICE']._serialized_start=1969
  _globals['_CONNECTIONSERVICE']._serialized_end=3195
# @@protoc_insertion_point(module_scope)
