# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/gitlab/v1/instance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/gitlab/v1/instance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.gitlab.v1 import maintenance_pb2 as yandex_dot_cloud_dot_gitlab_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/gitlab/v1/instance.proto\x12\x16yandex.cloud.gitlab.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a(yandex/cloud/gitlab/v1/maintenance.proto\"\xe0\x07\n\x08Instance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12<\n\x06labels\x18\x07 \x03(\x0b\x32,.yandex.cloud.gitlab.v1.Instance.LabelsEntry\x12\x1a\n\x12resource_preset_id\x18\x08 \x01(\t\x12\x11\n\tdisk_size\x18\t \x01(\x03\x12\x37\n\x06status\x18\n \x01(\x0e\x32\'.yandex.cloud.gitlab.v1.Instance.Status\x12\x13\n\x0b\x61\x64min_login\x18\x0b \x01(\t\x12\x13\n\x0b\x61\x64min_email\x18\x0c \x01(\t\x12\x0e\n\x06\x64omain\x18\r \x01(\t\x12\x11\n\tsubnet_id\x18\x0e \x01(\t\x12M\n\x11planned_operation\x18\x10 \x01(\x0b\x32,.yandex.cloud.gitlab.v1.MaintenanceOperationB\x04\xe8\xc7\x31\x00\x12!\n\x19\x62\x61\x63kup_retain_period_days\x18\x11 \x01(\x03\x12#\n\x1bmaintenance_delete_untagged\x18\x13 \x01(\x08\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x12\'\n\x11\x61pproval_rules_id\x18\x16 \x01(\tB\x0c\xe8\xc7\x31\x00\x8a\xc8\x31\x04<=30\x12\x16\n\x0egitlab_version\x18\x17 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x02\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0c\n\x08\x44\x45LETING\x10\x05\x12\x13\n\x0f\x42\x41\x43KUP_CREATING\x10\x06\x12\x14\n\x10\x42\x41\x43KUP_RESTORING\x10\x07\x12\x0c\n\x08STARTING\x10\x08\x12\x0c\n\x08STOPPING\x10\t\x12\x0b\n\x07STOPPED\x10\n\x12\x19\n\x15\x42\x41\x43KGROUND_MIGRATIONS\x10\x0b\x12\x1d\n\x19OBJECT_STORAGE_MIGRATIONS\x10\x0c\x12\x16\n\x12SNAPSHOT_RESTORING\x10\rJ\x04\x08\x0f\x10\x10J\x04\x08\x12\x10\x13J\x04\x08\x15\x10\x16\x42\x63\n\x1ayandex.cloud.api.gitlab.v1B\x02GIZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlabb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.gitlab.v1.instance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.gitlab.v1B\002GIZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlab'
  _globals['_INSTANCE_LABELSENTRY']._loaded_options = None
  _globals['_INSTANCE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_INSTANCE'].fields_by_name['planned_operation']._loaded_options = None
  _globals['_INSTANCE'].fields_by_name['planned_operation']._serialized_options = b'\350\3071\000'
  _globals['_INSTANCE'].fields_by_name['approval_rules_id']._loaded_options = None
  _globals['_INSTANCE'].fields_by_name['approval_rules_id']._serialized_options = b'\350\3071\000\212\3101\004<=30'
  _globals['_INSTANCE']._serialized_start=172
  _globals['_INSTANCE']._serialized_end=1164
  _globals['_INSTANCE_LABELSENTRY']._serialized_start=834
  _globals['_INSTANCE_LABELSENTRY']._serialized_end=879
  _globals['_INSTANCE_STATUS']._serialized_start=882
  _globals['_INSTANCE_STATUS']._serialized_end=1146
# @@protoc_insertion_point(module_scope)
