# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/opensearch/v1/extension.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/opensearch/v1/extension.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.opensearch.v1.extension import extension_type_pb2 as yandex_dot_cloud_dot_mdb_dot_opensearch_dot_v1_dot_extension_dot_extension__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/mdb/opensearch/v1/extension.proto\x12\x1eyandex.cloud.mdb.opensearch.v1\x1a\x1dyandex/cloud/validation.proto\x1a=yandex/cloud/mdb/opensearch/v1/extension/extension_type.proto\"\xa1\x01\n\tExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\ncluster_id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x03\x12\x0e\n\x06\x61\x63tive\x18\x05 \x01(\x08\x12\x45\n\x04type\x18\x06 \x01(\x0e\x32\x37.yandex.cloud.mdb.opensearch.v1.extension.ExtensionType\"\xa5\x01\n\rExtensionSpec\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x03uri\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\x12K\n\x04type\x18\x04 \x01(\x0e\x32\x37.yandex.cloud.mdb.opensearch.v1.extension.ExtensionTypeB\x04\xe8\xc7\x31\x01\x42s\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.opensearch.v1.extension_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.opensearch.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/opensearch/v1;opensearch'
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_EXTENSIONSPEC'].fields_by_name['uri']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['uri']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_EXTENSIONSPEC'].fields_by_name['type']._loaded_options = None
  _globals['_EXTENSIONSPEC'].fields_by_name['type']._serialized_options = b'\350\3071\001'
  _globals['_EXTENSION']._serialized_start=177
  _globals['_EXTENSION']._serialized_end=338
  _globals['_EXTENSIONSPEC']._serialized_start=341
  _globals['_EXTENSIONSPEC']._serialized_end=506
# @@protoc_insertion_point(module_scope)
