# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/user_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/user_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.oauth import claims_pb2 as yandex_dot_cloud_dot_oauth_dot_claims__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/organizationmanager/v1/user_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1fyandex/cloud/oauth/claims.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"z\n\x12ListMembersRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\xd7\x01\n\x13ListMembersResponse\x12X\n\x05users\x18\x01 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.ListMembersResponse.OrganizationUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1aM\n\x10OrganizationUser\x12\x39\n\x0esubject_claims\x18\x01 \x01(\x0b\x32!.yandex.cloud.oauth.SubjectClaims\"^\n\x17\x44\x65leteMembershipRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nsubject_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"c\n\x18\x44\x65leteMembershipMetadata\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"c\n\x18\x44\x65leteMembershipResponse\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xdc\x03\n\x0bUserService\x12\xc8\x01\n\x0bListMembers\x12\x37.yandex.cloud.organizationmanager.v1.ListMembersRequest\x1a\x38.yandex.cloud.organizationmanager.v1.ListMembersResponse\"F\x82\xd3\xe4\x93\x02@\x12>/organization-manager/v1/organizations/{organization_id}/users\x12\x81\x02\n\x10\x44\x65leteMembership\x12<.yandex.cloud.organizationmanager.v1.DeleteMembershipRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*4\n\x18\x44\x65leteMembershipMetadata\x12\x18\x44\x65leteMembershipResponse\x82\xd3\xe4\x93\x02M*K/organization-manager/v1/organizations/{organization_id}/users/{subject_id}B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.user_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTMEMBERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['subject_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPREQUEST'].fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['subject_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPMETADATA'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['organization_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['subject_id']._loaded_options = None
  _globals['_DELETEMEMBERSHIPRESPONSE'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_USERSERVICE'].methods_by_name['ListMembers']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['ListMembers']._serialized_options = b'\202\323\344\223\002@\022>/organization-manager/v1/organizations/{organization_id}/users'
  _globals['_USERSERVICE'].methods_by_name['DeleteMembership']._loaded_options = None
  _globals['_USERSERVICE'].methods_by_name['DeleteMembership']._serialized_options = b'\262\322*4\n\030DeleteMembershipMetadata\022\030DeleteMembershipResponse\202\323\344\223\002M*K/organization-manager/v1/organizations/{organization_id}/users/{subject_id}'
  _globals['_LISTMEMBERSREQUEST']._serialized_start=263
  _globals['_LISTMEMBERSREQUEST']._serialized_end=385
  _globals['_LISTMEMBERSRESPONSE']._serialized_start=388
  _globals['_LISTMEMBERSRESPONSE']._serialized_end=603
  _globals['_LISTMEMBERSRESPONSE_ORGANIZATIONUSER']._serialized_start=526
  _globals['_LISTMEMBERSRESPONSE_ORGANIZATIONUSER']._serialized_end=603
  _globals['_DELETEMEMBERSHIPREQUEST']._serialized_start=605
  _globals['_DELETEMEMBERSHIPREQUEST']._serialized_end=699
  _globals['_DELETEMEMBERSHIPMETADATA']._serialized_start=701
  _globals['_DELETEMEMBERSHIPMETADATA']._serialized_end=800
  _globals['_DELETEMEMBERSHIPRESPONSE']._serialized_start=802
  _globals['_DELETEMEMBERSHIPRESPONSE']._serialized_end=901
  _globals['_USERSERVICE']._serialized_start=904
  _globals['_USERSERVICE']._serialized_end=1380
# @@protoc_insertion_point(module_scope)
