# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/dataset/v1/dataset_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/dataset/v1/dataset_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.ai.dataset.v1 import dataset_pb2 as yandex_dot_cloud_dot_ai_dot_dataset_dot_v1_dot_dataset__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/ai/dataset/v1/dataset_service.proto\x12\x1ayandex.cloud.ai.dataset.v1\x1a\x1dyandex/cloud/validation.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a(yandex/cloud/ai/dataset/v1/dataset.proto\x1a google/protobuf/field_mask.proto\"2\n\x16\x44\x65scribeDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"S\n\x17\x44\x65scribeDatasetResponse\x12\x38\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\"2\n\x16ValidateDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"m\n\x17ValidateDatasetMetadata\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nvalid_rows\x18\x02 \x01(\x03\x12\x16\n\x0eprocessed_rows\x18\x03 \x01(\x03\x12\x12\n\ntotal_rows\x18\x04 \x01(\x03\"|\n\x17ValidateDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x10\n\x08is_valid\x18\x02 \x01(\x08\x12;\n\x06\x65rrors\x18\x03 \x03(\x0b\x32+.yandex.cloud.ai.dataset.v1.ValidationError\"0\n\x14\x44\x65leteDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x17\n\x15\x44\x65leteDatasetResponse\"\xd5\x02\n\x14\x43reateDatasetRequest\x12\x1a\n\x04name\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=63\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\x1f\n\ttask_type\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.ai.dataset.v1.CreateDatasetRequest.LabelsEntry\x12#\n\rupload_format\x18\x07 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x16\n\x0e\x61llow_data_log\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"e\n\x15\x43reateDatasetResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x38\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\"\x81\x02\n\x14UpdateDatasetRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12L\n\x06labels\x18\x05 \x03(\x0b\x32<.yandex.cloud.ai.dataset.v1.UpdateDatasetRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x15UpdateDatasetResponse\x12\x38\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\"P\n\x18GetUploadDraftUrlRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nsize_bytes\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\"C\n\x19GetUploadDraftUrlResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x12\n\nupload_url\x18\x02 \x01(\t\"g\n StartMultipartUploadDraftRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\nsize_bytes\x18\x02 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\r\n\x05parts\x18\x03 \x01(\x03\"V\n!StartMultipartUploadDraftResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x1d\n\x15multipart_upload_urls\x18\x02 \x03(\t\"E\n\x10UploadedPartInfo\x12\x1d\n\x08part_num\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-10000\x12\x12\n\x04\x65tag\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"\x83\x01\n!FinishMultipartUploadDraftRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x44\n\x0euploaded_parts\x18\x02 \x03(\x0b\x32,.yandex.cloud.ai.dataset.v1.UploadedPartInfo\"8\n\"FinishMultipartUploadDraftResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\"\xe2\x01\n\x13ListDatasetsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12>\n\x06status\x18\x02 \x03(\x0e\x32..yandex.cloud.ai.dataset.v1.DatasetInfo.Status\x12\x1c\n\x14\x64\x61taset_name_pattern\x18\x03 \x01(\t\x12\x18\n\x10task_type_filter\x18\x04 \x03(\t\x12\x11\n\tpage_size\x18\x05 \x01(\x03\x12\x12\n\npage_token\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x61taset_ids\x18\x07 \x03(\t\"j\n\x14ListDatasetsResponse\x12\x39\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\'.yandex.cloud.ai.dataset.v1.DatasetInfo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x18ListUploadFormatsRequest\x12\x17\n\ttask_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\",\n\x19ListUploadFormatsResponse\x12\x0f\n\x07\x66ormats\x18\x01 \x03(\t\"F\n\x18ListUploadSchemasRequest\x12\x17\n\ttask_type\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tfolder_id\x18\x02 \x01(\t\"]\n\x19ListUploadSchemasResponse\x12@\n\x07schemas\x18\x01 \x03(\x0b\x32/.yandex.cloud.ai.dataset.v1.DatasetUploadSchema\"%\n\x10ListTypesRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"\"\n\x11ListTypesResponse\x12\r\n\x05types\x18\x01 \x03(\t\"4\n\x18GetDatasetPreviewRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"F\n\x19GetDatasetPreviewResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12\x15\n\rpreview_lines\x18\x02 \x03(\t\"2\n\x16GetDownloadUrlsRequest\x12\x18\n\ndataset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"x\n\x17GetDownloadUrlsResponse\x12\x12\n\ndataset_id\x18\x01 \x01(\t\x12I\n\rdownload_urls\x18\x02 \x03(\x0b\x32\x32.yandex.cloud.ai.dataset.v1.DatasetFileDownloadUrl\".\n\x18ListOperationsIdsRequest\x12\x12\n\ndataset_id\x18\x01 \x03(\t\"\xd1\x01\n\x19ListOperationsIdsResponse\x12u\n\x1a\x64\x61taset_id_to_operation_id\x18\x01 \x03(\x0b\x32Q.yandex.cloud.ai.dataset.v1.ListOperationsIdsResponse.DatasetIdToOperationIdEntry\x1a=\n\x1b\x44\x61tasetIdToOperationIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x84\x0f\n\x0e\x44\x61tasetService\x12s\n\x08\x44\x65scribe\x12\x32.yandex.cloud.ai.dataset.v1.DescribeDatasetRequest\x1a\x33.yandex.cloud.ai.dataset.v1.DescribeDatasetResponse\x12\x99\x01\n\x08Validate\x12\x32.yandex.cloud.ai.dataset.v1.ValidateDatasetRequest\x1a!.yandex.cloud.operation.Operation\"6\xb2\xd2*2\n\x17ValidateDatasetMetadata\x12\x17ValidateDatasetResponse\x12m\n\x06\x43reate\x12\x30.yandex.cloud.ai.dataset.v1.CreateDatasetRequest\x1a\x31.yandex.cloud.ai.dataset.v1.CreateDatasetResponse\x12m\n\x06Update\x12\x30.yandex.cloud.ai.dataset.v1.UpdateDatasetRequest\x1a\x31.yandex.cloud.ai.dataset.v1.UpdateDatasetResponse\x12m\n\x06\x44\x65lete\x12\x30.yandex.cloud.ai.dataset.v1.DeleteDatasetRequest\x1a\x31.yandex.cloud.ai.dataset.v1.DeleteDatasetResponse\x12i\n\x04List\x12/.yandex.cloud.ai.dataset.v1.ListDatasetsRequest\x1a\x30.yandex.cloud.ai.dataset.v1.ListDatasetsResponse\x12\x85\x01\n\x11ListUploadFormats\x12\x34.yandex.cloud.ai.dataset.v1.ListUploadFormatsRequest\x1a\x35.yandex.cloud.ai.dataset.v1.ListUploadFormatsResponse\"\x03\x88\x02\x01\x12\x80\x01\n\x11ListUploadSchemas\x12\x34.yandex.cloud.ai.dataset.v1.ListUploadSchemasRequest\x1a\x35.yandex.cloud.ai.dataset.v1.ListUploadSchemasResponse\x12\x80\x01\n\x11GetUploadDraftUrl\x12\x34.yandex.cloud.ai.dataset.v1.GetUploadDraftUrlRequest\x1a\x35.yandex.cloud.ai.dataset.v1.GetUploadDraftUrlResponse\x12z\n\x0fGetDownloadUrls\x12\x32.yandex.cloud.ai.dataset.v1.GetDownloadUrlsRequest\x1a\x33.yandex.cloud.ai.dataset.v1.GetDownloadUrlsResponse\x12\x98\x01\n\x19StartMultipartUploadDraft\x12<.yandex.cloud.ai.dataset.v1.StartMultipartUploadDraftRequest\x1a=.yandex.cloud.ai.dataset.v1.StartMultipartUploadDraftResponse\x12\x9b\x01\n\x1a\x46inishMultipartUploadDraft\x12=.yandex.cloud.ai.dataset.v1.FinishMultipartUploadDraftRequest\x1a>.yandex.cloud.ai.dataset.v1.FinishMultipartUploadDraftResponse\x12h\n\tListTypes\x12,.yandex.cloud.ai.dataset.v1.ListTypesRequest\x1a-.yandex.cloud.ai.dataset.v1.ListTypesResponse\x12y\n\nGetPreview\x12\x34.yandex.cloud.ai.dataset.v1.GetDatasetPreviewRequest\x1a\x35.yandex.cloud.ai.dataset.v1.GetDatasetPreviewResponse\x12\x80\x01\n\x11ListOperationsIds\x12\x34.yandex.cloud.ai.dataset.v1.ListOperationsIdsRequest\x1a\x35.yandex.cloud.ai.dataset.v1.ListOperationsIdsResponseBe\n\x1eyandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.dataset.v1.dataset_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.ai.dataset.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/dataset/v1;fomo'
  _globals['_DESCRIBEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_DESCRIBEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_VALIDATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_VALIDATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_DELETEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_DELETEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=63'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['task_type']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['task_type']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEDATASETREQUEST'].fields_by_name['upload_format']._loaded_options = None
  _globals['_CREATEDATASETREQUEST'].fields_by_name['upload_format']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_UPDATEDATASETREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['size_bytes']._loaded_options = None
  _globals['_GETUPLOADDRAFTURLREQUEST'].fields_by_name['size_bytes']._serialized_options = b'\372\3071\002>0'
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['size_bytes']._loaded_options = None
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['size_bytes']._serialized_options = b'\372\3071\002>0'
  _globals['_UPLOADEDPARTINFO'].fields_by_name['part_num']._loaded_options = None
  _globals['_UPLOADEDPARTINFO'].fields_by_name['part_num']._serialized_options = b'\372\3071\0071-10000'
  _globals['_UPLOADEDPARTINFO'].fields_by_name['etag']._loaded_options = None
  _globals['_UPLOADEDPARTINFO'].fields_by_name['etag']._serialized_options = b'\350\3071\001'
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTDATASETSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTDATASETSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTUPLOADFORMATSREQUEST'].fields_by_name['task_type']._loaded_options = None
  _globals['_LISTUPLOADFORMATSREQUEST'].fields_by_name['task_type']._serialized_options = b'\350\3071\001'
  _globals['_LISTUPLOADSCHEMASREQUEST'].fields_by_name['task_type']._loaded_options = None
  _globals['_LISTUPLOADSCHEMASREQUEST'].fields_by_name['task_type']._serialized_options = b'\350\3071\001'
  _globals['_GETDATASETPREVIEWREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_GETDATASETPREVIEWREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_GETDOWNLOADURLSREQUEST'].fields_by_name['dataset_id']._loaded_options = None
  _globals['_GETDOWNLOADURLSREQUEST'].fields_by_name['dataset_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._loaded_options = None
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._serialized_options = b'8\001'
  _globals['_DATASETSERVICE'].methods_by_name['Validate']._loaded_options = None
  _globals['_DATASETSERVICE'].methods_by_name['Validate']._serialized_options = b'\262\322*2\n\027ValidateDatasetMetadata\022\027ValidateDatasetResponse'
  _globals['_DATASETSERVICE'].methods_by_name['ListUploadFormats']._loaded_options = None
  _globals['_DATASETSERVICE'].methods_by_name['ListUploadFormats']._serialized_options = b'\210\002\001'
  _globals['_DESCRIBEDATASETREQUEST']._serialized_start=261
  _globals['_DESCRIBEDATASETREQUEST']._serialized_end=311
  _globals['_DESCRIBEDATASETRESPONSE']._serialized_start=313
  _globals['_DESCRIBEDATASETRESPONSE']._serialized_end=396
  _globals['_VALIDATEDATASETREQUEST']._serialized_start=398
  _globals['_VALIDATEDATASETREQUEST']._serialized_end=448
  _globals['_VALIDATEDATASETMETADATA']._serialized_start=450
  _globals['_VALIDATEDATASETMETADATA']._serialized_end=559
  _globals['_VALIDATEDATASETRESPONSE']._serialized_start=561
  _globals['_VALIDATEDATASETRESPONSE']._serialized_end=685
  _globals['_DELETEDATASETREQUEST']._serialized_start=687
  _globals['_DELETEDATASETREQUEST']._serialized_end=735
  _globals['_DELETEDATASETRESPONSE']._serialized_start=737
  _globals['_DELETEDATASETRESPONSE']._serialized_end=760
  _globals['_CREATEDATASETREQUEST']._serialized_start=763
  _globals['_CREATEDATASETREQUEST']._serialized_end=1104
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._serialized_start=1059
  _globals['_CREATEDATASETREQUEST_LABELSENTRY']._serialized_end=1104
  _globals['_CREATEDATASETRESPONSE']._serialized_start=1106
  _globals['_CREATEDATASETRESPONSE']._serialized_end=1207
  _globals['_UPDATEDATASETREQUEST']._serialized_start=1210
  _globals['_UPDATEDATASETREQUEST']._serialized_end=1467
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._serialized_start=1059
  _globals['_UPDATEDATASETREQUEST_LABELSENTRY']._serialized_end=1104
  _globals['_UPDATEDATASETRESPONSE']._serialized_start=1469
  _globals['_UPDATEDATASETRESPONSE']._serialized_end=1550
  _globals['_GETUPLOADDRAFTURLREQUEST']._serialized_start=1552
  _globals['_GETUPLOADDRAFTURLREQUEST']._serialized_end=1632
  _globals['_GETUPLOADDRAFTURLRESPONSE']._serialized_start=1634
  _globals['_GETUPLOADDRAFTURLRESPONSE']._serialized_end=1701
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST']._serialized_start=1703
  _globals['_STARTMULTIPARTUPLOADDRAFTREQUEST']._serialized_end=1806
  _globals['_STARTMULTIPARTUPLOADDRAFTRESPONSE']._serialized_start=1808
  _globals['_STARTMULTIPARTUPLOADDRAFTRESPONSE']._serialized_end=1894
  _globals['_UPLOADEDPARTINFO']._serialized_start=1896
  _globals['_UPLOADEDPARTINFO']._serialized_end=1965
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST']._serialized_start=1968
  _globals['_FINISHMULTIPARTUPLOADDRAFTREQUEST']._serialized_end=2099
  _globals['_FINISHMULTIPARTUPLOADDRAFTRESPONSE']._serialized_start=2101
  _globals['_FINISHMULTIPARTUPLOADDRAFTRESPONSE']._serialized_end=2157
  _globals['_LISTDATASETSREQUEST']._serialized_start=2160
  _globals['_LISTDATASETSREQUEST']._serialized_end=2386
  _globals['_LISTDATASETSRESPONSE']._serialized_start=2388
  _globals['_LISTDATASETSRESPONSE']._serialized_end=2494
  _globals['_LISTUPLOADFORMATSREQUEST']._serialized_start=2496
  _globals['_LISTUPLOADFORMATSREQUEST']._serialized_end=2547
  _globals['_LISTUPLOADFORMATSRESPONSE']._serialized_start=2549
  _globals['_LISTUPLOADFORMATSRESPONSE']._serialized_end=2593
  _globals['_LISTUPLOADSCHEMASREQUEST']._serialized_start=2595
  _globals['_LISTUPLOADSCHEMASREQUEST']._serialized_end=2665
  _globals['_LISTUPLOADSCHEMASRESPONSE']._serialized_start=2667
  _globals['_LISTUPLOADSCHEMASRESPONSE']._serialized_end=2760
  _globals['_LISTTYPESREQUEST']._serialized_start=2762
  _globals['_LISTTYPESREQUEST']._serialized_end=2799
  _globals['_LISTTYPESRESPONSE']._serialized_start=2801
  _globals['_LISTTYPESRESPONSE']._serialized_end=2835
  _globals['_GETDATASETPREVIEWREQUEST']._serialized_start=2837
  _globals['_GETDATASETPREVIEWREQUEST']._serialized_end=2889
  _globals['_GETDATASETPREVIEWRESPONSE']._serialized_start=2891
  _globals['_GETDATASETPREVIEWRESPONSE']._serialized_end=2961
  _globals['_GETDOWNLOADURLSREQUEST']._serialized_start=2963
  _globals['_GETDOWNLOADURLSREQUEST']._serialized_end=3013
  _globals['_GETDOWNLOADURLSRESPONSE']._serialized_start=3015
  _globals['_GETDOWNLOADURLSRESPONSE']._serialized_end=3135
  _globals['_LISTOPERATIONSIDSREQUEST']._serialized_start=3137
  _globals['_LISTOPERATIONSIDSREQUEST']._serialized_end=3183
  _globals['_LISTOPERATIONSIDSRESPONSE']._serialized_start=3186
  _globals['_LISTOPERATIONSIDSRESPONSE']._serialized_end=3395
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._serialized_start=3334
  _globals['_LISTOPERATIONSIDSRESPONSE_DATASETIDTOOPERATIONIDENTRY']._serialized_end=3395
  _globals['_DATASETSERVICE']._serialized_start=3398
  _globals['_DATASETSERVICE']._serialized_end=5322
# @@protoc_insertion_point(module_scope)
