# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/mdb/postgresql/v1/backup_retention_policy.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"]\n\x07\x43ronTab\x12\x14\n\x0c\x64\x61y_of_month\x18\x03 \x01(\t\x12\r\n\x05month\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x61y_of_week\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\x06minuteR\x04hour\"\x82\x02\n\x15\x42\x61\x63kupRetentionPolicy\x12\x17\n\tpolicy_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12 \n\ncluster_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x0bpolicy_name\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x04\x63ron\x18\x05 \x01(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.CronTab\x12\x17\n\x0fretain_for_days\x18\x06 \x01(\x03\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\tBs\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.backup_retention_policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_id']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_id']._serialized_options = b'\350\3071\001'
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_name']._loaded_options = None
  _globals['_BACKUPRETENTIONPOLICY'].fields_by_name['policy_name']._serialized_options = b'\350\3071\001'
  _globals['_CRONTAB']._serialized_start=160
  _globals['_CRONTAB']._serialized_end=253
  _globals['_BACKUPRETENTIONPOLICY']._serialized_start=256
  _globals['_BACKUPRETENTIONPOLICY']._serialized_end=514
# @@protoc_insertion_point(module_scope)
