# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/clouddesktop/v1/desktop.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/clouddesktop/v1/desktop.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/clouddesktop/v1/desktop.proto\x12 yandex.cloud.clouddesktop.v1.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xbd\x05\n\x07\x44\x65sktop\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x18\n\x10\x64\x65sktop_group_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x06status\x18\x05 \x01(\x0e\x32\x30.yandex.cloud.clouddesktop.v1.api.Desktop.Status\x12\x0c\n\x04name\x18\x0b \x01(\t\x12>\n\tresources\x18\x15 \x01(\x0b\x32+.yandex.cloud.clouddesktop.v1.api.Resources\x12N\n\x12network_interfaces\x18\x16 \x03(\x0b\x32\x32.yandex.cloud.clouddesktop.v1.api.NetworkInterface\x12\x35\n\x05users\x18\x17 \x03(\x0b\x32&.yandex.cloud.clouddesktop.v1.api.User\x12\x45\n\x06labels\x18\x18 \x03(\x0b\x32\x35.yandex.cloud.clouddesktop.v1.api.Desktop.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaf\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\x0e\n\nRESTARTING\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x12\x0c\n\x08STARTING\x10\x06\x12\x0c\n\x08STOPPING\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x12\t\n\x05\x45RROR\x10\t\x12\x13\n\x0f\x43REATION_FAILED\x10\nJ\x04\x08\x0c\x10\x15J\x04\x08\x06\x10\x0b\"^\n\tResources\x12\x17\n\x06memory\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03>=1\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"N\n\x04User\x12!\n\nsubject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12#\n\x0csubject_type\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\"U\n\x10NetworkInterface\x12 \n\nnetwork_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\tsubnet_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50Bq\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktopb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.clouddesktop.v1.desktop_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n yandex.cloud.api.clouddesktop.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/clouddesktop/v1;clouddesktop'
  _globals['_DESKTOP_LABELSENTRY']._loaded_options = None
  _globals['_DESKTOP_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCES'].fields_by_name['memory']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['memory']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCES'].fields_by_name['cores']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['cores']._serialized_options = b'\372\3071\003>=1'
  _globals['_RESOURCES'].fields_by_name['core_fraction']._loaded_options = None
  _globals['_RESOURCES'].fields_by_name['core_fraction']._serialized_options = b'\372\3071\0050-100'
  _globals['_USER'].fields_by_name['subject_id']._loaded_options = None
  _globals['_USER'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_USER'].fields_by_name['subject_type']._loaded_options = None
  _globals['_USER'].fields_by_name['subject_type']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_NETWORKINTERFACE'].fields_by_name['network_id']._loaded_options = None
  _globals['_NETWORKINTERFACE'].fields_by_name['network_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_NETWORKINTERFACE'].fields_by_name['subnet_id']._loaded_options = None
  _globals['_NETWORKINTERFACE'].fields_by_name['subnet_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DESKTOP']._serialized_start=145
  _globals['_DESKTOP']._serialized_end=846
  _globals['_DESKTOP_LABELSENTRY']._serialized_start=611
  _globals['_DESKTOP_LABELSENTRY']._serialized_end=656
  _globals['_DESKTOP_STATUS']._serialized_start=659
  _globals['_DESKTOP_STATUS']._serialized_end=834
  _globals['_RESOURCES']._serialized_start=848
  _globals['_RESOURCES']._serialized_end=942
  _globals['_USER']._serialized_start=944
  _globals['_USER']._serialized_end=1022
  _globals['_NETWORKINTERFACE']._serialized_start=1024
  _globals['_NETWORKINTERFACE']._serialized_end=1109
# @@protoc_insertion_point(module_scope)
