# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/role_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/role_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.iam.v1 import role_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_role__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/iam/v1/role_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1eyandex/cloud/iam/v1/role.proto\"/\n\x0eGetRoleRequest\x12\x1d\n\x07role_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"m\n\x10ListRolesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"V\n\x11ListRolesResponse\x12(\n\x05roles\x18\x01 \x03(\x0b\x32\x19.yandex.cloud.iam.v1.Role\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xe3\x01\n\x0bRoleService\x12\x66\n\x03Get\x12#.yandex.cloud.iam.v1.GetRoleRequest\x1a\x19.yandex.cloud.iam.v1.Role\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/iam/v1/roles/{role_id}\x12l\n\x04List\x12%.yandex.cloud.iam.v1.ListRolesRequest\x1a&.yandex.cloud.iam.v1.ListRolesResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/iam/v1/rolesBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.role_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETROLEREQUEST'].fields_by_name['role_id']._loaded_options = None
  _globals['_GETROLEREQUEST'].fields_by_name['role_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTROLESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTROLESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTROLESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTROLESREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTROLESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTROLESREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_ROLESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_ROLESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\031\022\027/iam/v1/roles/{role_id}'
  _globals['_ROLESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_ROLESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\017\022\r/iam/v1/roles'
  _globals['_GETROLEREQUEST']._serialized_start=156
  _globals['_GETROLEREQUEST']._serialized_end=203
  _globals['_LISTROLESREQUEST']._serialized_start=205
  _globals['_LISTROLESREQUEST']._serialized_end=314
  _globals['_LISTROLESRESPONSE']._serialized_start=316
  _globals['_LISTROLESRESPONSE']._serialized_end=402
  _globals['_ROLESERVICE']._serialized_start=405
  _globals['_ROLESERVICE']._serialized_end=632
# @@protoc_insertion_point(module_scope)
