# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/trunk_connection.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/trunk_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.cic.v1.common import transceiver_type_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_transceiver__type__pb2
from yandex.cloud.cic.v1.common import lag_allocation_settings_pb2 as yandex_dot_cloud_dot_cic_dot_v1_dot_common_dot_lag__allocation__settings__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cic/v1/trunk_connection.proto\x12\x13yandex.cloud.cic.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31yandex/cloud/cic/v1/common/transceiver_type.proto\x1a\x38yandex/cloud/cic/v1/common/lag_allocation_settings.proto\"\xf1\r\n\x0fTrunkConnection\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x11\n\tfolder_id\x18\x05 \x01(\t\x12\x11\n\tregion_id\x18\x06 \x01(\t\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12^\n\x18single_port_direct_joint\x18\t \x01(\x0b\x32:.yandex.cloud.cic.v1.TrunkConnection.SinglePortDirectJointH\x00\x12O\n\x10lag_direct_joint\x18\n \x01(\x0b\x32\x33.yandex.cloud.cic.v1.TrunkConnection.LagDirectJointH\x00\x12S\n\x12partner_joint_info\x18\x0b \x01(\x0b\x32\x35.yandex.cloud.cic.v1.TrunkConnection.PartnerJointInfoH\x00\x12:\n\x14point_of_presence_id\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12?\n\x08\x63\x61pacity\x18\x16 \x01(\x0e\x32-.yandex.cloud.cic.v1.TrunkConnection.Capacity\x12@\n\x06labels\x18\x17 \x03(\x0b\x32\x30.yandex.cloud.cic.v1.TrunkConnection.LabelsEntry\x12;\n\x06status\x18\x18 \x01(\x0e\x32+.yandex.cloud.cic.v1.TrunkConnection.Status\x12\x1b\n\x13\x64\x65letion_protection\x18\x19 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a_\n\x10PartnerJointInfo\x12\x13\n\x0bservice_key\x18\x03 \x01(\t\x12\x30\n\npartner_id\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueJ\x04\x08\x01\x10\x03\x1a\xb1\x01\n\x15SinglePortDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverType\x12/\n\tport_name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1a\n\x12\x61\x63\x63\x65ss_device_name\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\x1a\xcd\x01\n\x0eLagDirectJoint\x12\x45\n\x10transceiver_type\x18\x01 \x01(\x0e\x32+.yandex.cloud.cic.v1.common.TransceiverType\x12R\n\x17lag_allocation_settings\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.cic.v1.common.LagAllocationSettings\x12\x1a\n\x12\x61\x63\x63\x65ss_device_name\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"\xb2\x03\n\x08\x43\x61pacity\x12\x18\n\x14\x43\x41PACITY_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43\x41PACITY_50_MBPS\x10\x01\x12\x15\n\x11\x43\x41PACITY_100_MBPS\x10\x02\x12\x15\n\x11\x43\x41PACITY_200_MBPS\x10\x03\x12\x15\n\x11\x43\x41PACITY_300_MBPS\x10\x04\x12\x15\n\x11\x43\x41PACITY_400_MBPS\x10\x05\x12\x15\n\x11\x43\x41PACITY_500_MBPS\x10\x06\x12\x13\n\x0f\x43\x41PACITY_1_GBPS\x10\x07\x12\x13\n\x0f\x43\x41PACITY_2_GBPS\x10\x08\x12\x13\n\x0f\x43\x41PACITY_3_GBPS\x10\t\x12\x13\n\x0f\x43\x41PACITY_4_GBPS\x10\n\x12\x13\n\x0f\x43\x41PACITY_5_GBPS\x10\x0b\x12\x14\n\x10\x43\x41PACITY_10_GBPS\x10\x0c\x12\x14\n\x10\x43\x41PACITY_20_GBPS\x10\r\x12\x14\n\x10\x43\x41PACITY_30_GBPS\x10\x0e\x12\x14\n\x10\x43\x41PACITY_40_GBPS\x10\x0f\x12\x14\n\x10\x43\x41PACITY_50_GBPS\x10\x10\x12\x15\n\x11\x43\x41PACITY_100_GBPS\x10\x11\x12\x15\n\x11\x43\x41PACITY_200_GBPS\x10\x12\"V\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08UPDATING\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x41\x43TIVE\x10\x04\x42\x07\n\x05jointJ\x04\x08\x04\x10\x05J\x04\x08\x08\x10\tJ\x04\x08\r\x10\x16\x42V\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.trunk_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_TRUNKCONNECTION_LABELSENTRY']._loaded_options = None
  _globals['_TRUNKCONNECTION_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_TRUNKCONNECTION']._serialized_start=242
  _globals['_TRUNKCONNECTION']._serialized_end=2019
  _globals['_TRUNKCONNECTION_LABELSENTRY']._serialized_start=937
  _globals['_TRUNKCONNECTION_LABELSENTRY']._serialized_end=982
  _globals['_TRUNKCONNECTION_PARTNERJOINTINFO']._serialized_start=984
  _globals['_TRUNKCONNECTION_PARTNERJOINTINFO']._serialized_end=1079
  _globals['_TRUNKCONNECTION_SINGLEPORTDIRECTJOINT']._serialized_start=1082
  _globals['_TRUNKCONNECTION_SINGLEPORTDIRECTJOINT']._serialized_end=1259
  _globals['_TRUNKCONNECTION_LAGDIRECTJOINT']._serialized_start=1262
  _globals['_TRUNKCONNECTION_LAGDIRECTJOINT']._serialized_end=1467
  _globals['_TRUNKCONNECTION_CAPACITY']._serialized_start=1470
  _globals['_TRUNKCONNECTION_CAPACITY']._serialized_end=1904
  _globals['_TRUNKCONNECTION_STATUS']._serialized_start=1906
  _globals['_TRUNKCONNECTION_STATUS']._serialized_end=1992
# @@protoc_insertion_point(module_scope)
