# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/ocr/v1/ocr.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/ocr/v1/ocr.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n yandex/cloud/ai/ocr/v1/ocr.proto\x12\x16yandex.cloud.ai.ocr.v1\";\n\x07Polygon\x12\x30\n\x08vertices\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.ai.ocr.v1.Vertex\"\x1e\n\x06Vertex\x12\t\n\x01x\x18\x01 \x01(\x03\x12\t\n\x01y\x18\x02 \x01(\x03\"\xc6\x02\n\x0eTextAnnotation\x12\r\n\x05width\x18\x01 \x01(\x03\x12\x0e\n\x06height\x18\x02 \x01(\x03\x12-\n\x06\x62locks\x18\x03 \x03(\x0b\x32\x1d.yandex.cloud.ai.ocr.v1.Block\x12\x30\n\x08\x65ntities\x18\x04 \x03(\x0b\x32\x1e.yandex.cloud.ai.ocr.v1.Entity\x12-\n\x06tables\x18\x05 \x03(\x0b\x32\x1d.yandex.cloud.ai.ocr.v1.Table\x12\x11\n\tfull_text\x18\x06 \x01(\t\x12-\n\x06rotate\x18\x07 \x01(\x0e\x32\x1d.yandex.cloud.ai.ocr.v1.Angle\x12\x10\n\x08markdown\x18\x08 \x01(\t\x12\x31\n\x08pictures\x18\t \x03(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Picture\"$\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xcf\x02\n\x05\x42lock\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12+\n\x05lines\x18\x02 \x03(\x0b\x32\x1c.yandex.cloud.ai.ocr.v1.Line\x12\x41\n\tlanguages\x18\x03 \x03(\x0b\x32..yandex.cloud.ai.ocr.v1.Block.DetectedLanguage\x12;\n\rtext_segments\x18\x04 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\x12\x37\n\x0blayout_type\x18\x05 \x01(\x0e\x32\".yandex.cloud.ai.ocr.v1.LayoutType\x1a)\n\x10\x44\x65tectedLanguage\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\"\xe9\x01\n\x04Line\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x0c\n\x04text\x18\x02 \x01(\t\x12+\n\x05words\x18\x03 \x03(\x0b\x32\x1c.yandex.cloud.ai.ocr.v1.Word\x12;\n\rtext_segments\x18\x04 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\x12\x32\n\x0borientation\x18\x05 \x01(\x0e\x32\x1d.yandex.cloud.ai.ocr.v1.Angle\"\x9e\x01\n\x04Word\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x14\n\x0c\x65ntity_index\x18\x03 \x01(\x03\x12;\n\rtext_segments\x18\x04 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\"3\n\x0cTextSegments\x12\x13\n\x0bstart_index\x18\x01 \x01(\x03\x12\x0e\n\x06length\x18\x02 \x01(\x03\"\x99\x01\n\x05Table\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x11\n\trow_count\x18\x02 \x01(\x03\x12\x14\n\x0c\x63olumn_count\x18\x03 \x01(\x03\x12\x30\n\x05\x63\x65lls\x18\x04 \x03(\x0b\x32!.yandex.cloud.ai.ocr.v1.TableCell\"\xdd\x01\n\tTableCell\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\x11\n\trow_index\x18\x02 \x01(\x03\x12\x14\n\x0c\x63olumn_index\x18\x03 \x01(\x03\x12\x13\n\x0b\x63olumn_span\x18\x04 \x01(\x03\x12\x10\n\x08row_span\x18\x05 \x01(\x03\x12\x0c\n\x04text\x18\x06 \x01(\t\x12;\n\rtext_segments\x18\x07 \x03(\x0b\x32$.yandex.cloud.ai.ocr.v1.TextSegments\"O\n\x07Picture\x12\x35\n\x0c\x62ounding_box\x18\x01 \x01(\x0b\x32\x1f.yandex.cloud.ai.ocr.v1.Polygon\x12\r\n\x05score\x18\x02 \x01(\x01*W\n\x05\x41ngle\x12\x15\n\x11\x41NGLE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x41NGLE_0\x10\x01\x12\x0c\n\x08\x41NGLE_90\x10\x02\x12\r\n\tANGLE_180\x10\x03\x12\r\n\tANGLE_270\x10\x04*\xa1\x02\n\nLayoutType\x12\x1b\n\x17LAYOUT_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13LAYOUT_TYPE_UNKNOWN\x10\x01\x12\x14\n\x10LAYOUT_TYPE_TEXT\x10\x02\x12\x16\n\x12LAYOUT_TYPE_HEADER\x10\x03\x12\x1e\n\x1aLAYOUT_TYPE_SECTION_HEADER\x10\x04\x12\x16\n\x12LAYOUT_TYPE_FOOTER\x10\x05\x12\x18\n\x14LAYOUT_TYPE_FOOTNOTE\x10\x06\x12\x17\n\x13LAYOUT_TYPE_PICTURE\x10\x07\x12\x17\n\x13LAYOUT_TYPE_CAPTION\x10\x08\x12\x15\n\x11LAYOUT_TYPE_TITLE\x10\t\x12\x14\n\x10LAYOUT_TYPE_LIST\x10\nB\\\n\x1ayandex.cloud.api.ai.ocr.v1Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/ocr/v1;ocrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.ocr.v1.ocr_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.ai.ocr.v1Z>github.com/yandex-cloud/go-genproto/yandex/cloud/ai/ocr/v1;ocr'
  _globals['_ANGLE']._serialized_start=1769
  _globals['_ANGLE']._serialized_end=1856
  _globals['_LAYOUTTYPE']._serialized_start=1859
  _globals['_LAYOUTTYPE']._serialized_end=2148
  _globals['_POLYGON']._serialized_start=60
  _globals['_POLYGON']._serialized_end=119
  _globals['_VERTEX']._serialized_start=121
  _globals['_VERTEX']._serialized_end=151
  _globals['_TEXTANNOTATION']._serialized_start=154
  _globals['_TEXTANNOTATION']._serialized_end=480
  _globals['_ENTITY']._serialized_start=482
  _globals['_ENTITY']._serialized_end=518
  _globals['_BLOCK']._serialized_start=521
  _globals['_BLOCK']._serialized_end=856
  _globals['_BLOCK_DETECTEDLANGUAGE']._serialized_start=815
  _globals['_BLOCK_DETECTEDLANGUAGE']._serialized_end=856
  _globals['_LINE']._serialized_start=859
  _globals['_LINE']._serialized_end=1092
  _globals['_WORD']._serialized_start=1095
  _globals['_WORD']._serialized_end=1253
  _globals['_TEXTSEGMENTS']._serialized_start=1255
  _globals['_TEXTSEGMENTS']._serialized_end=1306
  _globals['_TABLE']._serialized_start=1309
  _globals['_TABLE']._serialized_end=1462
  _globals['_TABLECELL']._serialized_start=1465
  _globals['_TABLECELL']._serialized_end=1686
  _globals['_PICTURE']._serialized_start=1688
  _globals['_PICTURE']._serialized_end=1767
# @@protoc_insertion_point(module_scope)
