# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/greenplum/v1/resource_groups.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/greenplum/v1/resource_groups.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/mdb/greenplum/v1/resource_groups.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xb9\x03\n\rResourceGroup\x12\x31\n\x04name\x18\x01 \x01(\tB#\xe8\xc7\x31\x01\xf2\xc7\x31\x12^[^\\|/*?.,;\"\'<>]+$\x8a\xc8\x31\x05\x33-200\x12\x33\n\x0fis_user_defined\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x0b\x63oncurrency\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\x0e\x63pu_rate_limit\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-100\x12<\n\x0cmemory_limit\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x43\n\x13memory_shared_quota\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x42\n\x12memory_spill_ratio\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100Bp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.resource_groups_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _globals['_RESOURCEGROUP'].fields_by_name['name']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\022^[^\\|/*?.,;\"\'<>]+$\212\3101\0053-200'
  _globals['_RESOURCEGROUP'].fields_by_name['concurrency']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['concurrency']._serialized_options = b'\372\3071\003>=0'
  _globals['_RESOURCEGROUP'].fields_by_name['cpu_rate_limit']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['cpu_rate_limit']._serialized_options = b'\372\3071\0051-100'
  _globals['_RESOURCEGROUP'].fields_by_name['memory_limit']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['memory_limit']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCEGROUP'].fields_by_name['memory_shared_quota']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['memory_shared_quota']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCEGROUP'].fields_by_name['memory_spill_ratio']._loaded_options = None
  _globals['_RESOURCEGROUP'].fields_by_name['memory_spill_ratio']._serialized_options = b'\372\3071\0050-100'
  _globals['_RESOURCEGROUP']._serialized_start=150
  _globals['_RESOURCEGROUP']._serialized_end=591
# @@protoc_insertion_point(module_scope)
