# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/maintenance_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/maintenance_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.maintenance.v2 import common_pb2 as yandex_dot_cloud_dot_maintenance_dot_v2_dot_common__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/compute/v1/maintenance_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a(yandex/cloud/maintenance/v2/common.proto\x1a&yandex/cloud/operation/operation.proto2\xa0\x04\n\x12MaintenanceService\x12\x95\x01\n\x04List\x12\x34.yandex.cloud.maintenance.v2.ListMaintenancesRequest\x1a\x35.yandex.cloud.maintenance.v2.ListMaintenancesResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/compute/v1/maintenances\x12\x96\x01\n\x03Get\x12\x32.yandex.cloud.maintenance.v2.GetMaintenanceRequest\x1a(.yandex.cloud.maintenance.v2.Maintenance\"1\x82\xd3\xe4\x93\x02+\x12)/compute/v1/maintenances/{maintenance_id}\x12\xd8\x01\n\nReschedule\x12\x39.yandex.cloud.maintenance.v2.RescheduleMaintenanceRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*)\x12\'yandex.cloud.maintenance.v2.Maintenance\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/maintenances/{maintenance_id}:reschedule:\x01*B{\n\x1byandex.cloud.api.compute.v1B\x17MaintenanceServiceProtoZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.maintenance_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1B\027MaintenanceServiceProtoZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_MAINTENANCESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_MAINTENANCESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\032\022\030/compute/v1/maintenances'
  _globals['_MAINTENANCESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_MAINTENANCESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002+\022)/compute/v1/maintenances/{maintenance_id}'
  _globals['_MAINTENANCESERVICE'].methods_by_name['Reschedule']._loaded_options = None
  _globals['_MAINTENANCESERVICE'].methods_by_name['Reschedule']._serialized_options = b'\262\322*)\022\'yandex.cloud.maintenance.v2.Maintenance\202\323\344\223\0029\"4/compute/v1/maintenances/{maintenance_id}:reschedule:\001*'
  _globals['_MAINTENANCESERVICE']._serialized_start=225
  _globals['_MAINTENANCESERVICE']._serialized_end=769
# @@protoc_insertion_point(module_scope)
