# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/serverless/apigateway/v1/apigateway_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/serverless/apigateway/v1/apigateway_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.serverless.apigateway.v1 import apigateway_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_v1_dot_apigateway__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/serverless/apigateway/v1/apigateway_service.proto\x12%yandex.cloud.serverless.apigateway.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1egoogle/protobuf/duration.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x36yandex/cloud/serverless/apigateway/v1/apigateway.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x14GetApiGatewayRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"g\n\x15ListApiGatewayRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\"z\n\x16ListApiGatewayResponse\x12G\n\x0c\x61pi_gateways\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.serverless.apigateway.v1.ApiGateway\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdc\x06\n\x17\x43reateApiGatewayRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32J.yandex.cloud.serverless.apigateway.v1.CreateApiGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x16\n\x0copenapi_spec\x18\x05 \x01(\tH\x00\x12I\n\x0c\x63onnectivity\x18\x06 \x01(\x0b\x32\x33.yandex.cloud.serverless.apigateway.v1.Connectivity\x12\x46\n\x0blog_options\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.serverless.apigateway.v1.LogOptions\x12`\n\tvariables\x18\x08 \x03(\x0b\x32M.yandex.cloud.serverless.apigateway.v1.CreateApiGatewayRequest.VariablesEntry\x12=\n\x06\x63\x61nary\x18\t \x01(\x0b\x32-.yandex.cloud.serverless.apigateway.v1.Canary\x12\x41\n\x11\x65xecution_timeout\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x30s-600s\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x66\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.serverless.apigateway.v1.VariableInput:\x02\x38\x01\x42\x0c\n\x04spec\x12\x04\xc0\xc1\x31\x01\"\x92\x07\n\x17UpdateApiGatewayRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9f\x01\n\x06labels\x18\x05 \x03(\x0b\x32J.yandex.cloud.serverless.apigateway.v1.UpdateApiGatewayRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x16\n\x0copenapi_spec\x18\x06 \x01(\tH\x00\x12I\n\x0c\x63onnectivity\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.serverless.apigateway.v1.Connectivity\x12\x46\n\x0blog_options\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.serverless.apigateway.v1.LogOptions\x12`\n\tvariables\x18\t \x03(\x0b\x32M.yandex.cloud.serverless.apigateway.v1.UpdateApiGatewayRequest.VariablesEntry\x12=\n\x06\x63\x61nary\x18\n \x01(\x0b\x32-.yandex.cloud.serverless.apigateway.v1.Canary\x12\x41\n\x11\x65xecution_timeout\x18\x0b \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x30s-600s\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x66\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.serverless.apigateway.v1.VariableInput:\x02\x38\x01\x42\x0c\n\x04spec\x12\x04\xc0\xc1\x31\x01\"7\n\x17\x44\x65leteApiGatewayRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"c\n\x10\x41\x64\x64\x44omainRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x04 \x01(\tJ\x04\x08\x02\x10\x03\"L\n\x13RemoveDomainRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tdomain_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"2\n\x18\x43reateApiGatewayMetadata\x12\x16\n\x0e\x61pi_gateway_id\x18\x01 \x01(\t\"2\n\x18UpdateApiGatewayMetadata\x12\x16\n\x0e\x61pi_gateway_id\x18\x01 \x01(\t\"2\n\x18\x44\x65leteApiGatewayMetadata\x12\x16\n\x0e\x61pi_gateway_id\x18\x01 \x01(\t\"k\n\x11\x41\x64\x64\x44omainMetadata\x12\x16\n\x0e\x61pi_gateway_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x04 \x01(\t\"A\n\x14RemoveDomainMetadata\x12\x16\n\x0e\x61pi_gateway_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x8f\x01\n\x15ListOperationsRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"h\n\x16ListOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc0\x01\n\x15GetOpenapiSpecRequest\x12\x1c\n\x0e\x61pi_gateway_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12S\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x43.yandex.cloud.serverless.apigateway.v1.GetOpenapiSpecRequest.Format\"4\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x08\n\x04JSON\x10\x01\x12\x08\n\x04YAML\x10\x02\"F\n\x16GetOpenapiSpecResponse\x12\x16\n\x0e\x61pi_gateway_id\x18\x01 \x01(\t\x12\x14\n\x0copenapi_spec\x18\x02 \x01(\t2\xda\x13\n\x11\x41piGatewayService\x12\xab\x01\n\x03Get\x12;.yandex.cloud.serverless.apigateway.v1.GetApiGatewayRequest\x1a\x31.yandex.cloud.serverless.apigateway.v1.ApiGateway\"4\x82\xd3\xe4\x93\x02.\x12,/apigateways/v1/apigateways/{api_gateway_id}\x12\xa8\x01\n\x04List\x12<.yandex.cloud.serverless.apigateway.v1.ListApiGatewayRequest\x1a=.yandex.cloud.serverless.apigateway.v1.ListApiGatewayResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/apigateways/v1/apigateways\x12\xbd\x01\n\x06\x43reate\x12>.yandex.cloud.serverless.apigateway.v1.CreateApiGatewayRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*&\n\x18\x43reateApiGatewayMetadata\x12\nApiGateway\x82\xd3\xe4\x93\x02 \"\x1b/apigateways/v1/apigateways:\x01*\x12\xce\x01\n\x06Update\x12>.yandex.cloud.serverless.apigateway.v1.UpdateApiGatewayRequest\x1a!.yandex.cloud.operation.Operation\"a\xb2\xd2*&\n\x18UpdateApiGatewayMetadata\x12\nApiGateway\x82\xd3\xe4\x93\x02\x31\x32,/apigateways/v1/apigateways/{api_gateway_id}:\x01*\x12\xd6\x01\n\x06\x44\x65lete\x12>.yandex.cloud.serverless.apigateway.v1.DeleteApiGatewayRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*1\n\x18\x44\x65leteApiGatewayMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.*,/apigateways/v1/apigateways/{api_gateway_id}\x12\xd8\x01\n\tAddDomain\x12\x37.yandex.cloud.serverless.apigateway.v1.AddDomainRequest\x1a!.yandex.cloud.operation.Operation\"o\xb2\xd2**\n\x11\x41\x64\x64\x44omainMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;\"6/apigateways/v1/apigateways/{api_gateway_id}:addDomain:\x01*\x12\xe4\x01\n\x0cRemoveDomain\x12:.yandex.cloud.serverless.apigateway.v1.RemoveDomainRequest\x1a!.yandex.cloud.operation.Operation\"u\xb2\xd2*-\n\x14RemoveDomainMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02>\"9/apigateways/v1/apigateways/{api_gateway_id}:removeDomain:\x01*\x12\xc8\x01\n\x0eGetOpenapiSpec\x12<.yandex.cloud.serverless.apigateway.v1.GetOpenapiSpecRequest\x1a=.yandex.cloud.serverless.apigateway.v1.GetOpenapiSpecResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/apigateways/v1/apigateways/{api_gateway_id}:spec\x12\xce\x01\n\x0eListOperations\x12<.yandex.cloud.serverless.apigateway.v1.ListOperationsRequest\x1a=.yandex.cloud.serverless.apigateway.v1.ListOperationsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/apigateways/v1/apigateways/{api_gateway_id}/operations\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</apigateways/v1/apigateways/{resource_id}:listAccessBindings\x12\xeb\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x83\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02@\";/apigateways/v1/apigateways/{resource_id}:setAccessBindings:\x01*\x12\xf7\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x43\x32>/apigateways/v1/apigateways/{resource_id}:updateAccessBindings:\x01*B\x81\x01\n)yandex.cloud.api.serverless.apigateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/v1;apigatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.apigateway.v1.apigateway_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.serverless.apigateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/v1;apigateway'
  _globals['_GETAPIGATEWAYREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_GETAPIGATEWAYREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTAPIGATEWAYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTAPIGATEWAYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEAPIGATEWAYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEAPIGATEWAYREQUEST_VARIABLESENTRY']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_CREATEAPIGATEWAYREQUEST'].oneofs_by_name['spec']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST'].oneofs_by_name['spec']._serialized_options = b'\300\3011\001'
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['execution_timeout']._loaded_options = None
  _globals['_CREATEAPIGATEWAYREQUEST'].fields_by_name['execution_timeout']._serialized_options = b'\372\3071\0070s-600s'
  _globals['_UPDATEAPIGATEWAYREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEAPIGATEWAYREQUEST_VARIABLESENTRY']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST_VARIABLESENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEAPIGATEWAYREQUEST'].oneofs_by_name['spec']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST'].oneofs_by_name['spec']._serialized_options = b'\300\3011\001'
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['execution_timeout']._loaded_options = None
  _globals['_UPDATEAPIGATEWAYREQUEST'].fields_by_name['execution_timeout']._serialized_options = b'\372\3071\0070s-600s'
  _globals['_DELETEAPIGATEWAYREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_DELETEAPIGATEWAYREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_ADDDOMAINREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_ADDDOMAINREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVEDOMAINREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_REMOVEDOMAINREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_REMOVEDOMAINREQUEST'].fields_by_name['domain_id']._loaded_options = None
  _globals['_REMOVEDOMAINREQUEST'].fields_by_name['domain_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTOPERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_GETOPENAPISPECREQUEST'].fields_by_name['api_gateway_id']._loaded_options = None
  _globals['_GETOPENAPISPECREQUEST'].fields_by_name['api_gateway_id']._serialized_options = b'\350\3071\001'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002.\022,/apigateways/v1/apigateways/{api_gateway_id}'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\035\022\033/apigateways/v1/apigateways'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateApiGatewayMetadata\022\nApiGateway\202\323\344\223\002 \"\033/apigateways/v1/apigateways:\001*'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateApiGatewayMetadata\022\nApiGateway\202\323\344\223\00212,/apigateways/v1/apigateways/{api_gateway_id}:\001*'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteApiGatewayMetadata\022\025google.protobuf.Empty\202\323\344\223\002.*,/apigateways/v1/apigateways/{api_gateway_id}'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['AddDomain']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['AddDomain']._serialized_options = b'\262\322**\n\021AddDomainMetadata\022\025google.protobuf.Empty\202\323\344\223\002;\"6/apigateways/v1/apigateways/{api_gateway_id}:addDomain:\001*'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['RemoveDomain']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['RemoveDomain']._serialized_options = b'\262\322*-\n\024RemoveDomainMetadata\022\025google.protobuf.Empty\202\323\344\223\002>\"9/apigateways/v1/apigateways/{api_gateway_id}:removeDomain:\001*'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['GetOpenapiSpec']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['GetOpenapiSpec']._serialized_options = b'\202\323\344\223\0023\0221/apigateways/v1/apigateways/{api_gateway_id}:spec'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0029\0227/apigateways/v1/apigateways/{api_gateway_id}/operations'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002>\022</apigateways/v1/apigateways/{resource_id}:listAccessBindings'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002@\";/apigateways/v1/apigateways/{resource_id}:setAccessBindings:\001*'
  _globals['_APIGATEWAYSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_APIGATEWAYSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002C2>/apigateways/v1/apigateways/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETAPIGATEWAYREQUEST']._serialized_start=396
  _globals['_GETAPIGATEWAYREQUEST']._serialized_end=448
  _globals['_LISTAPIGATEWAYREQUEST']._serialized_start=450
  _globals['_LISTAPIGATEWAYREQUEST']._serialized_end=553
  _globals['_LISTAPIGATEWAYRESPONSE']._serialized_start=555
  _globals['_LISTAPIGATEWAYRESPONSE']._serialized_end=677
  _globals['_CREATEAPIGATEWAYREQUEST']._serialized_start=680
  _globals['_CREATEAPIGATEWAYREQUEST']._serialized_end=1540
  _globals['_CREATEAPIGATEWAYREQUEST_LABELSENTRY']._serialized_start=1377
  _globals['_CREATEAPIGATEWAYREQUEST_LABELSENTRY']._serialized_end=1422
  _globals['_CREATEAPIGATEWAYREQUEST_VARIABLESENTRY']._serialized_start=1424
  _globals['_CREATEAPIGATEWAYREQUEST_VARIABLESENTRY']._serialized_end=1526
  _globals['_UPDATEAPIGATEWAYREQUEST']._serialized_start=1543
  _globals['_UPDATEAPIGATEWAYREQUEST']._serialized_end=2457
  _globals['_UPDATEAPIGATEWAYREQUEST_LABELSENTRY']._serialized_start=1377
  _globals['_UPDATEAPIGATEWAYREQUEST_LABELSENTRY']._serialized_end=1422
  _globals['_UPDATEAPIGATEWAYREQUEST_VARIABLESENTRY']._serialized_start=1424
  _globals['_UPDATEAPIGATEWAYREQUEST_VARIABLESENTRY']._serialized_end=1526
  _globals['_DELETEAPIGATEWAYREQUEST']._serialized_start=2459
  _globals['_DELETEAPIGATEWAYREQUEST']._serialized_end=2514
  _globals['_ADDDOMAINREQUEST']._serialized_start=2516
  _globals['_ADDDOMAINREQUEST']._serialized_end=2615
  _globals['_REMOVEDOMAINREQUEST']._serialized_start=2617
  _globals['_REMOVEDOMAINREQUEST']._serialized_end=2693
  _globals['_CREATEAPIGATEWAYMETADATA']._serialized_start=2695
  _globals['_CREATEAPIGATEWAYMETADATA']._serialized_end=2745
  _globals['_UPDATEAPIGATEWAYMETADATA']._serialized_start=2747
  _globals['_UPDATEAPIGATEWAYMETADATA']._serialized_end=2797
  _globals['_DELETEAPIGATEWAYMETADATA']._serialized_start=2799
  _globals['_DELETEAPIGATEWAYMETADATA']._serialized_end=2849
  _globals['_ADDDOMAINMETADATA']._serialized_start=2851
  _globals['_ADDDOMAINMETADATA']._serialized_end=2958
  _globals['_REMOVEDOMAINMETADATA']._serialized_start=2960
  _globals['_REMOVEDOMAINMETADATA']._serialized_end=3025
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=3028
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=3171
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=3173
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=3277
  _globals['_GETOPENAPISPECREQUEST']._serialized_start=3280
  _globals['_GETOPENAPISPECREQUEST']._serialized_end=3472
  _globals['_GETOPENAPISPECREQUEST_FORMAT']._serialized_start=3420
  _globals['_GETOPENAPISPECREQUEST_FORMAT']._serialized_end=3472
  _globals['_GETOPENAPISPECRESPONSE']._serialized_start=3474
  _globals['_GETOPENAPISPECRESPONSE']._serialized_end=3544
  _globals['_APIGATEWAYSERVICE']._serialized_start=3547
  _globals['_APIGATEWAYSERVICE']._serialized_end=6069
# @@protoc_insertion_point(module_scope)
