# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/gitlab/v1/maintenance.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/gitlab/v1/maintenance.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/gitlab/v1/maintenance.proto\x12\x16yandex.cloud.gitlab.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xe1\x01\n\x14MaintenanceOperation\x12\x17\n\x04info\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x31\n\rdelayed_until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17latest_maintenance_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x1cnext_maintenance_window_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampBc\n\x1ayandex.cloud.api.gitlab.v1B\x02GMZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlabb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.gitlab.v1.maintenance_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.gitlab.v1B\002GMZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/gitlab/v1;gitlab'
  _globals['_MAINTENANCEOPERATION'].fields_by_name['info']._loaded_options = None
  _globals['_MAINTENANCEOPERATION'].fields_by_name['info']._serialized_options = b'\212\3101\005<=256'
  _globals['_MAINTENANCEOPERATION']._serialized_start=133
  _globals['_MAINTENANCEOPERATION']._serialized_end=358
# @@protoc_insertion_point(module_scope)
