# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/raw_logs_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/raw_logs_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.cdn.v1 import raw_logs_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_raw__logs__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/cdn/v1/raw_logs_service.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/cdn/v1/raw_logs.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"s\n\x16\x41\x63tivateRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\".\n\x17\x41\x63tivateRawLogsMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"\x85\x01\n\x17\x41\x63tivateRawLogsResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".yandex.cloud.cdn.v1.RawLogsStatus\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\"=\n\x18\x44\x65\x61\x63tivateRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"0\n\x19\x44\x65\x61\x63tivateRawLogsMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"6\n\x11GetRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x80\x01\n\x12GetRawLogsResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".yandex.cloud.cdn.v1.RawLogsStatus\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\"q\n\x14UpdateRawLogsRequest\x12!\n\x0bresource_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\"\x83\x01\n\x15UpdateRawLogsResponse\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".yandex.cloud.cdn.v1.RawLogsStatus\x12\x36\n\x08settings\x18\x02 \x01(\x0b\x32$.yandex.cloud.cdn.v1.RawLogsSettings\",\n\x15UpdateRawLogsMetadata\x12\x13\n\x0bresource_id\x18\x01 \x01(\t2\xba\x05\n\x0eRawLogsService\x12\xb5\x01\n\x08\x41\x63tivate\x12+.yandex.cloud.cdn.v1.ActivateRawLogsRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*2\n\x17\x41\x63tivateRawLogsMetadata\x12\x17\x41\x63tivateRawLogsResponse\x82\xd3\xe4\x93\x02\x1d\"\x18/cdn/v1/rawLogs:activate:\x01*\x12\xbb\x01\n\nDeactivate\x12-.yandex.cloud.cdn.v1.DeactivateRawLogsRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*2\n\x19\x44\x65\x61\x63tivateRawLogsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1f\"\x1d/cdn/v1/rawLogs/{resource_id}\x12}\n\x03Get\x12&.yandex.cloud.cdn.v1.GetRawLogsRequest\x1a\'.yandex.cloud.cdn.v1.GetRawLogsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/cdn/v1/rawLogs/{resource_id}\x12\xb2\x01\n\x06Update\x12).yandex.cloud.cdn.v1.UpdateRawLogsRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*.\n\x15UpdateRawLogsMetadata\x12\x15UpdateRawLogsResponse\x82\xd3\xe4\x93\x02\"2\x1d/cdn/v1/rawLogs/{resource_id}:\x01*BV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.raw_logs_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_ACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_ACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DEACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_DEACTIVATERAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETRAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_GETRAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERAWLOGSREQUEST'].fields_by_name['resource_id']._loaded_options = None
  _globals['_UPDATERAWLOGSREQUEST'].fields_by_name['resource_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Activate']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Activate']._serialized_options = b'\262\322*2\n\027ActivateRawLogsMetadata\022\027ActivateRawLogsResponse\202\323\344\223\002\035\"\030/cdn/v1/rawLogs:activate:\001*'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Deactivate']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Deactivate']._serialized_options = b'\262\322*2\n\031DeactivateRawLogsMetadata\022\025google.protobuf.Empty\202\323\344\223\002\037\"\035/cdn/v1/rawLogs/{resource_id}'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\037\022\035/cdn/v1/rawLogs/{resource_id}'
  _globals['_RAWLOGSSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RAWLOGSSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*.\n\025UpdateRawLogsMetadata\022\025UpdateRawLogsResponse\202\323\344\223\002\"2\035/cdn/v1/rawLogs/{resource_id}:\001*'
  _globals['_ACTIVATERAWLOGSREQUEST']._serialized_start=238
  _globals['_ACTIVATERAWLOGSREQUEST']._serialized_end=353
  _globals['_ACTIVATERAWLOGSMETADATA']._serialized_start=355
  _globals['_ACTIVATERAWLOGSMETADATA']._serialized_end=401
  _globals['_ACTIVATERAWLOGSRESPONSE']._serialized_start=404
  _globals['_ACTIVATERAWLOGSRESPONSE']._serialized_end=537
  _globals['_DEACTIVATERAWLOGSREQUEST']._serialized_start=539
  _globals['_DEACTIVATERAWLOGSREQUEST']._serialized_end=600
  _globals['_DEACTIVATERAWLOGSMETADATA']._serialized_start=602
  _globals['_DEACTIVATERAWLOGSMETADATA']._serialized_end=650
  _globals['_GETRAWLOGSREQUEST']._serialized_start=652
  _globals['_GETRAWLOGSREQUEST']._serialized_end=706
  _globals['_GETRAWLOGSRESPONSE']._serialized_start=709
  _globals['_GETRAWLOGSRESPONSE']._serialized_end=837
  _globals['_UPDATERAWLOGSREQUEST']._serialized_start=839
  _globals['_UPDATERAWLOGSREQUEST']._serialized_end=952
  _globals['_UPDATERAWLOGSRESPONSE']._serialized_start=955
  _globals['_UPDATERAWLOGSRESPONSE']._serialized_end=1086
  _globals['_UPDATERAWLOGSMETADATA']._serialized_start=1088
  _globals['_UPDATERAWLOGSMETADATA']._serialized_end=1132
  _globals['_RAWLOGSSERVICE']._serialized_start=1135
  _globals['_RAWLOGSSERVICE']._serialized_end=1833
# @@protoc_insertion_point(module_scope)
