"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class User(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    RESOURCE_GROUP_FIELD_NUMBER: builtins.int
    name: builtins.str
    """User name"""
    password: builtins.str
    """User password. Used only in create and update requests"""
    resource_group: builtins.str
    """Resource group for user's queries"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        password: builtins.str = ...,
        resource_group: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "password", b"password", "resource_group", b"resource_group"]) -> None: ...

global___User = User
