"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.baremetal.v1alpha.storage_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class StorageServiceStub:
    """A set of methods to retrieve information about default storages."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetDefault: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.GetDefaultStorageRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage,
    ]
    """Returns the default storage for the specified configuration."""

    BatchGetDefault: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse,
    ]
    """Returns the default storages for the specified configurations."""

class StorageServiceAsyncStub:
    """A set of methods to retrieve information about default storages."""

    GetDefault: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.GetDefaultStorageRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage,
    ]
    """Returns the default storage for the specified configuration."""

    BatchGetDefault: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesRequest,
        yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse,
    ]
    """Returns the default storages for the specified configurations."""

class StorageServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods to retrieve information about default storages."""

    @abc.abstractmethod
    def GetDefault(
        self,
        request: yandex.cloud.baremetal.v1alpha.storage_service_pb2.GetDefaultStorageRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.storage_service_pb2.DefaultStorage]]:
        """Returns the default storage for the specified configuration."""

    @abc.abstractmethod
    def BatchGetDefault(
        self,
        request: yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse, collections.abc.Awaitable[yandex.cloud.baremetal.v1alpha.storage_service_pb2.BatchGetDefaultStoragesResponse]]:
        """Returns the default storages for the specified configurations."""

def add_StorageServiceServicer_to_server(servicer: StorageServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
