# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/trino.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/trino.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/connectionmanager/v1/trino.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"e\n\tTrinoAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xcd\x01\n\x0cTrinoCluster\x12P\n\x0b\x63oordinator\x18\x01 \x01(\x0b\x32;.yandex.cloud.connectionmanager.v1.TrinoCluster.Coordinator\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a)\n\x0b\x43oordinator\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\"\x8f\x01\n\x0fTrinoConnection\x12@\n\x07\x63luster\x18\x01 \x01(\x0b\x32/.yandex.cloud.connectionmanager.v1.TrinoCluster\x12:\n\x04\x61uth\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TrinoAuthB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.trino_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_TRINOAUTH']._serialized_start=132
  _globals['_TRINOAUTH']._serialized_end=233
  _globals['_TRINOCLUSTER']._serialized_start=236
  _globals['_TRINOCLUSTER']._serialized_end=441
  _globals['_TRINOCLUSTER_COORDINATOR']._serialized_start=400
  _globals['_TRINOCLUSTER_COORDINATOR']._serialized_end=441
  _globals['_TRINOCONNECTION']._serialized_start=444
  _globals['_TRINOCONNECTION']._serialized_end=587
# @@protoc_insertion_point(module_scope)
