"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.classifier_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListClassifiersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """Project id"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___ListClassifiersRequest = ListClassifiersRequest

@typing.final
class ListClassifiersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLASSIFIERS_FIELD_NUMBER: builtins.int
    @property
    def classifiers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.classifier_pb2.Classifier]:
        """Classifiers belonging to the given project"""

    def __init__(
        self,
        *,
        classifiers: collections.abc.Iterable[yandex.cloud.speechsense.v1.classifier_pb2.Classifier] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classifiers", b"classifiers"]) -> None: ...

global___ListClassifiersResponse = ListClassifiersResponse
