# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/connectionmanager/v1/mongodb.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/connectionmanager/v1/mongodb.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.connectionmanager.v1 import common_pb2 as yandex_dot_cloud_dot_connectionmanager_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/connectionmanager/v1/mongodb.proto\x12!yandex.cloud.connectionmanager.v1\x1a.yandex/cloud/connectionmanager/v1/common.proto\"g\n\x0bMongoDBAuth\x12L\n\ruser_password\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.connectionmanager.v1.UserPasswordAuthH\x00\x42\n\n\x08security\"\xe8\x04\n\x0eMongoDBCluster\x12\x45\n\x05hosts\x18\x01 \x03(\x0b\x32\x36.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host\x12@\n\ntls_params\x18\x02 \x01(\x0b\x32,.yandex.cloud.connectionmanager.v1.TLSParams\x1a\xcc\x03\n\x04Host\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x03\x12I\n\x04role\x18\x03 \x01(\x0e\x32;.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host.Role\x12M\n\x06health\x18\x04 \x01(\x0e\x32=.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host.Health\x12I\n\x04type\x18\x05 \x01(\x0e\x32;.yandex.cloud.connectionmanager.v1.MongoDBCluster.Host.Type\"D\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0e\n\nMONGOINFRA\x10\x03\"8\n\x04Role\x12\x14\n\x10ROLE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\r\n\tSECONDARY\x10\x02\"C\n\x06Health\x12\x16\n\x12HEALTH_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xc4\x01\n\x11MongoDBConnection\x12\x42\n\x07\x63luster\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.connectionmanager.v1.MongoDBCluster\x12\x1a\n\x12managed_cluster_id\x18\x02 \x01(\t\x12<\n\x04\x61uth\x18\x03 \x01(\x0b\x32..yandex.cloud.connectionmanager.v1.MongoDBAuth\x12\x11\n\tdatabases\x18\x04 \x03(\tB\x80\x01\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.connectionmanager.v1.mongodb_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.connectionmanager.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/connectionmanager/v1;connectionmanager'
  _globals['_MONGODBAUTH']._serialized_start=134
  _globals['_MONGODBAUTH']._serialized_end=237
  _globals['_MONGODBCLUSTER']._serialized_start=240
  _globals['_MONGODBCLUSTER']._serialized_end=856
  _globals['_MONGODBCLUSTER_HOST']._serialized_start=396
  _globals['_MONGODBCLUSTER_HOST']._serialized_end=856
  _globals['_MONGODBCLUSTER_HOST_TYPE']._serialized_start=661
  _globals['_MONGODBCLUSTER_HOST_TYPE']._serialized_end=729
  _globals['_MONGODBCLUSTER_HOST_ROLE']._serialized_start=731
  _globals['_MONGODBCLUSTER_HOST_ROLE']._serialized_end=787
  _globals['_MONGODBCLUSTER_HOST_HEALTH']._serialized_start=789
  _globals['_MONGODBCLUSTER_HOST_HEALTH']._serialized_end=856
  _globals['_MONGODBCONNECTION']._serialized_start=859
  _globals['_MONGODBCONNECTION']._serialized_end=1055
# @@protoc_insertion_point(module_scope)
