"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RoutingInstance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RoutingInstance._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: RoutingInstance._Status.ValueType  # 0
        CREATING: RoutingInstance._Status.ValueType  # 1
        UPDATING: RoutingInstance._Status.ValueType  # 2
        DELETING: RoutingInstance._Status.ValueType  # 3
        ACTIVE: RoutingInstance._Status.ValueType  # 4

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: RoutingInstance.Status.ValueType  # 0
    CREATING: RoutingInstance.Status.ValueType  # 1
    UPDATING: RoutingInstance.Status.ValueType  # 2
    DELETING: RoutingInstance.Status.ValueType  # 3
    ACTIVE: RoutingInstance.Status.ValueType  # 4

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class CicPrivateConnectionInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CIC_PRIVATE_CONNECTION_ID_FIELD_NUMBER: builtins.int
        cic_private_connection_id: builtins.str
        """ID of the cicPrivateConnection that is attached to the routingInstance."""
        def __init__(
            self,
            *,
            cic_private_connection_id: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["cic_private_connection_id", b"cic_private_connection_id"]) -> None: ...

    @typing.final
    class VpcInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        VPC_NETWORK_ID_FIELD_NUMBER: builtins.int
        AZ_INFOS_FIELD_NUMBER: builtins.int
        vpc_network_id: builtins.str
        """ID of the vpcNetwork that is attached to the routingInstance."""
        @property
        def az_infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingInstance.VpcAzInfo]:
            """List of the az-related info about vpcNetworks which are attached to routingInstance"""

        def __init__(
            self,
            *,
            vpc_network_id: builtins.str = ...,
            az_infos: collections.abc.Iterable[global___RoutingInstance.VpcAzInfo] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["az_infos", b"az_infos", "vpc_network_id", b"vpc_network_id"]) -> None: ...

    @typing.final
    class VpcAzInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        MANUAL_INFO_FIELD_NUMBER: builtins.int
        @property
        def manual_info(self) -> global___RoutingInstance.VpcManualInfo:
            """VpcInfo which is set by user"""

        def __init__(
            self,
            *,
            manual_info: global___RoutingInstance.VpcManualInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["manual_info", b"manual_info"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["manual_info", b"manual_info"]) -> None: ...

    @typing.final
    class VpcManualInfo(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AZ_ID_FIELD_NUMBER: builtins.int
        PREFIXES_FIELD_NUMBER: builtins.int
        az_id: builtins.str
        """ID of the AZ"""
        @property
        def prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """List of prefixes to announce"""

        def __init__(
            self,
            *,
            az_id: builtins.str = ...,
            prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["az_id", b"az_id", "prefixes", b"prefixes"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    VPC_INFO_FIELD_NUMBER: builtins.int
    CIC_PRIVATE_CONNECTION_INFO_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the routingInstance."""
    name: builtins.str
    """Name of the routingInstance.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the routingInstance. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the routingInstance belongs to."""
    region_id: builtins.str
    """ID of the region that the routingInstance belongs to."""
    status: global___RoutingInstance.Status.ValueType
    """Status of the routingInstance."""
    @property
    def vpc_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingInstance.VpcInfo]:
        """List of the info about vpcNetworks which are attached to routingInstance."""

    @property
    def cic_private_connection_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoutingInstance.CicPrivateConnectionInfo]:
        """List of the info about privateConnections which are attached to routingInstance."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        vpc_info: collections.abc.Iterable[global___RoutingInstance.VpcInfo] | None = ...,
        cic_private_connection_info: collections.abc.Iterable[global___RoutingInstance.CicPrivateConnectionInfo] | None = ...,
        status: global___RoutingInstance.Status.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cic_private_connection_info", b"cic_private_connection_info", "created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "region_id", b"region_id", "status", b"status", "vpc_info", b"vpc_info"]) -> None: ...

global___RoutingInstance = RoutingInstance
