# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/iam/v1/oauth_client_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/iam/v1/oauth_client_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.iam.v1 import oauth_client_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_oauth__client__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/iam/v1/oauth_client_service.proto\x12\x13yandex.cloud.iam.v1\x1a&yandex/cloud/iam/v1/oauth_client.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\">\n\x15GetOAuthClientRequest\x12%\n\x0foauth_client_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"y\n\x17ListOAuthClientsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1f\n\tfolder_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"t\n\x18ListOAuthClientsResponse\x12?\n\roauth_clients\x18\x01 \x03(\x0b\x32(.yandex.cloud.iam.v1.OAuthClientListView\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\x13OAuthClientListView\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"4\n\x19UpdateOAuthClientMetadata\x12\x17\n\x0foauth_client_id\x18\x01 \x01(\t\"4\n\x19\x44\x65leteOAuthClientMetadata\x12\x17\n\x0foauth_client_id\x18\x01 \x01(\t\"\xc5\x01\n\x18\x43reateOAuthClientRequest\x12\x35\n\x04name\x18\x01 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12+\n\rredirect_uris\x18\x02 \x03(\tB\x14\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x06<=1000\x12#\n\x06scopes\x18\x03 \x03(\tB\x13\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x05<=255\x12 \n\tfolder_id\x18\x04 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=255\"4\n\x19\x43reateOAuthClientMetadata\x12\x17\n\x0foauth_client_id\x18\x01 \x01(\t\"\xf3\x01\n\x18UpdateOAuthClientRequest\x12\x1d\n\x0foauth_client_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x35\n\x04name\x18\x03 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12+\n\rredirect_uris\x18\x04 \x03(\tB\x14\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x06<=1000\x12#\n\x06scopes\x18\x05 \x03(\tB\x13\x82\xc8\x31\x06<=1000\x8a\xc8\x31\x05<=255\"A\n\x18\x44\x65leteOAuthClientRequest\x12%\n\x0foauth_client_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xc7\x06\n\x12OAuthClientService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.iam.v1.GetOAuthClientRequest\x1a .yandex.cloud.iam.v1.OAuthClient\".\x82\xd3\xe4\x93\x02(\x12&/iam/v1/oauthClients/{oauth_client_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.iam.v1.ListOAuthClientsRequest\x1a-.yandex.cloud.iam.v1.ListOAuthClientsResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/iam/v1/oauthClients\x12\xa7\x01\n\x06\x43reate\x12-.yandex.cloud.iam.v1.CreateOAuthClientRequest\x1a!.yandex.cloud.operation.Operation\"K\xb2\xd2*(\n\x19\x43reateOAuthClientMetadata\x12\x0bOAuthClient\x82\xd3\xe4\x93\x02\x19\"\x14/iam/v1/oauthClients:\x01*\x12\xb9\x01\n\x06Update\x12-.yandex.cloud.iam.v1.UpdateOAuthClientRequest\x1a!.yandex.cloud.operation.Operation\"]\xb2\xd2*(\n\x19UpdateOAuthClientMetadata\x12\x0bOAuthClient\x82\xd3\xe4\x93\x02+2&/iam/v1/oauthClients/{oauth_client_id}:\x01*\x12\xc0\x01\n\x06\x44\x65lete\x12-.yandex.cloud.iam.v1.DeleteOAuthClientRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*2\n\x19\x44\x65leteOAuthClientMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/iam/v1/oauthClients/{oauth_client_id}BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.oauth_client_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_GETOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTOAUTHCLIENTSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._serialized_options = b'\202\3101\006<=1000\212\3101\006<=1000'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._serialized_options = b'\202\3101\006<=1000\212\3101\005<=255'
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEOAUTHCLIENTREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\005<=255'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['redirect_uris']._serialized_options = b'\202\3101\006<=1000\212\3101\006<=1000'
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._loaded_options = None
  _globals['_UPDATEOAUTHCLIENTREQUEST'].fields_by_name['scopes']._serialized_options = b'\202\3101\006<=1000\212\3101\005<=255'
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._loaded_options = None
  _globals['_DELETEOAUTHCLIENTREQUEST'].fields_by_name['oauth_client_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/iam/v1/oauthClients/{oauth_client_id}'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/iam/v1/oauthClients'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateOAuthClientMetadata\022\013OAuthClient\202\323\344\223\002\031\"\024/iam/v1/oauthClients:\001*'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateOAuthClientMetadata\022\013OAuthClient\202\323\344\223\002+2&/iam/v1/oauthClients/{oauth_client_id}:\001*'
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_OAUTHCLIENTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteOAuthClientMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/iam/v1/oauthClients/{oauth_client_id}'
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_start=280
  _globals['_GETOAUTHCLIENTREQUEST']._serialized_end=342
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_start=344
  _globals['_LISTOAUTHCLIENTSREQUEST']._serialized_end=465
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_start=467
  _globals['_LISTOAUTHCLIENTSRESPONSE']._serialized_end=583
  _globals['_OAUTHCLIENTLISTVIEW']._serialized_start=585
  _globals['_OAUTHCLIENTLISTVIEW']._serialized_end=632
  _globals['_UPDATEOAUTHCLIENTMETADATA']._serialized_start=634
  _globals['_UPDATEOAUTHCLIENTMETADATA']._serialized_end=686
  _globals['_DELETEOAUTHCLIENTMETADATA']._serialized_start=688
  _globals['_DELETEOAUTHCLIENTMETADATA']._serialized_end=740
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_start=743
  _globals['_CREATEOAUTHCLIENTREQUEST']._serialized_end=940
  _globals['_CREATEOAUTHCLIENTMETADATA']._serialized_start=942
  _globals['_CREATEOAUTHCLIENTMETADATA']._serialized_end=994
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_start=997
  _globals['_UPDATEOAUTHCLIENTREQUEST']._serialized_end=1240
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_start=1242
  _globals['_DELETEOAUTHCLIENTREQUEST']._serialized_end=1307
  _globals['_OAUTHCLIENTSERVICE']._serialized_start=1310
  _globals['_OAUTHCLIENTSERVICE']._serialized_end=2149
# @@protoc_insertion_point(module_scope)
