"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Thresholds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ShowMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ShowModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Thresholds._ShowMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHOW_MODE_UNSPECIFIED: Thresholds._ShowMode.ValueType  # 0
        SHOW_MODE_CONSTANT_LINE: Thresholds._ShowMode.ValueType  # 1

    class ShowMode(_ShowMode, metaclass=_ShowModeEnumTypeWrapper): ...
    SHOW_MODE_UNSPECIFIED: Thresholds.ShowMode.ValueType  # 0
    SHOW_MODE_CONSTANT_LINE: Thresholds.ShowMode.ValueType  # 1

    @typing.final
    class Item(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COLOR_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        color: builtins.str
        """Color in hexadecimal format"""
        value: builtins.float
        """Threshold value"""
        def __init__(
            self,
            *,
            color: builtins.str = ...,
            value: builtins.float | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["_value", b"_value", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["_value", b"_value", "color", b"color", "value", b"value"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["_value", b"_value"]) -> typing.Literal["value"] | None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    SHOW_MODE_FIELD_NUMBER: builtins.int
    show_mode: global___Thresholds.ShowMode.ValueType
    """Thresholds visualisation mode"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Thresholds.Item]:
        """Thresholds"""

    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___Thresholds.Item] | None = ...,
        show_mode: global___Thresholds.ShowMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["items", b"items", "show_mode", b"show_mode"]) -> None: ...

global___Thresholds = Thresholds
