# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/kafka/v1/connector_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/kafka/v1/connector_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.kafka.v1 import connector_pb2 as yandex_dot_cloud_dot_mdb_dot_kafka_dot_v1_dot_connector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/mdb/kafka/v1/connector_service.proto\x12\x19yandex.cloud.mdb.kafka.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a)yandex/cloud/mdb/kafka/v1/connector.proto\"q\n\x13GetConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"w\n\x15ListConnectorsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"k\n\x16ListConnectorsResponse\x12\x38\n\nconnectors\x18\x01 \x03(\x0b\x32$.yandex.cloud.mdb.kafka.v1.Connector\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x82\x01\n\x16\x43reateConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x46\n\x0e\x63onnector_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.kafka.v1.ConnectorSpecB\x04\xe8\xc7\x31\x01\"g\n\x17\x43reateConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"\xf3\x01\n\x16UpdateConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12L\n\x0e\x63onnector_spec\x18\x04 \x01(\x0b\x32..yandex.cloud.mdb.kafka.v1.UpdateConnectorSpecB\x04\xe8\xc7\x31\x01\"u\n\x17UpdateConnectorMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"t\n\x16\x44\x65leteConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"E\n\x17\x44\x65leteConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnector_name\x18\x02 \x01(\t\"t\n\x16ResumeConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"g\n\x17ResumeConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"s\n\x15PauseConnectorRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=256\"f\n\x16PauseConnectorMetadata\x12\x12\n\ncluster_id\x18\x01 \x01(\t\x12\x38\n\x0e\x63onnector_name\x18\x02 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_.a-zA-Z0-9]*\x8a\xc8\x31\x05<=2562\xa6\x0b\n\x10\x43onnectorService\x12\xa8\x01\n\x03Get\x12..yandex.cloud.mdb.kafka.v1.GetConnectorRequest\x1a$.yandex.cloud.mdb.kafka.v1.Connector\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}\x12\xa7\x01\n\x04List\x12\x30.yandex.cloud.mdb.kafka.v1.ListConnectorsRequest\x1a\x31.yandex.cloud.mdb.kafka.v1.ListConnectorsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/managed-kafka/v1/clusters/{cluster_id}/connectors\x12\xc5\x01\n\x06\x43reate\x12\x31.yandex.cloud.mdb.kafka.v1.CreateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"e\xb2\xd2*$\n\x17\x43reateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02\x37\"2/managed-kafka/v1/clusters/{cluster_id}/connectors:\x01*\x12\xd6\x01\n\x06Update\x12\x31.yandex.cloud.mdb.kafka.v1.UpdateConnectorRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*$\n\x17UpdateConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02H2C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}:\x01*\x12\xdf\x01\n\x06\x44\x65lete\x12\x31.yandex.cloud.mdb.kafka.v1.DeleteConnectorRequest\x1a!.yandex.cloud.operation.Operation\"\x7f\xb2\xd2*0\n\x17\x44\x65leteConnectorMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x45*C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}\x12\xdd\x01\n\x06Resume\x12\x31.yandex.cloud.mdb.kafka.v1.ResumeConnectorRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*$\n\x17ResumeConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02O\"J/managed-kafka/v1/clusters/{cluster_id}/connectors/resume/{connector_name}:\x01*\x12\xd9\x01\n\x05Pause\x12\x30.yandex.cloud.mdb.kafka.v1.PauseConnectorRequest\x1a!.yandex.cloud.operation.Operation\"{\xb2\xd2*#\n\x16PauseConnectorMetadata\x12\tConnector\x82\xd3\xe4\x93\x02N\"I/managed-kafka/v1/clusters/{cluster_id}/connectors/pause/{connector_name}:\x01*Bd\n\x1dyandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.kafka.v1.connector_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.kafka.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/kafka/v1;kafka'
  _globals['_GETCONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_GETCONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_GETCONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_GETCONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTCONNECTORSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['connector_spec']._loaded_options = None
  _globals['_CREATECONNECTORREQUEST'].fields_by_name['connector_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_CREATECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_spec']._loaded_options = None
  _globals['_UPDATECONNECTORREQUEST'].fields_by_name['connector_spec']._serialized_options = b'\350\3071\001'
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_UPDATECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_DELETECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_RESUMECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_RESUMECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_RESUMECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['cluster_id']._loaded_options = None
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['connector_name']._loaded_options = None
  _globals['_PAUSECONNECTORREQUEST'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_PAUSECONNECTORMETADATA'].fields_by_name['connector_name']._loaded_options = None
  _globals['_PAUSECONNECTORMETADATA'].fields_by_name['connector_name']._serialized_options = b'\350\3071\001\362\3071\017[-_.a-zA-Z0-9]*\212\3101\005<=256'
  _globals['_CONNECTORSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002E\022C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}'
  _globals['_CONNECTORSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\0024\0222/managed-kafka/v1/clusters/{cluster_id}/connectors'
  _globals['_CONNECTORSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateConnectorMetadata\022\tConnector\202\323\344\223\0027\"2/managed-kafka/v1/clusters/{cluster_id}/connectors:\001*'
  _globals['_CONNECTORSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateConnectorMetadata\022\tConnector\202\323\344\223\002H2C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}:\001*'
  _globals['_CONNECTORSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteConnectorMetadata\022\025google.protobuf.Empty\202\323\344\223\002E*C/managed-kafka/v1/clusters/{cluster_id}/connectors/{connector_name}'
  _globals['_CONNECTORSERVICE'].methods_by_name['Resume']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Resume']._serialized_options = b'\262\322*$\n\027ResumeConnectorMetadata\022\tConnector\202\323\344\223\002O\"J/managed-kafka/v1/clusters/{cluster_id}/connectors/resume/{connector_name}:\001*'
  _globals['_CONNECTORSERVICE'].methods_by_name['Pause']._loaded_options = None
  _globals['_CONNECTORSERVICE'].methods_by_name['Pause']._serialized_options = b'\262\322*#\n\026PauseConnectorMetadata\022\tConnector\202\323\344\223\002N\"I/managed-kafka/v1/clusters/{cluster_id}/connectors/pause/{connector_name}:\001*'
  _globals['_GETCONNECTORREQUEST']._serialized_start=292
  _globals['_GETCONNECTORREQUEST']._serialized_end=405
  _globals['_LISTCONNECTORSREQUEST']._serialized_start=407
  _globals['_LISTCONNECTORSREQUEST']._serialized_end=526
  _globals['_LISTCONNECTORSRESPONSE']._serialized_start=528
  _globals['_LISTCONNECTORSRESPONSE']._serialized_end=635
  _globals['_CREATECONNECTORREQUEST']._serialized_start=638
  _globals['_CREATECONNECTORREQUEST']._serialized_end=768
  _globals['_CREATECONNECTORMETADATA']._serialized_start=770
  _globals['_CREATECONNECTORMETADATA']._serialized_end=873
  _globals['_UPDATECONNECTORREQUEST']._serialized_start=876
  _globals['_UPDATECONNECTORREQUEST']._serialized_end=1119
  _globals['_UPDATECONNECTORMETADATA']._serialized_start=1121
  _globals['_UPDATECONNECTORMETADATA']._serialized_end=1238
  _globals['_DELETECONNECTORREQUEST']._serialized_start=1240
  _globals['_DELETECONNECTORREQUEST']._serialized_end=1356
  _globals['_DELETECONNECTORMETADATA']._serialized_start=1358
  _globals['_DELETECONNECTORMETADATA']._serialized_end=1427
  _globals['_RESUMECONNECTORREQUEST']._serialized_start=1429
  _globals['_RESUMECONNECTORREQUEST']._serialized_end=1545
  _globals['_RESUMECONNECTORMETADATA']._serialized_start=1547
  _globals['_RESUMECONNECTORMETADATA']._serialized_end=1650
  _globals['_PAUSECONNECTORREQUEST']._serialized_start=1652
  _globals['_PAUSECONNECTORREQUEST']._serialized_end=1767
  _globals['_PAUSECONNECTORMETADATA']._serialized_start=1769
  _globals['_PAUSECONNECTORMETADATA']._serialized_end=1871
  _globals['_CONNECTORSERVICE']._serialized_start=1874
  _globals['_CONNECTORSERVICE']._serialized_end=3320
# @@protoc_insertion_point(module_scope)
