# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/storage.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/storage.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.baremetal.v1alpha import disk_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/baremetal/v1alpha/storage.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a)yandex/cloud/baremetal/v1alpha/disk.proto\"}\n\x10StoragePartition\x12\x42\n\x04type\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.baremetal.v1alpha.StoragePartitionType\x12\x10\n\x08size_gib\x18\x02 \x01(\x03\x12\x13\n\x0bmount_point\x18\x03 \x01(\t\"\xd7\x01\n\x07Storage\x12\x44\n\npartitions\x18\x03 \x03(\x0b\x32\x30.yandex.cloud.baremetal.v1alpha.StoragePartition\x12\x34\n\x04\x64isk\x18\x04 \x01(\x0b\x32$.yandex.cloud.baremetal.v1alpha.DiskH\x00\x12\x34\n\x04raid\x18\x05 \x01(\x0b\x32$.yandex.cloud.baremetal.v1alpha.RaidH\x00\x42\x0e\n\x0cstorage_typeJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"s\n\x04Raid\x12\x36\n\x04type\x18\x01 \x01(\x0e\x32(.yandex.cloud.baremetal.v1alpha.RaidType\x12\x33\n\x05\x64isks\x18\x02 \x03(\x0b\x32$.yandex.cloud.baremetal.v1alpha.Disk*e\n\x14StoragePartitionType\x12&\n\"STORAGE_PARTITION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04\x45XT4\x10\x01\x12\x08\n\x04SWAP\x10\x02\x12\x08\n\x04\x45XT3\x10\x03\x12\x07\n\x03XFS\x10\x04*G\n\x08RaidType\x12\x19\n\x15RAID_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05RAID0\x10\x01\x12\t\n\x05RAID1\x10\x02\x12\n\n\x06RAID10\x10\x03\x42r\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_STORAGEPARTITIONTYPE']._serialized_start=585
  _globals['_STORAGEPARTITIONTYPE']._serialized_end=686
  _globals['_RAIDTYPE']._serialized_start=688
  _globals['_RAIDTYPE']._serialized_end=759
  _globals['_STORAGEPARTITION']._serialized_start=123
  _globals['_STORAGEPARTITION']._serialized_end=248
  _globals['_STORAGE']._serialized_start=251
  _globals['_STORAGE']._serialized_end=466
  _globals['_RAID']._serialized_start=468
  _globals['_RAID']._serialized_end=583
# @@protoc_insertion_point(module_scope)
