"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ResourcePreset(google.protobuf.message.Message):
    """A ResourcePreset resource for describing hardware configuration presets."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    CORES_FIELD_NUMBER: builtins.int
    CORE_FRACTION_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Human-readable ID of the preset."""
    cores: builtins.int
    """Number of CPU cores for an instance created with the preset."""
    core_fraction: builtins.int
    """Baseline level of CPU performance with the possibility to burst performance above that baseline level.
    This field sets baseline performance for each core.
    """
    memory: builtins.int
    """RAM volume for an instance created with the preset, in bytes."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cores: builtins.int = ...,
        core_fraction: builtins.int = ...,
        memory: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["core_fraction", b"core_fraction", "cores", b"cores", "id", b"id", "memory", b"memory"]) -> None: ...

global___ResourcePreset = ResourcePreset
